@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -104,7 +104,7 @@ QMMPStarter::QMMPStarter() : QObject()
         qApp->installTranslator(translator);
 
     QTranslator *qt_translator = new QTranslator(qApp);
-    if(qt_translator->load(QLibraryInfo::location(QLibraryInfo::TranslationsPath) + u"/qtbase_"_s + locale))
+    if(qt_translator->load(QLibraryInfo::path(QLibraryInfo::TranslationsPath) + u"/qtbase_"_s + locale))
         qApp->installTranslator(qt_translator);
 
     m_option_manager = new BuiltinCommandLineOption(this);
@@ -143,8 +143,8 @@ QMMPStarter::QMMPStarter() : QObject()
     for(auto it = commands.cbegin(); it != commands.cend(); ++it)
     {
         CommandLineHandler::OptionFlags flags;
-        if(m_option_manager->identify(it.key()) < 0 && !CommandLineManager::hasOption(it.key(), &flags) &&
-                it.key() != u"--no-start"_s && it.key() != u"--ui"_s && it.key() != u"--debug"_s)
+        if(!m_option_manager->identify(it.key()) && !CommandLineManager::hasOption(it.key(), &flags) &&
+                it.key() != u"--no-start"_s && it.key() != u"--ui"_s)
         {
             cout << qPrintable(tr("Unknown command")) << endl;
             m_exit_code = EXIT_FAILURE;
@@ -298,6 +298,35 @@ void QMMPStarter::startPlayer()
     theme_paths << share_path + u"/icons"_s;
     theme_paths.removeDuplicates();
     QIcon::setThemeSearchPaths(theme_paths);
+
+    //copy config from previous version
+    QString configFile = Qmmp::configDir() + u"/qmmp.conf"_s;
+    if(!QFile::exists(configFile))
+    {
+        QString oldConfigFile = QDir::homePath() + u"/.qmmp/qmmp2rc"_s;
+        if(!QFile::exists(oldConfigFile))
+            oldConfigFile = QDir::homePath() + u"/.qmmp/qmmprc"_s;
+
+        if(QFile::exists(oldConfigFile))
+        {
+            QFile::copy(oldConfigFile, configFile);
+            static const QStringList filesToCopy = {
+                u"converterrc"_s,  u"eq.auto_preset"_s, u"history.sqlite"_s, u"library.sqlite"_s,
+                u"playlist.txt"_s, u"Songlengths.txt"_s, u"winamp_presets"_s
+            };
+
+            for(const QString &name : std::as_const(filesToCopy))
+                QFile::copy(QDir::homePath() + u"/.qmmp/"_s + name, Qmmp::configDir() + QLatin1Char('/') + name);
+
+            QProcess::execute(QStringLiteral("cp"), { u"-r"_s, QDir::homePath() + u"/.qmmp/skins"_s, Qmmp::configDir() });
+            if(qApp->platformName() == QLatin1String("wayland"))
+            {
+                //force qsui by default for wayland
+                QSettings settings(QStringLiteral("qmmp"), QStringLiteral("qmmp"));
+                settings.remove("Ui/current_plugin"_L1);
+            }
+        }
+    }
 #endif
 
     //prepare libqmmp and libqmmpui libraries for usage
@@ -335,7 +364,7 @@ void QMMPStarter::startPlayer()
     processCommandArgs(args, QDir::currentPath());
     if(args.isEmpty())
     {
-        QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+        QSettings settings;
         settings.beginGroup(u"General"_s);
         if(settings.value(u"resume_playback"_s, false).toBool())
         {
@@ -353,7 +382,7 @@ void QMMPStarter::createPaths()
 
 void QMMPStarter::savePosition()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(u"General"_s);
     settings.setValue(u"resume_playback"_s, m_core->state() == Qmmp::Playing &&
                       QmmpUiSettings::instance()->resumeOnStartup());
@@ -398,7 +427,7 @@ void QMMPStarter::writeCommand()
     m_socket->flush();
     //reading answer
     while(m_socket->waitForReadyRead(1500))
-        cout << qPrintable(QString::fromUtf8(m_socket->readAll()).trimmed()) << endl;
+        cout << m_socket->readAll().constData();
 
 #ifndef Q_OS_WIN
     if (argString.isEmpty())
@@ -424,7 +453,7 @@ void QMMPStarter::readCommand()
     if(!out.isEmpty())
     {
         //writing answer
-        socket->write(out.toUtf8());
+        socket->write(out.toLocal8Bit());
         while(socket->waitForBytesWritten())
             socket->flush();
     }
