@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -26,23 +26,24 @@
 
 void IncDecVolumeCommandLineOption::registerOprions()
 {
-    registerOption(VOLUME_UP, "--volume-inc", tr("Increase volume by 5 steps"));
-    registerOption(VOLUME_DOWN, "--volume-dec", tr("Decrease volume by 5 steps"));
+    registerOption(VOLUME_UP, u"--volume-inc"_s, tr("Increase volume by 5 steps"));
+    registerOption(VOLUME_DOWN, u"--volume-dec"_s, tr("Decrease volume by 5 steps"));
 }
 
 QString IncDecVolumeCommandLineOption::shortName() const
 {
-    return "IncDecVolumeCommandLineOption";
+    return "IncDecVolumeCommandLineOption"_L1;
 }
 
 QString IncDecVolumeCommandLineOption::translation() const
 {
-    return QLatin1String(":/incdecvolume_plugin_");
+    return ":/incdecvolume_plugin_"_L1;
 }
 
-QString IncDecVolumeCommandLineOption::executeCommand(int id, const QStringList &args)
+QString IncDecVolumeCommandLineOption::executeCommand(int id, const QStringList &args, const QString &cwd)
 {
     Q_UNUSED(args);
+    Q_UNUSED(cwd);
 
     switch (id)
     {
