@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -37,7 +37,7 @@ public:
     void registerOprions() override;
     QString shortName() const override;
     QString translation() const override;
-    QString executeCommand(int id, const QStringList &args) override;
+    QString executeCommand(int id, const QStringList &args, const QString &cwd) override;
 
 private:
     enum Command
