@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2025 by Ilya Kotov <forkotov02@ya.ru>              *
+ *   Copyright (C) 2009-2024 by Ilya Kotov <forkotov02@ya.ru>              *
  *   Copyright (C) 2009 by Sebastian Pipping <sebastian@pipping.org>       *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -30,7 +30,7 @@ Bs2bPlugin::Bs2bPlugin() : Effect(),
     m_bs2b_handler(bs2b_open())
 {
     m_instance = this;
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     bs2b_set_level(m_bs2b_handler, settings.value(u"bs2b/level"_s, BS2B_DEFAULT_CLEVEL).toUInt());
 }
 
