@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2025 by Ilya Kotov <forkotov02@ya.ru>              *
+ *   Copyright (C) 2009-2024 by Ilya Kotov <forkotov02@ya.ru>              *
  *   Copyright (C) 2009 by Sebastian Pipping <sebastian@pipping.org>       *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -28,7 +28,7 @@ CrossfadePlugin::CrossfadePlugin() : Effect()
 {
     m_core = SoundCore::instance() ;
     m_handler = StateHandler::instance();
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     m_overlap = settings.value(u"Crossfade/overlap"_s, 6000).toLongLong();
 }
 
