@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2010-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2010-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -27,7 +27,7 @@ CrossfadeSettingsDialog::CrossfadeSettingsDialog(QWidget *parent)
  : QDialog(parent), m_ui(new Ui::CrossfadeSettingsDialog)
 {
     m_ui->setupUi(this);
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     m_ui->overlapSpinBox->setValue(settings.value(u"Crossfade/overlap"_s, 6000).toInt());
 }
 
@@ -39,7 +39,7 @@ CrossfadeSettingsDialog::~CrossfadeSettingsDialog()
 
 void CrossfadeSettingsDialog::accept()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.setValue(u"Crossfade/overlap"_s, m_ui->overlapSpinBox->value());
     QDialog::accept();
 }
