@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2002-2003 Nick Lamb <njl195@zepler.org.uk>              *
  *   Copyright (C) 2005 Giacomo Lozito <city_hunter@users.sf.net>          *
- *   Copyright (C) 2009-2025 by Ilya Kotov <forkotov02@ya.ru>              *
+ *   Copyright (C) 2009-2024 by Ilya Kotov <forkotov02@ya.ru>              *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -44,7 +44,7 @@ LADSPAHost::LADSPAHost(QObject *parent) : QObject(parent)
     m_instance = this;
     loadModules();
 
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     int pluginNumber = settings.value(u"LADSPA/plugin_number"_s, 0).toInt();
     for(int i = 0; i < pluginNumber; ++i)
     {
@@ -69,12 +69,12 @@ LADSPAHost::LADSPAHost(QObject *parent) : QObject(parent)
 LADSPAHost::~LADSPAHost()
 {
     m_instance = nullptr;
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     for(int i = 0; i < settings.value(u"LADSPA/plugin_number"_s, 0).toInt(); ++i)
     {
         settings.remove(QStringLiteral("LADSPA_%1/").arg(i));
     }
-    settings.setValue("LADSPA/plugin_number"_L1, m_effects.count());
+    settings.setValue("LADSPA/plugin_number", m_effects.count());
     for(int i = 0; i < m_effects.count(); ++i)
     {
         QString section = QStringLiteral("LADSPA_%1/").arg(i);
