@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2018-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2018-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -23,11 +23,11 @@
 #include "effectmonotostereofactory.h"
 #include "monotostereoplugin.h"
 
-const EffectProperties EffectMonoToStereoFactory::properties() const
+EffectProperties EffectMonoToStereoFactory::properties() const
 {
     EffectProperties properties;
     properties.name = tr("Mono to Stereo Converter Plugin");
-    properties.shortName = "monotostereo";
+    properties.shortName = "monotostereo"_L1;
     properties.hasSettings = false;
     properties.hasAbout = true;
     return properties;
@@ -38,15 +38,16 @@ Effect *EffectMonoToStereoFactory::create()
     return new MonoToStereoPlugin();
 }
 
-void EffectMonoToStereoFactory::showSettings(QWidget *parent)
+QDialog *EffectMonoToStereoFactory::createSettings(QWidget *parent)
 {
-   Q_UNUSED(parent);
+    Q_UNUSED(parent);
+    return nullptr;
 }
 
 void EffectMonoToStereoFactory::showAbout(QWidget *parent)
 {
     QMessageBox::about(parent, tr("About Mono to Stereo Converter Plugin"),
-                       tr("Qmmp Mono to Stereo Converter Plugin")+"\n"+
+                       tr("Qmmp Mono to Stereo Converter Plugin") + QChar::LineFeed +
                        tr("Written by: Ilya Kotov <forkotov02@ya.ru>"));
 }
 
