@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2018-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2018-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -34,9 +34,9 @@ Q_PLUGIN_METADATA(IID "org.qmmp.qmmp.EffectFactoryInterface.1.0")
 Q_INTERFACES(EffectFactory)
 
 public:
-    const EffectProperties properties() const override;
+    EffectProperties properties() const override;
     Effect *create() override;
-    void showSettings(QWidget *parent) override;
+    QDialog *createSettings(QWidget *parent) override;
     void showAbout(QWidget *parent) override;
     QString translation() const override;
 };
