@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2016-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2016-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -26,7 +26,7 @@
 
 SoXResampler::SoXResampler() : Effect()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     m_overSamplingFs = settings.value(u"SOXR/sample_rate"_s, 48000).toInt();
     m_quality = soxr_quality_spec(settings.value(u"SOXR/quality"_s, SOXR_HQ).toInt(), 0);
 }
