@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2016-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2016-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -28,7 +28,7 @@ SoXRSettingsDialog::SoXRSettingsDialog(QWidget *parent)
  : QDialog(parent), m_ui(new Ui::SoXRSettingsDialog)
 {
     m_ui->setupUi(this);
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     m_ui->srSpinBox->setValue(settings.value(u"SOXR/sample_rate"_s, 48000).toInt());
 
     m_ui->qualityComboBox->addItem(tr("Quick"), SOXR_QQ);
@@ -49,7 +49,7 @@ SoXRSettingsDialog::~SoXRSettingsDialog()
 
 void SoXRSettingsDialog::accept()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.setValue(u"SOXR/sample_rate"_s, m_ui->srSpinBox->value());
     settings.setValue(u"SOXR/quality"_s, m_ui->qualityComboBox->itemData(m_ui->qualityComboBox->currentIndex()).toInt());
     QDialog::accept();
