@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -21,14 +21,14 @@
 #include <QMessageBox>
 #include <qmmp/qmmp.h>
 #include "effectstereofactory.h"
-#include "settingsdialog.h"
+#include "stereosettingsdialog.h"
 #include "stereoplugin.h"
 
-const EffectProperties EffectStereoFactory::properties() const
+EffectProperties EffectStereoFactory::properties() const
 {
     EffectProperties properties;
     properties.name = tr("Extra Stereo Plugin");
-    properties.shortName = "stereo";
+    properties.shortName = "stereo"_L1;
     properties.hasSettings = true;
     properties.hasAbout = true;
     return properties;
@@ -39,18 +39,17 @@ Effect *EffectStereoFactory::create()
     return new StereoPlugin();
 }
 
-void EffectStereoFactory::showSettings(QWidget *parent)
+QDialog *EffectStereoFactory::createSettings(QWidget *parent)
 {
-    SettingsDialog *s = new SettingsDialog(parent);
-    s ->show();
+    return new StereoSettingsDialog(parent);
 }
 
 void EffectStereoFactory::showAbout(QWidget *parent)
 {
-    QMessageBox::about (parent, tr("About Extra Stereo Plugin"),
-                        tr("Qmmp Extra Stereo Plugin")+"\n"+
-                        tr("Written by: Ilya Kotov <forkotov02@ya.ru>")+"\n"+
-                        tr("Based on the Extra Stereo Plugin for Xmms by Johan Levin"));
+    QMessageBox::about(parent, tr("About Extra Stereo Plugin"),
+                       tr("Qmmp Extra Stereo Plugin") + QChar::LineFeed +
+                       tr("Written by: Ilya Kotov <forkotov02@ya.ru>") + QChar::LineFeed +
+                       tr("Based on the Extra Stereo Plugin for Xmms by Johan Levin"));
 }
 
 QString EffectStereoFactory::translation() const
