@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 1999 by Johan Levin                                     *
  *                                                                         *
- *   Copyright (C) 2011-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2011-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -31,7 +31,7 @@ StereoPlugin *StereoPlugin::m_instance = nullptr;
 StereoPlugin::StereoPlugin() : Effect()
 {
     m_instance = this;
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     m_mul = settings.value(u"extra_stereo/intensity"_s, 1.0).toDouble();
 }
 
