@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -130,7 +130,7 @@ bool MplayerEngine::initialize()
     delete info;
     m_args.clear();
     m_args << u"-slave"_s;
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     QString ao_str = settings.value(u"mplayer/ao"_s, u"default"_s).toString();
     QString vo_str = settings.value(u"mplayer/vo"_s, u"default"_s).toString();
     if (ao_str != "default"_L1)
