@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -20,7 +20,7 @@
 
 #include <QMessageBox>
 #include "mplayermetadatamodel.h"
-#include "settingsdialog.h"
+#include "mplayersettingsdialog.h"
 #include "mplayerengine.h"
 #include "mplayerenginefactory.h"
 
@@ -31,11 +31,11 @@ EngineProperties MplayerEngineFactory::properties() const
 {
     EngineProperties properties;
     properties.name = tr("Mplayer Plugin");
-    properties.shortName = "mplayer";
+    properties.shortName = "mplayer"_L1;
     properties.filters = MplayerInfo::filters();
     properties.description = tr("Video Files");
     //properties.contentType = "application/ogg;audio/x-vorbis+ogg";
-    properties.protocols = QStringList { "file" };
+    properties.protocols = QStringList { u"file"_s };
     properties.hasAbout = true;
     properties.hasSettings = true;
     return properties;
@@ -63,18 +63,17 @@ MetaDataModel* MplayerEngineFactory::createMetaDataModel(const QString &path, bo
     return new MplayerMetaDataModel(path);
 }
 
-void MplayerEngineFactory::showSettings(QWidget *parent)
+QDialog *MplayerEngineFactory::createSettings(QWidget *parent)
 {
-    SettingsDialog *s = new SettingsDialog(parent);
-    s->show();
+    return new MplayerSettingsDialog(parent);
 }
 
 void MplayerEngineFactory::showAbout(QWidget *parent)
 {
-    QMessageBox::about (parent, tr("About MPlayer Plugin"),
-                        tr("Qmmp MPlayer Plugin")+"\n"+
-                        tr("This plugin uses MPlayer as backend")+"\n"+
-                        tr("Written by: Ilya Kotov <forkotov02@ya.ru>"));
+    QMessageBox::about(parent, tr("About MPlayer Plugin"),
+                       tr("Qmmp MPlayer Plugin") + QChar::LineFeed +
+                       tr("This plugin uses MPlayer as backend") + QChar::LineFeed +
+                       tr("Written by: Ilya Kotov <forkotov02@ya.ru>"));
 }
 
 QString MplayerEngineFactory::translation() const
