@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -22,6 +22,7 @@
 #include <QFileInfo>
 #include <QStringList>
 #include <QProcess>
+#include <QHash>
 #include "mplayermetadatamodel.h"
 
 MplayerMetaDataModel::MplayerMetaDataModel(const QString &path)
@@ -34,36 +35,38 @@ MplayerMetaDataModel::~MplayerMetaDataModel()
 
 QList<MetaDataItem> MplayerMetaDataModel::extraProperties() const
 {
-    QList<MetaDataItem> ep;
-    ep << MetaDataItem(tr("Size"), QFileInfo(m_path).size ()/1024, tr("KiB"));
     //prepare and start mplayer process
-    QStringList args = { "-slave", "-identify", "-frames", "0", "-vo", "null", "-ao", "null", m_path };
+    QStringList args = { u"-slave"_s, u"-identify"_s, u"-frames"_s, u"0"_s, u"-vo"_s, u"null"_s, u"-ao"_s, u"null"_s, m_path };
     QProcess mplayer_process;
-    mplayer_process.start("mplayer", args);
+    mplayer_process.start(u"mplayer"_s, args);
     mplayer_process.waitForFinished();
     QString str = QString::fromLocal8Bit(mplayer_process.readAll()).trimmed();
-    const QStringList lines = str.split("\n");
+    const QStringList lines = str.split(QChar::LineFeed);
     //mplayer std output parsing
-    QRegularExpression rx_id("^(ID_.*)=(.*)");
-    QMap<QString, QString> params;
-    for(const QString &line : qAsConst(lines))
+    static const QRegularExpression rx_id(u"^(ID_.*)=(.*)"_s);
+    QHash<QString, QString> params;
+    for(const QString &line : std::as_const(lines))
     {
         QRegularExpressionMatch match = rx_id.match(line.trimmed());
         if(match.hasMatch())
             params.insert(match.captured(1), match.captured(2));
     }
-    //general info
-    ep << MetaDataItem(tr("Demuxer"), params["ID_DEMUXER"]);
-    //video info
-    ep << MetaDataItem(tr("Video format"), params["ID_VIDEO_FORMAT"]);
-    ep << MetaDataItem(tr("FPS"), params["ID_VIDEO_FPS"]);
-    ep << MetaDataItem(tr("Video codec"), params["ID_VIDEO_CODEC"]);
-    ep << MetaDataItem(tr("Aspect ratio"), params["ID_VIDEO_ASPECT"]);
-    ep << MetaDataItem(tr("Video bitrate"), params["ID_VIDEO_BITRATE"].toInt() / 1000, tr("kbps"));
-    ep << MetaDataItem(tr("Resolution"), QString("%1x%2").arg(params["ID_VIDEO_WIDTH"]).arg(params["ID_VIDEO_HEIGHT"]));
-    ep << MetaDataItem(tr("Audio codec"), params["ID_AUDIO_CODEC"]);
-    ep << MetaDataItem(tr("Sample rate"), params["ID_AUDIO_RATE"], tr("Hz"));
-    ep << MetaDataItem(tr("Audio bitrate"), params["ID_AUDIO_BITRATE"].toInt() / 1000, tr("kbps"));
-    ep << MetaDataItem(tr("Channels"), params["ID_AUDIO_NCH"]);
+
+    QList<MetaDataItem> ep = {
+        //general info
+        MetaDataItem(tr("Size"), QFileInfo(m_path).size () / 1024, tr("KiB")),
+        MetaDataItem(tr("Demuxer"), params[u"ID_DEMUXER"_s]),
+        //video info
+        MetaDataItem(tr("Video format"), params[u"ID_VIDEO_FORMAT"_s]),
+        MetaDataItem(tr("FPS"), params[u"ID_VIDEO_FPS"_s]),
+        MetaDataItem(tr("Video codec"), params[u"ID_VIDEO_CODEC"_s]),
+        MetaDataItem(tr("Aspect ratio"), params[u"ID_VIDEO_ASPECT"_s]),
+        MetaDataItem(tr("Video bitrate"), params[u"ID_VIDEO_BITRATE"_s].toInt() / 1000, tr("kbps")),
+        MetaDataItem(tr("Resolution"), QStringLiteral("%1x%2").arg(params[u"ID_VIDEO_WIDTH"_s], params[u"ID_VIDEO_HEIGHT"_s])),
+        MetaDataItem(tr("Audio codec"), params[u"ID_AUDIO_CODEC"_s]),
+        MetaDataItem(tr("Sample rate"), params[u"ID_AUDIO_RATE"_s], tr("Hz")),
+        MetaDataItem(tr("Audio bitrate"), params[u"ID_AUDIO_BITRATE"_s].toInt() / 1000, tr("kbps")),
+        MetaDataItem(tr("Channels"), params[u"ID_AUDIO_NCH"_s])
+    };
     return ep;
 }
