@@ -1,5 +1,5 @@
 /**************************************************************************
-*   Copyright (C) 2008-2025 by Ilya Kotov                                 *
+*   Copyright (C) 2008-2024 by Ilya Kotov                                 *
 *   forkotov02@ya.ru                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
@@ -69,7 +69,7 @@ QmmpFileDialogImpl::QmmpFileDialogImpl(QWidget *parent, Qt::WindowFlags f) : QDi
     PathCompleter* completer = new PathCompleter(m_model, m_ui->fileListView, this);
     m_ui->fileNameLineEdit->setCompleter(completer);
 
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     m_ui->closeOnAddToolButton->setChecked(settings.value(u"QMMPFileDialog/close_on_add"_s, false).toBool());
     restoreGeometry(settings.value(u"QMMPFileDialog/geometry"_s).toByteArray());
     m_history = settings.value(u"QMMPFileDialog/history"_s).toStringList();
@@ -341,7 +341,7 @@ void QmmpFileDialogImpl::on_fileTypeComboBox_activated(int index)
 
 void QmmpFileDialogImpl::hideEvent (QHideEvent *event)
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.setValue(u"QMMPFileDialog/close_on_add"_s, m_ui->closeOnAddToolButton->isChecked());
     settings.setValue(u"QMMPFileDialog/geometry"_s, saveGeometry());
     settings.setValue(u"QMMPFileDialog/history"_s, m_history);
