@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2011-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2011-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -266,11 +266,7 @@ void Converter::run()
             if(full_path.endsWith(u".mp3"_s, Qt::CaseInsensitive))
             {
                 TagLib::MPEG::File *mpeg_file = dynamic_cast <TagLib::MPEG::File *> (file.file());
-#if ((TAGLIB_MAJOR_VERSION == 1) && (TAGLIB_MINOR_VERSION <= 11))
-                mpeg_file->save(TagLib::MPEG::File::ID3v2, true);
-#else
                 mpeg_file->save(TagLib::MPEG::File::ID3v2, TagLib::File::StripOthers);
-#endif
             }
             else
                 file.save();
