@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2011-2016 by Ilya Kotov                                 *
+ *   Copyright (C) 2011-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -33,7 +33,7 @@ ConverterHelper::ConverterHelper(QObject *parent) : QObject(parent)
     m_action = new QAction(tr("Convert"), this);
     m_action->setShortcut(tr("Meta+C"));
     UiHelper::instance()->addAction(m_action, UiHelper::PLAYLIST_MENU);
-    connect (m_action, SIGNAL(triggered ()), SLOT(openConverter()));
+    connect(m_action, &QAction::triggered, this, &ConverterHelper::openConverter);
 
 }
 
@@ -43,10 +43,10 @@ ConverterHelper::~ConverterHelper()
 void ConverterHelper::openConverter()
 {
     PlayListManager *pl_manager = MediaPlayer::instance()->playListManager();
-    QList <PlayListTrack *> tracks = pl_manager->selectedPlayList()->selectedTracks();
-    if (tracks.isEmpty())
+    QList<PlayListTrack *> tracks = pl_manager->selectedPlayList()->selectedTracks();
+    if(tracks.isEmpty())
         return;
 
-    ConverterDialog d(tracks, qApp->activeWindow ());
+    ConverterDialog d(tracks, qApp->activeWindow());
     d.exec();
 }
