@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2013-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2013-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -45,9 +45,9 @@ CopyPaste::CopyPaste(QObject *parent) : QObject(parent)
     QAction *pasteAction = new QAction(tr("&Paste"), this);
     pasteAction->setShortcut(tr("Ctrl+V"));
     //register all actions
-    connect(cutAction, SIGNAL(triggered()), SLOT(cut()));
-    connect(copyAction, SIGNAL(triggered()), SLOT(copy()));
-    connect(pasteAction, SIGNAL(triggered()), SLOT(paste()));
+    connect(cutAction, &QAction::triggered, this, &CopyPaste::cut);
+    connect(copyAction, &QAction::triggered, this, &CopyPaste::copy);
+    connect(pasteAction, &QAction::triggered, this, &CopyPaste::paste);
     UiHelper::instance()->addAction(cutAction, UiHelper::PLAYLIST_MENU);
     UiHelper::instance()->addAction(copyAction, UiHelper::PLAYLIST_MENU);
     UiHelper::instance()->addAction(pasteAction, UiHelper::PLAYLIST_MENU);
@@ -61,7 +61,7 @@ CopyPaste::~CopyPaste()
 
 void CopyPaste::cut()
 {
-    qDebug("%s", Q_FUNC_INFO);
+    qCDebug(plugin) << Q_FUNC_INFO;
     qDeleteAll(m_buffer);
     m_buffer.clear();
     for(PlayListTrack *track : m_pl_manager->selectedPlayList()->selectedTracks())
@@ -73,7 +73,7 @@ void CopyPaste::cut()
 
 void CopyPaste::copy()
 {
-    qDebug("%s", Q_FUNC_INFO);
+    qCDebug(plugin) << Q_FUNC_INFO;
     qDeleteAll(m_buffer);
     m_buffer.clear();
     for(PlayListTrack *track : m_pl_manager->selectedPlayList()->selectedTracks())
@@ -84,9 +84,9 @@ void CopyPaste::copy()
 
 void CopyPaste::paste()
 {
-    qDebug("%s", Q_FUNC_INFO);
-    for(const PlayListTrack *track : qAsConst(m_buffer))
+    qCDebug(plugin) << Q_FUNC_INFO;
+    for(const PlayListTrack *track : std::as_const(m_buffer))
     {
-        m_pl_manager->selectedPlayList()->add(new PlayListTrack(*track));
+        m_pl_manager->selectedPlayList()->addTrack(new PlayListTrack(*track));
     }
 }
