@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -35,7 +35,11 @@ CoverWidget::CoverWidget(QWidget *parent)
     setWindowFlags(Qt::Window);
     setAttribute(Qt::WA_DeleteOnClose, true);
     m_menu = new QMenu(this);
+#if QT_VERSION < QT_VERSION_CHECK(6, 3, 0)
     m_menu->addAction(tr("&Save As..."), this, &CoverWidget::saveAs, tr("Ctrl+S"));
+#else
+    m_menu->addAction(tr("&Save As..."), tr("Ctrl+S"), this, &CoverWidget::saveAs);
+#endif
     QMenu *sizeMenu = m_menu->addMenu(tr("Size"));
     QActionGroup *sizeGroup = new QActionGroup(this);
     sizeGroup->addAction(tr("Actual Size"))->setData(0);
@@ -45,11 +49,15 @@ CoverWidget::CoverWidget(QWidget *parent)
     sizeGroup->addAction(tr("1024x1024"))->setData(1024);
     sizeMenu->addActions(sizeGroup->actions());
     connect(sizeMenu, &QMenu::triggered, this, &CoverWidget::processResizeAction);
+#if QT_VERSION < QT_VERSION_CHECK(6, 3, 0)
     m_menu->addAction(tr("&Close"), this, &CoverWidget::close, tr("Alt+F4"));
+#else
+    m_menu->addAction(tr("&Close"), tr("Alt+F4"), this, &CoverWidget::close);
+#endif
     addActions(m_menu->actions());
     m_size = 0;
     //settings
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     m_size = settings.value(u"CoverManager/size"_s, 0).toInt();
     for(QAction *a : sizeMenu->actions())
     {
@@ -80,7 +88,7 @@ void CoverWidget::paintEvent(QPaintEvent *p)
 void CoverWidget::mousePressEvent(QMouseEvent *e)
 {
     if(e->button() == Qt::RightButton)
-        m_menu->exec(e->globalPos());
+        m_menu->exec(e->globalPosition().toPoint());
 }
 
 void CoverWidget::saveAs()
@@ -100,6 +108,6 @@ void CoverWidget::processResizeAction(QAction *action)
     else
         resize(m_size, m_size);
     update();
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.setValue(u"CoverManager/size"_s, m_size);
 }
