@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -45,7 +45,7 @@ FileOps::FileOps(QObject *parent) : QObject(parent)
     QAction *separator2 = new QAction(this);
     separator2->setSeparator(true);
     //load settings
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup("FileOps"_L1);
     if(!settings.value("name_0"_L1).isNull())
         UiHelper::instance()->addAction(separator1, UiHelper::PLAYLIST_MENU);
