@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright(C)  2009-2025 by Ilya Kotov                                 *
+ *   Copyright(C)  2009-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -38,7 +38,7 @@ FileOpsSettingsDialog::FileOpsSettingsDialog(QWidget *parent)
     m_ui->tableWidget->verticalHeader()->setSectionResizeMode(QHeaderView::ResizeToContents);
     m_ui->tableWidget->horizontalHeader()->setSectionResizeMode(QHeaderView::ResizeToContents);
 
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(u"FileOps"_s);
     int i = 0;
     while(!settings.value(QStringLiteral("name_%1").arg(i)).isNull())
@@ -51,7 +51,7 @@ FileOpsSettingsDialog::FileOpsSettingsDialog(QWidget *parent)
         QComboBox *comboBox = createComboBox();
         int ci = comboBox->findData(settings.value(QStringLiteral("action_%1").arg(i), FileOps::COPY).toInt());
         comboBox->setCurrentIndex(qMax(ci, 0));
-        connect(comboBox, qOverload<int>(&QComboBox::activated), this, &FileOpsSettingsDialog::updateLineEdits);
+        connect(comboBox, &QComboBox::activated, this, &FileOpsSettingsDialog::updateLineEdits);
 
         QTableWidgetItem *nameItem = new QTableWidgetItem(settings.value(QStringLiteral("name_%1").arg(i)).toString());
         nameItem->setData(PatternRole, settings.value(QStringLiteral("pattern_%1").arg(i)).toString());
@@ -83,7 +83,7 @@ FileOpsSettingsDialog::~FileOpsSettingsDialog()
 
 void FileOpsSettingsDialog::accept()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup("FileOps"_L1);
     //remove all previous keys
     settings.remove(QString());
@@ -127,7 +127,8 @@ void FileOpsSettingsDialog::on_newButton_clicked()
     QTableWidgetItem *nameItem = new QTableWidgetItem(tr("New action"));
     nameItem->setData(DestionationRole, QStandardPaths::writableLocation(QStandardPaths::MusicLocation));
     nameItem->setData(PatternRole, u"%p - %t"_s);
-    connect(comboBox, qOverload<int>(&QComboBox::activated), this, &FileOpsSettingsDialog::updateLineEdits);
+
+    connect(comboBox, &QComboBox::activated, this, &FileOpsSettingsDialog::updateLineEdits);
 
     m_ui->tableWidget->setCellWidget(row, 0, checkBox);
     m_ui->tableWidget->setCellWidget(row, 1, comboBox);
