@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2017-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2017-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -122,7 +122,11 @@ void HistoryWindow::loadHistory()
         info.setPath(query.value(11).toString());
 
         QDateTime dateTime = QDateTime::fromString(query.value(0).toString(), u"yyyy-MM-dd hh:mm:ss"_s);
+#if QT_VERSION >= QT_VERSION_CHECK(6, 8, 0)
+        dateTime.setTimeZone(QTimeZone::UTC);
+#else
         dateTime.setTimeSpec(Qt::UTC);
+#endif
         QString dateStr = dateTime.toLocalTime().toString(tr("dd MMMM yyyy"));
         QString timeStr = dateTime.toLocalTime().toString(tr("hh:mm:ss"));
         int topLevelCount = m_ui->historyTreeWidget->topLevelItemCount();
@@ -351,7 +355,7 @@ void HistoryWindow::loadTopGenres()
 
 void HistoryWindow::readSettings()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(u"History"_s);
     restoreGeometry(settings.value(u"geometry"_s).toByteArray());
     m_ui->historyTreeWidget->header()->restoreState(settings.value(u"history_state"_s).toByteArray());
@@ -421,7 +425,7 @@ void HistoryWindow::showInformation(QTreeWidgetItem *item)
 
 void HistoryWindow::closeEvent(QCloseEvent *)
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(u"History"_s);
     settings.setValue(u"geometry"_s, saveGeometry());
     settings.setValue(u"history_state"_s, m_ui->historyTreeWidget->header()->saveState());
@@ -493,7 +497,7 @@ void HistoryWindow::on_historyTreeWidget_customContextMenuRequested(const QPoint
         QString path = item->data(1, PathRole).toString();
         QMenu menu(this);
         menu.addAction(QIcon::fromTheme(u"list-add"_s),tr("Add to Playlist"), this, [=] { PlayListManager::instance()->addPath(path); } );
-        menu.addAction(QIcon::fromTheme(u"dialog-information"_s), tr("&View Track Details"), this, [=] { showInformation(item); });
+        menu.addAction(QIcon::fromTheme(u"dialog-information"_s), tr("&View Track Details"), [=] { showInformation(item); });
         menu.addSeparator();
         menu.addAction(QIcon::fromTheme(u"edit-delete"_s), tr("Remove from History"), this, [=] { removeTrack(item); } );
         menu.exec(m_ui->historyTreeWidget->viewport()->mapToGlobal(pos));
