@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -50,7 +50,7 @@ HotkeySettingsDialog::HotkeySettingsDialog(QWidget *parent)
     m_ui->tableWidget->setItem(11,0, new QTableWidgetItem(tr("Jump to track")));
     m_ui->tableWidget->setItem(12,0, new QTableWidgetItem(tr("Mute")));
 
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(u"Hotkey"_s);
     for (int i = Hotkey::PLAY, j = 0; i <= Hotkey::VOLUME_MUTE; ++i, ++j)
     {
@@ -75,7 +75,7 @@ HotkeySettingsDialog::~HotkeySettingsDialog()
 
 void HotkeySettingsDialog::accept()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(u"Hotkey"_s);
     for(const Hotkey *k : std::as_const(m_hotkeys))
     {
