@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2020-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2020-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -66,7 +66,7 @@ public:
 LibraryModel::LibraryModel(QObject *parent) : QAbstractItemModel(parent)
 {
     m_rootItem = new LibraryTreeItem;
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     m_showYear = settings.value(u"Library/show_year"_s, false).toBool();
     refresh();
 }
@@ -339,8 +339,6 @@ void LibraryModel::replace(const QModelIndexList &indexes)
 void LibraryModel::showTrackInformation(const QModelIndexList &indexes, QWidget *parent)
 {
     QList<PlayListTrack *> tracks = getTracks(indexes);
-    if(tracks.isEmpty())
-        return;
 
     DetailsDialog *dialog = new DetailsDialog(tracks, parent);
     dialog->setAttribute(Qt::WA_DeleteOnClose, true);
