@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2020-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2020-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -32,7 +32,7 @@ LibrarySettingsDialog::LibrarySettingsDialog(QWidget *parent) :
     m_ui(new Ui::LibrarySettingsDialog)
 {
     m_ui->setupUi(this);
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     m_lastPath = settings.value(u"Library/last_path"_s, QDir::homePath()).toString();
     QStringList dirs = settings.value(u"Library/dirs"_s).toStringList();
     m_ui->dirsListWidget->addItems(dirs);
@@ -47,7 +47,7 @@ LibrarySettingsDialog::~LibrarySettingsDialog()
 
 void LibrarySettingsDialog::accept()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.setValue(u"Library/last_path"_s, m_lastPath);
 
     QStringList dirs;
