@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2019-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2019-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -48,7 +48,7 @@ ListenBrainz::ListenBrainz(QObject *parent)
     m_ua = QStringLiteral("qmmp-plugins/%1").arg(Qmmp::strVersion().toLower()).toLatin1();
     m_http = new QNetworkAccessManager(this);
     m_core = SoundCore::instance();
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     m_token = settings.value(u"ListenBrainz/user_token"_s).toString().trimmed();
 
     connect(m_http, &QNetworkAccessManager::finished, this, &ListenBrainz::processResponse);
@@ -131,7 +131,7 @@ void ListenBrainz::updateMetaData()
     if(!info.value(Qmmp::TITLE).isEmpty() && !info.value(Qmmp::ARTIST).isEmpty())
     {
         m_song = TrackMetaData(info);
-        m_song.setTimeStamp(QDateTime::currentSecsSinceEpoch());
+        m_song.setTimeStamp(QDateTime::currentDateTime().toSecsSinceEpoch());
         sendNotification(m_song);
     }
     m_time->restart();
