@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2019-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2019-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -27,7 +27,7 @@ ListenBrainzSettingsDialog::ListenBrainzSettingsDialog(QWidget *parent) :
     QDialog(parent), m_ui(new Ui::ListenBrainzSettingsDialog)
 {
     m_ui->setupUi(this);
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     m_ui->userTokenLineEdit->setText(settings.value(u"ListenBrainz/user_token"_s).toString());
 }
 
@@ -38,7 +38,7 @@ ListenBrainzSettingsDialog::~ListenBrainzSettingsDialog()
 
 void ListenBrainzSettingsDialog::accept()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.setValue(u"ListenBrainz/user_token"_s, m_ui->userTokenLineEdit->text());
     QDialog::accept();
 }
