@@ -21,7 +21,6 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
-#include <QtDebug>
 #include <QRegularExpression>
 #include <qmmp/trackinfo.h>
 #include "lyricsprovider.h"
@@ -52,7 +51,7 @@ void LyricsProvider::addUrlFormat(const QString &replace, const QString &with)
 void LyricsProvider::addRule(const QList<QPair<QString, QString> > &args, bool exclude)
 {
     Rule rule;
-    for(const QPair<QString, QString> &i : qAsConst(args))
+    for(const QPair<QString, QString> &i : std::as_const(args))
     {
         Item item;
         if(!i.first.isEmpty() && !i.second.isEmpty())
@@ -60,7 +59,7 @@ void LyricsProvider::addRule(const QList<QPair<QString, QString> > &args, bool e
             item.begin = i.first;
             item.end = i.second;
         }
-        else if(i.first.contains("://")) //url
+        else if(i.first.contains(u"://"_s)) //url
         {
             item.url = i.first;
         }
@@ -84,14 +83,14 @@ void LyricsProvider::addInvalidIndicator(const QString &indicator)
 QString LyricsProvider::getUrl(const TrackInfo &track) const
 {
     QString url = m_url;
-    const QMap<QString, QString> replaceMap = generateReplaceMap(track);
-    QMap<QString, QString>::const_iterator it = replaceMap.constBegin();
-    while(it != replaceMap.constEnd())
+    const QHash<QString, QString> replaceHash = generateReplaceHash(track);
+    QHash<QString, QString>::const_iterator it = replaceHash.constBegin();
+    while(it != replaceHash.constEnd())
     {
         QString value = it.value();
 
         for(const UrlFormat &format: m_urlFormats)
-            value.replace(QRegularExpression(QString("[%1]").arg(QRegularExpression::escape(format.replace))), format.with);
+            value.replace(QRegularExpression(QStringLiteral("[%1]").arg(QRegularExpression::escape(format.replace))), format.with);
 
         url.replace(it.key(), value);
 
@@ -106,7 +105,7 @@ QString LyricsProvider::format(const QByteArray &data, const TrackInfo &track) c
     const QString content = QString::fromUtf8(data);
     QString out;
 
-    for(const QString &indicator : qAsConst(m_invalidIndicators))
+    for(const QString &indicator : std::as_const(m_invalidIndicators))
     {
         if(content.contains(indicator))
             return QString();
@@ -115,17 +114,17 @@ QString LyricsProvider::format(const QByteArray &data, const TrackInfo &track) c
     if(m_skipRules)
         return content;
 
-    const QMap<QString, QString> replaceMap = generateReplaceMap(track);
+    const QHash<QString, QString> replaceHash = generateReplaceHash(track);
 
-    for(const Rule &rule : qAsConst(m_extractRules))
+    for(const Rule &rule : std::as_const(m_extractRules))
     {
         Rule tmpRule = rule;
         QString tmpContent = content;
 
         for(Item &item : tmpRule)
         {
-            QMap<QString, QString>::const_iterator it = replaceMap.constBegin();
-            while(it != replaceMap.constEnd())
+            QHash<QString, QString>::const_iterator it = replaceHash.constBegin();
+            while(it != replaceHash.constEnd())
             {
                 item.begin.replace(it.key(), it.value());
                 item.url.replace(it.key(), it.value());
@@ -137,7 +136,7 @@ QString LyricsProvider::format(const QByteArray &data, const TrackInfo &track) c
 
         if(!tmpContent.isEmpty())
         {
-            for(const Rule &excludeRule : qAsConst(m_excludeRules))
+            for(const Rule &excludeRule : std::as_const(m_excludeRules))
                 tmpContent = exclude(tmpContent, excludeRule);
         }
         if(tmpContent.isEmpty())
@@ -151,20 +150,20 @@ QString LyricsProvider::format(const QByteArray &data, const TrackInfo &track) c
         }
     }
 
-    while (out.endsWith("<br />"))
+    while (out.endsWith(u"<br />"_s))
     {
         out.chop(6);
         out = out.trimmed();
     }
 
-    while (out.endsWith("<br>"))
+    while (out.endsWith(u"<br>"_s))
     {
         out.chop(4);
         out = out.trimmed();
     }
 
     //plain text support
-    if(out.contains(QChar::LineFeed) && !out.contains(QChar('<')))
+    if(out.contains(QChar::LineFeed) && !out.contains(QLatin1Char('<')))
         out.replace(QChar::LineFeed, QStringLiteral("<br>"));
 
     return out;
@@ -197,22 +196,22 @@ QString LyricsProvider::fixCase(const QString &title) const
     return out;
 }
 
-QMap<QString, QString> LyricsProvider::generateReplaceMap(const TrackInfo &track) const
+QHash<QString, QString> LyricsProvider::generateReplaceHash(const TrackInfo &track) const
 {
-    QMap<QString, QString> replaceMap = {
-        { "{artist}", track.value(Qmmp::ARTIST).toLower() },
-        { "{artist2}", track.value(Qmmp::ARTIST).toLower().remove(' ') },
-        { "{Artist}", track.value(Qmmp::ARTIST) },
-        { "{ARTIST}", track.value(Qmmp::ARTIST).toUpper() },
-        { "{a}", track.value(Qmmp::ARTIST).left(1).toLower() },
-        { "{album}", track.value(Qmmp::ALBUM).toLower() },
-        { "{album2}", track.value(Qmmp::ALBUM).toLower().remove(' ') },
-        { "{Album}", track.value(Qmmp::ALBUM) },
-        { "{title}",  track.value(Qmmp::TITLE).toLower() },
-        { "{Title}", track.value(Qmmp::TITLE) },
-        { "{Title2}", fixCase(track.value(Qmmp::TITLE)) },
-        { "{track}", track.value(Qmmp::TRACK) },
-        { "{year}",  track.value(Qmmp::YEAR) }
+    const QHash<QString, QString> replaceMap = {
+        { u"{artist}"_s, track.value(Qmmp::ARTIST).toLower() },
+        { u"{artist2}"_s, track.value(Qmmp::ARTIST).toLower().remove(QChar::Space) },
+        { u"{Artist}"_s, track.value(Qmmp::ARTIST) },
+        { u"{ARTIST}"_s, track.value(Qmmp::ARTIST).toUpper() },
+        { u"{a}"_s, track.value(Qmmp::ARTIST).left(1).toLower() },
+        { u"{album}"_s, track.value(Qmmp::ALBUM).toLower() },
+        { u"{album2}"_s, track.value(Qmmp::ALBUM).toLower().remove(QChar::Space) },
+        { u"{Album}"_s, track.value(Qmmp::ALBUM) },
+        { u"{title}"_s,  track.value(Qmmp::TITLE).toLower() },
+        { u"{Title}"_s, track.value(Qmmp::TITLE) },
+        { u"{Title2}"_s, fixCase(track.value(Qmmp::TITLE)) },
+        { u"{track}"_s, track.value(Qmmp::TRACK) },
+        { u"{year}"_s,  track.value(Qmmp::YEAR) }
     };
 
     return replaceMap;
@@ -222,20 +221,21 @@ QString LyricsProvider::extract(const QString &content, const Rule &rule) const
 {
     QString out = content;
 
-    for(const Item &item : qAsConst(rule))
+    for(const Item &item : std::as_const(rule))
     {
         if(!item.url.isEmpty())
         {
             QString url = item.url;
             QString id = rule.count() >= 2 ? out.section(rule[1].begin, 1).section(rule[1].end, 0, 0) : QString();
-            url.replace("{id}", id);
+            url.replace(u"{id}"_s, id);
             return url;
         }
-        else if(!item.tag.isEmpty())
+
+        if(!item.tag.isEmpty())
         {
-            const QRegularExpression re("<(\\w+).*>");
+            static const QRegularExpression re(u"<(\\w+).*>"_s);
             QRegularExpressionMatch m = re.match(item.tag);
-            out = out.section(item.tag, 1).section(QString("</%1>").arg(m.captured(1)), 0, 0);
+            out = out.section(item.tag, 1).section(QStringLiteral("</%1>").arg(m.captured(1)), 0, 0);
         }
         else
         {
@@ -249,13 +249,13 @@ QString LyricsProvider::exclude(const QString &content, const LyricsProvider::Ru
 {
     QString out = content;
 
-    for(const Item &item : qAsConst(rule))
+    for(const Item &item : std::as_const(rule))
     {
         if(!item.tag.isEmpty())
         {
-            const QRegularExpression re("<(\\w+).*>");
+            static const QRegularExpression re(u"<(\\w+).*>"_s);
             QRegularExpressionMatch m = re.match(item.tag);
-            out = out.section(item.tag, 0, 0) + out.section(item.tag, 1).section(QString("</%1>").arg(m.captured(1)), 1);
+            out = out.section(item.tag, 0, 0) + out.section(item.tag, 1).section(QStringLiteral("</%1>").arg(m.captured(1)), 1);
         }
         else
         {
