@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2019-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2019-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -29,7 +29,7 @@ LyricsSettingsDialog::LyricsSettingsDialog(QWidget *parent) :
     m_ui(new Ui::LyricsSettingsDialog)
 {
     m_ui->setupUi(this);
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);  
+    QSettings settings;  
     UltimateLyricsParser parser;
     parser.load(u":/ultimate_providers.xml"_s);
     QStringList enabledProviders = settings.value(u"Lyrics/enabled_providers"_s, parser.defaultProviders()).toStringList();
@@ -49,7 +49,7 @@ LyricsSettingsDialog::~LyricsSettingsDialog()
 
 void LyricsSettingsDialog::accept()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     QStringList enabledProviders;
     for(int i = 0; i < m_ui->providersListWidget->count(); ++i)
     {
