@@ -23,11 +23,8 @@
 
 #include <QXmlStreamReader>
 #include <QFile>
-#include <QtDebug>
 #include <algorithm>
-#if (QT_VERSION < QT_VERSION_CHECK(5, 7, 0)) //qAsConst template
 #include <qmmp/qmmp.h>
-#endif
 #include "ultimatelyricsparser.h"
 
 UltimateLyricsParser::UltimateLyricsParser()
@@ -62,54 +59,54 @@ bool UltimateLyricsParser::load(const QString &path)
 
         if(reader.isStartElement())
         {
-            if(reader.name() == "provider")
+            if(reader.name() == QLatin1String("provider"))
             {
                 LyricsProvider *provider = new LyricsProvider;
                 QXmlStreamAttributes attrs = reader.attributes();
-                provider->setName(attrs.value("name").toString());
-                provider->setTitle(attrs.value("title").toString());
-                provider->setUrl(attrs.value("url").toString());
+                provider->setName(attrs.value("name"_L1).toString());
+                provider->setTitle(attrs.value("title"_L1).toString());
+                provider->setUrl(attrs.value("url"_L1).toString());
                 m_providers << provider;
             }
-            else if(reader.name() == "urlFormat" && !m_providers.isEmpty())
+            else if(reader.name() == QLatin1String("urlFormat") && !m_providers.isEmpty())
             {
-                m_providers.last()->addUrlFormat(reader.attributes().value("replace").toString(),
-                                                 reader.attributes().value("with").toString());
+                m_providers.last()->addUrlFormat(reader.attributes().value("replace"_L1).toString(),
+                                                 reader.attributes().value("with"_L1).toString());
             }
-            else if(reader.name() == "extract" || reader.name() == "exclude")
+            else if(reader.name() == QLatin1String("extract") || reader.name() == QLatin1String("exclude"))
             {
                 parentElement = reader.name().toString();
             }
-            else if(reader.name() == "invalidIndicator" && !m_providers.isEmpty())
+            else if(reader.name() == QLatin1String("invalidIndicator") && !m_providers.isEmpty())
             {
-                m_providers.last()->addInvalidIndicator(reader.attributes().value("value").toString());
+                m_providers.last()->addInvalidIndicator(reader.attributes().value("value"_L1).toString());
             }
-            else if(reader.name() == "item")
+            else if(reader.name() == QLatin1String("item"))
             {
                 QXmlStreamAttributes attrs = reader.attributes();
                 QString arg1, arg2;
-                if(attrs.hasAttribute("begin") && attrs.hasAttribute("end"))
+                if(attrs.hasAttribute("begin"_L1) && attrs.hasAttribute("end"_L1))
                 {
-                    arg1 = attrs.value("begin").toString();
-                    arg2 = attrs.value("end").toString();
+                    arg1 = attrs.value("begin"_L1).toString();
+                    arg2 = attrs.value("end"_L1).toString();
                 }
-                else if(attrs.hasAttribute("tag"))
+                else if(attrs.hasAttribute("tag"_L1))
                 {
-                    arg1 = attrs.value("tag").toString();
+                    arg1 = attrs.value("tag"_L1).toString();
                 }
-                else if(attrs.hasAttribute("url"))
+                else if(attrs.hasAttribute("url"_L1))
                 {
-                    arg1 = attrs.value("url").toString();
+                    arg1 = attrs.value("url"_L1).toString();
                 }
                 args << qMakePair(arg1, arg2);
             }
         }
         else if(reader.isEndElement())
         {
-            if(reader.name() == "extract" || reader.name() == "exclude")
+            if(reader.name() == QLatin1String("extract") || reader.name() == QLatin1String("exclude"))
             {
                 parentElement.clear();
-                m_providers.last()->addRule(args, reader.name() == "exclude");
+                m_providers.last()->addRule(args, reader.name() == QLatin1String("exclude"));
                 args.clear();
             }
         }
@@ -142,9 +139,9 @@ LyricsProvider *UltimateLyricsParser::provider(const QString &name) const
 const QStringList &UltimateLyricsParser::defaultProviders()
 {
     static const QStringList out = {
-        "Encyclopaedia Metallum",
-        "letras.mus.br",
-        "darklyrics.com"
+        u"Encyclopaedia Metallum"_s,
+        u"letras.mus.br"_s,
+        u"darklyrics.com"_s
     };
 
     return out;
