@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -28,7 +28,6 @@
 #undef Visual
 
 #ifdef X11_FOUND
-#include <QX11Info>
 #include <X11/X.h>
 #include <X11/Xatom.h>
 #include <X11/Xlib.h>
@@ -42,7 +41,7 @@
 
 Notifier::Notifier(QObject *parent) : QObject(parent)
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(u"Notifier"_s);
     m_desktop = settings.value(u"song_notification"_s, true).toBool();
     m_resumeNotification = settings.value(u"resume_notification"_s, false).toBool();
@@ -141,20 +140,21 @@ void Notifier::showMetaData()
             continue;
 
         QFile file(path);
-        if(file.open(QIODevice::WriteOnly | QIODevice::Text | QIODevice::Truncate))
-            file.write(data);
+        file.open(QIODevice::WriteOnly | QIODevice::Text | QIODevice::Truncate);
+        file.write(data);
+        file.close();
     }
 }
 
 void Notifier::showVolume(int v)
 {
-    if((m_volume != v) && m_showVolume)
+    if ((m_volume != v) && m_showVolume)
     {
         if (m_volume >= 0 && !hasFullscreenWindow())
         {
             if (!m_popupWidget)
                 m_popupWidget = new PopupWidget();
-            m_popupWidget->showVolume(v);
+            m_popupWidget->showVolume(m_volume);
         }
         m_volume = v;
     }
@@ -172,14 +172,14 @@ void Notifier::removePsiTuneFiles()
 #ifdef X11_FOUND
 bool Notifier::hasFullscreenWindow() const
 {
-    if(!m_disableForFullScreen || !QX11Info::isPlatformX11())
+    if(!m_disableForFullScreen || !Notifier::isPlatformX11())
         return false;
     Atom type = None;
     int format = 0;
     unsigned long nitems = 0, bytes_after = 0;
     unsigned char *prop;
 
-    Display *display = QX11Info::display();
+    Display *display = Notifier::display();
 
     Atom filter = XInternAtom(display, "_NET_WM_STATE_FULLSCREEN", False);
     Atom net_wm_state = XInternAtom(display, "_NET_WM_STATE", False);
@@ -209,6 +209,21 @@ bool Notifier::hasFullscreenWindow() const
     return false;
 }
 
+Display *Notifier::display()
+{
+    if(!qApp)
+        return nullptr;
+    QNativeInterface::QX11Application *app = qApp->nativeInterface<QNativeInterface::QX11Application>();
+    if(!app)
+        return nullptr;
+
+    return app->display();
+}
+
+bool Notifier::isPlatformX11()
+{
+    return QGuiApplication::platformName() == QLatin1String("xcb");
+}
 #elif defined(Q_OS_WIN)
 bool Notifier::hasFullscreenWindow() const
 {
