@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -20,14 +20,14 @@
 
 #include <QMessageBox>
 #include "notifier.h"
-#include "settingsdialog.h"
+#include "notifiersettingsdialog.h"
 #include "notifierfactory.h"
 
 GeneralProperties NotifierFactory::properties() const
 {
     GeneralProperties properties;
     properties.name = tr("Notifier Plugin");
-    properties.shortName = "notifier";
+    properties.shortName = "notifier"_L1;
     properties.hasAbout = true;
     properties.hasSettings = true;
     properties.visibilityControl = false;
@@ -39,16 +39,16 @@ QObject *NotifierFactory::create(QObject *parent)
     return new Notifier(parent);
 }
 
-QDialog *NotifierFactory::createConfigDialog(QWidget *parent)
+QDialog *NotifierFactory::createSettings(QWidget *parent)
 {
-    return new SettingsDialog(parent);
+    return new NotifierSettingsDialog(parent);
 }
 
 void NotifierFactory::showAbout(QWidget *parent)
 {
-    QMessageBox::about (parent, tr("About Notifier Plugin"),
-                        tr("Qmmp Notifier Plugin")+"\n"+
-                        tr("Written by: Ilya Kotov <forkotov02@ya.ru>"));
+    QMessageBox::about(parent, tr("About Notifier Plugin"),
+                       tr("Qmmp Notifier Plugin") + QChar::LineFeed +
+                       tr("Written by: Ilya Kotov <forkotov02@ya.ru>"));
 }
 
 QString NotifierFactory::translation() const
