@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2018-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2018-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -26,7 +26,7 @@ RDetectSettingsDialog::RDetectSettingsDialog(QWidget *parent)
         : QDialog(parent), m_ui(new Ui::RDetectSettingsDialog)
 {
     m_ui->setupUi(this);
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup("rdetect"_L1);
     m_ui->cdGroupBox->setChecked(settings.value("cda"_L1, true).toBool());
     m_ui->addTracksCheckBox->setChecked(settings.value("add_tracks"_L1, false).toBool());
@@ -44,7 +44,7 @@ RDetectSettingsDialog::~RDetectSettingsDialog()
 
 void RDetectSettingsDialog::accept()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup("rdetect"_L1);
     settings.setValue("cda"_L1, m_ui->cdGroupBox->isChecked());
     settings.setValue("add_tracks"_L1, m_ui->addTracksCheckBox->isChecked());
