@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2013-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2013-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -98,7 +98,7 @@ RGScanDialog::RGScanDialog(QList<PlayListTrack *> tracks,  QWidget *parent) : QD
     m_ui->tableWidget->resizeColumnsToContents();
     m_ui->writeButton->setEnabled(false);
     //read settings
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     restoreGeometry(settings.value(u"RGScanner/geometry"_s).toByteArray());
     m_ui->trackCheckBox->setChecked(settings.value(u"RGScanner/write_track"_s, true).toBool());
     m_ui->albumCheckBox->setChecked(settings.value(u"RGScanner/write_album"_s, true).toBool());
@@ -242,7 +242,7 @@ void RGScanDialog::onScanFinished(const QString &url)
 
 void RGScanDialog::reject()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.setValue(u"RGScanner/geometry"_s, saveGeometry());
     settings.setValue(u"RGScanner/write_track"_s, m_ui->trackCheckBox->isChecked());
     settings.setValue(u"RGScanner/write_album"_s, m_ui->albumCheckBox->isChecked());
@@ -398,11 +398,7 @@ void RGScanDialog::on_writeButton_clicked()
             TagLib::MPEG::File file(qPrintable(item->url));
             writeAPETag(file.APETag(true), item);
             writeID3v2Tag(file.ID3v2Tag(true), item);
-#if ((TAGLIB_MAJOR_VERSION == 1) && (TAGLIB_MINOR_VERSION <= 11))
-            file.save(TagLib::MPEG::File::APE | TagLib::MPEG::File::ID3v2, false);
-#else
             file.save(TagLib::MPEG::File::APE | TagLib::MPEG::File::ID3v2, TagLib::File::StripNone);
-#endif
         }
         else if(ext == "flac"_L1) //flac
         {
