@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2010-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2010-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -89,7 +89,7 @@ Scrobbler::Scrobbler(const QString &scrobblerUrl, const QString &name, QObject *
       m_name(name)
 {
 
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     m_session = settings.value(u"Scrobbler/"_s + name + u"_session"_s).toString();
 
     connect(m_http, &QNetworkAccessManager::finished, this, &Scrobbler::processResponse);
@@ -173,7 +173,7 @@ void Scrobbler::updateMetaData()
     if(!info.value(Qmmp::TITLE).isEmpty() && !info.value(Qmmp::ARTIST).isEmpty())
     {
         m_song = SongInfo(info);
-        m_song.setTimeStamp(QDateTime::currentSecsSinceEpoch());
+        m_song.setTimeStamp(QDateTime::currentDateTime().toSecsSinceEpoch());
         sendNotification(m_song);
     }
     m_time->restart();
