@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -22,14 +22,14 @@
 #include <QMessageBox>
 #include <qmmp/qmmp.h>
 #include "scrobblerhandler.h"
-#include "settingsdialog.h"
+#include "scrobblersettingsdialog.h"
 #include "scrobblerfactory.h"
 
 GeneralProperties ScrobblerFactory::properties() const
 {
     GeneralProperties properties;
     properties.name = tr("Scrobbler Plugin");
-    properties.shortName = "scrobbler";
+    properties.shortName = "scrobbler"_L1;
     properties.hasAbout = true;
     properties.hasSettings = true;
     properties.visibilityControl = false;
@@ -41,16 +41,16 @@ QObject *ScrobblerFactory::create(QObject *parent)
     return new ScrobblerHandler(parent);
 }
 
-QDialog *ScrobblerFactory::createConfigDialog(QWidget *parent)
+QDialog *ScrobblerFactory::createSettings(QWidget *parent)
 {
-    return new SettingsDialog(parent);
+    return new ScrobblerSettingsDialog(parent);
 }
 
 void ScrobblerFactory::showAbout(QWidget *parent)
 {
-    QMessageBox::about (parent, tr("About Scrobbler Plugin"),
-                        tr("Qmmp AudioScrobbler Plugin")+"\n"+
-                        tr("Written by: Ilya Kotov <forkotov02@ya.ru>"));
+    QMessageBox::about(parent, tr("About Scrobbler Plugin"),
+                       tr("Qmmp AudioScrobbler Plugin") + QChar::LineFeed +
+                       tr("Written by: Ilya Kotov <forkotov02@ya.ru>"));
 }
 
 QString ScrobblerFactory::translation() const
