@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -25,7 +25,7 @@
 
 ScrobblerHandler::ScrobblerHandler(QObject *parent) : QObject(parent)
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(u"Scrobbler"_s);
     if(settings.value(u"use_lastfm"_s, false).toBool())
         new Scrobbler(SCROBBLER_LASTFM_URL, u"lastfm"_s, this);
