@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -36,11 +36,6 @@ QmmpTrayIcon::QmmpTrayIcon(QObject *parent)
         : QSystemTrayIcon(parent)
 {}
 
-
-QmmpTrayIcon::~QmmpTrayIcon()
-{
-}
-
 void QmmpTrayIcon::setToolTip(const QString &tip)
 {
 #ifdef QMMP_WS_X11
@@ -83,12 +78,12 @@ bool QmmpTrayIcon::hasToolTipEvent()
     //checking for XEmbed system tray implementation
     //only this implementation is able to send QHelpEvent
     const QWindowList windowList = qApp->allWindows();
-    return std::any_of(windowList.cbegin(), windowList.cend(), [](QWindow *w){ return w->objectName() == "QSystemTrayIconSysWindow"; });
+    return std::any_of(windowList.cbegin(), windowList.cend(), [](QWindow *w){ return w->objectName() == u"QSystemTrayIconSysWindow"_s; });
 }
 
 void QmmpTrayIcon::wheelEvent(QWheelEvent *e)
 {
-    SoundCore::instance()->changeVolume(e->delta()/20);
+    SoundCore::instance()->changeVolume(e->angleDelta().y() / 20);
 }
 
 void QmmpTrayIcon::showToolTip()
