@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -37,9 +37,9 @@ class QmmpTrayIcon : public QSystemTrayIcon
 Q_OBJECT
 public:
     QmmpTrayIcon(QObject *parent = nullptr);
-    ~QmmpTrayIcon();
+    ~QmmpTrayIcon() = default;
 
-     void setToolTip(const QString &tip);
+    void setToolTip(const QString &tip);
 
 #ifdef QMMP_WS_X11
 private:
