@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -40,7 +40,7 @@ StatusIcon::StatusIcon(QObject *parent) : QObject(parent)
     //m_tray->show();
     m_core = SoundCore::instance();
     m_player = MediaPlayer::instance();
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(u"Tray"_s);
     m_showMessage = settings.value(u"show_message"_s, false).toBool();
     m_messageDelay = settings.value(u"message_delay"_s, 2000).toInt();
