@@ -2,7 +2,7 @@
  *   Copyright (C) 2009 by Artur Guzik                                     *
  *   a.guzik88@gmail.com                                                   *
  *                                                                         *
- *   Copyright (C) 2009-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -74,7 +74,7 @@ StatusIconPopupWidget::StatusIconPopupWidget(QWidget * parent)
     connect(m_timer, &QTimer::timeout, this, &StatusIconPopupWidget::deleteLater);
     connect(SoundCore::instance(), &SoundCore::elapsedChanged, this, &StatusIconPopupWidget::updateTime);
 
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(u"Tray"_s);
     m_timer->setInterval(settings.value(u"tooltip_delay"_s, 2000).toInt());
     setWindowOpacity(1.0 - settings.value(u"tooltip_transparency"_s, 0).toInt() / 100.0);
