@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2018-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2018-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -22,7 +22,7 @@
 #define EDITSTREAMDIALOG_H
 
 #include <QDialog>
-#include <QMap>
+#include <QHash>
 
 namespace Ui {
 class EditStreamDialog;
@@ -45,18 +45,18 @@ public:
         TYPE
     };
 
+    void setValues(const QHash<Key, QString> &values);
+    QHash<Key, QString> values() const;
+
 public slots:
     void accept() override;
 
-    void setValues(const QMap<Key, QString> &values);
-    const QMap<Key, QString> &values() const;
-
 private slots:
     void validate();
 
 private:
     Ui::EditStreamDialog *m_ui;
-    QMap<Key, QString> m_values;
+    QHash<Key, QString> m_values;
 };
 
 #endif // EDITSTREAMDIALOG_H
