@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2012 by Ilya Kotov                                      *
+ *   Copyright (C) 2012-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -36,8 +36,7 @@ class StreamBrowser : public QObject
 Q_OBJECT
 public:
     StreamBrowser(QObject *parent = nullptr);
-
-    ~StreamBrowser();
+    ~StreamBrowser() = default;
 
 private slots:
     void showStreamWindow();
