@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2012-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2012-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -98,7 +98,7 @@ StreamWindow::StreamWindow(QWidget *parent)
     }
     connect(m_http, &QNetworkAccessManager::finished, this, &StreamWindow::showText);
     //read settings
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(u"StreamBrowser"_s);
     restoreGeometry(settings.value(u"geometry"_s).toByteArray());
     m_ui->icecastTableView->horizontalHeader()->restoreState(settings.value(u"icecast_headers"_s).toByteArray());
@@ -132,8 +132,13 @@ StreamWindow::StreamWindow(QWidget *parent)
     m_editAction = m_favoritesMenu->addAction(QIcon::fromTheme(u"document-properties"_s), tr("&Edit"),
                                               this, &StreamWindow::editStream);
     m_favoritesMenu->addSeparator();
+#if QT_VERSION < QT_VERSION_CHECK(6, 3, 0)
     m_removeAction = m_favoritesMenu->addAction(QIcon::fromTheme(u"edit-delete"_s), tr("&Remove"),
                                                 this, &StreamWindow::removeFromFavorites, QKeySequence::Delete);
+#else
+    m_removeAction = m_favoritesMenu->addAction(QIcon::fromTheme(u"edit-delete"_s), tr("&Remove"), QKeySequence::Delete,
+                                                this, &StreamWindow::removeFromFavorites);
+#endif
     addActions(m_favoritesMenu->actions());
 }
 
@@ -164,7 +169,7 @@ void StreamWindow::showText(QNetworkReply *reply)
 void StreamWindow::on_updatePushButton_clicked()
 {
     QNetworkRequest request;
-    request.setUrl(QUrl(u"https://dir.xiph.org/yp.xml"_s));
+    request.setUrl(QUrl(u"http://dir.xiph.org/yp.xml"_s));
     request.setRawHeader("User-Agent", QStringLiteral("qmmp/%1").arg(Qmmp::strVersion()).toLatin1());
     m_requestReply = m_http->get(request);
     m_ui->statusLabel->setText(tr("Receiving"));
@@ -321,7 +326,7 @@ void StreamWindow::removeFromFavorites()
 
 void StreamWindow::closeEvent(QCloseEvent *)
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(u"StreamBrowser"_s);
     settings.setValue(u"geometry"_s, saveGeometry());
     settings.setValue(u"icecast_headers"_s, m_ui->icecastTableView->horizontalHeader()->saveState());
@@ -331,8 +336,7 @@ void StreamWindow::closeEvent(QCloseEvent *)
 
      //save icecast directory
     QFile file(Qmmp::configDir() + u"/streambrowser/icecast.xml"_s);
-    if(!file.open(QIODevice::WriteOnly))
-        return;
+    file.open(QIODevice::WriteOnly);
     QXmlStreamWriter writer(&file);
     writer.setAutoFormatting(true);
     writer.writeStartDocument();
@@ -352,8 +356,7 @@ void StreamWindow::closeEvent(QCloseEvent *)
     file.close();
     //save favorites
     QFile file2(Qmmp::configDir() + u"/streambrowser/favorites.xml"_s);
-    if(!file2.open(QIODevice::WriteOnly))
-        return;
+    file2.open(QIODevice::WriteOnly);
     QXmlStreamWriter writer2(&file2);
     writer2.setAutoFormatting(true);
     writer2.writeStartDocument();
