@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2013-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2013-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -34,7 +34,7 @@ TrackChangeSettingsDialog::TrackChangeSettingsDialog(QWidget *parent) : QDialog(
     addMenu(m_ui->endOfPlayListButton);
     addMenu(m_ui->titleChangeButton);
 
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(u"TrackChange"_s);
     m_ui->newTrackLineEdit->setText(settings.value(u"new_track_command"_s).toString());
     m_ui->endOfTrackLineEdit->setText(settings.value(u"end_of_track_command"_s).toString());
@@ -52,7 +52,7 @@ TrackChangeSettingsDialog::~TrackChangeSettingsDialog()
 
 void TrackChangeSettingsDialog::accept()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(u"TrackChange"_s);
     settings.setValue(u"new_track_command"_s, m_ui->newTrackLineEdit->text());
     settings.setValue(u"end_of_track_command"_s,  m_ui->endOfTrackLineEdit->text());
