@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2013-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2013-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -41,7 +41,7 @@ UDisksPlugin::UDisksPlugin(QObject *parent) : QObject(parent)
     connect(m_manager, &UDisksManager::deviceRemoved, this, &UDisksPlugin::removeDevice);
     connect(m_actions, &QActionGroup::triggered, this, &UDisksPlugin::processAction);
     //load settings
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(u"UDisks"_s);
     m_detectCDA = settings.value(u"cda"_s, true).toBool();
     m_detectRemovable = settings.value(u"removable"_s, true).toBool();
