@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2013-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2013-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -26,7 +26,7 @@ UDisksSettingsDialog::UDisksSettingsDialog(QWidget *parent)
         : QDialog(parent), m_ui(new Ui::UDisksSettingsDialog)
 {
     m_ui->setupUi(this);
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(u"UDisks"_s);
     m_ui->cdGroupBox->setChecked(settings.value(u"cda"_s, true).toBool());
     m_ui->addTracksCheckBox->setChecked(settings.value(u"add_tracks"_s, false).toBool());
@@ -45,7 +45,7 @@ UDisksSettingsDialog::~UDisksSettingsDialog()
 
 void UDisksSettingsDialog::accept()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(u"UDisks"_s);
     settings.setValue(u"cda"_s, m_ui->cdGroupBox->isChecked());
     settings.setValue(u"add_tracks"_s, m_ui->addTracksCheckBox->isChecked());
