@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -45,7 +45,7 @@ AACFile::AACFile(QIODevice *input, bool metaData, bool adts) : m_input(input)
         {
             if(header.tagSize() >= buf_at)
             {
-                qWarning("AACFile: unable to parse id3v2");
+                qCWarning(plugin, "unable to parse id3v2");
                 return;
             }
 
@@ -77,46 +77,60 @@ AACFile::AACFile(QIODevice *input, bool metaData, bool adts) : m_input(input)
 
     while(adts_offset < buf_at - 6)
     {
-        //try to determnate header type;
-        if ((uchar) buf[adts_offset] == 0xff && (((uchar)buf[adts_offset+1] & 0xf6) == 0xf0))
-        {
-            unsigned int frame_length = uchar(buf[adts_offset + 3]) << 11;
-            frame_length |= uchar(buf[adts_offset + 4]) << 3;
-            frame_length |= uchar(buf[adts_offset + 5]) >> 5;
-            frame_length &= 0x1FFF;
+        int adts_pos = adts_offset;
+        int adts_frames = 0;
 
-            if(frame_length == 0 || (adts_offset + frame_length > buf_at - 6))
+        while(adts_pos < buf_at - 6)
+        {
+            //try to determnate header type;
+            if ((uchar) buf[adts_pos] == 0xff && (((uchar)buf[adts_pos + 1] & 0xf6) == 0xf0))
             {
-                adts_offset++;
+                unsigned int frame_length = uchar(buf[adts_pos + 3]) << 11;
+                frame_length |= uchar(buf[adts_pos + 4]) << 3;
+                frame_length |= uchar(buf[adts_pos + 5]) >> 5;
+                frame_length &= 0x1FFF;
+
+                if(frame_length < 7)
+                {
+                    adts_frames = 0;
+                    break;
+                }
+
+                adts_pos += frame_length;
+                adts_frames++;
                 continue;
             }
 
-            //check second sync word
-            if (((uchar)buf[adts_offset + frame_length] == 0xFF) &&
-                    (((uchar)buf[adts_offset + frame_length + 1] & 0xF6) == 0xF0))
-            {
-                qDebug("AACFile: ADTS header found");
-                if (!input->isSequential() && adts)
-                    parseADTS();
-                m_isValid = true;
-                m_offset += adts_offset;
-                return;
-            }
+            adts_frames = 0;
+            break;
         }
+
+        if(adts_frames > 1)
+        {
+            qCDebug(plugin, "ADTS header found");
+
+            if (!input->isSequential() && adts)
+                parseADTS();
+            m_isValid = true;
+            m_offset += adts_offset;
+            qCDebug(plugin, "ok");
+            return;
+        }
+
         adts_offset++;
     }
 
-    if (memcmp(buf, "ADIF", 4) == 0)
+    if(memcmp(buf, "ADIF", 4) == 0)
     {
-        qDebug("AACFile: ADIF header found");
+        qCDebug(plugin, "ADIF header found");
         int skip_size = (buf[4] & 0x80) ? 9 : 0;
-        m_bitrate = ((buf[4 + skip_size] & 0x0F)<<19) |
-                (buf[5 + skip_size]<<11) |
-                (buf[6 + skip_size]<<3) |
+        m_bitrate = ((buf[4 + skip_size] & 0x0F) << 19) |
+                (buf[5 + skip_size] << 11) |
+                (buf[6 + skip_size] << 3) |
                 (buf[7 + skip_size] & 0xE0);
 
         if (!input->isSequential ())
-            m_duration = (qint64) (((float)input->size()*8000.f)/((float)m_bitrate) + 0.5f);
+            m_duration = (qint64)(((float)input->size() * 8000.f) / ((float)m_bitrate) + 0.5f);
         else
             m_duration = 0;
         m_bitrate = (int)((float)m_bitrate/1000.0f + 0.5f);
@@ -124,9 +138,6 @@ AACFile::AACFile(QIODevice *input, bool metaData, bool adts) : m_input(input)
     }
 }
 
-AACFile::~AACFile()
-{}
-
 qint64 AACFile::duration() const
 {
     return m_duration;
@@ -183,7 +194,7 @@ void AACFile::parseADTS()
     /* Read all frames to ensure correct time and bitrate */
     for (frames = 0; /* */; frames++)
     {
-        //qDebug("frame header = %d", buf[0]);
+        //qCDebug(plugin, "frame header = %d", buf[0]);
         buf_at += m_input->read((char *)buf + buf_at, FAAD_MIN_STREAMSIZE*MAX_CHANNELS - buf_at);
 
         if (buf_at > 7)
