@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -44,7 +44,7 @@ class AACFile
 public:
     explicit AACFile(QIODevice *input, bool metaData = true, bool adts = true);
 
-    ~AACFile();
+    ~AACFile() = default;
 
     qint64 duration() const;
     quint32 bitrate() const;
