@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -35,15 +35,15 @@ DecoderAAC::DecoderAAC(QIODevice *i) : Decoder(i)
 
 DecoderAAC::~DecoderAAC()
 {
-    if (data())
+    if(data())
     {
-        if (data()->handle)
+        if(data()->handle)
             NeAACDecClose (data()->handle);
         delete data();
         m_data = nullptr;
     }
-    if (m_input_buf)
-        delete [] m_input_buf;
+
+    delete [] m_input_buf;
     m_input_buf = nullptr;
     m_bitrate = 0;
 }
@@ -53,35 +53,36 @@ bool DecoderAAC::initialize()
     m_bitrate = 0;
     m_totalTime = 0;
 
-    if (!input())
+    if(!input())
     {
-        qWarning("DecoderAAC: cannot initialize.  No input.");
+        qCWarning(plugin, "cannot initialize.  No input.");
         return false;
     }
-    if (!m_input_buf)
+    if(!m_input_buf)
         m_input_buf = new char[AAC_BUFFER_SIZE];
     m_input_at = 0;
 
     AACFile aac_file(input());
-    if (!aac_file.isValid())
+    if(!aac_file.isValid())
     {
-        qWarning("DecoderAAC: unsupported AAC file");
+        qCWarning(plugin, "unsupported AAC file");
         return false;
     }
 
     //skip id3 tag and partial frame
     if(aac_file.offset() > 0)
     {
-        qDebug("DecoderAAC: header offset = %d bytes", aac_file.offset());
+        qCDebug(plugin, "header offset = %d bytes", aac_file.offset());
 
-        char data[aac_file.offset()];
+        char *data = new char[aac_file.offset()];
         input()->read(data, aac_file.offset());
+        delete [] data;
     }
 
     m_totalTime = aac_file.duration();
     m_bitrate = aac_file.bitrate();
 
-    if (!m_data)
+    if(!m_data)
         m_data = new aac_data;
 
     data()->handle = NeAACDecOpen();
@@ -96,32 +97,26 @@ bool DecoderAAC::initialize()
     NeAACDecSetConfiguration(data()->handle, conf);
 
     m_input_at = input()->read((char *)m_input_buf, AAC_BUFFER_SIZE);
-
-#ifdef FAAD_MODIFIED
-    uint32_t freq = 0;
-    uint8_t chan = 0;
-#else
     unsigned long freq = 0;
     unsigned char chan = 0;
-#endif
-    int res = NeAACDecInit (data()->handle, (unsigned char*) m_input_buf, m_input_at, &freq, &chan);
+    int res = NeAACDecInit(data()->handle, (unsigned char*) m_input_buf, m_input_at, &freq, &chan);
 
-    if (res < 0)
+    if(res < 0)
     {
-        qWarning("DecoderAAC: NeAACDecInit() failed");
+        qCWarning(plugin, "NeAACDecInit() failed");
         return false;
     }
-    if (!freq || !chan)
+    if(!freq || !chan)
     {
-        qWarning("DecoderAAC: invalid sound parameters");
+        qCWarning(plugin, "invalid sound parameters");
         return false;
     }
 
     memmove(m_input_buf, m_input_buf + res, m_input_at - res);
     m_input_at -= res;
-    setProperty(Qmmp::FORMAT_NAME, "AAC");
+    setProperty(Qmmp::FORMAT_NAME, u"AAC"_s);
     configure(freq, chan, Qmmp::PCM_S16LE);
-    qDebug("DecoderAAC: initialize succes");
+    qCDebug(plugin, "initialize succes");
     return true;
 }
 
@@ -134,7 +129,7 @@ qint64 DecoderAAC::read(unsigned char *audio, qint64 maxSize)
     while(m_sample_buf_size <= 0 && !eof)
     {
         m_sample_buf_at = 0;
-        if (m_input_at < AAC_BUFFER_SIZE)
+        if(m_input_at < AAC_BUFFER_SIZE)
         {
             to_read = AAC_BUFFER_SIZE - m_input_at;
             read = input()->read((char *) (m_input_buf + m_input_at),  to_read);
@@ -153,10 +148,11 @@ qint64 DecoderAAC::read(unsigned char *audio, qint64 maxSize)
 
         if(eof && frame_info.error > 0) //ignore error on end of file
             return 0;
-        else if (frame_info.error > 0)
+
+        if(frame_info.error > 0)
         {
             m_input_at = 0;
-            qDebug("DecoderAAC: %s", NeAACDecGetErrorMessage(frame_info.error));
+            qCDebug(plugin) << NeAACDecGetErrorMessage(frame_info.error);
             return -1;
         }
         if(frame_info.samples > 0)
