@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2016-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2016-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -19,14 +19,17 @@
  ***************************************************************************/
 
 #include <QRegularExpression>
+#include <qmmp/qmmp.h>
 #include "archiveinputdevice.h"
 
+using namespace Qt::Literals::StringLiterals;
+
 ArchiveInputDevice::ArchiveInputDevice(const QString &url, QObject *parent)  : QIODevice(parent)
 {
-    QString filePath = url.section("#", -1);
+    QString filePath = url.section(QLatin1Char('#'), -1);
     QString archivePath = url;
-    archivePath.remove(QRegularExpression("^.+://"));
-    archivePath.remove(QRegularExpression("#.+$"));
+    archivePath.remove(QRegularExpression(u"^.+://"_s));
+    archivePath.remove(QRegularExpression(u"#.+$"_s));
 
     m_archive = archive_read_new();
     archive_read_support_filter_all(m_archive);
@@ -35,7 +38,7 @@ ArchiveInputDevice::ArchiveInputDevice(const QString &url, QObject *parent)  : Q
     int r = archive_read_open_filename(m_archive, archivePath.toLocal8Bit().constData(), 10240);
     if (r != ARCHIVE_OK)
     {
-        qWarning("ArchiveInputDevice: unable to open file '%s', libarchive error: %s",
+        qCWarning(plugin, "unable to open file '%s', libarchive error: %s",
                  qPrintable(archivePath), archive_error_string(m_archive));
         return;
     }
@@ -43,8 +46,8 @@ ArchiveInputDevice::ArchiveInputDevice(const QString &url, QObject *parent)  : Q
     while (archive_read_next_header(m_archive, &m_entry) == ARCHIVE_OK)
     {
         QString pathName = QString::fromLocal8Bit(archive_entry_pathname(m_entry));
-        if(!pathName.startsWith("/"))
-            pathName.prepend("/");
+        if(!pathName.startsWith(QLatin1Char('/')))
+            pathName.prepend(QLatin1Char('/'));
 
         if(archive_entry_filetype(m_entry) == AE_IFREG && filePath == pathName)
         {
@@ -96,9 +99,10 @@ bool ArchiveInputDevice::seek(qint64 pos)
                 delta -= r;
                 continue;
             }
-            else if(r < 0)
+
+            if(r < 0)
             {
-                qWarning("ArchiveInputDevice: seeking failed; libarchive error: %s", archive_error_string(m_archive));
+                qCWarning(plugin, "seeking failed; libarchive error: %s", archive_error_string(m_archive));
                 setErrorString(QString::fromLocal8Bit(archive_error_string(m_archive)));
                 close();
             }
@@ -122,16 +126,18 @@ qint64 ArchiveInputDevice::readData(char *data, qint64 maxSize)
     if(m_buffer.pos() + maxSize > m_buffer.size())
     {
         qint64 l = m_buffer.pos() + maxSize - m_buffer.size();
-        char tmp[l];
+        char *tmp = new char[l];
         int r = archive_read_data(m_archive, tmp, l);
         if(r > 0)
             m_buffer.buffer().append(tmp, r);
         else if(r < 0)
         {
-            qWarning("ArchiveInputDevice: reading failed; libarchive error: %s", archive_error_string(m_archive));
+            qCWarning(plugin, "reading failed; libarchive error: %s", archive_error_string(m_archive));
             setErrorString(QString::fromLocal8Bit(archive_error_string(m_archive)));
+            delete [] tmp;
             return -1;
         }
+        delete [] tmp;
     }
     return m_buffer.read(data, maxSize);
 }
