@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2016-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2016-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -26,9 +26,9 @@ class IODeviceStream : public TagLib::IOStream
 public:
     IODeviceStream(QIODevice *input, const QString &url) : m_input(input),
 #ifdef Q_OS_WIN
-          m_fileName(url.section("/", -1))
+          m_fileName(url.section(QLatin1Char('/'), -1))
 #else
-          m_fileName(url.section("/", -1).toLocal8Bit())
+          m_fileName(url.section(QLatin1Char('/'), -1).toLocal8Bit())
 #endif
     {}
 
@@ -48,14 +48,15 @@ public:
     virtual TagLib::ByteVector readBlock(unsigned long length) override
 #endif
     {
-        char data[length];
-        qint64 l = m_input->read(data, length);
+        TagLib::ByteVector data(length, 0);
+        qint64 l = m_input->read(data.data(), length);
         if(l < 0)
         {
             m_input->close();
             return TagLib::ByteVector();
         }
-        return TagLib::ByteVector(data, l);
+        data.resize(l);
+        return data;
     }
     virtual void writeBlock(const TagLib::ByteVector &) override
     {}
