@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2016-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2016-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -44,14 +44,14 @@ DecoderArchive::~DecoderArchive()
 
 bool DecoderArchive::initialize()
 {
-    QString filePath = m_url.section("#", -1);
+    QString filePath = m_url.section(QLatin1Char('#'), -1);
     QString archivePath = m_url;
-    archivePath.remove(QRegularExpression("^.+://"));
-    archivePath.remove(QRegularExpression("#.+$"));
+    archivePath.remove(QRegularExpression(u"^.+://"_s));
+    archivePath.remove(QRegularExpression(u"#.+$"_s));
 
     if(!QFile::exists(archivePath))
     {
-        qWarning("DecoderArchive: file '%s' not found", qPrintable(archivePath));
+        qCWarning(plugin, "file '%s' not found", qPrintable(archivePath));
         return false;
     }
 
@@ -65,7 +65,7 @@ bool DecoderArchive::initialize()
 
     if(filtered.isEmpty())
     {
-        qWarning("DecoderArchive: unable to find decoder");
+        qCWarning(plugin, "unable to find decoder");
         return false;
     }
 
@@ -73,17 +73,17 @@ bool DecoderArchive::initialize()
 
     if(!m_input->isOpen())
     {
-        qWarning("DecoderArchive: unable to open archive");
+        qCWarning(plugin, "unable to open archive");
         return false;
     }
 
     DecoderFactory *factory = nullptr;
     if(filtered.size() == 1)
-        factory = filtered.first();
+        factory = filtered.constFirst();
     else
     {
         //multiple factories, so trying to determine by content
-        for(DecoderFactory *fact : qAsConst(filtered))
+        for(DecoderFactory *fact : std::as_const(filtered))
         {
             if(fact->canDecode(m_input))
             {
@@ -95,11 +95,11 @@ bool DecoderArchive::initialize()
 
     if(!factory)
     {
-        qWarning("DecoderArchive: unable to find decoder factory");
+        qCWarning(plugin, "unable to find decoder factory");
         return false;
     }
 
-    qDebug("DecoderArchive: selected decoder: %s", qPrintable(factory->properties().shortName));
+    qCDebug(plugin, "selected decoder: %s", qPrintable(factory->properties().shortName));
 
     ArchiveTagReader reader(m_input, m_url);
     addMetaData(reader.metaData());
@@ -108,7 +108,7 @@ bool DecoderArchive::initialize()
     m_decoder = factory->create(m_url, m_input);
     if(!m_decoder->initialize())
     {
-        qWarning("DecoderArchive: unable to initialize decoder");
+        qCWarning(plugin, "unable to initialize decoder");
         return false;
     }
     configure(m_decoder->audioParameters());
