@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -28,7 +28,7 @@ CDAudioSettingsDialog::CDAudioSettingsDialog(QWidget *parent)
         : QDialog(parent), m_ui(new Ui::CDAudioSettingsDialog)
 {
     m_ui->setupUi(this);
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(u"cdaudio"_s);
     m_ui->deviceLineEdit->setText(settings.value(u"device"_s).toString());
     m_ui->deviceCheckBox->setChecked(!m_ui->deviceLineEdit->text().isEmpty());
@@ -56,7 +56,7 @@ CDAudioSettingsDialog::~CDAudioSettingsDialog()
 
 void CDAudioSettingsDialog::accept()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(u"cdaudio"_s);
     if(m_ui->deviceCheckBox->isChecked())
         settings.setValue(u"device"_s, m_ui->deviceLineEdit->text());
