@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -97,7 +97,7 @@ DecoderCDAudio::~DecoderCDAudio()
 QList<CDATrack> DecoderCDAudio::generateTrackList(const QString &device, TrackInfo::Parts parts)
 {
     //read settings
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     int cd_speed = settings.value(u"cdaudio/speed"_s, 0).toInt();
     bool use_cd_text = settings.value(u"cdaudio/cdtext"_s, true).toBool();
     QList<CDATrack> tracks;
@@ -402,7 +402,7 @@ bool DecoderCDAudio::initialize()
 
     if (device_path.isEmpty() || device_path == "/"_L1) //try default path from config
     {
-        QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+        QSettings settings;
         device_path = settings.value("cdaudio/device"_L1).toString();
         m_url = QStringLiteral("cdda://%1#%2").arg(device_path).arg(track_number);
     }
