@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -33,7 +33,7 @@
 
 DecoderCDAudioFactory::DecoderCDAudioFactory()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     if(settings.value("cdaudio/cddb_server"_L1).toByteArray() == "freedb.org")
     {
         qCDebug(plugin, "switching to gnudb.org");
