@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -23,9 +23,9 @@
 #include <QDirIterator>
 #include <QSettings>
 #include <QTextStream>
-#include <QTextCodec>
 #include <qmmp/decoder.h>
 #include <qmmp/metadatamanager.h>
+#include <qmmp/qmmptextcodec.h>
 #ifdef WITH_ENCA
 #include <enca.h>
 #endif
@@ -44,10 +44,10 @@ CueFile::CueFile(const QString &path) : CueParser()
     QByteArray data = file.readAll();
     file.close();
 
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(u"CUE"_s);
     m_dirty = settings.value(u"dirty_cue"_s, false).toBool();
-    QTextCodec *codec = nullptr;
+    QmmpTextCodec *codec = nullptr;
 #ifdef WITH_ENCA
     EncaAnalyser analyser = nullptr;
     if(settings.value(u"use_enca"_s, false).toBool())
@@ -60,7 +60,7 @@ CueFile::CueFile(const QString &path) : CueParser()
             EncaEncoding encoding = enca_analyse(analyser, (uchar *)data.constData(), data.size());
             if(encoding.charset != ENCA_CS_UNKNOWN)
             {
-                codec = QTextCodec::codecForName(enca_charset_name(encoding.charset,ENCA_NAME_STYLE_ENCA));
+                codec = new QmmpTextCodec(enca_charset_name(encoding.charset,ENCA_NAME_STYLE_ENCA));
                 //qCDebug(plugin, "detected charset: %s",
                 //       enca_charset_name(encoding.charset,ENCA_NAME_STYLE_ENCA));
             }
@@ -69,12 +69,11 @@ CueFile::CueFile(const QString &path) : CueParser()
     }
 #endif
     if(!codec)
-        codec = QTextCodec::codecForName(settings.value(u"encoding"_s, u"UTF-8"_s).toByteArray ());
-    if(!codec)
-        codec = QTextCodec::codecForName("UTF-8");
+        codec = new QmmpTextCodec(settings.value(u"encoding"_s, u"UTF-8"_s).toByteArray ());
     settings.endGroup();
     //qCDebug(plugin, "using %s encoding", codec->name().constData());
     loadData(data, codec);
+    delete codec;
     setUrl(u"cue"_s, m_filePath);
     for(const QString &dataFileName : files())
     {
