@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -24,7 +24,7 @@
 #include <qmmp/metadatamodel.h>
 
 class CueFile;
-class QTextCodec;
+class QmmpTextCodec;
 
 class CUEMetaDataModel : public MetaDataModel
 {
@@ -39,7 +39,7 @@ public:
 
 private:
     QString m_dataFilePath, m_cueFilePath;
-    mutable QTextCodec *m_codec = nullptr;
+    mutable QmmpTextCodec *m_codec = nullptr;
 };
 
 #endif // CUEMETADATAMODEL_H
