@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -19,7 +19,7 @@
  ***************************************************************************/
 #include <QSettings>
 #include <QRegularExpression>
-#include <QTextCodec>
+#include <qmmp/qmmptextcodec.h>
 #include <qmmp/qmmp.h>
 
 #ifdef WITH_ENCA
@@ -33,9 +33,7 @@ CueSettingsDialog::CueSettingsDialog(QWidget *parent)
         : QDialog(parent), m_ui(new Ui::CueSettingsDialog)
 {
     m_ui->setupUi(this);
-    findCodecs();
-    for(const QTextCodec *codec : qAsConst(m_codecs))
-        m_ui->cueEncComboBox->addItem(QString::fromLatin1(codec->name()));
+    m_ui->cueEncComboBox->addItems(QmmpTextCodec::availableCharsets());
 
 #ifdef WITH_ENCA
     size_t n = 0;
@@ -43,7 +41,7 @@ CueSettingsDialog::CueSettingsDialog(QWidget *parent)
     for (size_t i = 0; i < n; ++i)
         m_ui->encaAnalyserComboBox->addItem(QString::fromLatin1(langs[i]));
 #endif
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(u"CUE"_s);
     int pos = m_ui->cueEncComboBox->findText(settings.value(u"encoding"_s, u"UTF-8"_s).toString());
     m_ui->cueEncComboBox->setCurrentIndex(pos);
@@ -65,7 +63,7 @@ CueSettingsDialog::~CueSettingsDialog()
 
 void CueSettingsDialog::accept()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(u"CUE"_s);
     settings.setValue(u"encoding"_s, m_ui->cueEncComboBox->currentText());
 #ifdef WITH_ENCA
@@ -76,42 +74,3 @@ void CueSettingsDialog::accept()
     settings.endGroup();
     QDialog::accept();
 }
-
-void CueSettingsDialog::findCodecs()
-{
-    QMap<QString, QTextCodec *> codecMap;
-    static const QRegularExpression iso8859RegExp(u"ISO[- ]8859-([0-9]+).*"_s);
-
-    for(int mib : QTextCodec::availableMibs())
-    {
-        QTextCodec *codec = QTextCodec::codecForMib(mib);
-
-        QString sortKey = QString::fromLatin1(codec->name().toUpper());
-        int rank;
-        QRegularExpressionMatch match;
-
-        if (sortKey.startsWith(u"UTF-8"_s))
-        {
-            rank = 1;
-        }
-        else if (sortKey.startsWith(u"UTF-16"_s))
-        {
-            rank = 2;
-        }
-        else if ((match = iso8859RegExp.match(sortKey)).hasMatch())
-        {
-            if (match.captured(1).size() == 1)
-                rank = 3;
-            else
-                rank = 4;
-        }
-        else
-        {
-            rank = 5;
-        }
-        sortKey.prepend(QChar('0' + rank));
-
-        codecMap.insert(sortKey, codec);
-    }
-    m_codecs = codecMap.values();
-}
