@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -35,14 +35,11 @@ DecoderCUE::DecoderCUE(const QString &url) : Decoder(),
 
 DecoderCUE::~DecoderCUE()
 {
-    if(m_decoder)
-        delete m_decoder;
+    delete m_decoder;
     m_decoder = nullptr;
-    if(m_cueFile)
-        delete m_cueFile;
+    delete m_cueFile;
     m_cueFile = nullptr;
-    if(m_buf)
-        delete [] m_buf;
+    delete [] m_buf;
     m_buf = nullptr;
     if(m_input)
         m_input->deleteLater();
@@ -54,20 +51,20 @@ bool DecoderCUE::initialize()
     m_cueFile = new CueFile(m_path);
     if (m_cueFile->count() == 0)
     {
-        qWarning("DecoderCUE: invalid cue file");
+        qCWarning(plugin, "invalid cue file");
         return false;
     }
-    m_track = m_path.section("#", -1).toInt();
+    m_track = m_path.section(QLatin1Char('#'), -1).toInt();
     m_path = m_cueFile->dataFilePath(m_track);
     if (!QFile::exists(m_path))
     {
-        qWarning("DecoderCUE: file \"%s\" doesn't exist", qPrintable(m_path));
+        qCWarning(plugin, "file \"%s\" doesn't exist", qPrintable(m_path));
         return false;
     }
     DecoderFactory *df = Decoder::findByFilePath(m_path);
     if (!df)
     {
-        qWarning("DecoderCUE: unsupported file format");
+        qCWarning(plugin, "unsupported file format");
         return false;
     }
     m_length = m_cueFile->duration(m_track);
@@ -77,14 +74,14 @@ bool DecoderCUE::initialize()
         m_input = new QFile(m_path);
         if(!m_input->open(QIODevice::ReadOnly))
         {
-            qWarning("DecoderCUE: error: %s", qPrintable(m_input->errorString()));
+            qCWarning(plugin, "error: %s", qPrintable(m_input->errorString()));
             return false;
         }
     }
     m_decoder = df->create(m_path, m_input);
     if(!m_decoder->initialize())
     {
-        qWarning("DecoderCUE: invalid audio file");
+        qCWarning(plugin, "invalid audio file");
         return false;
     }
     m_decoder->seek(m_offset);
@@ -149,8 +146,7 @@ qint64 DecoderCUE::read(unsigned char *data, qint64 size)
     len2 = (len2 / m_sz) * m_sz; //whole of samples of each channel
     m_totalBytes += len2;
     //save data of the next track
-    if(m_buf)
-        delete[] m_buf;
+    delete[] m_buf;
     m_buf_size = len - len2;
     m_buf = new char[m_buf_size];
     memmove(m_buf, data + len2, m_buf_size);
@@ -166,8 +162,8 @@ const QString DecoderCUE::nextURL() const
 {
     if(m_track +1 <= m_cueFile->count() && m_cueFile->dataFilePath(m_track) == m_cueFile->dataFilePath(m_track + 1))
         return m_cueFile->url(m_track + 1);
-    else
-        return QString();
+
+    return QString();
 }
 
 void DecoderCUE::next()
