@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -18,7 +18,6 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
-#include <QtDebug>
 #include "replaygainreader.h"
 #include "decoder_ffmpeg.h"
 extern "C"{
@@ -35,7 +34,10 @@ static int ffmpeg_read(void *data, uint8_t *buf, int size)
     if(d->input()->atEnd())
         return AVERROR_EOF;
 #endif
-    return static_cast<int>(d->input()->read((char*)buf, size));
+    size = static_cast<int>(d->input()->read((char*)buf, size));
+    if(size < 0)
+        return AVERROR(EPIPE);
+    return size;
 }
 
 static int64_t ffmpeg_seek(void *data, int64_t offset, int whence)
@@ -126,7 +128,7 @@ bool DecoderFFmpeg::initialize()
     pd.buf = buf;
     if(pd.buf_size < PROBE_BUFFER_SIZE)
     {
-        qWarning("DecoderFFmpeg: too small buffer size: %d bytes", pd.buf_size);
+        qCWarning(plugin, "too small buffer size: %d bytes", pd.buf_size);
         return false;
     }
 #if LIBAVFORMAT_VERSION_INT >= AV_VERSION_INT(59, 0, 101)
@@ -136,11 +138,11 @@ bool DecoderFFmpeg::initialize()
 #endif
     if(!fmt)
     {
-        qWarning("DecoderFFmpeg: usupported format");
+        qCWarning(plugin, "usupported format");
         return false;
     }
-    qDebug("DecoderFFmpeg: detected format: %s", fmt->long_name);
-    qDebug("=%s=", fmt->name);
+    qCDebug(plugin, "detected format: %s", fmt->long_name);
+    qCDebug(plugin, "=%s=", fmt->name);
 
 #if (LIBAVCODEC_VERSION_INT >= AV_VERSION_INT(58,10,100)) //ffmpeg-3.5
     m_input_buf = (uchar*)av_malloc(INPUT_BUFFER_SIZE + AV_INPUT_BUFFER_PADDING_SIZE);
@@ -153,7 +155,7 @@ bool DecoderFFmpeg::initialize()
     {
         av_free(m_input_buf);
         m_input_buf = nullptr;
-        qWarning("DecoderFFmpeg: unable to initialize I/O callbacks");
+        qCWarning(plugin, "unable to initialize I/O callbacks");
         return false;
     }
     m_stream->seekable = !input()->isSequential();
@@ -162,7 +164,7 @@ bool DecoderFFmpeg::initialize()
 
     if(avformat_open_input(&m_formatContext, nullptr, fmt, nullptr) != 0)
     {
-        qDebug("DecoderFFmpeg: avformat_open_input() failed");
+        qCDebug(plugin, "avformat_open_input() failed");
         return false;
     }
     avformat_find_stream_info(m_formatContext, nullptr);
@@ -213,9 +215,9 @@ bool DecoderFFmpeg::initialize()
         if(title)
             metaData.insert(Qmmp::TITLE, QString::fromUtf8(title->value).trimmed());
         if(year)
-            metaData.insert(Qmmp::YEAR, year->value);
+            metaData.insert(Qmmp::YEAR, QString::fromLatin1(year->value).trimmed());
         if(track)
-            metaData.insert(Qmmp::TRACK, track->value);
+            metaData.insert(Qmmp::TRACK, QString::fromLatin1(track->value).trimmed());
         addMetaData(metaData);
     }
 
@@ -229,7 +231,7 @@ bool DecoderFFmpeg::initialize()
     m_audioIndex = av_find_best_stream(m_formatContext, AVMEDIA_TYPE_AUDIO, -1, -1, nullptr, 0);
     if(m_audioIndex < 0)
     {
-        qWarning("DecoderFFmpeg: unable to find audio stream");
+        qCWarning(plugin, "unable to find audio stream");
         return false;
     }
 
@@ -265,13 +267,13 @@ bool DecoderFFmpeg::initialize()
 
     if (!codec)
     {
-        qWarning("DecoderFFmpeg: unsupported codec for output stream");
+        qCWarning(plugin, "unsupported codec for output stream");
         return false;
     }
 
     if (avcodec_open2(m_codecContext, codec, nullptr) < 0)
     {
-        qWarning("DecoderFFmpeg: error while opening codec for output stream");
+        qCWarning(plugin, "error while opening codec for output stream");
         return false;
     }
 
@@ -302,7 +304,7 @@ bool DecoderFFmpeg::initialize()
         format = Qmmp::PCM_FLOAT;
         break;
     default:
-        qWarning("DecoderFFmpeg: unsupported audio format");
+        qCWarning(plugin, "unsupported audio format");
         return false;
     }
 
@@ -313,8 +315,8 @@ bool DecoderFFmpeg::initialize()
         m_bitrate = m_formatContext->bit_rate/1000;
     if(m_codecContext->bit_rate)
         m_bitrate = m_codecContext->bit_rate/1000;
-    qDebug("DecoderFFmpeg: initialize succes");
-    qDebug() << "DecoderFFmpeg: total time =" << m_totalTime;
+    qCDebug(plugin, "initialize succes");
+    qCDebug(plugin) << "total time =" << m_totalTime;
 
     return true;
 }
@@ -415,7 +417,7 @@ void DecoderFFmpeg::fillBuffer()
                 {
                     char errbuf[AV_ERROR_MAX_STRING_SIZE] = { 0 };
                     av_strerror(read_error, errbuf, sizeof(errbuf));
-                    qWarning("DecoderFFmpeg: av_read_frame error: %s", errbuf);
+                    qCWarning(plugin, "av_read_frame error: %s", errbuf);
                 }
                 m_eof = true;
             }
@@ -446,13 +448,13 @@ void DecoderFFmpeg::fillBuffer()
             {
                 char errbuf[AV_ERROR_MAX_STRING_SIZE] = { 0 };
                 av_strerror(send_error, errbuf, sizeof(errbuf));
-                qWarning("DecoderFFmpeg: avcodec_send_packet error: %s", errbuf);
+                qCWarning(plugin, "avcodec_send_packet error: %s", errbuf);
                 av_strerror(recv_error, errbuf, sizeof(errbuf));
-                qWarning("DecoderFFmpeg: avcodec_receive_frame error: %s", errbuf);
+                qCWarning(plugin, "avcodec_receive_frame error: %s", errbuf);
             }
             else
             {
-                qDebug("DecoderFFmpeg: finished");
+                qCDebug(plugin, "finished");
             }
             return;
         }
