@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2011-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2011-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -20,7 +20,6 @@
 
 #include <QObject>
 #include <QFile>
-#include <QRegularExpression>
 #include <qmmp/cueparser.h>
 #include "decoder_ffmpeg.h"
 #include "decoder_ffmpegcue.h"
@@ -31,14 +30,11 @@ DecoderFFmpegCue::DecoderFFmpegCue(const QString &url) : Decoder(),
 
 DecoderFFmpegCue::~DecoderFFmpegCue()
 {
-    if(m_decoder)
-        delete m_decoder;
+    delete m_decoder;
     m_decoder = nullptr;
-    if(m_parser)
-        delete m_parser;
+    delete m_parser;
     m_parser = nullptr;
-    if(m_buf)
-        delete [] m_buf;
+    delete [] m_buf;
     m_buf = nullptr;
     if(m_input)
         m_input->deleteLater();
@@ -47,15 +43,12 @@ DecoderFFmpegCue::~DecoderFFmpegCue()
 
 bool DecoderFFmpegCue::initialize()
 {
-    QString filePath = m_url;
-    if(!m_url.startsWith("ffmpeg://"))
+    if(!m_url.startsWith(u"ffmpeg://"_s))
     {
-        qWarning("DecoderFFmpegCue: invalid url.");
+        qCWarning(plugin, "invalid url.");
         return false;
     }
-    filePath.remove("ffmpeg://");
-    filePath.remove(QRegularExpression("#\\d+$"));
-    m_track = m_url.section("#", -1).toInt();
+    QString filePath = TrackInfo::pathFromUrl(m_url, &m_track);
 
     AVFormatContext *in = nullptr;
 #ifdef Q_OS_WIN
@@ -64,7 +57,7 @@ bool DecoderFFmpegCue::initialize()
     if(avformat_open_input(&in, filePath.toLocal8Bit().constData(), nullptr, nullptr) < 0)
 #endif
     {
-        qDebug("DecoderFFmpegCue: unable to open file");
+        qCDebug(plugin, "unable to open file");
         return false;
     }
 
@@ -73,25 +66,25 @@ bool DecoderFFmpegCue::initialize()
     if(!cuesheet)
     {
         avformat_close_input(&in);
-        qWarning("DecoderFFmpegCue: unable to find cuesheet comment.");
+        qCWarning(plugin, "unable to find cuesheet comment.");
         return false;
     }
 
     m_parser = new CueParser(cuesheet->value);
     m_parser->setDuration(in->duration * 1000 / AV_TIME_BASE);
-    m_parser->setUrl("ffmpeg", filePath);
+    m_parser->setUrl(u"ffmpeg"_s, filePath);
 
     avformat_close_input(&in);
 
     if(m_track > m_parser->count() || m_parser->isEmpty())
     {
-        qWarning("DecoderFFmpegCue: invalid cuesheet");
+        qCWarning(plugin, "invalid cuesheet");
         return false;
     }
     m_input = new QFile(filePath);
     if(!m_input->open(QIODevice::ReadOnly))
     {
-        qWarning("DecoderFFmpegCue: unable to open file; error: %s", qPrintable(m_input->errorString()));
+        qCWarning(plugin, "unable to open file; error: %s", qPrintable(m_input->errorString()));
         return false;
     }
 
@@ -101,7 +94,7 @@ bool DecoderFFmpegCue::initialize()
     m_decoder = new DecoderFFmpeg(filePath, m_input);
     if(!m_decoder->initialize())
     {
-        qWarning("DecoderFFapCUE: invalid audio file");
+        qCWarning(plugin, "DecoderFFapCUE: invalid audio file");
         return false;
     }
     m_decoder->seek(m_offset);
@@ -168,8 +161,7 @@ qint64 DecoderFFmpegCue::read(unsigned char *data, qint64 size)
     len2 = (len2 / m_frameSize) * m_frameSize; //integer number of samples
     m_written += len2;
     //save data of the next track
-    if(m_buf)
-        delete[] m_buf;
+    delete[] m_buf;
     m_bufSize = len - len2;
     m_buf = new char[m_bufSize];
     memmove(m_buf, data + len2, m_bufSize);
@@ -185,8 +177,8 @@ const QString DecoderFFmpegCue::nextURL() const
 {
     if(m_track +1 <= m_parser->count())
         return m_parser->url(m_track + 1);
-    else
-        return QString();
+
+    return QString();
 }
 
 void DecoderFFmpegCue::next()
