@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -72,7 +72,7 @@ bool DecoderFFmpegFactory::canDecode(QIODevice *i) const
         return true;
     if(filters.contains(u"*.aac"_s) && formats.contains(u"aac"_s))
         return true;
-    if(filters.contains(u"*.ac3"_s) && (formats.contains(u"ac3"_s) || formats.contains(u"eac3"_s)))
+    if(filters.contains(u"*.ac3"_s) && formats.contains(u"eac3"_s))
         return true;
     if(filters.contains(u"*.dts"_s) && formats.contains(u"dts"_s))
         return true;
@@ -95,10 +95,10 @@ bool DecoderFFmpegFactory::canDecode(QIODevice *i) const
 
 DecoderProperties DecoderFFmpegFactory::properties() const
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     QSet<QString> filters = {
         u"*.wma"_s, u"*.ape"_s, u"*.tta"_s, u"*.m4a"_s, u"*.m4b"_s, u"*.aac"_s, u"*.mp3"_s, u"*.ra"_s, u"*.shn"_s,
-        u"*.ac3"_s, u"*.dts"_s, u"*.mka"_s,  u"*.vqf"_s, u"*.tak"_s, u"*.dsf"_s, u"*.dsdiff"_s
+        u"*.vqf"_s, u"*.ac3"_s, u"*.tak"_s, u"*.dsf"_s, u"*.dsdiff"_s, u"*.mka"_s
     };
     const QStringList disabledFilters = settings.value(u"FFMPEG/disabled_filters"_s, { u"*.mp3"_s }).toStringList();
 
@@ -124,7 +124,7 @@ DecoderProperties DecoderFFmpegFactory::properties() const
         filters.remove(u"*.ra"_s);
     if(!avcodec_find_decoder(AV_CODEC_ID_SHORTEN))
         filters.remove(u"*.shn"_s);
-    if(!avcodec_find_decoder(AV_CODEC_ID_AC3) && !avcodec_find_decoder(AV_CODEC_ID_EAC3))
+    if(!avcodec_find_decoder(AV_CODEC_ID_EAC3))
         filters.remove(u"*.ac3"_s);
     if(!avcodec_find_decoder(AV_CODEC_ID_DTS))
         filters.remove(u"*.dts"_s);
@@ -142,11 +142,7 @@ DecoderProperties DecoderFFmpegFactory::properties() const
 
     DecoderProperties properties;
     properties.name = tr("FFmpeg Plugin");
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 15, 0))
     properties.filters = QStringList(filters.cbegin(), filters.cend());
-#else
-    properties.filters = filters.toList();
-#endif
     properties.description = tr("FFmpeg Formats");
     if(filters.contains(u"*.wma"_s))
         properties.contentTypes << u"audio/x-ms-wma"_s;
