@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -34,7 +34,7 @@ FFmpegSettingsDialog::FFmpegSettingsDialog(QWidget *parent)
         : QDialog(parent), m_ui(new Ui::FFmpegSettingsDialog)
 {
     m_ui->setupUi(this);
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     QStringList disabledFilters = { u"*.mp3"_s };
     disabledFilters = settings.value(u"FFMPEG/disabled_filters"_s, disabledFilters).toStringList();
 
@@ -54,9 +54,8 @@ FFmpegSettingsDialog::FFmpegSettingsDialog(QWidget *parent)
     m_ui->raCheckBox->setEnabled(avcodec_find_decoder(AV_CODEC_ID_RA_288));
     m_ui->raCheckBox->setChecked(!disabledFilters.contains(u"*.ra"_s) && avcodec_find_decoder(AV_CODEC_ID_RA_288));
     m_ui->shCheckBox->setChecked(!disabledFilters.contains(u"*.shn"_s) && avcodec_find_decoder(AV_CODEC_ID_SHORTEN));
-    m_ui->ac3CheckBox->setEnabled(avcodec_find_decoder(AV_CODEC_ID_AC3) || avcodec_find_decoder(AV_CODEC_ID_EAC3));
-    m_ui->ac3CheckBox->setChecked(!disabledFilters.contains(u"*.ac3"_s) && (avcodec_find_decoder(AV_CODEC_ID_AC3) ||
-                                  avcodec_find_decoder(AV_CODEC_ID_EAC3)));
+    m_ui->ac3CheckBox->setEnabled(avcodec_find_decoder(AV_CODEC_ID_EAC3));
+    m_ui->ac3CheckBox->setChecked(!disabledFilters.contains(u"*.ac3"_s) && avcodec_find_decoder(AV_CODEC_ID_EAC3));
     m_ui->dtsCheckBox->setEnabled(avcodec_find_decoder(AV_CODEC_ID_DTS));
     m_ui->dtsCheckBox->setChecked(!disabledFilters.contains(u"*.dts"_s) && avcodec_find_decoder(AV_CODEC_ID_DTS));
     m_ui->mkaCheckBox->setEnabled(avcodec_find_decoder(AV_CODEC_ID_TRUEHD));
@@ -105,7 +104,7 @@ void FFmpegSettingsDialog::accept()
         disabledFilters << u"*.tak"_s;
     if (!m_ui->dsdCheckBox->isChecked())
         disabledFilters << u"*.dsf"_s << u"*.dsdiff"_s;
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.setValue(u"FFMPEG/disabled_filters"_s, disabledFilters);
     QDialog::accept();
 }
