@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -34,7 +34,6 @@
 #include <QObject>
 #include <QFile>
 #include <QIODevice>
-#include <QRegularExpression>
 #include <FLAC/all.h>
 #include <stdint.h>
 #include <qmmp/cueparser.h>
@@ -227,7 +226,7 @@ static void flac_callback_metadata (const FLAC__StreamDecoder *,
 
     if (metadata->type == FLAC__METADATA_TYPE_STREAMINFO)
     {
-        qDebug ("DecoderFLAC: getting metadata info");
+        qCDebug(plugin) << "getting metadata info";
 
         data->total_samples =
             (unsigned)(metadata->data.stream_info.total_samples
@@ -280,20 +279,18 @@ DecoderFLAC::~DecoderFLAC()
         delete m_data;
         m_data = nullptr;
     }
-    if(m_buf)
-        delete[] m_buf;
+
+    delete[] m_buf;
     m_buf = nullptr;
 }
 
 bool DecoderFLAC::initialize()
 {
-    if (!m_data->input)
+    if(!m_data->input)
     {
-        if (m_path.startsWith("flac://")) //embeded cue track
+        if(m_path.startsWith(u"flac://"_s)) //embeded cue track
         {
-            QString p = m_path;
-            p.remove("flac://");
-            p.remove(QRegularExpression("#\\d+$"));
+            QString p = TrackInfo::pathFromUrl(m_path);
             TagLib::FileStream stream(QStringToFileName(p), true);
 #if TAGLIB_MAJOR_VERSION >= 2
             TagLib::FLAC::File fileRef(&stream);
@@ -306,14 +303,14 @@ bool DecoderFLAC::initialize()
 
             if (ap && tag && tag->fieldListMap().contains("CUESHEET"))
             {
-                qDebug("DecoderFLAC: using cuesheet xiph comment.");
+                qCDebug(plugin, "using cuesheet xiph comment.");
                 m_parser = new CueParser(tag->fieldListMap()["CUESHEET"].toString() .toCString(true));
                 m_parser->setDuration(fileRef.audioProperties()->lengthInMilliseconds());
-                m_parser->setUrl("flac", p);
-                m_track = m_path.section("#", -1).toInt();
+                m_parser->setUrl(u"flac"_s, p);
+                m_track = m_path.section(QLatin1Char('#'), -1).toInt();
                 if(m_track < 1 || m_track > m_parser->count())
                 {
-                    qWarning("DecoderFLAC: invalid cuesheet xiph comment");
+                    qCWarning(plugin, "invalid cuesheet xiph comment");
                     return false;
                 }
                 m_data->input = new QFile(p);
@@ -330,20 +327,20 @@ bool DecoderFLAC::initialize()
             }
             else
             {
-                qWarning("DecoderFLAC: unable to find cuesheet comment.");
+                qCWarning(plugin, "unable to find cuesheet comment.");
                 return false;
             }
         }
         else
         {
-            qWarning("DecoderFLAC: cannot initialize. No input.");
+            qCWarning(plugin, "cannot initialize. No input.");
             return false;
         }
     }
 
     if (!m_data->input->isOpen())
     {
-        qWarning("DecoderFLAC: unable to open input file");
+        qCWarning(plugin, "unable to open input file");
         return false;
     }
 
@@ -357,7 +354,7 @@ bool DecoderFLAC::initialize()
 
     if (!m_data->decoder)
     {
-        qDebug("DecoderFLAC: creating FLAC__StreamDecoder");
+        qCDebug(plugin, "creating FLAC__StreamDecoder");
         m_data->decoder = FLAC__stream_decoder_new ();
     }
     char buf[500];
@@ -366,17 +363,17 @@ bool DecoderFLAC::initialize()
     ulong id3v2_size = findID3v2(buf, sizeof(buf));
     if(id3v2_size)
     {
-        qDebug("DecoderFLAC: skipping id3v2 tag (%lu bytes)", id3v2_size);
+        qCDebug(plugin, "skipping id3v2 tag (%lu bytes)", id3v2_size);
         m_data->input->seek(id3v2_size);
     }
     m_data->input->peek(buf,sizeof(buf));
     m_data->input->seek(0);
-    qDebug("DecoderFLAC: setting callbacks");
+    qCDebug(plugin, "setting callbacks");
     if(!memcmp(buf, "OggS", 4))
     {
         if(!FLAC_API_SUPPORTS_OGG_FLAC)
         {
-            qWarning("DecoderFLAC: unsupported format");
+            qCWarning(plugin, "unsupported format");
             return false;
         }
         if (FLAC__stream_decoder_init_ogg_stream(
@@ -393,8 +390,8 @@ bool DecoderFLAC::initialize()
         {
             return false;
         }
-        qDebug("DecoderFLAC: Ogg FLAC stream found");
-        setProperty(Qmmp::FORMAT_NAME, "Ogg FLAC");
+        qCDebug(plugin, "Ogg FLAC stream found");
+        setProperty(Qmmp::FORMAT_NAME, u"Ogg FLAC"_s);
     }
     else if (!memcmp(buf, "fLaC", 4))
     {
@@ -412,12 +409,12 @@ bool DecoderFLAC::initialize()
         {
             return false;
         }
-        qDebug("DecoderFLAC: native FLAC stream found");
-        setProperty(Qmmp::FORMAT_NAME, "FLAC");
+        qCDebug(plugin, "native FLAC stream found");
+        setProperty(Qmmp::FORMAT_NAME, u"FLAC"_s);
     }
     else
     {
-        qWarning("DecoderFLAC: unsupported format");
+        qCWarning(plugin, "unsupported format");
         return false;
     }
 
@@ -430,7 +427,7 @@ bool DecoderFLAC::initialize()
     ChannelMap chmap = findChannelMap(m_data->channels);
     if(chmap.isEmpty())
     {
-        qWarning("DecoderFLAC: unsupported number of channels: %d", m_data->channels);
+        qCWarning(plugin, "unsupported number of channels: %d", m_data->channels);
         return false;
     }
 
@@ -462,7 +459,7 @@ bool DecoderFLAC::initialize()
     m_totalBytes = 0;
     m_sz = audioParameters().frameSize();
 
-    qDebug("DecoderFLAC: initialize succes");
+    qCDebug(plugin, "initialize succes");
     return true;
 }
 
@@ -528,8 +525,7 @@ qint64 DecoderFLAC::read(unsigned char *buf, qint64 size)
         len2 = (len2 / m_sz) * m_sz; //returned size must contain integer number of samples
         m_totalBytes += len2;
         //save data of the next track
-        if(m_buf)
-            delete[] m_buf;
+        delete[] m_buf;
         m_buf_size = len - len2;
         m_buf = new char[m_buf_size];
         memmove(m_buf, buf + len2, m_buf_size);
@@ -549,8 +545,7 @@ void DecoderFLAC::deinit()
         delete m_data->input;
         m_data->input = nullptr;
     };
-    if(m_parser)
-        delete m_parser;
+    delete m_parser;
     m_parser = nullptr;
 }
 
@@ -558,8 +553,8 @@ const QString DecoderFLAC::nextURL() const
 {
     if(m_parser && m_track +1 <= m_parser->count())
         return m_parser->url(m_track + 1);
-    else
-        return QString();
+
+    return QString();
 }
 
 void DecoderFLAC::next()
