@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -20,7 +20,6 @@
 
 #include <QMessageBox>
 #include <QFileInfo>
-#include <QRegularExpression>
 #include <taglib/tag.h>
 #include <taglib/fileref.h>
 #include <taglib/flacfile.h>
@@ -52,11 +51,11 @@ DecoderProperties DecoderFLACFactory::properties() const
 {
     DecoderProperties properties;
     properties.name = tr("FLAC Plugin");
-    properties.filters = QStringList { "*.flac", "*.oga" };
+    properties.filters = QStringList { u"*.flac"_s, u"*.oga"_s };
     properties.description = tr("FLAC Files");
-    properties.contentTypes = QStringList { "audio/x-flac", "audio/flac" };
-    properties.shortName = "flac";
-    properties.protocols = QStringList { "flac" };
+    properties.contentTypes = QStringList { u"audio/x-flac"_s, u"audio/flac"_s };
+    properties.shortName = "flac"_L1;
+    properties.protocols = QStringList { u"flac"_s };
     properties.hasAbout = true;
     properties.hasSettings = false;
     return properties;
@@ -74,11 +73,9 @@ QList<TrackInfo*> DecoderFLACFactory::createPlayList(const QString &path, TrackI
     int track = -1; //cue track
     QString filePath = path;
 
-    if(path.contains("://")) //is it cue track?
+    if(path.contains(u"://"_s)) //is it cue track?
     {
-        filePath.remove("flac://");
-        filePath.remove(QRegularExpression("#\\d+$"));
-        track = path.section("#", -1).toInt();
+        filePath = TrackInfo::pathFromUrl(path, &track);
         parts = TrackInfo::AllParts; //extract all metadata for single cue track
     }
 
@@ -95,7 +92,7 @@ QList<TrackInfo*> DecoderFLACFactory::createPlayList(const QString &path, TrackI
 
     TagLib::FileStream stream(QStringToFileName(filePath), true);
 
-    if(filePath.endsWith(".flac", Qt::CaseInsensitive))
+    if(filePath.endsWith(u".flac"_s, Qt::CaseInsensitive))
     {
 #if TAGLIB_MAJOR_VERSION >= 2
         flacFile = new TagLib::FLAC::File(&stream);
@@ -105,7 +102,7 @@ QList<TrackInfo*> DecoderFLACFactory::createPlayList(const QString &path, TrackI
         tag = flacFile->xiphComment();
         ap = flacFile->audioProperties();
     }
-    else if(filePath.endsWith(".oga", Qt::CaseInsensitive))
+    else if(filePath.endsWith(u".oga"_s, Qt::CaseInsensitive))
     {
         oggFlacFile = new TagLib::Ogg::FLAC::File(&stream);
         tag = oggFlacFile->tag();
@@ -123,7 +120,7 @@ QList<TrackInfo*> DecoderFLACFactory::createPlayList(const QString &path, TrackI
         info->setValue(Qmmp::SAMPLERATE, ap->sampleRate());
         info->setValue(Qmmp::CHANNELS, ap->channels());
         info->setValue(Qmmp::BITS_PER_SAMPLE, ap->bitsPerSample());
-        info->setValue(Qmmp::FORMAT_NAME, flacFile ? "FLAC" : "Ogg FLAC");
+        info->setValue(Qmmp::FORMAT_NAME, flacFile ? u"FLAC"_s : u"Ogg FLAC"_s);
         info->setValue(Qmmp::FILE_SIZE, QFileInfo(filePath).size()); //adds file size for cue tracks
         info->setDuration(ap->lengthInMilliseconds());
     }
@@ -163,23 +160,18 @@ QList<TrackInfo*> DecoderFLACFactory::createPlayList(const QString &path, TrackI
             }
             parser.setDuration(ap->lengthInMilliseconds());
             parser.setProperties(info->properties());
-            parser.setUrl("flac", filePath);
-
-            if(flacFile)
-                delete flacFile;
-            if(oggFlacFile)
-                delete oggFlacFile;
+            parser.setUrl(u"flac"_s, filePath);
 
+            delete flacFile;
+            delete oggFlacFile;
             delete info;
             return parser.createPlayList(track);
         }
-        else if(track > 0) //cue track is not available
-        {
-            if(flacFile)
-                delete flacFile;
-            if(oggFlacFile)
-                delete oggFlacFile;
 
+        if(track > 0) //cue track is not available
+        {
+            delete flacFile;
+            delete oggFlacFile;
             delete info;
             return QList<TrackInfo *>();
         }
@@ -202,29 +194,29 @@ QList<TrackInfo*> DecoderFLACFactory::createPlayList(const QString &path, TrackI
 
     }
 
-    if(flacFile)
-        delete flacFile;
-    if(oggFlacFile)
-        delete oggFlacFile;
+    delete flacFile;
+    delete oggFlacFile;
     return QList<TrackInfo *>() << info;
 }
 
 MetaDataModel* DecoderFLACFactory::createMetaDataModel(const QString &path, bool readOnly)
 {
-    if (!path.contains("://") || path.startsWith("flac://"))
+    if (!path.contains(u"://"_s) || path.startsWith(u"flac://"_s))
         return new FLACMetaDataModel(path, readOnly);
-    else
-        return nullptr;
+
+    return nullptr;
 }
 
-void DecoderFLACFactory::showSettings(QWidget *)
-{}
+QDialog *DecoderFLACFactory::createSettings(QWidget *)
+{
+    return nullptr;
+}
 
 void DecoderFLACFactory::showAbout(QWidget *parent)
 {
-    QMessageBox::about (parent, tr("About FLAC Audio Plugin"),
-                        tr("Qmmp FLAC Audio Plugin")+"\n"+
-                        tr("Written by: Ilya Kotov <forkotov02@ya.ru>"));
+    QMessageBox::about(parent, tr("About FLAC Audio Plugin"),
+                       tr("Qmmp FLAC Audio Plugin") + QChar::LineFeed +
+                       tr("Written by: Ilya Kotov <forkotov02@ya.ru>"));
 }
 
 QString DecoderFLACFactory::translation() const
