@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -18,7 +18,7 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
-#include <QPixmap>
+#include <QImage>
 #include <QBuffer>
 #include <taglib/tag.h>
 #include <taglib/fileref.h>
@@ -29,24 +29,23 @@
 #include "flacmetadatamodel.h"
 
 FLACMetaDataModel::FLACMetaDataModel(const QString &path, bool readOnly) :
-    MetaDataModel(readOnly, MetaDataModel::IsCoverEditable),
-    m_path(path)
+    MetaDataModel(readOnly, MetaDataModel::IsCoverEditable)
 {
-    if(path.startsWith("flac://"))
-    {
-        m_path.remove("flac://");
-        m_path.remove(QRegularExpression("#\\d+$"));
-    }
+    m_path = path.contains(u"://"_s) ? TrackInfo::pathFromUrl(m_path) : path;
 
-    if(m_path.endsWith(".flac", Qt::CaseInsensitive))
+    if(m_path.endsWith(u".flac"_s, Qt::CaseInsensitive))
     {
         m_stream = new TagLib::FileStream(QStringToFileName(m_path), readOnly);
+#if TAGLIB_MAJOR_VERSION >= 2
+        TagLib::FLAC::File *f = new TagLib::FLAC::File(m_stream);
+#else
         TagLib::FLAC::File *f = new TagLib::FLAC::File(m_stream, TagLib::ID3v2::FrameFactory::instance());
+#endif
         m_tag = f->xiphComment();
         m_file = f;
         setDialogHints(dialogHints() | MetaDataModel::IsCueEditable);
     }
-    else if(m_path.endsWith(".oga", Qt::CaseInsensitive))
+    else if(m_path.endsWith(u".oga"_s, Qt::CaseInsensitive))
     {
         m_stream = new TagLib::FileStream(QStringToFileName(m_path), readOnly);
         TagLib::Ogg::FLAC::File *f = new TagLib::Ogg::FLAC::File(m_stream);
@@ -57,7 +56,7 @@ FLACMetaDataModel::FLACMetaDataModel(const QString &path, bool readOnly) :
     if(m_file)
         setReadOnly(m_file->readOnly());
 
-    if(m_file && m_file->isValid() && !path.startsWith("flac://"))
+    if(m_file && m_file->isValid() && !path.startsWith(u"flac://"_s))
     {
         m_tags << new VorbisCommentModel(m_tag, m_file);
     }
@@ -67,13 +66,9 @@ FLACMetaDataModel::~FLACMetaDataModel()
 {
     while(!m_tags.isEmpty())
         delete m_tags.takeFirst();
-    if(m_file)
-    {
-        delete m_file;
-        m_file = nullptr;
-    }
-    if(m_stream)
-        delete m_stream;
+
+    delete m_file;
+    delete m_stream;
 }
 
 QList<TagModel* > FLACMetaDataModel::tags() const
@@ -81,7 +76,7 @@ QList<TagModel* > FLACMetaDataModel::tags() const
     return m_tags;
 }
 
-QPixmap FLACMetaDataModel::cover() const
+QImage FLACMetaDataModel::cover() const
 {
     TagLib::FLAC::File *flacFile = dynamic_cast<TagLib::FLAC::File *>(m_file);
     TagLib::List<TagLib::FLAC::Picture *> list;
@@ -99,12 +94,12 @@ QPixmap FLACMetaDataModel::cover() const
     {
         if(list[i]->type() == TagLib::FLAC::Picture::FrontCover)
         {
-            QPixmap cover;
+            QImage cover;
             cover.loadFromData(QByteArray(list[i]->data().data(), list[i]->data().size())); //read binary picture data
             return cover;
         }
     }
-    return QPixmap();
+    return QImage();
 }
 
 QString FLACMetaDataModel::coverPath() const
@@ -112,7 +107,7 @@ QString FLACMetaDataModel::coverPath() const
     return MetaDataManager::instance()->findCoverFile(m_path);
 }
 
-void FLACMetaDataModel::setCover(const QPixmap &pix)
+void FLACMetaDataModel::setCover(const QImage &img)
 {
     removeCover();
 
@@ -123,7 +118,7 @@ void FLACMetaDataModel::setCover(const QPixmap &pix)
     QByteArray data;
     QBuffer buffer(&data);
     buffer.open(QIODevice::WriteOnly);
-    pix.save(&buffer, "JPEG");
+    img.save(&buffer, "JPEG");
     picture->setMimeType("image/jpeg");
     picture->setData(TagLib::ByteVector(data.constData(), data.size()));
     if(flacFile)
@@ -131,7 +126,7 @@ void FLACMetaDataModel::setCover(const QPixmap &pix)
         flacFile->addPicture(picture);
         flacFile->save();
     }
-    else if(m_tag)
+    else if(m_tag && m_file)
     {
         m_tag->addPicture(picture);
         m_file->save();
@@ -141,27 +136,30 @@ void FLACMetaDataModel::setCover(const QPixmap &pix)
 void FLACMetaDataModel::removeCover()
 {
     TagLib::FLAC::File *flacFile = dynamic_cast<TagLib::FLAC::File *>(m_file);
-    TagLib::List<TagLib::FLAC::Picture *> list;
     bool save = false;
 
     if(flacFile)
     {
-        list = flacFile->pictureList(); //native flac
+        const TagLib::List<TagLib::FLAC::Picture *> list = flacFile->pictureList(); //native flac
+        for(TagLib::FLAC::Picture *p : std::as_const(list))
+        {
+            if(p->type() == TagLib::FLAC::Picture::FrontCover)
+            {
+                flacFile->removePicture(p, false);
+                save = true;
+            }
+        }
     }
     else if(m_tag && !m_tag->isEmpty())
     {
-        list = m_tag->pictureList(); //ogg flac
-    }
-
-    for(uint i = 0; i < list.size(); ++i)
-    {
-        if(list[i]->type() == TagLib::FLAC::Picture::FrontCover)
+        const TagLib::List<TagLib::FLAC::Picture *> list = m_tag->pictureList(); //ogg flac
+        for(TagLib::FLAC::Picture *p : std::as_const(list))
         {
-            if(flacFile)
-                flacFile->removePicture(list[i], false);
-            else
-                m_tag->removePicture(list[i], false);
-            save = true;
+            if(p->type() == TagLib::FLAC::Picture::FrontCover)
+            {
+                m_tag->removePicture(p, false);
+                save = true;
+            }
         }
     }
 
@@ -203,7 +201,7 @@ QString FLACMetaDataModel::lyrics() const
 
         if(!map["UNSYNCEDLYRICS"].isEmpty())
             return TStringToQString(map["UNSYNCEDLYRICS"].front());
-        else if(!map["LYRICS"].isEmpty())
+        if(!map["LYRICS"].isEmpty())
             return TStringToQString(map["LYRICS"].front());
     }
 
@@ -221,7 +219,7 @@ VorbisCommentModel::~VorbisCommentModel()
 
 QString VorbisCommentModel::name() const
 {
-    return "Vorbis Comment";
+    return u"Vorbis Comment"_s;
 }
 
 QString VorbisCommentModel::value(Qmmp::MetaData key) const
@@ -300,7 +298,7 @@ void VorbisCommentModel::setValue(Qmmp::MetaData key, const QString &value)
         m_tag->setYear(value.toInt());
         return;
     case Qmmp::DISCNUMBER:
-        value == "0" ?
+        value == "0"_L1 ?
         m_tag->removeFields("DISCNUMBER"):
         m_tag->addField("DISCNUMBER", str, true);
     }
