@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -33,9 +33,9 @@ public:
     FLACMetaDataModel(const QString &path, bool readOnly);
     ~FLACMetaDataModel();
     QList<TagModel* > tags() const override;
-    QPixmap cover() const override;
+    QImage cover() const override;
     QString coverPath() const override;
-    void setCover(const QPixmap &pix) override;
+    void setCover(const QImage &img) override;
     void removeCover() override;
     QString cue() const override;
     void setCue(const QString &content) override;
