@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2010-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2010-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -19,8 +19,7 @@
  ***************************************************************************/
 
 #include <QMessageBox>
-#include <QRegularExpression>
-#include "settingsdialog.h"
+#include "gmesettingsdialog.h"
 #include "gmehelper.h"
 #include "decoder_gme.h"
 #include "decodergmefactory.h"
@@ -36,15 +35,17 @@ DecoderProperties DecoderGmeFactory::properties() const
 {
     DecoderProperties properties;
     properties.name = tr("GME Plugin");
-    properties.filters = QStringList { "*.ay", "*.gbs", "*.gym", "*.hes", "*.kss", "*.nsf", "*.nsfe",
-            "*.sap", "*.spc", "*.vgm", "*.vgz" };
+    properties.filters = QStringList {
+            u"*.ay"_s, u"*.gbs"_s, u"*.gym"_s, u"*.hes"_s, u"*.kss"_s,
+            u"*.nsf"_s, u"*.nsfe"_s, u"*.sap"_s, u"*.spc"_s, u"*.vgm"_s, u"*.vgz"_s
+};
     properties.description = tr("Game Music Files");
     //properties.contentType = ;
-    properties.shortName = "gme";
+    properties.shortName = "gme"_L1;
     properties.hasAbout = true;
     properties.hasSettings = true;
     properties.noInput = true;
-    properties.protocols = QStringList { "gme" };
+    properties.protocols = QStringList { u"gme"_s };
     return properties;
 }
 
@@ -58,12 +59,10 @@ QList<TrackInfo *> DecoderGmeFactory::createPlayList(const QString &path, TrackI
 {
     GmeHelper helper;
     //is it one track?
-    if(path.contains("://"))
+    if(path.contains(u"://"_s))
     {
-        QString filePath = path;
-        filePath.remove("gme://");
-        filePath.remove(QRegularExpression("#\\d+$"));
-        int track = path.section("#", -1).toInt();
+        int track = -1;
+        QString filePath = TrackInfo::pathFromUrl(path, &track);
         QList<TrackInfo *> list = createPlayList(filePath, parts, ignoredFiles);
         if (list.isEmpty() || track <= 0 || track > list.count())
         {
@@ -79,7 +78,7 @@ QList<TrackInfo *> DecoderGmeFactory::createPlayList(const QString &path, TrackI
     Music_Emu *emu = helper.load(path);
     if(!emu)
     {
-        qWarning("DecoderGmeFactory: unable to open file");
+        qCWarning(plugin, "unable to open file");
         return QList<TrackInfo *>();
     }
     return helper.createPlayList(parts);
@@ -92,18 +91,17 @@ MetaDataModel* DecoderGmeFactory::createMetaDataModel(const QString &path, bool
     return nullptr;
 }
 
-void DecoderGmeFactory::showSettings(QWidget *parent)
+QDialog *DecoderGmeFactory::createSettings(QWidget *parent)
 {
-   SettingsDialog *d = new SettingsDialog(parent);
-   d->show();
+    return new GmeSettingsDialog(parent);
 }
 
 void DecoderGmeFactory::showAbout(QWidget *parent)
 {
-    QMessageBox::about (parent, tr("About GME Audio Plugin"),
-                        tr("Qmmp GME Audio Plugin")+"\n"+
-                        tr("This plugin uses Game_Music_Emu library to play game music files")+"\n"+
-                        tr("Written by: Ilya Kotov <forkotov02@ya.ru>"));
+    QMessageBox::about(parent, tr("About GME Audio Plugin"),
+                       tr("Qmmp GME Audio Plugin") + QChar::LineFeed +
+                       tr("This plugin uses Game_Music_Emu library to play game music files") + QChar::LineFeed +
+                       tr("Written by: Ilya Kotov <forkotov02@ya.ru>"));
 }
 
 QString DecoderGmeFactory::translation() const
