@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2015-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2015-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -28,7 +28,7 @@ GmeSettingsDialog::GmeSettingsDialog(QWidget *parent) :
     m_ui(new Ui::GmeSettingsDialog)
 {
     m_ui->setupUi(this);
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     m_ui->fadeoutCheckBox->setChecked(settings.value(u"GME/fadeout"_s, false).toBool());
     m_ui->fadeoutSpinBox->setValue(settings.value(u"GME/fadeout_length"_s, 7000).toInt());
 }
@@ -40,7 +40,7 @@ GmeSettingsDialog::~GmeSettingsDialog()
 
 void GmeSettingsDialog::accept()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.setValue(u"GME/fadeout"_s, m_ui->fadeoutCheckBox->isChecked());
     settings.setValue(u"GME/fadeout_length"_s, m_ui->fadeoutSpinBox->value());
     QDialog::accept();
