@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -81,7 +81,7 @@ bool DecoderMPC::initialize()
 
     if (!input())
     {
-        qWarning("DecoderMPC: cannot initialize.  No input.");
+        qCWarning(plugin, "cannot initialize.  No input.");
         return false;
     }
 
@@ -90,7 +90,7 @@ bool DecoderMPC::initialize()
         m_data = new mpc_data;
     }
 
-    qDebug("DecoderMPC: setting callbacks");
+    qCDebug(plugin, "setting callbacks");
     m_data->reader.read = mpc_callback_read;
     m_data->reader.seek = mpc_callback_seek;
     m_data->reader.tell = mpc_callback_tell;
@@ -114,7 +114,7 @@ bool DecoderMPC::initialize()
     setReplayGainInfo(rg_info);
 
     m_totalTime = mpc_streaminfo_get_length(&data()->info) * 1000;
-    qDebug("DecoderMPC: initialize succes");
+    qCDebug(plugin, "initialize succes");
     return true;
 }
 
@@ -141,14 +141,13 @@ qint64 DecoderMPC::read(unsigned char *audio, qint64 maxSize)
         if (err != MPC_STATUS_OK || frame.bits == -1)
         {
             m_len = 0;
-            qDebug("finished");
+            qCDebug(plugin, "finished");
             return 0;
         }
-        else
-        {
-            m_len = frame.samples * data()->info.channels;
-            memcpy(audio, buffer, qMin(qint64(m_len * sizeof(float)), maxSize));
-        }
+
+        m_len = frame.samples * data()->info.channels;
+        memcpy(audio, buffer, qMin(qint64(m_len * sizeof(float)), maxSize));
+
     }
     m_bitrate = frame.bits * data()->info.sample_freq / 1152000;
     return m_len * sizeof(float);
