@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -26,7 +26,7 @@
 #include <taglib/mpcfile.h>
 #include <taglib/tfilestream.h>
 
-class QTextCodec;
+class QmmpTextCodec;
 
 class MPCMetaDataModel : public MetaDataModel
 {
@@ -56,7 +56,7 @@ public:
     void save() override;
 
 private:
-    QTextCodec *m_codec;
+    QmmpTextCodec *m_codec;
     TagLib::MPC::File *m_file;
     TagLib::Tag *m_tag;
     TagLib::MPC::File::TagTypes m_tagType;
