@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -22,7 +22,6 @@
 #include <QMessageBox>
 #include <QSettings>
 #include <QFile>
-#include <QTextCodec>
 #include <taglib/tag.h>
 #include <taglib/fileref.h>
 #include <taglib/id3v1tag.h>
@@ -34,6 +33,7 @@
 #include <taglib/id3v2header.h>
 #include <taglib/textidentificationframe.h>
 #include <taglib/id3v2framefactory.h>
+#include <qmmp/qmmptextcodec.h>
 #include "tagextractor.h"
 #include "mpegmetadatamodel.h"
 #include "mpegsettingsdialog.h"
@@ -54,9 +54,9 @@ DecoderMpegFactory::DecoderMpegFactory()
     //detecting rusxmms patch
     m_using_rusxmms = false;
     char str[] = { char(0xF2), char(0xE5), char(0xF1), char(0xF2), '\0'};
-    QTextCodec *codec = QTextCodec::codecForName("windows-1251");
+    QmmpTextCodec codec("windows-1251");
     TagLib::String tstr(str);
-    if(codec->toUnicode(str) == QString::fromUtf8(tstr.toCString(true)))
+    if(codec.toUnicode(str) == QString::fromUtf8(tstr.toCString(true)))
     {
         qCDebug(plugin, "found taglib with rusxmms patch");
         m_using_rusxmms = true;
@@ -103,13 +103,14 @@ bool DecoderMpegFactory::canDecode(QIODevice *input) const
     if(dataSize <= 0)
         return false;
 
+    QString decoderName;
 #if defined(WITH_MAD) && defined(WITH_MPG123)
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    QString decoderName = settings.value(u"MPEG/decoder"_s, u"mad"_s).toString();
+    QSettings settings;
+    decoderName = settings.value(u"MPEG/decoder"_s, u"mad"_s).toString();
 #elif defined(WITH_MAD)
-    QString decoderName = u"mad"_s;
+    decoderName = "mad";
 #elif defined(WITH_MPG123)
-    QString decoderName = u"mpg123"_s;
+    decoderName = "mpg123";
 #endif
 
 #ifdef WITH_MAD
@@ -188,7 +189,7 @@ Decoder *DecoderMpegFactory::create(const QString &, QIODevice *input)
 {
     Decoder *d = nullptr;
 #if defined(WITH_MAD) && defined(WITH_MPG123)
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     if(settings.value(u"MPEG/decoder"_s, u"mad"_s).toString() == "mpg123"_L1)
     {
         qCDebug(plugin, "using mpg123 decoder");
@@ -201,7 +202,7 @@ Decoder *DecoderMpegFactory::create(const QString &, QIODevice *input)
         d = new DecoderMAD(crc, input);
     }
 #elif defined(WITH_MAD)
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     bool crc = settings.value(u"MPEG/enable_crc"_s, false).toBool();
     d = new DecoderMAD(crc, input);
 #elif defined(WITH_MPG123)
@@ -226,7 +227,7 @@ QList<TrackInfo *> DecoderMpegFactory::createPlayList(const QString &path, Track
 
     if (parts & TrackInfo::MetaData)
     {
-        QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+        QSettings settings;
         settings.beginGroup("MPEG"_L1);
 
         QList< QMap<Qmmp::MetaData, QString> > metaData;
@@ -272,9 +273,7 @@ QList<TrackInfo *> DecoderMpegFactory::createPlayList(const QString &path, Track
                         codecName = detectedCharset;
                 }
 
-                QTextCodec *codec = QTextCodec::codecForName(codecName);
-                if(!codec)
-                    codec = QTextCodec::codecForName("UTF-8");
+                QmmpTextCodec *codec = new QmmpTextCodec(codecName);
 
                 bool utf = codec->name().contains("UTF");
 
@@ -317,6 +316,8 @@ QList<TrackInfo *> DecoderMpegFactory::createPlayList(const QString &path, Track
 
                 metaData << tags;
 
+                delete codec;
+
                 if(!merge)
                     break;
             }
