@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright(C) 2009-2025 by Ilya Kotov                                 *
+ *   Copyright(C) 2009-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -21,7 +21,6 @@
 #include <QSettings>
 #include <QByteArray>
 #include <QBuffer>
-#include <QTextCodec>
 #include <taglib/tag.h>
 #include <taglib/fileref.h>
 #include <taglib/id3v1tag.h>
@@ -34,6 +33,7 @@
 #include <taglib/textidentificationframe.h>
 #include <taglib/attachedpictureframe.h>
 #include <taglib/id3v2framefactory.h>
+#include <qmmp/qmmptextcodec.h>
 #include "tagextractor.h"
 #include "mpegmetadatamodel.h"
 
@@ -170,7 +170,7 @@ MpegFileTagModel::MpegFileTagModel(bool using_rusxmms, TagLib::MPEG::File *file,
           m_type(type)
 {
     QByteArray codecName;
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(u"MPEG"_s);
     if(m_type == TagLib::MPEG::File::ID3v1)
     {
@@ -201,16 +201,15 @@ MpegFileTagModel::MpegFileTagModel(bool using_rusxmms, TagLib::MPEG::File *file,
             codecName = detectedCharset;
     }
 
-    m_codec = QTextCodec::codecForName(codecName);
-
-    if(!m_codec)
-        m_codec = QTextCodec::codecForName("UTF-8");
+    m_codec = new QmmpTextCodec(codecName);
 
     settings.endGroup();
 }
 
 MpegFileTagModel::~MpegFileTagModel()
-{}
+{
+    delete m_codec;
+}
 
 QString MpegFileTagModel::name() const
 {
@@ -429,11 +428,7 @@ void MpegFileTagModel::remove()
 void MpegFileTagModel::save()
 {
     if(m_tag)
-#if((TAGLIB_MAJOR_VERSION == 1) &&(TAGLIB_MINOR_VERSION <= 11))
-        m_file->save(m_type, false);
-#else
         m_file->save(m_type, TagLib::File::StripNone, TagLib::ID3v2::v4, TagLib::File::DoNotDuplicate);
-#endif
     else
         m_file->strip(m_type);
 }
