@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -19,8 +19,8 @@
  ***************************************************************************/
 
 #include <QSettings>
-#include <QTextCodec>
 #include <qmmp/qmmp.h>
+#include <qmmp/qmmptextcodec.h>
 #include "ui_mpegsettingsdialog.h"
 #include "mpegsettingsdialog.h"
 
@@ -28,14 +28,11 @@ MpegSettingsDialog::MpegSettingsDialog(bool using_rusxmms, QWidget *parent)
         : QDialog(parent), m_ui(new Ui::MpegSettingsDialog)
 {
     m_ui->setupUi(this);
-    findCodecs();
-    for(const QTextCodec *codec : qAsConst(m_codecs))
-    {
-        m_ui->id3v1EncComboBox->addItem(QString::fromLatin1(codec->name()));
-        m_ui->id3v2EncComboBox->addItem(QString::fromLatin1(codec->name()));
-    }
 
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    m_ui->id3v1EncComboBox->addItems(QmmpTextCodec::availableCharsets());
+    m_ui->id3v2EncComboBox->addItems(QmmpTextCodec::availableCharsets());
+
+    QSettings settings;
     settings.beginGroup(u"MPEG"_s);
 
 #if defined(WITH_MAD) && defined(WITH_MPG123)
@@ -79,7 +76,7 @@ MpegSettingsDialog::~MpegSettingsDialog()
 
 void MpegSettingsDialog::accept()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(u"MPEG"_s);
     settings.setValue(u"decoder"_s, m_ui->mpg123RadioButton->isChecked() ? u"mpg123"_s : u"mad"_s);
     settings.setValue(u"enable_crc"_s, m_ui->enableCrcCheckBox->isChecked());
@@ -93,42 +90,3 @@ void MpegSettingsDialog::accept()
     settings.endGroup();
     QDialog::accept();
 }
-
-void MpegSettingsDialog::findCodecs()
-{
-    QMap<QString, QTextCodec *> codecMap;
-    static const QRegularExpression iso8859RegExp(u"ISO[- ]8859-([0-9]+).*"_s);
-
-    for(int mib : QTextCodec::availableMibs())
-    {
-        QTextCodec *codec = QTextCodec::codecForMib(mib);
-
-        QString sortKey = QString::fromLatin1(codec->name().toUpper());
-        int rank;
-        QRegularExpressionMatch match;
-
-        if (sortKey.startsWith(u"UTF-8"_s))
-        {
-            rank = 1;
-        }
-        else if (sortKey.startsWith(u"UTF-16"_s))
-        {
-            rank = 2;
-        }
-        else if ((match = iso8859RegExp.match(sortKey)).hasMatch())
-        {
-            if (match.captured(1).size() == 1)
-                rank = 3;
-            else
-                rank = 4;
-        }
-        else
-        {
-            rank = 5;
-        }
-        sortKey.prepend(QChar('0' + rank));
-
-        codecMap.insert(sortKey, codec);
-    }
-    m_codecs = codecMap.values();
-}
