@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -43,10 +43,7 @@ public slots:
     void accept() override;
 
 private:
-    void findCodecs();
-
     Ui::MpegSettingsDialog *m_ui;
-    QList<QTextCodec *> m_codecs;
 };
 
 #endif
