@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -23,11 +23,11 @@
 #include <QByteArray>
 #include <QBuffer>
 #include <QSet>
-#include <QTextCodec>
 #include <stdlib.h>
 #ifdef WITH_LIBRCD
 #include <librcd.h>
 #endif
+#include <qmmp/qmmptextcodec.h>
 #include "tagextractor.h"
 
 #define CSTR_TO_QSTR(str,utf) codec->toUnicode(str.toCString(utf)).trimmed()
@@ -51,7 +51,7 @@ QMap<Qmmp::MetaData, QString> TagExtractor::id3v2tag() const
     if (tag.isEmpty())
         return QMap<Qmmp::MetaData, QString>();
 
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(u"MPEG"_s);
     QByteArray codecName = settings.value(u"ID3v2_encoding"_s, u"UTF-8"_s).toByteArray();
 
@@ -66,10 +66,7 @@ QMap<Qmmp::MetaData, QString> TagExtractor::id3v2tag() const
     }
     settings.endGroup();
 
-    QTextCodec *codec = QTextCodec::codecForName(codecName);
-
-    if(!codec)
-        codec = QTextCodec::codecForName("UTF-8");
+    QmmpTextCodec *codec = new QmmpTextCodec(codecName);
 
     bool utf = codec->name().contains("UTF");
 
@@ -94,6 +91,8 @@ QMap<Qmmp::MetaData, QString> TagExtractor::id3v2tag() const
         tags.insert(Qmmp::DISCNUMBER, QString::fromLatin1(disc.toCString()).trimmed());
     }
 
+    delete codec;
+
     return tags;
 }
 
