@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2013-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2013-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -77,13 +77,13 @@ DecoderOpus::~DecoderOpus()
 
 bool DecoderOpus::initialize()
 {
-    qDebug("DecoderOpus: initialize");
+    qCDebug(plugin, "initialize");
     m_chan = 0;
     m_totalTime = 0;
 
     if (!input())
     {
-        qDebug("DecoderOpus: cannot initialize.  No input");
+        qCDebug(plugin, "cannot initialize.  No input");
         return false;
     }
 
@@ -98,7 +98,7 @@ bool DecoderOpus::initialize()
 
     if (!m_opusfile)
     {
-        qWarning("DecoderOpus: cannot open stream");
+        qCWarning(plugin, "cannot open stream");
         return false;
     }
 
@@ -110,7 +110,7 @@ bool DecoderOpus::initialize()
     const OpusHead *head = op_head(m_opusfile, -1);
     if (!head)
     {
-        qWarning("DecoderOpus: unable to read header");
+        qCWarning(plugin, "unable to read header");
         return false;
     }
 
@@ -119,10 +119,10 @@ bool DecoderOpus::initialize()
     ChannelMap chmap = findChannelMap(m_chan);
     if(chmap.isEmpty())
     {
-        qWarning("DecoderOpus: unsupported number of channels: %d", m_chan);
+        qCWarning(plugin, "unsupported number of channels: %d", m_chan);
         return false;
     }
-    setProperty(Qmmp::FORMAT_NAME, "Ogg Opus");
+    setProperty(Qmmp::FORMAT_NAME, u"Ogg Opus"_s);
     configure(48000, chmap, Qmmp::PCM_FLOAT); //opus codec supports 48 kHz only
     return true;
 }
@@ -141,7 +141,7 @@ int DecoderOpus::bitrate() const
 
 void DecoderOpus::seek(qint64 time)
 {
-    op_pcm_seek(m_opusfile, time*48);
+    op_pcm_seek(m_opusfile, time * 48);
 }
 
 qint64 DecoderOpus::read(unsigned char *data, qint64 maxSize)
