@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2013-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2013-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -84,7 +84,7 @@ bool DecoderSID::initialize()
     addMetaData(metadata);
 
     //read settings
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(u"SID"_s);
     if(settings.value(u"use_hvsc"_s, false).toBool())
     {
@@ -112,7 +112,7 @@ bool DecoderSID::initialize()
     rs->create(m_player->info().maxsids());
 
     SidConfig cfg = m_player->config();
-    cfg.frequency    = settings.value(u"sample_rate"_s, 48000).toInt();
+    cfg.frequency    = settings.value(u"sample_rate"_s, 44100).toInt();
     int sm = settings.value(u"resampling_method"_s, SidConfig::INTERPOLATE).toInt();
     cfg.samplingMethod = (SidConfig::sampling_method_t) sm;
     cfg.playback     = SidConfig::STEREO;
@@ -132,11 +132,7 @@ bool DecoderSID::initialize()
         return false;
     }
 
-#if (LIBSIDPLAYFP_VERSION_MAJ > 2) || ((LIBSIDPLAYFP_VERSION_MAJ == 2) && (LIBSIDPLAYFP_VERSION_MIN >= 15))
-    m_player->initMixer(true);
-#endif
-
-    configure(cfg.frequency, 2);
+    configure(44100, 2);
     m_length_in_bytes = audioParameters().sampleRate() *
             audioParameters().frameSize() * m_length;
     qCDebug(plugin, "initialize succes");
@@ -164,14 +160,6 @@ qint64 DecoderSID::read(unsigned char *data, qint64 size)
     size -= size % 4;
     if(size <= 0)
         return 0;
-
-#if (LIBSIDPLAYFP_VERSION_MAJ > 2) || ((LIBSIDPLAYFP_VERSION_MAJ == 2) && (LIBSIDPLAYFP_VERSION_MIN >= 15))
-    int cycles = size * 1000000 / m_player->config().frequency; //ms
-    int samples = m_player->play(cycles);
-    int decoded_bytes = m_player->mix((short *)data, samples) * 2;
-#else
-    int decoded_bytes = m_player->play((short *)data, size / 2) * 2;
-#endif
-    m_read_bytes += decoded_bytes;
-    return decoded_bytes;
+    m_read_bytes += size;
+    return m_player->play((short *)data, size/2) * 2;
 }
