@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2007-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2007-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -35,7 +35,6 @@
 #define WAVE_FORMAT_IEEE_FLOAT 0x0003
 #define WAVE_FORMAT_ALAW 0x0006
 #define WAVE_FORMAT_MULAW 0x0007
-#define WAVE_FORMAT_IMA_ADPCM 0x0011
 #define WAVE_FORMAT_EXTENSIBLE 0xfffe
 
 // DecoderSndFileFactory
@@ -73,8 +72,6 @@ bool DecoderSndFileFactory::canDecode(QIODevice *input) const
                     size_t size = buf[4] | buf[5] << 8 | buf[6] << 16 | buf[7] << 24;
                     if(!input->seek(input->pos() + size + 8))
                         break;
-
-                    continue;
                 }
 
                 break;
@@ -89,7 +86,6 @@ bool DecoderSndFileFactory::canDecode(QIODevice *input) const
         case WAVE_FORMAT_IEEE_FLOAT:
         case WAVE_FORMAT_ALAW:
         case WAVE_FORMAT_MULAW:
-        case WAVE_FORMAT_IMA_ADPCM:
         case WAVE_FORMAT_EXTENSIBLE:
             return true;
         default:
@@ -98,7 +94,7 @@ bool DecoderSndFileFactory::canDecode(QIODevice *input) const
     }
     else if(!memcmp(buf, "FORM", 4))
     {
-        if(!memcmp(buf + 8, "AIFF", 4) || !memcmp(buf + 8, "AIFC", 4))
+        if(!memcmp(buf + 8, "AIFF", 4))
             return true;
         if(!memcmp(buf + 8, "8SVX", 4))
             return true;
@@ -121,7 +117,7 @@ DecoderProperties DecoderSndFileFactory::properties() const
 {
     DecoderProperties properties;
     properties.name = tr("Sndfile Plugin");
-    properties.filters = QStringList {
+    properties.filters = {
         u"*.wav"_s, u"*.au"_s, u"*.snd"_s, u"*.aif"_s, u"*.aiff"_s, u"*.8svx"_s, u"*.sph"_s, u"*.sf"_s, u"*.voc"_s, u"*.w64"_s
     };
     properties.description = tr("PCM Files");
