@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -42,10 +42,10 @@ DecoderProperties DecoderVorbisFactory::properties() const
 {
     DecoderProperties properties;
     properties.name = tr("Ogg Vorbis Plugin");
-    properties.shortName = "vorbis";
-    properties.filters = QStringList { "*.ogg" };
+    properties.shortName = "vorbis"_L1;
+    properties.filters = QStringList { u"*.ogg"_s };
     properties.description = tr("Ogg Vorbis Files");
-    properties.contentTypes = QStringList { "application/ogg", "audio/x-vorbis+ogg" };
+    properties.contentTypes = QStringList { u"application/ogg"_s, u"audio/x-vorbis+ogg"_s };
     properties.hasAbout = true;
     properties.hasSettings = false;
     properties.noInput = false;
@@ -97,7 +97,7 @@ QList<TrackInfo *> DecoderVorbisFactory::createPlayList(const QString &path, Tra
         info->setValue(Qmmp::SAMPLERATE, fileRef.audioProperties()->sampleRate());
         info->setValue(Qmmp::CHANNELS, fileRef.audioProperties()->channels());
         info->setValue(Qmmp::BITS_PER_SAMPLE, 32);  //float
-        info->setValue(Qmmp::FORMAT_NAME, "Ogg Vorbis");
+        info->setValue(Qmmp::FORMAT_NAME, u"Ogg Vorbis"_s);
         info->setDuration(fileRef.audioProperties()->lengthInMilliseconds());
     }
 
@@ -118,16 +118,18 @@ QList<TrackInfo *> DecoderVorbisFactory::createPlayList(const QString &path, Tra
     return QList<TrackInfo*>() << info;
 }
 
-void DecoderVorbisFactory::showSettings(QWidget *)
-{}
+QDialog *DecoderVorbisFactory::createSettings(QWidget *)
+{
+    return nullptr;
+}
 
 void DecoderVorbisFactory::showAbout(QWidget *parent)
 {
-    QMessageBox::about (parent, tr("About Ogg Vorbis Audio Plugin"),
-                        tr("Qmmp Ogg Vorbis Audio Plugin")+"\n"+
-                        tr("Written by: Ilya Kotov <forkotov02@ya.ru>")+"\n"+
-                        tr("Source code based on mq3 project")
-                        );
+    QMessageBox::about(parent, tr("About Ogg Vorbis Audio Plugin"),
+                       tr("Qmmp Ogg Vorbis Audio Plugin") + QChar::LineFeed +
+                       tr("Written by: Ilya Kotov <forkotov02@ya.ru>") + QChar::LineFeed +
+                       tr("Source code based on mq3 project")
+                       );
 }
 
 QString DecoderVorbisFactory::translation() const
