@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -52,26 +52,26 @@ QList<TagModel* > VorbisMetaDataModel::tags() const
     return m_tags;
 }
 
-QPixmap VorbisMetaDataModel::cover() const
+QImage VorbisMetaDataModel::cover() const
 {
     if(!m_tag || m_tag->isEmpty())
-        return QPixmap();
+        return QImage();
 
     TagLib::List<TagLib::FLAC::Picture *> list = m_tag->pictureList();
     for(uint i = 0; i < list.size(); ++i)
     {
         if(list[i]->type() == TagLib::FLAC::Picture::FrontCover)
         {
-            QPixmap cover;
+            QImage cover;
             cover.loadFromData(QByteArray(list[i]->data().data(), list[i]->data().size())); //read binary picture data
             return cover;
         }
     }
 
-    return QPixmap();
+    return QImage();
 }
 
-void VorbisMetaDataModel::setCover(const QPixmap &pix)
+void VorbisMetaDataModel::setCover(const QImage &img)
 {
     removeCover();
     if(m_tag)
@@ -82,7 +82,7 @@ void VorbisMetaDataModel::setCover(const QPixmap &pix)
         QByteArray data;
         QBuffer buffer(&data);
         buffer.open(QIODevice::WriteOnly);
-        pix.save(&buffer, "JPEG");
+        img.save(&buffer, "JPEG");
         picture->setMimeType("image/jpeg");
         picture->setData(TagLib::ByteVector(data.constData(), data.size()));
         m_tag->addPicture(picture);
@@ -119,7 +119,7 @@ QString VorbisMetaDataModel::lyrics() const
 
         if(!map["UNSYNCEDLYRICS"].isEmpty())
             return TStringToQString(map["UNSYNCEDLYRICS"].front());
-        else if(!map["LYRICS"].isEmpty())
+        if(!map["LYRICS"].isEmpty())
             return TStringToQString(map["LYRICS"].front());
     }
 
@@ -136,7 +136,7 @@ VorbisCommentModel::~VorbisCommentModel()
 
 QString VorbisCommentModel::name() const
 {
-    return "Vorbis Comment";
+    return u"Vorbis Comment"_s;
 }
 
 QString VorbisCommentModel::value(Qmmp::MetaData key) const
@@ -219,7 +219,7 @@ void VorbisCommentModel::setValue(Qmmp::MetaData key, const QString &value)
         tag->setYear(value.toInt());
         return;
     case Qmmp::DISCNUMBER:
-        value == "0" ?
+        value == "0"_L1 ?
         tag->removeFields("DISCNUMBER"):
         tag->addField("DISCNUMBER", str, true);
     }
