@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -20,7 +20,6 @@
 
 #include <QMessageBox>
 #include <QFileInfo>
-#include <QRegularExpression>
 #include <qmmp/cueparser.h>
 #include "wavpackmetadatamodel.h"
 #include "decoder_wavpack.h"
@@ -37,14 +36,14 @@ DecoderProperties DecoderWavPackFactory::properties() const
 {
     DecoderProperties properties;
     properties.name = tr("WavPack Plugin");
-    properties.filters = QStringList { "*.wv" };
+    properties.filters = QStringList { u"*.wv"_s };
     properties.description = tr("WavPack Files");
-    properties.contentTypes = QStringList { "audio/x-wavpack" };
-    properties.shortName = "wavpack";
+    properties.contentTypes = QStringList { u"audio/x-wavpack"_s };
+    properties.shortName = u"wavpack"_s;
     properties.hasAbout = true;
     properties.hasSettings = false;
     properties.noInput = true;
-    properties.protocols = QStringList { "file", "wvpack" };
+    properties.protocols = QStringList { u"file"_s, u"wvpack"_s };
     return properties;
 }
 
@@ -60,11 +59,9 @@ QList<TrackInfo *> DecoderWavPackFactory::createPlayList(const QString &path, Tr
     int track = -1; //cue track
     QString filePath = path;
 
-    if(path.contains("://")) //is it cue track?
+    if(path.contains(u"://"_s)) //is it cue track?
     {
-        filePath.remove("wvpack://");
-        filePath.remove(QRegularExpression("#\\d+$"));
-        track = path.section("#", -1).toInt();
+        filePath = TrackInfo::pathFromUrl(path, &track);
         parts = TrackInfo::AllParts; //extract all metadata for single cue track
     }
 
@@ -84,7 +81,7 @@ QList<TrackInfo *> DecoderWavPackFactory::createPlayList(const QString &path, Tr
 #endif
     if (!ctx)
     {
-        qWarning("DecoderWavPackFactory: error: %s", err);
+        qCWarning(plugin, "error: %s", err);
         delete info;
         return QList<TrackInfo *>();
     }
@@ -95,7 +92,7 @@ QList<TrackInfo *> DecoderWavPackFactory::createPlayList(const QString &path, Tr
         info->setValue(Qmmp::SAMPLERATE, WavpackGetSampleRate(ctx));
         info->setValue(Qmmp::CHANNELS, WavpackGetNumChannels(ctx));
         info->setValue(Qmmp::BITS_PER_SAMPLE, WavpackGetBitsPerSample(ctx));
-        info->setValue(Qmmp::FORMAT_NAME, "WavPack");
+        info->setValue(Qmmp::FORMAT_NAME, u"WavPack"_s);
         info->setValue(Qmmp::FILE_SIZE, QFileInfo(filePath).size()); //adds file size for cue tracks
         info->setDuration((qint64)WavpackGetNumSamples(ctx) * 1000 / WavpackGetSampleRate(ctx));
     }
@@ -104,13 +101,13 @@ QList<TrackInfo *> DecoderWavPackFactory::createPlayList(const QString &path, Tr
     {
         char value[200] = { 0 };
         WavpackGetTagItem(ctx, "REPLAYGAIN_TRACK_GAIN", value, sizeof(value));
-        info->setValue(Qmmp::REPLAYGAIN_TRACK_GAIN, value);
+        info->setValue(Qmmp::REPLAYGAIN_TRACK_GAIN, QString::fromLatin1(value));
         WavpackGetTagItem(ctx, "REPLAYGAIN_TRACK_PEAK", value, sizeof(value));
-        info->setValue(Qmmp::REPLAYGAIN_TRACK_PEAK, value);
+        info->setValue(Qmmp::REPLAYGAIN_TRACK_PEAK, QString::fromLatin1(value));
         WavpackGetTagItem(ctx, "REPLAYGAIN_ALBUM_GAIN", value, sizeof(value));
-        info->setValue(Qmmp::REPLAYGAIN_ALBUM_GAIN, value);
+        info->setValue(Qmmp::REPLAYGAIN_ALBUM_GAIN, QString::fromLatin1(value));
         WavpackGetTagItem(ctx, "REPLAYGAIN_ALBUM_PEAK", value, sizeof(value));
-        info->setValue(Qmmp::REPLAYGAIN_ALBUM_PEAK, value);
+        info->setValue(Qmmp::REPLAYGAIN_ALBUM_PEAK, QString::fromLatin1(value));
     }
 
     if(parts & TrackInfo::MetaData)
@@ -118,49 +115,47 @@ QList<TrackInfo *> DecoderWavPackFactory::createPlayList(const QString &path, Tr
         int cue_len = WavpackGetTagItem(ctx, "cuesheet", nullptr, 0);
         if(cue_len > 0)
         {
-            char value[cue_len + 1];
-            memset(value, 0, cue_len + 1);
-            WavpackGetTagItem(ctx, "cuesheet", value, cue_len + 1);
+            QByteArray value(cue_len, '\0');
+            WavpackGetTagItem(ctx, "cuesheet", value.data(), cue_len);
 
             CueParser parser(value);
             parser.setDuration(info->duration());
             parser.setProperties(info->properties());
-            parser.setUrl("wvpack", filePath);
+            parser.setUrl(u"wvpack"_s, filePath);
 
             WavpackCloseFile(ctx);
             delete info;
             return parser.createPlayList(track);
         }
-        else if(track > 0)
+
+        if(track > 0)
         {
             WavpackCloseFile(ctx);
             delete info;
             return QList<TrackInfo *>();
         }
-        else
-        {
-            char value[200] = { 0 };
-            WavpackGetTagItem(ctx, "Album", value, sizeof(value));
-            info->setValue(Qmmp::ALBUM, QString::fromUtf8(value));
-            WavpackGetTagItem(ctx, "Artist", value, sizeof(value));
-            info->setValue(Qmmp::ARTIST, QString::fromUtf8(value));
-            WavpackGetTagItem(ctx, "Album Artist", value, sizeof(value));
-            info->setValue(Qmmp::ALBUMARTIST, QString::fromUtf8(value));
-            WavpackGetTagItem(ctx, "Comment", value, sizeof(value));
-            info->setValue(Qmmp::COMMENT, QString::fromUtf8(value));
-            WavpackGetTagItem(ctx, "Genre", value, sizeof(value));
-            info->setValue(Qmmp::GENRE, QString::fromUtf8(value));
-            WavpackGetTagItem(ctx, "Title", value, sizeof(value));
-            info->setValue(Qmmp::TITLE, QString::fromUtf8(value));
-            WavpackGetTagItem(ctx, "Composer", value, sizeof(value));
-            info->setValue(Qmmp::COMPOSER, QString::fromUtf8(value));
-            WavpackGetTagItem(ctx, "Year", value, sizeof(value));
-            info->setValue(Qmmp::YEAR, QString::fromUtf8(value).toInt());
-            WavpackGetTagItem(ctx, "Track", value, sizeof(value));
-            info->setValue(Qmmp::TRACK, QString::fromUtf8(value).toInt());
-            WavpackGetTagItem(ctx, "Disc", value, sizeof(value));
-            info->setValue(Qmmp::DISCNUMBER, QString::fromUtf8(value).toInt());
-        }
+
+        char value[200] = { 0 };
+        WavpackGetTagItem(ctx, "Album", value, sizeof(value));
+        info->setValue(Qmmp::ALBUM, QString::fromUtf8(value));
+        WavpackGetTagItem(ctx, "Artist", value, sizeof(value));
+        info->setValue(Qmmp::ARTIST, QString::fromUtf8(value));
+        WavpackGetTagItem(ctx, "Album Artist", value, sizeof(value));
+        info->setValue(Qmmp::ALBUMARTIST, QString::fromUtf8(value));
+        WavpackGetTagItem(ctx, "Comment", value, sizeof(value));
+        info->setValue(Qmmp::COMMENT, QString::fromUtf8(value));
+        WavpackGetTagItem(ctx, "Genre", value, sizeof(value));
+        info->setValue(Qmmp::GENRE, QString::fromUtf8(value));
+        WavpackGetTagItem(ctx, "Title", value, sizeof(value));
+        info->setValue(Qmmp::TITLE, QString::fromUtf8(value));
+        WavpackGetTagItem(ctx, "Composer", value, sizeof(value));
+        info->setValue(Qmmp::COMPOSER, QString::fromUtf8(value));
+        WavpackGetTagItem(ctx, "Year", value, sizeof(value));
+        info->setValue(Qmmp::YEAR, QString::fromUtf8(value).toInt());
+        WavpackGetTagItem(ctx, "Track", value, sizeof(value));
+        info->setValue(Qmmp::TRACK, QString::fromUtf8(value).toInt());
+        WavpackGetTagItem(ctx, "Disc", value, sizeof(value));
+        info->setValue(Qmmp::DISCNUMBER, QString::fromUtf8(value).toInt());
     }
 
     WavpackCloseFile (ctx);
@@ -169,22 +164,24 @@ QList<TrackInfo *> DecoderWavPackFactory::createPlayList(const QString &path, Tr
 
 MetaDataModel* DecoderWavPackFactory::createMetaDataModel(const QString &path, bool readOnly)
 {
-    if (!path.contains("://") || path.startsWith("wvpack://"))
+    if(!path.contains(u"://"_s) || path.startsWith(u"wvpack://"_s))
         return new WavPackMetaDataModel(path, readOnly);
-    else
-        return nullptr;
+
+    return nullptr;
 }
 
-void DecoderWavPackFactory::showSettings(QWidget *)
-{}
+QDialog *DecoderWavPackFactory::createSettings(QWidget *)
+{
+    return nullptr;
+}
 
 void DecoderWavPackFactory::showAbout(QWidget *parent)
 {
-    QMessageBox::about (parent, tr("About WavPack Audio Plugin"),
-                        tr("Qmmp WavPack Audio Plugin")+"\n"+
-                        tr("WavPack library version:") +
-                        QString(" %1").arg(WavpackGetLibraryVersionString ())+"\n"+
-                        tr("Written by: Ilya Kotov <forkotov02@ya.ru>"));
+    QMessageBox::about(parent, tr("About WavPack Audio Plugin"),
+                       tr("Qmmp WavPack Audio Plugin") + QChar::LineFeed +
+                       tr("WavPack library version: %1").arg(QString::fromLatin1(WavpackGetLibraryVersionString())) +
+                       QChar::LineFeed +
+                       tr("Written by: Ilya Kotov <forkotov02@ya.ru>"));
 }
 
 QString DecoderWavPackFactory::translation() const
