@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2010-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2010-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -30,12 +30,12 @@ WildMidiSettingsDialog::WildMidiSettingsDialog(QWidget *parent)
 {
     m_ui->setupUi(this);
 
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(u"Midi"_s);
     QStringList files = WildMidiHelper::instance()->configFiles();
-    QString configPath = files.isEmpty() ? QString() : files.constFirst();
+    QString conf_path = files.isEmpty() ? QString() : files.constFirst();
     m_ui->confPathComboBox->addItems(files);
-    m_ui->confPathComboBox->setEditText(settings.value(u"conf_path"_s, configPath).toString());
+    m_ui->confPathComboBox->setEditText(settings.value(u"conf_path"_s, conf_path).toString());
     m_ui->sampleRateComboBox->addItem(tr("44100 Hz"), 44100);
     m_ui->sampleRateComboBox->addItem(tr("48000 Hz"), 48000);
     int i = m_ui->sampleRateComboBox->findData(settings.value(u"sample_rate"_s, 44100).toInt());
@@ -52,7 +52,7 @@ WildMidiSettingsDialog::~WildMidiSettingsDialog()
 
 void WildMidiSettingsDialog::accept()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(u"Midi"_s);
     settings.setValue(u"conf_path"_s, m_ui->confPathComboBox->currentText());
     settings.setValue(u"sample_rate"_s,
