@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -32,9 +32,9 @@ AlsaSettingsDialog::AlsaSettingsDialog(QWidget *parent)
     m_ui->deviceComboBox->setEditable (true);
     getCards();
     getSoftDevices();
-    connect(m_ui->deviceComboBox, qOverload<int>(&QComboBox::activated), this, &AlsaSettingsDialog::setText);
-    connect(m_ui->mixerCardComboBox, qOverload<int>(&QComboBox::activated), this, &AlsaSettingsDialog::showMixerDevices);
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    connect(m_ui->deviceComboBox, &QComboBox::activated, this, &AlsaSettingsDialog::setText);
+    connect(m_ui->mixerCardComboBox, &QComboBox::activated, this, &AlsaSettingsDialog::showMixerDevices);
+    QSettings settings;
     settings.beginGroup(u"ALSA"_s);
     m_ui->deviceComboBox->setEditText(settings.value(u"device"_s, u"default"_s).toString());
     m_ui->bufferSpinBox->setValue(settings.value(u"buffer_time"_s, 500).toInt());
@@ -210,7 +210,7 @@ void AlsaSettingsDialog::setText(int n)
 void AlsaSettingsDialog::accept()
 {
     qCDebug(plugin, "AlsaSettingsDialog (ALSA):: writeSettings()");
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(u"ALSA"_s);
     settings.setValue(u"device"_s, m_ui->deviceComboBox->currentText ());
     settings.setValue(u"buffer_time"_s, m_ui->bufferSpinBox->value());
