@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -34,7 +34,7 @@
 
 OutputALSA::OutputALSA()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     QString dev_name = settings.value(u"ALSA/device"_s, u"default"_s).toString();
     m_use_mmap = settings.value(u"ALSA/use_mmap"_s, false).toBool();
     pcm_name = strdup(dev_name.toLatin1().data());
@@ -78,8 +78,8 @@ bool OutputALSA::initialize(quint32 freq, ChannelMap map, Qmmp::AudioFormat form
     uint exact_rate = freq;   /* Sample rate returned by */
 
     /* load settings from config */
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    settings.beginGroup("ALSA"_L1);
+    QSettings settings;
+    settings.beginGroup("ALSA");
     uint buffer_time = settings.value(u"buffer_time"_s, 500).toUInt()*1000;
     uint period_time = settings.value(u"period_time"_s, 100).toUInt()*1000;
     bool use_pause =  settings.value(u"use_snd_pcm_pause"_s, false).toBool();
@@ -158,7 +158,7 @@ bool OutputALSA::initialize(quint32 freq, ChannelMap map, Qmmp::AudioFormat form
     }
     if (c != (uint)map.count())
     {
-        qCWarning(plugin) << "The channel number" << map.count() << "is not supported by your hardware";
+        qCWarning(plugin, "The channel number %lld is not supported by your hardware", map.count());
         qCWarning(plugin, "==> Using %d instead.", c);
     }
     if ((err = snd_pcm_hw_params_set_period_time_near(pcm_handle, hwparams, &period_time, nullptr)) < 0)
@@ -396,7 +396,7 @@ VolumeALSA::VolumeALSA()
 {
     //alsa mixer
     m_mixer = nullptr;
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     QString card = settings.value(u"ALSA/mixer_card"_s, u"hw:0"_s).toString();
     QString dev = settings.value(u"ALSA/mixer_device"_s, u"PCM"_s).toString();
     setupMixer(card, dev);
