@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2014-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2014-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -100,32 +100,22 @@ bool OutputDirectSound::initialize(quint32 freq, ChannelMap map, Qmmp::AudioForm
     {
         wfex.Format.wBitsPerSample = 16;
         wfex.Samples.wValidBitsPerSample = 16;
-        wfex.SubFormat = KSDATAFORMAT_SUBTYPE_PCM;
     }
     else if(format == Qmmp::PCM_S24LE)
     {
         wfex.Format.wBitsPerSample  = 32;
         wfex.Samples.wValidBitsPerSample = 24;
-        wfex.SubFormat = KSDATAFORMAT_SUBTYPE_PCM;
     }
     else if(format == Qmmp::PCM_S32LE)
     {
         wfex.Format.wBitsPerSample  = 32;
         wfex.Samples.wValidBitsPerSample = 32;
-        wfex.SubFormat = KSDATAFORMAT_SUBTYPE_PCM;
-    }
-    else if(format == Qmmp::PCM_FLOAT)
-    {
-        wfex.Format.wBitsPerSample  = 32;
-        wfex.Samples.wValidBitsPerSample = 32;
-        wfex.SubFormat = KSDATAFORMAT_SUBTYPE_IEEE_FLOAT;
     }
     else
     {
         format = Qmmp::PCM_S16LE;
         wfex.Format.wBitsPerSample  = 16;
         wfex.Samples.wValidBitsPerSample = 16;
-        wfex.SubFormat = KSDATAFORMAT_SUBTYPE_PCM;
     }
 
     wfex.Format.nBlockAlign     = (wfex.Format.wBitsPerSample / 8) * wfex.Format.nChannels;
@@ -146,6 +136,7 @@ bool OutputDirectSound::initialize(quint32 freq, ChannelMap map, Qmmp::AudioForm
     }
 
     wfex.dwChannelMask = mask;
+    wfex.SubFormat = KSDATAFORMAT_SUBTYPE_PCM;
 
     if((result = m_primaryBuffer->SetFormat((WAVEFORMATEX*)&wfex)) != DS_OK)
     {
@@ -334,7 +325,7 @@ DWORD OutputDirectSound::bytesToWrite()
 VolumeDirectSound::VolumeDirectSound()
 {
     OutputDirectSound::volumeControl = this;
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     m_volume.left = settings.value("DirectSound/left_volume"_L1, 100).toInt();
     m_volume.right = settings.value("DirectSound/right_volume"_L1, 100).toInt();
     m_muted = settings.value("DirectSound/muted"_L1, false).toBool();
@@ -343,7 +334,7 @@ VolumeDirectSound::VolumeDirectSound()
 VolumeDirectSound::~VolumeDirectSound()
 {
     m_volume = VolumeDirectSound::volume();
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.setValue("DirectSound/left_volume"_L1, m_volume.left);
     settings.setValue("DirectSound/right_volume"_L1, m_volume.right);
     settings.setValue("DirectSound/muted"_L1, m_muted);
