@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2010-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2010-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -86,9 +86,9 @@ Oss4SettingsDialog::Oss4SettingsDialog (QWidget *parent) : QDialog (parent), m_u
                                                                         QString::fromLatin1(audio_info.devnode)));
         }
     }
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     m_ui->deviceComboBox->setEditText(settings.value(u"OSS4/device"_s, QStringLiteral(DEFAULT_DEV)).toString());
-    connect(m_ui->deviceComboBox, qOverload<int>(&QComboBox::activated), this, &Oss4SettingsDialog::setText);
+    connect(m_ui->deviceComboBox, &QComboBox::activated, this, &Oss4SettingsDialog::setText);
 }
 
 Oss4SettingsDialog::~Oss4SettingsDialog()
@@ -104,7 +104,7 @@ void Oss4SettingsDialog::setText(int n)
 void Oss4SettingsDialog::accept()
 {
     qCDebug(plugin) << Q_FUNC_INFO;
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.setValue(u"OSS4/device"_s, m_ui->deviceComboBox->currentText());
     QDialog::accept();
 }
