@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2010-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2010-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -69,7 +69,7 @@ Qmmp::ChannelPosition OutputOSS4::m_oss_pos[16] =
 
 OutputOSS4::OutputOSS4() : Output()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     m_audio_device = settings.value(u"OSS4/device"_s, QStringLiteral(DEFAULT_DEV)).toString();
     m_instance = this;
 }
@@ -204,7 +204,7 @@ void OutputOSS4::reset()
 /***** MIXER *****/
 VolumeOSS4::VolumeOSS4()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     m_volume = settings.value(u"OSS4/volume"_s, 0x3232).toInt();
     OutputOSS4::m_vc = this;
 }
@@ -214,7 +214,7 @@ VolumeOSS4::~VolumeOSS4()
     VolumeSettings vol = VolumeOSS4::volume();
     m_volume = (vol.right << 8) | vol.left;
     OutputOSS4::m_vc = nullptr;
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.setValue(u"OSS4/volume"_s, m_volume);
 }
 
