@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -448,7 +448,7 @@ void OutputPipeWire::onRegistryEventGlobal(void *data, uint32_t id, uint32_t per
 //volume control
 VolumePipeWire::VolumePipeWire()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     m_volume.left = settings.value("OutputPipeWire/left_volume"_L1, 100).toInt();
     m_volume.right = settings.value("OutputPipeWire/right_volume"_L1, 100).toInt();
     OutputPipeWire::volumeControl = this;
@@ -456,9 +456,9 @@ VolumePipeWire::VolumePipeWire()
 
 VolumePipeWire::~VolumePipeWire()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    settings.setValue("OutputPipeWire/left_volume"_L1, m_volume.left);
-    settings.setValue("OutputPipeWire/right_volume"_L1, m_volume.right);
+    QSettings settings;
+    settings.setValue("OutputPipeWire/left_volume", m_volume.left);
+    settings.setValue("OutputPipeWire/right_volume", m_volume.right);
     OutputPipeWire::volumeControl = nullptr;
 }
 
