@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -347,16 +347,16 @@ void OutputPulseAudio::stream_success_cb(pa_stream *, int success, void *data)
 VolumePulseAudio::VolumePulseAudio()
 {
     OutputPulseAudio::volumeControl = this;
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     m_volume.left = settings.value("PulseAudio/left_volume"_L1, 100).toInt();
     m_volume.right = settings.value("PulseAudio/right_volume"_L1, 100).toInt();
 }
 
 VolumePulseAudio::~VolumePulseAudio()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    settings.setValue("PulseAudio/left_volume"_L1, m_volume.left);
-    settings.setValue("PulseAudio/right_volume"_L1, m_volume.right);
+    QSettings settings;
+    settings.setValue("PulseAudio/left_volume", m_volume.left);
+    settings.setValue("PulseAudio/right_volume", m_volume.right);
     OutputPulseAudio::volumeControl = nullptr;
 }
 
