@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2007-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2007-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -30,7 +30,7 @@ OutputProperties OutputPulseAudioFactory::properties() const
     properties.name = tr("PulseAudio Plugin");
     properties.hasAbout = true;
     properties.hasSettings = false;
-    properties.shortName = "pulse";
+    properties.shortName = "pulse"_L1;
     return properties;
 }
 
@@ -44,15 +44,16 @@ Volume *OutputPulseAudioFactory::createVolume()
     return new VolumePulseAudio;
 }
 
-void OutputPulseAudioFactory::showSettings(QWidget* parent)
+QDialog *OutputPulseAudioFactory::createSettings(QWidget *parent)
 {
-   Q_UNUSED(parent);
+    Q_UNUSED(parent);
+    return nullptr;
 }
 
 void OutputPulseAudioFactory::showAbout(QWidget *parent)
 {
-   QMessageBox::about (parent, tr("About PulseAudio Output Plugin"),
-                        tr("Qmmp PulseAudio Output Plugin")+"\n"+
+    QMessageBox::about(parent, tr("About PulseAudio Output Plugin"),
+                       tr("Qmmp PulseAudio Output Plugin") + QChar::LineFeed +
                        tr("Written by: Ilya Kotov <forkotov02@ya.ru>"));
 }
 
