@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2017-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2017-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -44,8 +44,8 @@ ShoutClient::~ShoutClient()
 
 void ShoutClient::readSettings()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
-    settings.beginGroup("Shout"_L1);
+    QSettings settings;
+    settings.beginGroup("Shout");
     shout_set_host(m_shout_conn, settings.value(u"host"_s, u"127.0.0.1"_s).toString().toLatin1().constData());
     shout_set_port(m_shout_conn, settings.value(u"port"_s, 8000).toInt());
     shout_set_password(m_shout_conn, settings.value(u"passw"_s, u"hackme"_s).toString().toLatin1().constData());
