@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2016-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2016-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -56,7 +56,7 @@ OutputWASAPI::DWASAPIChannels OutputWASAPI::m_wasapi_pos[10]  = {
 OutputWASAPI::OutputWASAPI() : Output()
 {
     instance = this;
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     m_id = settings.value("WASAPI/device"_L1, u"default"_s).toString();
     m_bufferSize = settings.value("WASAPI/buffer_size"_L1, 1000).toInt() * 1000LL;
     m_exclusive = settings.value("WASAPI/exclusive_mode"_L1, false).toBool();
@@ -120,32 +120,22 @@ bool OutputWASAPI::initialize(quint32 freq, ChannelMap map, Qmmp::AudioFormat fo
     {
         wfex.Format.wBitsPerSample = 16;
         wfex.Samples.wValidBitsPerSample = 16;
-        wfex.SubFormat = KSDATAFORMAT_SUBTYPE_PCM;
     }
     else if(format == Qmmp::PCM_S24LE)
     {
         wfex.Format.wBitsPerSample  = 32;
         wfex.Samples.wValidBitsPerSample = 24;
-        wfex.SubFormat = KSDATAFORMAT_SUBTYPE_PCM;
     }
     else if(format == Qmmp::PCM_S32LE)
     {
         wfex.Format.wBitsPerSample  = 32;
         wfex.Samples.wValidBitsPerSample = 32;
-        wfex.SubFormat = KSDATAFORMAT_SUBTYPE_PCM;
-    }
-    else if(format == Qmmp::PCM_FLOAT)
-    {
-        wfex.Format.wBitsPerSample  = 32;
-        wfex.Samples.wValidBitsPerSample = 32;
-        wfex.SubFormat = KSDATAFORMAT_SUBTYPE_IEEE_FLOAT;
     }
     else
     {
         format = Qmmp::PCM_S16LE;
         wfex.Format.wBitsPerSample  = 16;
         wfex.Samples.wValidBitsPerSample = 16;
-        wfex.SubFormat = KSDATAFORMAT_SUBTYPE_PCM;
     }
 
     wfex.Format.nBlockAlign     = (wfex.Format.wBitsPerSample / 8) * wfex.Format.nChannels;
@@ -166,6 +156,7 @@ bool OutputWASAPI::initialize(quint32 freq, ChannelMap map, Qmmp::AudioFormat fo
     }
 
     wfex.dwChannelMask = mask;
+    wfex.SubFormat = KSDATAFORMAT_SUBTYPE_PCM;
 
     AUDCLNT_SHAREMODE mode = m_exclusive ? AUDCLNT_SHAREMODE_EXCLUSIVE :  AUDCLNT_SHAREMODE_SHARED;
     DWORD streamFlags = 0;
@@ -323,7 +314,7 @@ void OutputWASAPI::uninitialize()
 VolumeWASAPI::VolumeWASAPI()
 {
     OutputWASAPI::volumeControl = this;
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     m_volume.left = settings.value("WASAPI/left_volume"_L1, 100).toInt();
     m_volume.right = settings.value("WASAPI/right_volume"_L1, 100).toInt();
     m_muted = settings.value("WASAPI/muted"_L1, false).toBool();
@@ -332,7 +323,7 @@ VolumeWASAPI::VolumeWASAPI()
 VolumeWASAPI::~VolumeWASAPI()
 {
     m_volume = VolumeWASAPI::volume();
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.setValue("WASAPI/left_volume"_L1, m_volume.left);
     settings.setValue("WASAPI/right_volume"_L1, m_volume.right);
     settings.setValue("WASAPI/muted"_L1, m_muted);
