@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2016-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2016-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -19,7 +19,7 @@
  ***************************************************************************/
 
 #include <QMessageBox>
-#include "settingsdialog.h"
+#include "wasapisettingsdialog.h"
 #include "outputwasapi.h"
 #include "outputwasapifactory.h"
 
@@ -29,7 +29,7 @@ OutputProperties OutputWASAPIFactory::properties() const
     properties.name = tr("WASAPI Plugin");
     properties.hasAbout = true;
     properties.hasSettings = true;
-    properties.shortName = "wasapi";
+    properties.shortName = "wasapi"_L1;
     return properties;
 }
 
@@ -43,16 +43,15 @@ Volume *OutputWASAPIFactory::createVolume()
     return new VolumeWASAPI;
 }
 
-void OutputWASAPIFactory::showSettings(QWidget* parent)
+QDialog *OutputWASAPIFactory::createSettings(QWidget* parent)
 {
-    SettingsDialog *s = new SettingsDialog(parent);
-    s->show();
+    return new WASAPISettingsDialog(parent);
 }
 
 void OutputWASAPIFactory::showAbout(QWidget *parent)
 {
-   QMessageBox::about (parent, tr("About WASAPI Output Plugin"),
-                        tr("Qmmp WASAPI Output Plugin")+"\n"+
+    QMessageBox::about(parent, tr("About WASAPI Output Plugin"),
+                       tr("Qmmp WASAPI Output Plugin") + QChar::LineFeed +
                        tr("Written by: Ilya Kotov <forkotov02@ya.ru>"));
 }
 
