@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2017-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2017-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -36,7 +36,7 @@ WASAPISettingsDialog::WASAPISettingsDialog(QWidget *parent) :
 
     enumDevices();
 
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     QString id = settings.value("WASAPI/device"_L1, u"default"_s).toString();
     int index = m_ui->deviceComboBox->findData(id);
     m_ui->deviceComboBox->setCurrentIndex(qMax(index, 0));
@@ -51,7 +51,7 @@ WASAPISettingsDialog::~WASAPISettingsDialog()
 
 void WASAPISettingsDialog::accept()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     int index = m_ui->deviceComboBox->currentIndex();
     settings.setValue("WASAPI/device"_L1, m_ui->deviceComboBox->itemData(index).toString());
     settings.setValue("WASAPI/buffer_size"_L1, m_ui->bufferSizeSpinBox->value());
