@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -31,9 +31,9 @@
 PlayListFormatProperties XSPFPlaylistFormat::XSPFPlaylistFormat::properties() const
 {
     PlayListFormatProperties p;
-    p.filters = QStringList { "*.xspf" };
-    p.shortName = "xspf";
-    p.contentTypes = QStringList { "application/xspf+xml" };
+    p.filters = QStringList { u"*.xspf"_s };
+    p.shortName = "xspf"_L1;
+    p.contentTypes = QStringList { u"application/xspf+xml"_s };
     return p;
 }
 
@@ -46,9 +46,9 @@ QList<PlayListTrack*> XSPFPlaylistFormat::decode(const QByteArray &contents)
     //remove control symbols to avoid xml errors
     for(int i = 0; i < contents_copy.size(); ++i)
     {
-        if(contents_copy[i] <= 0x1F)
+        if(contents_copy[i] <= QChar(0x1F))
         {
-            contents_copy.replace(i, 1, "");
+            contents_copy.replace(i, 1, QString());
             i--;
         }
     }
@@ -60,7 +60,7 @@ QList<PlayListTrack*> XSPFPlaylistFormat::decode(const QByteArray &contents)
         if (xml.isStartElement())
         {
             currentTag = xml.name().toString();
-            if(currentTag == "track")
+            if(currentTag == "track"_L1)
                 out << new PlayListTrack();
         }
         else if (xml.isCharacters() && !xml.isWhitespace())
@@ -68,31 +68,31 @@ QList<PlayListTrack*> XSPFPlaylistFormat::decode(const QByteArray &contents)
             if(out.isEmpty())
                 continue;
 
-            if(currentTag == "location")
+            if(currentTag == "location"_L1)
             {
                 QUrl url(xml.text().toString());
-                if (url.scheme() == "file")  //remove scheme for local files only
-                    out.last()->setPath(QUrl::fromPercentEncoding(url.toString().toLatin1()).remove("file://"));
+                if (url.scheme() == "file"_L1)  //remove scheme for local files only
+                    out.last()->setPath(QUrl::fromPercentEncoding(url.toString().toLatin1()).remove(u"file://"_s));
                 else
                     out.last()->setPath(QUrl::fromPercentEncoding(url.toString().toLatin1()));
             }
-            else if(currentTag == "title")
+            else if(currentTag == "title"_L1)
             {
                 out.last()->setValue(Qmmp::TITLE, xml.text().toString());
             }
-            else if(currentTag == "creator")
+            else if(currentTag == "creator"_L1)
             {
                 out.last()->setValue(Qmmp::ARTIST, xml.text().toString());
             }
-            else if(currentTag == "annotation")
+            else if(currentTag == "annotation"_L1)
             {
                 out.last()->setValue(Qmmp::COMMENT, xml.text().toString());
             }
-            else if(currentTag == "album")
+            else if(currentTag == "album"_L1)
             {
                 out.last()->setValue(Qmmp::ALBUM, xml.text().toString());
             }
-            else if(currentTag == "meta" && xml.attributes().value("rel") == "year")
+            else if(currentTag == "meta"_L1 && xml.attributes().value("rel"_L1) == QLatin1String("year"))
             {
                 out.last()->setValue(Qmmp::YEAR, xml.text().toString());
             }
@@ -103,7 +103,7 @@ QList<PlayListTrack*> XSPFPlaylistFormat::decode(const QByteArray &contents)
 
     if(xml.hasError())
     {
-        qDebug("XSPFPlaylistFormat: parse error: %s (row:%lld, col:%lld",
+        qCDebug(plugin, "parse error: %s (row:%lld, col:%lld",
                qPrintable(xml.errorString()), xml.lineNumber(), xml.columnNumber());
     }
     return out;
@@ -116,47 +116,46 @@ QByteArray XSPFPlaylistFormat::encode(const QList<PlayListTrack*> &files, const
     QString xspfDir = QFileInfo(path).canonicalPath();
     QByteArray out;
     QXmlStreamWriter xml(&out);
-    xml.setCodec("UTF-8");
     xml.setAutoFormatting(true);
     xml.writeStartDocument();
-    xml.writeStartElement("playlist");
-    xml.writeAttribute("version", "1");
-    xml.writeAttribute("xmlns", "http://xspf.org/ns/0/");
-    xml.writeTextElement("creator", "qmmp-" + Qmmp::strVersion());
-    xml.writeStartElement("trackList");
+    xml.writeStartElement("playlist"_L1);
+    xml.writeAttribute("version"_L1, "1"_L1);
+    xml.writeAttribute("xmlns"_L1, u"http://xspf.org/ns/0/"_s);
+    xml.writeTextElement("creator"_L1, u"qmmp-"_s + Qmmp::strVersion());
+    xml.writeStartElement("trackList"_L1);
 
     int counter = 1;
-    for(PlayListTrack *f : qAsConst(files))
+    for(PlayListTrack *f : std::as_const(files))
     {
-        xml.writeStartElement("track");
+        xml.writeStartElement("track"_L1);
 
         QString url;
-        if (f->path().contains("://"))
+        if (f->path().contains(u"://"_s))
         {
-            url = QUrl::toPercentEncoding(f->path(), ":/");
+            url = QString::fromLatin1(QUrl::toPercentEncoding(f->path(), ":/"));
         }
         else if(f->path().startsWith(xspfDir)) //relative path
         {
             QString p = f->path();
             p.remove(0, xspfDir.size());
-            if(p.startsWith("/"))
+            if(p.startsWith(QLatin1Char('/')))
                 p.remove(0, 1);
-            url = QUrl::toPercentEncoding(p, ":/");
+            url = QString::fromLatin1(QUrl::toPercentEncoding(p, ":/"));
         }
         else  //absolute path
         {
-            url = QUrl::toPercentEncoding(QLatin1String("file://") + f->path(), ":/");
+            url = QString::fromLatin1(QUrl::toPercentEncoding(u"file://"_s + f->path(), ":/"));
         }
 
-        xml.writeTextElement("location", url);
-        xml.writeTextElement("title", f->value(Qmmp::TITLE));
-        xml.writeTextElement("creator", f->value(Qmmp::ARTIST));
-        xml.writeTextElement("annotation", f->value(Qmmp::COMMENT));
-        xml.writeTextElement("album", f->value(Qmmp::ALBUM));
-        xml.writeTextElement("trackNum", QString::number(counter));
+        xml.writeTextElement("location"_L1, url);
+        xml.writeTextElement("title"_L1, f->value(Qmmp::TITLE));
+        xml.writeTextElement("creator"_L1, f->value(Qmmp::ARTIST));
+        xml.writeTextElement("annotation"_L1, f->value(Qmmp::COMMENT));
+        xml.writeTextElement("album"_L1, f->value(Qmmp::ALBUM));
+        xml.writeTextElement("trackNum"_L1, QString::number(counter));
 
-        xml.writeStartElement("meta");
-        xml.writeAttribute("rel", "year");
+        xml.writeStartElement("meta"_L1);
+        xml.writeAttribute("rel"_L1, u"year"_s);
         xml.writeCharacters(f->value(Qmmp::YEAR));
         xml.writeEndElement(); // meta
         xml.writeEndElement(); // track
