@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2016 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -22,16 +22,16 @@
 #include <QMessageBox>
 #include <curl/curlver.h>
 #include <qmmp/qmmp.h>
-#include "settingsdialog.h"
+#include "httpsettingsdialog.h"
 #include "httpinputsource.h"
 #include "httpinputfactory.h"
 
 InputSourceProperties HTTPInputFactory::properties() const
 {
     InputSourceProperties properties;
-    properties.protocols = QStringList { "http", "https" };
+    properties.protocols = QStringList { u"http"_s, u"https"_s };
     properties.name = tr("HTTP Plugin");
-    properties.shortName = "http";
+    properties.shortName = "http"_L1;
     properties.hasAbout = true;
     properties.hasSettings = true;
     return properties;
@@ -42,18 +42,17 @@ InputSource *HTTPInputFactory::create(const QString &url, QObject *parent)
     return new HTTPInputSource(url, parent);
 }
 
-void HTTPInputFactory::showSettings(QWidget *parent)
+QDialog *HTTPInputFactory::createSettings(QWidget *parent)
 {
-    SettingsDialog *s = new SettingsDialog(parent);
-    s->show();
+    return new HttpSettingsDialog(parent);
 }
 
 void HTTPInputFactory::showAbout(QWidget *parent)
 {
-    QMessageBox::about (parent, tr("About HTTP Transport Plugin"),
-                        tr("Qmmp HTTP Transport Plugin")+"\n"+
-                        tr("Compiled against libcurl-%1").arg(LIBCURL_VERSION) + "\n" +
-                        tr("Written by: Ilya Kotov <forkotov02@ya.ru>"));
+    QMessageBox::about(parent, tr("About HTTP Transport Plugin"),
+                       tr("Qmmp HTTP Transport Plugin") + QChar::LineFeed +
+                       tr("Compiled against libcurl-%1").arg(QLatin1StringView(LIBCURL_VERSION)) + QChar::LineFeed +
+                       tr("Written by: Ilya Kotov <forkotov02@ya.ru>"));
 }
 
 QString HTTPInputFactory::translation() const
