@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2013 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -24,8 +24,8 @@
 HTTPInputSource::HTTPInputSource(const QString &url, QObject *parent) : InputSource(url,parent)
 {
     m_reader = new HttpStreamReader(url, this);
-    connect(m_reader, SIGNAL(ready()),SIGNAL(ready()));
-    connect(m_reader, SIGNAL(error()),SIGNAL(error()));
+    connect(m_reader, &HttpStreamReader::ready, this, &HTTPInputSource::ready);
+    connect(m_reader, &HttpStreamReader::error, this, &HTTPInputSource::error);
 }
 
 QIODevice *HTTPInputSource::ioDevice() const
