@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2010-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2010-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -19,27 +19,25 @@
  ***************************************************************************/
 #include <QSettings>
 #include <QRegularExpression>
-#include <QTextCodec>
 #include <qmmp/qmmp.h>
 #ifdef WITH_ENCA
 #include <enca.h>
 #endif
+#include <qmmp/qmmptextcodec.h>
 #include "ui_httpsettingsdialog.h"
 #include "httpsettingsdialog.h"
 
 HttpSettingsDialog::HttpSettingsDialog(QWidget *parent) : QDialog(parent), m_ui(new Ui::HttpSettingsDialog)
 {
     m_ui->setupUi(this);
-    findCodecs();
-    for(const QTextCodec *codec : qAsConst(m_codecs))
-        m_ui->icyEncodingComboBox->addItem(QString::fromLatin1(codec->name()));
+    m_ui->icyEncodingComboBox->addItems(QmmpTextCodec::availableCharsets());
 #ifdef WITH_ENCA
     size_t n = 0;
     const char **langs = enca_get_languages(&n);
     for (size_t i = 0; i < n; ++i)
         m_ui->encaAnalyserComboBox->addItem(QString::fromLatin1(langs[i]));
 #endif
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup("HTTP"_L1);
     int pos = m_ui->icyEncodingComboBox->findText(settings.value("icy_encoding"_L1, u"UTF-8"_s).toString());
     m_ui->icyEncodingComboBox->setCurrentIndex(pos);
@@ -65,7 +63,7 @@ HttpSettingsDialog::~HttpSettingsDialog()
 
 void HttpSettingsDialog::accept()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup("HTTP"_L1);
     settings.setValue("icy_encoding"_L1, m_ui->icyEncodingComboBox->currentText());
     settings.setValue("buffer_size"_L1, m_ui->bufferSizeSpinBox->value());
@@ -79,42 +77,3 @@ void HttpSettingsDialog::accept()
     settings.endGroup();
     QDialog::accept();
 }
-
-void HttpSettingsDialog::findCodecs()
-{
-    QMap<QString, QTextCodec *> codecMap;
-    static const QRegularExpression iso8859RegExp(u"ISO[- ]8859-([0-9]+).*"_s);
-
-    for(int mib : QTextCodec::availableMibs())
-    {
-        QTextCodec *codec = QTextCodec::codecForMib(mib);
-
-        QString sortKey = QString::fromLatin1(codec->name().toUpper());
-        int rank;
-        QRegularExpressionMatch match;
-
-        if (sortKey.startsWith(u"UTF-8"_s))
-        {
-            rank = 1;
-        }
-        else if (sortKey.startsWith(u"UTF-16"_s))
-        {
-            rank = 2;
-        }
-        else if ((match = iso8859RegExp.match(sortKey)).hasMatch())
-        {
-            if (match.captured(1).size() == 1)
-                rank = 3;
-            else
-                rank = 4;
-        }
-        else
-        {
-            rank = 5;
-        }
-        sortKey.prepend(QChar('0' + rank));
-
-        codecMap.insert(sortKey, codec);
-    }
-    m_codecs = codecMap.values();
-}
