@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2010-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2010-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -42,10 +42,8 @@ private slots:
     virtual void accept() override;
 
 private:
-    void findCodecs();
-
     Ui::HttpSettingsDialog *m_ui;
-    QList<QTextCodec *> m_codecs;
+
 };
 
 #endif
