@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -21,13 +21,13 @@
 #include <QStringList>
 #include <QDir>
 #include <QSettings>
-#include <QTextCodec>
 #include <stdint.h>
 #include <stdlib.h>
 #include <qmmp/qmmpsettings.h>
 #include <qmmp/qmmp.h>
 #include <qmmp/statehandler.h>
 #include <qmmp/inputsource.h>
+#include <qmmp/qmmptextcodec.h>
 #include "httpinputsource.h"
 #include "httpstreamreader.h"
 
@@ -145,17 +145,15 @@ HttpStreamReader::HttpStreamReader(const QString &url, HTTPInputSource *parent)
 {
     curl_global_init(CURL_GLOBAL_ALL);
     m_thread = new DownloadThread(this);
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup("HTTP"_L1);
-    m_codec = QTextCodec::codecForName(settings.value("icy_encoding"_L1, "UTF-8"_ba).toByteArray());
+    m_codec = new QmmpTextCodec(settings.value("icy_encoding"_L1, u"UTF-8"_s).toByteArray ());
     m_prebufferSize = settings.value("buffer_size"_L1, 384).toInt() * 1024;
     m_bufferDuration = settings.value("buffer_duration"_L1, 10000).toInt();
     if(settings.value(u"override_user_agent"_s, false).toBool())
         m_userAgent = settings.value("user_agent"_L1).toString();
     if(m_userAgent.isEmpty())
-        m_userAgent = QStringLiteral("qmmp/%1").arg(Qmmp::strVersion());
-    if(!m_codec)
-        m_codec = QTextCodec::codecForName("UTF-8");
+        m_userAgent = QStringLiteral("qmmp/%1").arg(Qmmp::strVersion());;
 #ifdef WITH_ENCA
     if(settings.value("use_enca"_L1, false).toBool())
         m_analyser = enca_analyser_alloc(settings.value("enca_lang"_L1).toByteArray ().constData());
@@ -180,6 +178,7 @@ HttpStreamReader::~HttpStreamReader()
     if(m_analyser)
         enca_analyser_free(m_analyser);
 #endif
+    delete m_codec;
 }
 
 bool HttpStreamReader::atEnd() const
@@ -491,16 +490,13 @@ void HttpStreamReader::parseICYMetaData(char *data, qint64 size)
     if(m_analyser)
     {
         EncaEncoding encoding = enca_analyse(m_analyser, (uchar *) data, size);
-        QTextCodec *prevCodec = m_codec;
-
         if(encoding.charset != ENCA_CS_UNKNOWN)
         {
-            qCDebug(plugin, "detected charset: %s", enca_charset_name(encoding.charset,ENCA_NAME_STYLE_ENCA));
-            m_codec = QTextCodec::codecForName(enca_charset_name(encoding.charset,ENCA_NAME_STYLE_ENCA));
+            qCDebug(plugin, "detected charset: %s",
+                   enca_charset_name(encoding.charset,ENCA_NAME_STYLE_ENCA));
+            delete m_codec;
+            m_codec = new QmmpTextCodec(enca_charset_name(encoding.charset,ENCA_NAME_STYLE_ENCA));
         }
-
-        if (!m_codec)
-            m_codec = prevCodec;
     }
 #endif
     QString str = m_codec->toUnicode(data).trimmed();
@@ -534,7 +530,7 @@ void HttpStreamReader::parseICYMetaData(char *data, qint64 size)
     }
 }
 
-void HttpStreamReader::sendStreamInfo(QTextCodec *codec)
+void HttpStreamReader::sendStreamInfo(QmmpTextCodec *codec)
 {
     QHash<QString, QString> info;
     for(auto it = m_stream.header.cbegin(); it != m_stream.header.cend(); ++it)
