@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -32,7 +32,7 @@
 #include <enca.h>
 #endif
 
-class QTextCodec;
+class QmmpTextCodec;
 class QFileInfo;
 class DownloadThread;
 class HTTPInputSource;
@@ -97,7 +97,7 @@ private:
     qint64 readBuffer(char* data, qint64 maxlen);
     void readICYMetaData();
     void parseICYMetaData(char *data, qint64 size);
-    void sendStreamInfo(QTextCodec *codec);
+    void sendStreamInfo(QmmpTextCodec *codec);
     CURL *m_handle = nullptr;
     QMutex m_mutex;
     HttpStreamData m_stream;
@@ -109,7 +109,7 @@ private:
     bool m_meta_sent = false;
     size_t m_prebufferSize;
     int m_bufferDuration;
-    QTextCodec *m_codec = nullptr;
+    QmmpTextCodec *m_codec = nullptr;
     DownloadThread *m_thread;
     HTTPInputSource *m_parent;
 #ifdef WITH_ENCA
