@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2013-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2013-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -106,7 +106,14 @@ FileSystemBrowser::FileSystemBrowser(QWidget *parent) :
     m_treeModeAction->setCheckable(true);
     m_showFilterAction = new QAction(tr("Quick Search"), this);
     m_showFilterAction->setCheckable(true);
-    m_sortAction = new QAction(QIcon::fromTheme(u"view-sort-ascending"_s), tr("Sort"), this);
+    QMenu *sortMenu = new QMenu(this);
+    sortMenu->addAction(tr("By Name"), this, [this]() { m_fileSystemModel->sort(0); } );
+    sortMenu->addAction(tr("By Size"), this, [this]() { m_fileSystemModel->sort(1); } );
+    sortMenu->addAction(tr("By Type"), this, [this]() { m_fileSystemModel->sort(2); } );
+    sortMenu->addAction(tr("By Date"), this, [this]() { m_fileSystemModel->sort(3); } );
+    m_sortAction = sortMenu->menuAction();
+    m_sortAction->setIcon(QIcon::fromTheme(u"view-sort-ascending"_s));
+    m_sortAction->setText(tr("Sort"));
 
     const QList<QAction *> contextMenuActions = {
         addToPlayListAction, replacePlayListAction, selectDirAction, separatorAction,
@@ -114,12 +121,6 @@ FileSystemBrowser::FileSystemBrowser(QWidget *parent) :
     };
 
     addActions(contextMenuActions);
-    QMenu *sortMenu = new QMenu(this);
-    sortMenu->addAction(tr("By Name"), this, [this]() { m_fileSystemModel->sort(0); } );
-    sortMenu->addAction(tr("By Size"), this, [this]() { m_fileSystemModel->sort(1); } );
-    sortMenu->addAction(tr("By Type"), this, [this]() { m_fileSystemModel->sort(2); } );
-    sortMenu->addAction(tr("By Date"), this, [this]() { m_fileSystemModel->sort(3); } );
-    m_sortAction->setMenu(sortMenu);
     connect(addToPlayListAction, &QAction::triggered, this, &FileSystemBrowser::addToPlayList);
     connect(replacePlayListAction, &QAction::triggered, this, &FileSystemBrowser::replacePlayList);
     connect(selectDirAction, &QAction::triggered, this, &FileSystemBrowser::selectDirectory);
@@ -133,7 +134,7 @@ FileSystemBrowser::FileSystemBrowser(QWidget *parent) :
 
 FileSystemBrowser::~FileSystemBrowser()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(u"Simple"_s);
     settings.setValue(u"fsbrowser_current_dir"_s, m_fileSystemModel->rootDirectory().canonicalPath());
     settings.setValue(u"fsbrowser_quick_search"_s, m_showFilterAction->isChecked());
@@ -143,7 +144,7 @@ FileSystemBrowser::~FileSystemBrowser()
 
 void FileSystemBrowser::readSettings()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(u"Simple"_s);
     if(!m_update)
     {
