@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2013-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2013-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -25,10 +25,11 @@
 
 class QFileSystemModel;
 class QModelIndex;
-class QListView;
+class QTreeView;
 class QAction;
 class QLineEdit;
 class FileSystemFilterProxyModel;
+class PlayListModel;
 
 namespace Utils {
    class ElidingLabel;
@@ -50,19 +51,23 @@ public:
 private slots:
     void onListViewActivated(const QModelIndex &index);
     void addToPlayList();
+    void replacePlayList();
     void selectDirectory();
     void onFilterLineEditTextChanged(const QString &str);
+    void setTreeViewMode(bool enabled);
 
 private:
+    QStringList selectedPaths() const;
     void setCurrentDirectory(const QString &path);
     bool m_update = false;
     Utils::ElidingLabel *m_label;
     QFileSystemModel *m_fileSystemModel;
-    QListView *m_listView;
-    FileSystemFilterProxyModel  *m_proxyModel;
+    QTreeView *m_treeView;
+    FileSystemFilterProxyModel *m_proxyModel;
     QLineEdit *m_filterLineEdit;
     QAction *m_showFilterAction;
-
+    QAction *m_treeModeAction;
+    QAction *m_sortAction;
 };
 
 #endif // FILESYSTEMBROWSER_H
