@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2010-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2010-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -50,7 +50,7 @@ QSUiActionManager::QSUiActionManager(QObject *parent) :
         { EJECT, createAction(tr("&Play Files"), u"eject"_s, tr("E"), u"media-eject"_s) },
         { RECORD, createAction2(tr("&Record"), u"record"_s, QString(), u"media-record"_s) },
         { REPEAT_ALL, createAction2(tr("&Repeat Playlist"), u"repeate_playlist"_s, tr("R"), u"media-playlist-repeat"_s) },
-        { REPEAT_TRACK, createAction2(tr("&Repeat Track"), u"repeate_track"_s, tr("Ctrl+R"), u"media-repeat-single"_s) },
+        { REPEAT_TRACK, createAction2(tr("&Repeat Track"), u"repeate_track"_s, tr("Ctrl+R")) },
         { SHUFFLE, createAction2(tr("&Shuffle"), u"shuffle"_s, tr("S"), u"media-playlist-shuffle"_s) },
         { NO_PL_ADVANCE, createAction2(tr("&No Playlist Advance"), u"no_playlist_advance"_s, tr("Ctrl+N")) },
         { TRANSIT_BETWEEN_PLAYLISTS, createAction2(tr("&Transit between playlists"), u"transit_between_playlists"_s) },
@@ -177,7 +177,7 @@ void QSUiActionManager::readStates()
 
 void QSUiActionManager::saveStates()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(u"Simple"_s);
     settings.setValue(u"pl_show_header"_s, m_actions[PL_SHOW_HEADER]->isChecked());
     settings.endGroup();
@@ -185,7 +185,7 @@ void QSUiActionManager::saveStates()
 
 void QSUiActionManager::saveActions()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(u"SimpleUiShortcuts"_s);
 
     for(const QAction *action : std::as_const(m_actions))
@@ -223,7 +223,7 @@ void QSUiActionManager::registerAction(int id, QAction *action, const QString &c
     if(m_actions.value(id))
         qCFatal(plugin) << "invalid action id";
 
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(u"SimpleUiShortcuts"_s);
     action->setShortcut(settings.value(confKey, key).toString());
     action->setProperty("defaultShortcut", key);
@@ -247,7 +247,7 @@ void QSUiActionManager::registerWidget(int id, QWidget *w, const QString &text,
 
 void QSUiActionManager::registerDockWidget(QDockWidget *w, const QString &confKey, const QString &key)
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(u"SimpleUiShortcuts"_s);
     w->toggleViewAction()->setShortcut(settings.value(confKey, key).toString());
     settings.endGroup();
@@ -316,7 +316,7 @@ QSUiActionManager::ToolBarInfo QSUiActionManager::defaultToolBar() const
 QList<QSUiActionManager::ToolBarInfo> QSUiActionManager::readToolBarSettings() const
 {
     QList<ToolBarInfo> list;
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     int iconSize = settings.value(u"Simple/toolbar_icon_size"_s, -1).toInt();
     if(iconSize <= 0)
         iconSize = qApp->style()->pixelMetric(QStyle::PM_ToolBarIconSize);
@@ -342,7 +342,7 @@ QList<QSUiActionManager::ToolBarInfo> QSUiActionManager::readToolBarSettings() c
 
 void QSUiActionManager::writeToolBarSettings(const QList<ToolBarInfo> &l)
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginWriteArray(u"SimpleUiToolbars"_s);
     for(int i = 0; i < l.size(); ++i)
     {
