@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2011-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2011-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -53,7 +53,7 @@ private:
     QSUiListWidget *m_listWidget = nullptr;
 
     template <typename Func1>
-    void addAction(QKeySequence keys, Func1 slot);
+    void addAction(QKeyCombination keys, Func1 slot);
 
     enum SelectMode
     {
