@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -74,7 +74,7 @@ QSUiListWidget::~QSUiListWidget()
 
 void QSUiListWidget::readSettings()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(u"Simple"_s);
     m_show_protocol = settings.value(u"pl_show_protocol"_s, false).toBool();
     bool show_popup = settings.value(u"pl_show_popup"_s, false).toBool();
@@ -222,7 +222,7 @@ void QSUiListWidget::paintEvent(QPaintEvent *)
 
 void QSUiListWidget::mouseDoubleClickEvent(QMouseEvent *e)
 {
-    int y = e->pos().y();
+    int y = e->position().y();
     int lineIndex = lineAt(y);
 
     if(lineIndex >= 0)
@@ -264,7 +264,7 @@ void QSUiListWidget::mousePressEvent(QMouseEvent *e)
     if(m_popupWidget)
         m_popupWidget->hide();
 
-    const int pressedLine = lineAt(e->pos().y());
+    const int pressedLine = lineAt(e->position().y());
 
     if(pressedLine >= 0 && pressedLine < m_model->lineCount())
     {
@@ -340,7 +340,7 @@ void QSUiListWidget::wheelEvent(QWheelEvent *e)
             ((m_firstLine == m_model->lineCount() - m_row_count) && e->angleDelta().y() < 0))
         return;
 
-    m_firstLine -= e->angleDelta().y() * qApp->wheelScrollLines() / 120;
+    m_firstLine -= e->angleDelta().y() / 40;  //40*3 TODO: add step to config
     if(m_firstLine < 0)
         m_firstLine = 0;
 
@@ -377,7 +377,7 @@ bool QSUiListWidget::event(QEvent *e)
         if(e->type() == QEvent::Leave)
             m_popupWidget->deactivate();
     }
-    if(e->type() == QEvent::StyleChange || e->type() == QEvent::PaletteChange)
+    if(e->type() == QEvent::StyleChange)
         readSettings();
 
     return QWidget::event(e);
@@ -411,6 +411,7 @@ void QSUiListWidget::updateList(int flags)
             m_firstLine = 0;
             m_scrollBar->setMaximum(0);
             m_scrollBar->setValue(0);
+            emit positionChanged(0, 0);
         }
         else if(m_firstLine + m_row_count >= count)
         {
@@ -424,6 +425,7 @@ void QSUiListWidget::updateList(int flags)
                 m_firstLine = qMax(0, count - m_row_count);
             m_scrollBar->setMaximum(count - m_row_count);
             m_scrollBar->setValue(m_firstLine);
+            emit positionChanged(m_firstLine, m_firstLine);
         }
         else if(!m_filterMode && (m_lineCount > 0) && (m_lineCount != m_model->lineCount()) &&
                 m_firstItem && m_model->itemAtLine(m_firstLine) != m_firstItem)
@@ -431,11 +433,13 @@ void QSUiListWidget::updateList(int flags)
             restoreFirstVisible();
             m_scrollBar->setMaximum(count - m_row_count);
             m_scrollBar->setValue(m_firstLine);
+            emit positionChanged(m_firstLine, m_model->lineCount() - m_row_count);
         }
         else
         {
             m_scrollBar->setMaximum(count - m_row_count);
             m_scrollBar->setValue(m_firstLine);
+            emit positionChanged(m_firstLine, count - m_row_count);
         }
         m_scrollBar->blockSignals(false);
 
@@ -660,6 +664,12 @@ void QSUiListWidget::removeUnselected()
     }
 }
 
+void QSUiListWidget::updateSkin()
+{
+    m_drawer.loadSystemColors();
+    update();
+}
+
 void QSUiListWidget::dragEnterEvent(QDragEnterEvent *event)
 {
     if(event->mimeData()->hasFormat(u"text/uri-list"_s) || event->mimeData()->hasFormat(u"application/json"_s))
@@ -673,7 +683,7 @@ void QSUiListWidget::dropEvent(QDropEvent *event)
         event->acceptProposedAction();
         QApplication::restoreOverrideCursor();
 
-        int index = lineAt(event->pos().y());
+        int index = lineAt(event->position().y());
         if(index < 0)
             index = qMin(m_firstLine + m_row_count, m_model->lineCount());
 
@@ -699,7 +709,7 @@ void QSUiListWidget::dragLeaveEvent(QDragLeaveEvent *)
 
 void QSUiListWidget::dragMoveEvent(QDragMoveEvent *event)
 {
-    int index = lineAt(event->pos().y());
+    int index = lineAt(event->position().y());
     if(index < 0)
         index = qMin(m_firstLine + m_row_count, m_model->lineCount());
     if(index != m_dropLine)
@@ -812,14 +822,14 @@ void QSUiListWidget::mouseMoveEvent(QMouseEvent *e)
 
     if(e->buttons() == Qt::LeftButton)
     {
-        if (m_prev_y > e->pos().y())
+        if (m_prev_y > e->position().y())
             m_scroll_direction = TOP;
-        else if (m_prev_y < e->pos().y())
+        else if (m_prev_y < e->position().y())
             m_scroll_direction = DOWN;
         else
             m_scroll_direction = NONE;
 
-        if(e->pos().y() < 0 || e->pos().y() > height())
+        if(e->position().y() < 0 || e->position().y() > height())
         {
             if(!m_timer->isActive())
                 m_timer->start();
@@ -827,7 +837,7 @@ void QSUiListWidget::mouseMoveEvent(QMouseEvent *e)
         }
         m_timer->stop();
 
-        int index = lineAt(e->pos().y());
+        int index = lineAt(e->position().y());
 
         if(index >= 0)
         {
@@ -847,13 +857,13 @@ void QSUiListWidget::mouseMoveEvent(QMouseEvent *e)
             m_model->moveTracks(m_model->trackIndexAtLine(m_pressedLine),
                                m_model->trackIndexAtLine(index));
 
-            m_prev_y = e->pos().y();
+            m_prev_y = e->position().y();
             m_pressedLine = index;
         }
     }
     else if(m_popupWidget)
     {
-        PlayListTrack *track = trackAt(e->pos().y());
+        PlayListTrack *track = trackAt(e->position().y());
         if(!track || m_popupWidget->url() != track->path())
             m_popupWidget->deactivate();
     }
