@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2015-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2015-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -44,7 +44,7 @@ QSUiListWidgetDrawer::~QSUiListWidgetDrawer()
 
 void QSUiListWidgetDrawer::readSettings()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(u"Simple"_s);
     m_show_anchor = settings.value(u"pl_show_anchor"_s, false).toBool();
     m_show_numbers = settings.value(u"pl_show_numbers"_s, true).toBool();
@@ -76,12 +76,21 @@ void QSUiListWidgetDrawer::readSettings()
 
     if(!m_use_system_colors)
     {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 4, 0)
+        m_normal_bg = QColor::fromString(settings.value(u"pl_bg1_color"_s, m_normal_bg.name()).toString());
+        m_alternate_bg = QColor::fromString(settings.value(u"pl_bg2_color"_s, m_alternate_bg.name()).toString());
+        m_selected_bg = QColor::fromString(settings.value(u"pl_highlight_color"_s, m_selected_bg.name()).toString());
+        m_normal = QColor::fromString(settings.value(u"pl_normal_text_color"_s, m_normal.name()).toString());
+        m_highlighted = QColor::fromString(settings.value(u"pl_hl_text_color"_s ,m_highlighted.name()).toString());
+        m_splitter = QColor::fromString(settings.value(u"pl_splitter_color"_s, m_splitter).toString());
+#else
         m_normal_bg.setNamedColor(settings.value(u"pl_bg1_color"_s, m_normal_bg.name()).toString());
         m_alternate_bg.setNamedColor(settings.value(u"pl_bg2_color"_s, m_alternate_bg.name()).toString());
         m_selected_bg.setNamedColor(settings.value(u"pl_highlight_color"_s, m_selected_bg.name()).toString());
         m_normal.setNamedColor(settings.value(u"pl_normal_text_color"_s, m_normal.name()).toString());
         m_highlighted.setNamedColor(settings.value(u"pl_hl_text_color"_s ,m_highlighted.name()).toString());
         m_splitter.setNamedColor(settings.value(u"pl_splitter_color"_s, m_splitter).toString());
+#endif
 
         m_group_bg = m_normal_bg;
         m_group_alt_bg = m_alternate_bg;
@@ -94,16 +103,28 @@ void QSUiListWidgetDrawer::readSettings()
 
     if(settings.value(u"pl_override_group_colors"_s, false).toBool())
     {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 4, 0)
+        m_group_bg = QColor::fromString(settings.value(u"pl_group_bg"_s, m_normal_bg.name()).toString());
+        m_group_alt_bg = m_group_bg;
+        m_group_text = QColor::fromString(settings.value(u"pl_group_text"_s, m_group_text.name()).toString());
+#else
         m_group_bg.setNamedColor(settings.value(u"pl_group_bg"_s, m_normal_bg.name()).toString());
         m_group_alt_bg = m_group_bg;
         m_group_text.setNamedColor(settings.value(u"pl_group_text"_s, m_group_text.name()).toString());
+#endif
     }
 
     if(settings.value(u"pl_override_current_track_colors"_s, false).toBool())
     {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 4, 0)
+        m_current_bg = QColor::fromString(settings.value(u"pl_current_bg_color"_s, m_normal_bg.name()).toString());
+        m_current_alt_bg = m_current_bg;
+        m_current = QColor::fromString(settings.value(u"pl_current_text_color"_s, m_current.name()).toString());
+#else
         m_current_bg.setNamedColor(settings.value(u"pl_current_bg_color"_s, m_normal_bg.name()).toString());
         m_current_alt_bg = m_current_bg;
         m_current.setNamedColor(settings.value(u"pl_current_text_color"_s, m_current.name()).toString());
+#endif
     }
     
     settings.endGroup();
