@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -351,7 +351,7 @@ void QSUiMainWindow::showAppMenu()
 
     QPoint menuPos = pos();
 
-    for(QWidget *o : action->associatedWidgets())
+    for(QObject *o : action->associatedObjects())
     {
         QToolButton *toolButton = qobject_cast<QToolButton *>(o);
         if(toolButton && toolButton->parentWidget())
@@ -395,37 +395,27 @@ void QSUiMainWindow::playPause()
         m_player->play();
 }
 
-bool QSUiMainWindow::event(QEvent *event)
-{
-    if(event->type() == QEvent::StyleChange || event->type() == QEvent::PaletteChange)
-    {
-        const QWidgetList widgets = m_statusBar->findChildren<QWidget *>();
-        for(QWidget *w : std::as_const(widgets))
-            w->setPalette(qApp->palette(w));
-    }
-    return QMainWindow::event(event);
-}
-
-void QSUiMainWindow::closeEvent(QCloseEvent *e)
+void QSUiMainWindow::closeEvent(QCloseEvent *)
 {
     if(!m_hideOnClose || !m_uiHelper->visibilityControl())
         m_uiHelper->exit();
-    QMainWindow::closeEvent(e);
+
 }
 
-void QSUiMainWindow::hideEvent(QHideEvent *e)
+void QSUiMainWindow::hideEvent(QHideEvent *)
 {
     writeSettings();
     m_wasMaximized = isMaximized();
-    QMainWindow::hideEvent(e);
 }
 
 QMenu *QSUiMainWindow::createPopupMenu()
 {
     QMenu *menu = QMainWindow::createPopupMenu();
     menu->addSeparator();
-    menu->addAction(m_menuBarAction);
-    m_menuBarAction->setChecked(menuBar()->isVisible());
+    QAction *menuBarAction = menu->addAction(tr("Menu Bar"));
+    menuBarAction->setCheckable(true);
+    menuBarAction->setChecked(menuBar()->isVisible());
+    connect(menuBarAction, &QAction::toggled, menuBar(), &QMenuBar::setVisible);
     return menu;
 }
 
@@ -648,10 +638,6 @@ void QSUiMainWindow::createActions()
     connect(backwardAction, &QAction::triggered, this, &QSUiMainWindow::backward);
     //application menu
     SET_ACTION(QSUiActionManager::APPLICATION_MENU, this, &QSUiMainWindow::showAppMenu);
-    //menu bar
-    m_menuBarAction = new QAction(tr("Menu Bar"), this);
-    m_menuBarAction->setCheckable(true);
-    connect(m_menuBarAction, &QAction::triggered, menuBar(), &QMenuBar::setVisible);
 
     addActions({ forwardAction, backwardAction });
     addActions(QSUiActionManager::instance()->actions());
@@ -660,7 +646,7 @@ void QSUiMainWindow::createActions()
 
 void QSUiMainWindow::readSettings()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(u"Simple"_s);
     m_titleFormatter.setPattern(settings.value(u"window_title_format"_s, u"%if(%p,%p - %t,%t)"_s).toString());
 
@@ -719,8 +705,7 @@ void QSUiMainWindow::readSettings()
     else
     {
         restoreGeometry(settings.value(u"mw_geometry"_s).toByteArray());
-        m_menuBarAction->setChecked(settings.value(u"show_menubar"_s, true).toBool());
-        menuBar()->setVisible(m_menuBarAction->isChecked());
+        menuBar()->setVisible(settings.value(u"show_menubar"_s, true).toBool());
 
         QByteArray wstate = settings.value(u"mw_state"_s).toByteArray();
         if(wstate.isEmpty())
@@ -820,14 +805,15 @@ void QSUiMainWindow::showTabMenu(const QPoint &pos)
 
 void QSUiMainWindow::writeSettings()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.setValue(u"Simple/mw_geometry"_s, saveGeometry());
     settings.setValue(u"Simple/mw_state"_s, saveState());
     settings.setValue(u"Simple/always_on_top"_s, ACTION(QSUiActionManager::WM_ALLWAYS_ON_TOP)->isChecked());
+    settings.setValue(u"Simple/show_analyzer"_s, ACTION(QSUiActionManager::UI_ANALYZER)->isChecked());
     settings.setValue(u"Simple/show_tabs"_s, ACTION(QSUiActionManager::UI_SHOW_TABS)->isChecked());
     settings.setValue(u"Simple/block_dockwidgets"_s, ACTION(QSUiActionManager::UI_BLOCK_DOCKWIDGETS)->isChecked());
     settings.setValue(u"Simple/block_toolbars"_s, ACTION(QSUiActionManager::UI_BLOCK_TOOLBARS)->isChecked());
-    settings.setValue(u"Simple/show_menubar"_s, m_menuBarAction->isChecked() );
+    settings.setValue(u"Simple/show_menubar"_s, menuBar()->isVisible());
 }
 
 void QSUiMainWindow::savePlayList()
@@ -878,11 +864,13 @@ void QSUiMainWindow::setDockWidgetsBlocked(bool blocked)
         m_ui->waveformSeekBarDockWidget
     };
 
+#if (QT_VERSION < QT_VERSION_CHECK(5, 7, 0))
     if(qApp->platformName() == QLatin1String("wayland"))
     {
         for(QDockWidget *w : std::as_const(widgetList))
             w->setFeatures(QDockWidget::DockWidgetClosable | QDockWidget::DockWidgetMovable);
     }
+#endif
 
     if(blocked)
     {
