@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2015-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2015-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -95,7 +95,7 @@ void QSUiPlayListHeader::readSettings()
         m_metrics = nullptr;
     }
 
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(u"Simple"_s);
 
     QFont header_font = qApp->font("QAbstractItemView");
@@ -757,7 +757,7 @@ int QSUiPlayListHeader::autoResizeColumn() const
 
 void QSUiPlayListHeader::writeSettings()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(u"Simple"_s);
     m_model->saveSettings(&settings);
     QList<QVariant> sizes, alignment;
