@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -43,7 +43,7 @@ QSUiPopupWidget::QSUiPopupWidget(QWidget *parent)
     hlayout->addWidget(m_label1);
 
     //settings
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(u"Simple"_s);
     setWindowOpacity(settings.value(u"popup_opacity"_s, 1.0).toDouble());
     m_coverSize = settings.value(u"popup_cover_size"_s, 48).toInt();
