@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2011-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2011-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -41,11 +41,11 @@ void QSUiPositionSlider::mousePressEvent (QMouseEvent *event)
     {
         int val;
         if(orientation() == Qt::Vertical)
-            val = minimum() + ((maximum() - minimum()) * (height() - event->pos().y())) / height();
+            val = minimum() + ((maximum() - minimum()) * (height() - event->position().y())) / height();
         else if(layoutDirection() == Qt::RightToLeft)
-            val = maximum() - ((maximum() - minimum()) * event->pos().x()) / width();
+            val = maximum() - ((maximum() - minimum()) * event->position().x()) / width();
         else
-            val = minimum() + ((maximum() - minimum()) * event->pos().x()) / width();
+            val = minimum() + ((maximum() - minimum()) * event->position().x()) / width();
 
         if(invertedAppearance())
         {
