@@ -1,6 +1,6 @@
 /***************************************************************************
  *   Copyright (C) 2016 The Qt Company Ltd.                                *
- *   Copyright (C) 2016-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2016-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -86,7 +86,7 @@ void QSUiTabWidget::setCornerWidget(QWidget *widget, Qt::Corner corner)
 
 void QSUiTabWidget::readSettings()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(u"Simple"_s);
     m_tabBar->setTabsClosable(settings.value(u"pl_tabs_closable"_s, false).toBool());
     QFont tab_font = qApp->font(m_tabBar);
