@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2012-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2012-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -212,18 +212,22 @@ void QSUIVisualization::updateCover()
 void QSUIVisualization::mousePressEvent (QMouseEvent *e)
 {
     if (e->button() == Qt::RightButton)
-        m_menu->exec(e->globalPos());
+        m_menu->exec(e->globalPosition().toPoint());
 }
 
 void QSUIVisualization::readSettings()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(u"Simple"_s);
     //general settings
     m_show_cover = settings.value(u"vis_show_cover"_s, true).toBool();
     m_timer->setInterval(1000 / settings.value(u"vis_refresh_rate"_s, 25).toInt());
     QString visName = settings.value(u"vis_type"_s, u"analyzer"_s).toString();
+#if QT_VERSION >= QT_VERSION_CHECK(6, 4, 0)
+    m_bgColor = QColor::fromString(settings.value(u"vis_bg_color"_s, u"Black"_s).toString());
+#else
     m_bgColor.setNamedColor(settings.value(u"vis_bg_color"_s, u"Black"_s).toString());
+#endif
     //analyzer settings
     double peaks_falloff = settings.value(u"vis_peaks_falloff"_s, 0.2).toDouble();
     double analyzer_falloff = settings.value(u"vis_analyzer_falloff"_s, 2.2).toDouble();
@@ -282,7 +286,7 @@ void QSUIVisualization::readSettings()
 
 void QSUIVisualization::writeSettings()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(u"Simple"_s);
 
     QAction *act = m_fpsGroup->checkedAction ();
@@ -381,11 +385,17 @@ void QSUiScope::clear()
 
 void QSUiScope::readSettings()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(u"Simple"_s);
+#if QT_VERSION >= QT_VERSION_CHECK(6, 4, 0)
+    m_color1 = QColor::fromString(settings.value(u"vis_color1"_s, u"#BECBFF"_s).toString());
+    m_color2 = QColor::fromString(settings.value(u"vis_color2"_s, u"#BECBFF"_s).toString());
+    m_color3 = QColor::fromString(settings.value(u"vis_color3"_s, u"#BECBFF"_s).toString());
+#else
     m_color1.setNamedColor(settings.value(u"vis_color1"_s, u"#BECBFF"_s).toString());
     m_color2.setNamedColor(settings.value(u"vis_color2"_s, u"#BECBFF"_s).toString());
     m_color3.setNamedColor(settings.value(u"vis_color3"_s, u"#BECBFF"_s).toString());
+#endif
     settings.endGroup();
 }
 
@@ -422,14 +432,7 @@ void QSUiAnalyzer::process(float *buffer, int width, int height)
         m_x_scale = new int[m_cols + 1] { 0 };
 
         for(int i = 0; i < m_cols + 1; ++i)
-        {
-            m_x_scale[i] = powf(255.0, float(i) / m_cols);
-            if(i > 0)
-            {
-                if(m_x_scale[i - 1] >= m_x_scale[i]) //avoid several bars in a row with the same frequency
-                    m_x_scale[i] = qMin(m_x_scale[i - 1] + 1, m_cols);
-            }
-        }
+            m_x_scale[i] = pow(pow(255.0, 1.0 / m_cols), i);
 
         QLinearGradient gradient(0, 0, 0, m_height);
         gradient.setColorAt(0.33, m_color3);
@@ -443,25 +446,30 @@ void QSUiAnalyzer::process(float *buffer, int width, int height)
 
     double y_scale = (double) 1.25 * m_rows / log(256);
 
-    for(int i = 0; i < m_cols; i++)
+    for (int i = 0; i < m_cols; i++)
     {
-        int y = 0;
+        short y = 0;
         int magnitude = 0;
 
         if(m_x_scale[i] == m_x_scale[i + 1])
         {
-            y = dest[m_x_scale[i]] >> 7; //128
+            y = dest[i];
         }
         for (int k = m_x_scale[i]; k < m_x_scale[i + 1]; k++)
         {
-            y = qMax(dest[k] >> 7, y);
+            y = qMax(dest[k], y);
         }
 
-        if(y > 0)
+        y >>= 7; //256
+
+
+        if (y)
         {
-            magnitude = qBound(0, int(log(y) * y_scale), m_rows);
+            magnitude = int(log (y) * y_scale);
+            magnitude = qBound(0, magnitude, m_rows);
         }
 
+
         m_intern_vis_data[i] -= m_analyzer_falloff * m_rows / 15;
         m_intern_vis_data[i] = magnitude > m_intern_vis_data[i] ? magnitude : m_intern_vis_data[i];
 
@@ -508,12 +516,19 @@ void QSUiAnalyzer::clear()
 
 void QSUiAnalyzer::readSettings()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(u"Simple"_s);
+#if QT_VERSION >= QT_VERSION_CHECK(6, 4, 0)
+    m_color1 = QColor::fromString(settings.value(u"vis_color1"_s, u"#BECBFF"_s).toString());
+    m_color2 = QColor::fromString(settings.value(u"vis_color2"_s, u"#BECBFF"_s).toString());
+    m_color3 = QColor::fromString(settings.value(u"vis_color3"_s, u"#BECBFF"_s).toString());
+    m_peakColor = QColor::fromString(settings.value(u"vis_peak_color"_s, u"#DDDDDD"_s).toString());
+#else
     m_color1.setNamedColor(settings.value(u"vis_color1"_s, u"#BECBFF"_s).toString());
     m_color2.setNamedColor(settings.value(u"vis_color2"_s, u"#BECBFF"_s).toString());
     m_color3.setNamedColor(settings.value(u"vis_color3"_s, u"#BECBFF"_s).toString());
     m_peakColor.setNamedColor(settings.value(u"vis_peak_color"_s, u"#DDDDDD"_s).toString());
+#endif
     m_cell_size =  QSize(14, 8);
     m_peaks_falloff = settings.value(u"vis_peaks_falloff"_s, 0.2).toDouble();
     m_analyzer_falloff = settings.value(u"vis_analyzer_falloff"_s, 2.2).toDouble();
