@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2012-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2012-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -39,7 +39,7 @@ public:
     explicit QSUIVisualization(QWidget *parent = nullptr);
     virtual ~QSUIVisualization();
 
-    void setCover(const QPixmap &pixmap);
+    void setCover(const QImage &img);
     void clear();
     void clearCover();
     QSize sizeHint() const override;
@@ -63,7 +63,7 @@ private:
     void createMenu();
     void updateCover();
 
-    QPixmap m_cover;
+    QImage m_cover;
     QTimer *m_timer;
     QColor m_bgColor;
     bool m_show_cover = false;
