@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2020-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2020-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -56,12 +56,19 @@ QSize QSUiWaveformSeekBar::sizeHint() const
 
 void QSUiWaveformSeekBar::readSettings()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(u"Simple"_s);
+#if QT_VERSION >= QT_VERSION_CHECK(6, 4, 0)
+    m_bgColor = QColor::fromString(settings.value(u"wfsb_bg_color"_s, u"Black"_s).toString());
+    m_rmsColor = QColor::fromString(settings.value(u"wfsb_rms_color"_s, u"#DDDDDD"_s).toString());
+    m_waveFormColor = QColor::fromString(settings.value(u"wfsb_waveform_color"_s, u"#BECBFF"_s).toString());
+    m_progressBar = QColor::fromString(settings.value(u"wfsb_progressbar_color"_s, u"#9633CA10"_s).toString());
+#else
     m_bgColor.setNamedColor(settings.value(u"wfsb_bg_color"_s, u"Black"_s).toString());
     m_rmsColor.setNamedColor(settings.value(u"wfsb_rms_color"_s, u"#DDDDDD"_s).toString());
     m_waveFormColor.setNamedColor(settings.value(u"wfsb_waveform_color"_s, u"#BECBFF"_s).toString());
     m_progressBar.setNamedColor(settings.value(u"wfsb_progressbar_color"_s, u"#9633CA10"_s).toString());
+#endif
     if(!m_update)
     {
         m_update = true;
@@ -142,7 +149,7 @@ void QSUiWaveformSeekBar::onElapsedChanged(qint64 elapsed)
 
 void QSUiWaveformSeekBar::writeSettings()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(u"Simple"_s);
     settings.setValue(u"wfsb_show_two_channels"_s, m_showTwoChannelsAction->isChecked());
     settings.setValue(u"wfsb_show_rms"_s, m_showRmsAction->isChecked());
@@ -189,7 +196,7 @@ void QSUiWaveformSeekBar::mousePressEvent(QMouseEvent *e)
         update();
     }
     else if(e->button() == Qt::RightButton)
-        m_menu->exec(e->globalPos());
+        m_menu->exec(e->globalPosition().toPoint());
 }
 
 void QSUiWaveformSeekBar::mouseReleaseEvent(QMouseEvent *)
