@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2011-2016 by Ilya Kotov                                 *
+ *   Copyright (C) 2011-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -36,9 +36,12 @@ public:
     explicit VolumeSlider(QWidget *parent = nullptr);
     virtual ~VolumeSlider(){}
 
+public slots:
+    void setValue(int value);
+
 protected:
-    virtual void mousePressEvent (QMouseEvent *event) override;
-    virtual void mouseReleaseEvent (QMouseEvent *event) override;
+    virtual void mousePressEvent(QMouseEvent *event) override;
+    virtual void mouseReleaseEvent(QMouseEvent *event) override;
     virtual void wheelEvent(QWheelEvent *event) override;
 
 private slots:
