@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2007-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2007-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   Based on Promoe, an XMMS2 Client                                      *
@@ -43,7 +43,7 @@ Skin *Skin::m_instance = nullptr;
 Skin::Skin(QObject *parent) : QObject (parent)
 {
     m_instance = this;
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     QString path = settings.value("Skinned/skin_path"_L1, SkinReader::defaultSkinPath()).toString();
 #ifdef Q_OS_WIN
     if(Qmmp::isPortable())
@@ -54,9 +54,9 @@ Skin::Skin(QObject *parent) : QObject (parent)
     ACTION(SkinnedActionManager::WM_DOUBLE_SIZE)->setChecked(m_double_size);
     ACTION(SkinnedActionManager::WM_ANTIALIASING)->setChecked(m_antialiasing);
     setSkin(QDir::cleanPath(path), false);
-    /* skin directories */
-    QDir::root().mkpath(Qmmp::userDataPath() + u"/skins"_s);
-    QDir::root().mkpath(Qmmp::configDir() + u"/skins"_s);
+    /* skin directory */
+    QDir skinDir(Qmmp::configDir());
+    skinDir.mkdir(u"skins"_s);
 }
 
 Skin::~Skin()
@@ -176,7 +176,7 @@ const QRegion Skin::getRegion(uint r) const
 
 void Skin::setSkin(const QString &path, bool force)
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     m_use_cursors = settings.value("Skinned/skin_cursors"_L1, false).toBool();
     m_double_size = ACTION(SkinnedActionManager::WM_DOUBLE_SIZE)->isChecked();
     m_antialiasing = ACTION(SkinnedActionManager::WM_ANTIALIASING)->isChecked();
@@ -282,7 +282,7 @@ void Skin::setSkin(const QString &path, bool force)
 
 void Skin::reloadSkin()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     setSkin(settings.value("Skinned/skin_path"_L1, SkinReader::defaultSkinPath()).toString(), false);
 }
 
