@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -44,21 +44,21 @@ int SkinnedBalanceBar::value() const
 void SkinnedBalanceBar::mousePressEvent(QMouseEvent *e)
 {
     m_moving = true;
-    press_pos = e->pos().x();
+    press_pos = e->position().x();
     if(e->button() == Qt::MiddleButton)
     {
         m_value = 0;
         emit sliderPressed();
         emit sliderMoved(m_value);
     }
-    else if(m_pos<e->pos().x() && e->pos().x()<m_pos+11*skin()->ratio())
+    else if(m_pos<e->position().x() && e->position().x()<m_pos+11*skin()->ratio())
     {
-        press_pos = e->pos().x()-m_pos;
+        press_pos = e->position().x()-m_pos;
         emit sliderPressed();
     }
     else
     {
-        m_value = convert(qMax(qMin(width() - 18 * skin()->ratio(), e->pos().x() - 6 * skin()->ratio()),0));
+        m_value = convert(qMax(qMin(width() - 18 * skin()->ratio(), qRound(e->position().x()) - 6 * skin()->ratio()),0));
         press_pos = 6 * skin()->ratio();
         emit sliderPressed();
         if (m_value != m_old)
@@ -73,7 +73,7 @@ void SkinnedBalanceBar::mouseMoveEvent(QMouseEvent *e)
 {
     if(m_moving)
     {
-        int po = e->pos().x();
+        int po = e->position().x();
         po = po - press_pos;
 
         if(0 <= po && po <= width() - 13 * skin()->ratio())
