@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2007-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2007-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -38,7 +38,7 @@ SkinnedEqTitleBar::SkinnedEqTitleBar(SkinnedEqWidget *parent)
     connect(m_close, &SkinnedButton::clicked, m_eq, &SkinnedEqWidget::closed);
     m_shade = new SkinnedButton(this, Skin::EQ_BT_SHADE1_N, Skin::EQ_BT_SHADE1_P, Skin::CUR_EQNORMAL);
     connect(m_shade, &SkinnedButton::clicked, this, &SkinnedEqTitleBar::shade);
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     if(settings.value("Skinned/eq_shaded"_L1, false).toBool())
         shade();
     m_align = true;
@@ -50,7 +50,7 @@ SkinnedEqTitleBar::SkinnedEqTitleBar(SkinnedEqWidget *parent)
 
 SkinnedEqTitleBar::~SkinnedEqTitleBar()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.setValue("Skinned/eq_shaded"_L1, m_shaded);
 }
 
@@ -93,7 +93,7 @@ void SkinnedEqTitleBar::mousePressEvent(QMouseEvent *event)
         m_pos = event->pos();
         break;
     case Qt::RightButton:
-        m_mw->menu()->exec(event->globalPos());
+        m_mw->menu()->exec(event->globalPosition().toPoint());
         break;
     default:
         ;
@@ -104,7 +104,7 @@ void SkinnedEqTitleBar::mouseMoveEvent(QMouseEvent* event)
 {
     if(m_pos.x() < width() - 30 * skin()->ratio())
     {
-        QPoint npos = (event->globalPos() - m_pos);
+        QPoint npos = (event->globalPosition().toPoint() - m_pos);
         Dock::instance()->move(m_eq, npos);
     }
 }
