@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2015-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2015-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -60,17 +60,17 @@ void SkinnedHorizontalSlider::paintEvent(QPaintEvent *)
 
 void SkinnedHorizontalSlider::mousePressEvent(QMouseEvent *e)
 {
-    m_press_pos = e->pos().x();
-    if (m_slider_pos < e->pos().x() && e->pos().x() < m_slider_pos + sliderSize())
+    m_press_pos = e->position().x();
+    if (m_slider_pos < e->position().x() && e->position().x() < m_slider_pos + sliderSize())
     {
-        m_press_pos = e->pos().x() - m_slider_pos;
+        m_press_pos = e->position().x() - m_slider_pos;
     }
     update();
 }
 
 void SkinnedHorizontalSlider::mouseMoveEvent(QMouseEvent* e)
 {
-    int po = e->pos().x() - m_press_pos;
+    int po = e->position().x() - m_press_pos;
     bool rtl = (layoutDirection() == Qt::RightToLeft);
 
     if (0 <= po && po <= width() - sliderSize())
@@ -97,8 +97,13 @@ void SkinnedHorizontalSlider::setPos(int v, int max)
 
 void SkinnedHorizontalSlider::updateSkin()
 {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 4, 0)
+    m_normal = QColor::fromString(m_skin->getPLValue("normal"));
+    m_normal_bg = QColor::fromString(m_skin->getPLValue("normalbg"));
+#else
     m_normal.setNamedColor(m_skin->getPLValue("normal"));
     m_normal_bg.setNamedColor(m_skin->getPLValue("normalbg"));
+#endif
     update();
 }
 
