@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -74,7 +74,7 @@ SkinnedListWidget::~SkinnedListWidget()
 
 void SkinnedListWidget::readSettings()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup("Skinned"_L1);
     m_show_protocol = settings.value("pl_show_protocol"_L1, false).toBool();
     bool show_popup = settings.value("pl_show_popup"_L1, false).toBool();
@@ -176,7 +176,7 @@ void SkinnedListWidget::paintEvent(QPaintEvent *)
 
 void SkinnedListWidget::mouseDoubleClickEvent (QMouseEvent *e)
 {
-    int y = e->pos().y();
+    int y = e->position().y();
     int lineIndex = lineAt(y);
 
     if(lineIndex >= 0)
@@ -206,7 +206,7 @@ void SkinnedListWidget::mousePressEvent(QMouseEvent *e)
     if(m_popupWidget)
         m_popupWidget->hide();
 
-    const int pressedLine = lineAt(e->pos().y());
+    const int pressedLine = lineAt(e->position().y());
 
     if(pressedLine >= 0 && pressedLine < m_model->lineCount())
     {
@@ -280,7 +280,7 @@ void SkinnedListWidget::wheelEvent(QWheelEvent *e)
             ((m_firstLine == m_model->lineCount() - m_row_count) && e->angleDelta().y() < 0))
         return;
 
-    m_firstLine -= e->angleDelta().y() * qApp->wheelScrollLines() / 120;
+    m_firstLine -= e->angleDelta().y() / 40;  //40*3 TODO: add step to config
     if(m_firstLine < 0)
         m_firstLine = 0;
 
@@ -546,7 +546,7 @@ void SkinnedListWidget::dropEvent(QDropEvent *event)
         event->acceptProposedAction();
         QApplication::restoreOverrideCursor();
 
-        int index = lineAt(event->pos().y());
+        int index = lineAt(event->position().y());
         if(index < 0)
             index = qMin(m_firstLine + m_row_count, m_model->lineCount());
 
@@ -572,7 +572,7 @@ void SkinnedListWidget::dragLeaveEvent(QDragLeaveEvent *)
 
 void SkinnedListWidget::dragMoveEvent(QDragMoveEvent *event)
 {
-    int index = lineAt(event->pos().y());
+    int index = lineAt(event->position().y());
     if(index < 0)
         index = qMin(m_firstLine + m_row_count, m_model->lineCount());
     if(index != m_dropLine)
@@ -660,14 +660,14 @@ void SkinnedListWidget::mouseMoveEvent(QMouseEvent *e)
 {    
     if(e->buttons() == Qt::LeftButton)
     {
-        if (m_prev_y > e->pos().y())
+        if (m_prev_y > e->position().y())
             m_scroll_direction = TOP;
-        else if (m_prev_y < e->pos().y())
+        else if (m_prev_y < e->position().y())
             m_scroll_direction = DOWN;
         else
             m_scroll_direction = NONE;
 
-        if(e->pos().y() < 0 || e->pos().y() > height())
+        if(e->position().y() < 0 || e->position().y() > height())
         {
             if(!m_timer->isActive())
                 m_timer->start();
@@ -675,7 +675,7 @@ void SkinnedListWidget::mouseMoveEvent(QMouseEvent *e)
         }
         m_timer->stop();
 
-        int index = lineAt(e->pos().y());
+        int index = lineAt(e->position().y());
 
         if(index >= 0)
         {
@@ -695,13 +695,13 @@ void SkinnedListWidget::mouseMoveEvent(QMouseEvent *e)
             m_model->moveTracks(m_model->trackIndexAtLine(m_pressedLine),
                                m_model->trackIndexAtLine(index));
 
-            m_prev_y = e->pos().y();
+            m_prev_y = e->position().y();
             m_pressedLine = index;
         }
     }
     else if(m_popupWidget)
     {
-        PlayListTrack *track = trackAt(e->pos().y());
+        PlayListTrack *track = trackAt(e->position().y());
         if(!track || m_popupWidget->url() != track->path())
             m_popupWidget->deactivate();
     }
