@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2015-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2015-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -46,7 +46,7 @@ SkinnedListWidgetDrawer::~SkinnedListWidgetDrawer()
 
 void SkinnedListWidgetDrawer::readSettings()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup("Skinned"_L1);
     m_show_anchor = settings.value("pl_show_anchor"_L1, false).toBool();
     m_show_numbers = settings.value ("pl_show_numbers"_L1, true).toBool();
@@ -75,11 +75,19 @@ void SkinnedListWidgetDrawer::readSettings()
     {
         Skin *skin = Skin::instance();
         bool alternate_splitter_color = settings.value("pl_alt_splitter_color"_L1, false).toBool();
+#if QT_VERSION >= QT_VERSION_CHECK(6, 4, 0)
+        m_normal = QColor::fromString(skin->getPLValue("normal"));
+        m_current = QColor::fromString(skin->getPLValue("current"));
+        m_highlighted = m_normal;
+        m_normal_bg = QColor::fromString(skin->getPLValue("normalbg"));
+        m_selected_bg = QColor::fromString(skin->getPLValue("selectedbg"));
+#else
         m_normal.setNamedColor(skin->getPLValue("normal"));
         m_current.setNamedColor(skin->getPLValue("current"));
         m_highlighted = m_normal;
         m_normal_bg.setNamedColor(skin->getPLValue("normalbg"));
         m_selected_bg.setNamedColor(skin->getPLValue("selectedbg"));
+#endif
         m_alternate_bg = m_normal_bg;
         m_splitter = alternate_splitter_color ? m_current : m_normal;
         m_group_bg = m_normal_bg;
@@ -91,6 +99,16 @@ void SkinnedListWidgetDrawer::readSettings()
 
     if(!settings.value("pl_use_skin_colors"_L1, true).toBool())
     {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 4, 0)
+        m_normal_bg = QColor::fromString(settings.value("pl_bg1_color"_L1, m_normal_bg.name()).toString());
+        m_alternate_bg = QColor::fromString(settings.value("pl_bg2_color"_L1, m_alternate_bg.name()).toString());
+        m_selected_bg = QColor::fromString(settings.value("pl_highlight_color"_L1, m_selected_bg.name()).toString());
+        m_normal = QColor::fromString(settings.value("pl_normal_text_color"_L1, m_normal.name()).toString());
+        m_current = QColor::fromString(settings.value("pl_current_text_color"_L1, m_current.name()).toString());
+        m_highlighted = QColor::fromString(settings.value(u"pl_hl_text_color"_s, m_highlighted.name()).toString());
+        m_splitter = QColor::fromString(settings.value("pl_splitter_color"_L1, m_splitter).toString());
+        m_group_text = QColor::fromString(settings.value("pl_group_text"_L1, m_group_text.name()).toString());
+#else
         m_normal_bg.setNamedColor(settings.value("pl_bg1_color"_L1, m_normal_bg.name()).toString());
         m_alternate_bg.setNamedColor(settings.value("pl_bg2_color"_L1, m_alternate_bg.name()).toString());
         m_selected_bg.setNamedColor(settings.value("pl_highlight_color"_L1, m_selected_bg.name()).toString());
@@ -99,6 +117,7 @@ void SkinnedListWidgetDrawer::readSettings()
         m_highlighted.setNamedColor(settings.value(u"pl_hl_text_color"_s, m_highlighted.name()).toString());
         m_splitter.setNamedColor(settings.value("pl_splitter_color"_L1, m_splitter).toString());
         m_group_text.setNamedColor(settings.value("pl_group_text"_L1, m_group_text.name()).toString());
+#endif
         m_group_bg = m_normal_bg;
         m_group_alt_bg = m_alternate_bg;
         m_current_bg = m_normal_bg;
@@ -107,13 +126,21 @@ void SkinnedListWidgetDrawer::readSettings()
 
     if(settings.value("pl_override_group_bg"_L1, false).toBool())
     {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 4, 0)
+        m_group_bg = QColor::fromString(settings.value("pl_group_bg"_L1, m_normal_bg.name()).toString());
+#else
         m_group_bg.setNamedColor(settings.value("pl_group_bg"_L1, m_normal_bg.name()).toString());
+#endif
         m_group_alt_bg = m_group_bg;
     }
 
     if(settings.value("pl_override_current_bg"_L1, false).toBool())
     {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 4, 0)
+        m_current_bg = QColor::fromString(settings.value("pl_current_bg_color"_L1, m_normal_bg.name()).toString());
+#else
         m_current_bg.setNamedColor(settings.value("pl_current_bg_color"_L1, m_normal_bg.name()).toString());
+#endif
         m_current_alt_bg = m_current_bg;
     }
 
