@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -385,8 +385,8 @@ void SkinnedPlayList::mouseMoveEvent (QMouseEvent *e)
         int dx = m_ratio * 25;
         int dy = m_ratio * 29;
 
-        int sx = ((e->pos().x() - 275 * m_ratio) + 14) / dx;
-        int sy = ((e->pos().y() - 116 * m_ratio) + 14) / dy;
+        int sx = ((e->position().x() - 275 * m_ratio) + 14) / dx;
+        int sy = ((e->position().y() - 116 * m_ratio) + 14) / dy;
 
         sx = qMax(sx, 0);
         sy = qMax(sy, 0);
@@ -455,7 +455,7 @@ void SkinnedPlayList::readSettings()
     {
         QScreen *primaryScreen = QGuiApplication::primaryScreen();
         QRect availableGeometry = primaryScreen->availableGeometry();
-        QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+        QSettings settings;
         QPoint pos = settings.value("Skinned/pl_pos"_L1, QPoint (100, 332)).toPoint();
         m_ratio = m_skin->ratio();
         //TODO QGuiApplication::screenAt
@@ -484,7 +484,7 @@ bool SkinnedPlayList::event(QEvent *event)
 
 void SkinnedPlayList::writeSettings()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     //position
     settings.setValue("Skinned/pl_pos"_L1, this->pos());
 }
