@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2015-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2015-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -112,7 +112,7 @@ SkinnedPlayListHeader::~SkinnedPlayListHeader()
 
 void SkinnedPlayListHeader::readSettings()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup("Skinned"_L1);
     m_font.fromString(settings.value("pl_header_font"_L1, qApp->font().toString()).toString());
 
@@ -156,6 +156,21 @@ void SkinnedPlayListHeader::readSettings()
         }
     }
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 4, 0)
+    if(settings.value("pl_use_skin_colors"_L1, true).toBool())
+    {
+        Skin *skin = Skin::instance();
+        m_normal = QColor::fromString(skin->getPLValue("normal"));
+        m_current = QColor::fromString(skin->getPLValue("current"));
+        m_normal_bg = QColor::fromString(skin->getPLValue("normalbg"));
+    }
+    else
+    {
+        m_normal_bg = QColor::fromString(settings.value("pl_bg1_color"_L1, m_normal_bg.name()).toString());
+        m_normal = QColor::fromString(settings.value("pl_normal_text_color"_L1, m_normal.name()).toString());
+        m_current = QColor::fromString(settings.value("pl_current_text_color"_L1,m_current.name()).toString());
+    }
+#else
     if(settings.value("pl_use_skin_colors"_L1, true).toBool())
     {
         Skin *skin = Skin::instance();
@@ -169,6 +184,7 @@ void SkinnedPlayListHeader::readSettings()
         m_normal.setNamedColor(settings.value("pl_normal_text_color"_L1, m_normal.name()).toString());
         m_current.setNamedColor(settings.value("pl_current_text_color"_L1,m_current.name()).toString());
     }
+#endif
 
     QPixmap px1(skinned_arrow_up_xpm);
     QPixmap px2(skinned_arrow_down_xpm);
@@ -857,7 +873,7 @@ const QString SkinnedPlayListHeader::name(int index) const
 
 void SkinnedPlayListHeader::writeSettings()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup("Skinned"_L1);
     m_model->saveSettings(&settings);
     QList<QVariant> sizes, alignment;
