@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -55,7 +55,7 @@ SkinnedPlayListSelector::~SkinnedPlayListSelector()
 
 void SkinnedPlayListSelector::readSettings()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup("Skinned"_L1);
     m_font.fromString(settings.value("pl_font"_L1, QApplication::font().toString()).toString());
     if (m_metrics)
@@ -70,24 +70,42 @@ void SkinnedPlayListSelector::readSettings()
     if(settings.value("pl_use_skin_colors"_L1, true).toBool())
     {
         Skin *skin = Skin::instance();
+#if QT_VERSION >= QT_VERSION_CHECK(6, 4, 0)
+        m_normal = QColor::fromString(skin->getPLValue("normal"));
+        m_current = QColor::fromString(skin->getPLValue("current"));
+        m_normal_bg = QColor::fromString(skin->getPLValue("normalbg"));
+        m_selected_bg = QColor::fromString(skin->getPLValue("selectedbg"));
+#else
         m_normal.setNamedColor(skin->getPLValue("normal"));
         m_current.setNamedColor(skin->getPLValue("current"));
         m_normal_bg.setNamedColor(skin->getPLValue("normalbg"));
         m_selected_bg.setNamedColor(skin->getPLValue("selectedbg"));
+#endif
         m_selected_text = m_normal;
         m_current_bg = m_normal_bg;
     }
     else
     {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 4, 0)
+        m_normal_bg = QColor::fromString(settings.value("pl_bg1_color"_L1, m_normal_bg.name()).toString());
+        m_selected_bg = QColor::fromString(settings.value("pl_highlight_color"_L1, m_selected_bg.name()).toString());
+        m_normal = QColor::fromString(settings.value("pl_normal_text_color"_L1, m_normal.name()).toString());
+        m_current = QColor::fromString(settings.value("pl_current_text_color"_L1, m_current.name()).toString());
+        m_selected_text = QColor::fromString(settings.value("pl_hl_text_color"_L1, m_selected_text.name()).toString());
+#else
         m_normal_bg.setNamedColor(settings.value("pl_bg1_color"_L1, m_normal_bg.name()).toString());
         m_selected_bg.setNamedColor(settings.value("pl_highlight_color"_L1, m_selected_bg.name()).toString());
         m_normal.setNamedColor(settings.value("pl_normal_text_color"_L1, m_normal.name()).toString());
         m_current.setNamedColor(settings.value("pl_current_text_color"_L1, m_current.name()).toString());
         m_selected_text.setNamedColor(settings.value("pl_hl_text_color"_L1, m_selected_text.name()).toString());
-
+#endif
         if(settings.value("pl_override_current_bg"_L1, false).toBool())
         {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 4, 0)
+            m_current_bg = QColor::fromString(settings.value("pl_current_bg_color"_L1, m_normal_bg.name()).toString());
+#else
             m_current_bg.setNamedColor(settings.value("pl_current_bg_color"_L1, m_normal_bg.name()).toString());
+#endif
         }
         else
         {
@@ -242,7 +260,7 @@ void SkinnedPlayListSelector::mousePressEvent (QMouseEvent *e)
     if(e->button() == Qt::RightButton)
     {
         update();
-        m_menu->exec(e->globalPos());
+        m_menu->exec(e->globalPosition().toPoint());
         return;
     }
 
@@ -291,7 +309,7 @@ void SkinnedPlayListSelector::mouseReleaseEvent (QMouseEvent *e)
 
 void SkinnedPlayListSelector::mouseDoubleClickEvent (QMouseEvent *e)
 {
-    if(e->button() == Qt::LeftButton && !(m_scrollable && (e->pos().x() > width() - 40)))
+    if(e->button() == Qt::LeftButton && !(m_scrollable && (e->position().x() > width() - 40)))
         ACTION(SkinnedActionManager::PL_RENAME)->trigger();
     else
         QWidget::mouseDoubleClickEvent(e);
