@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -59,14 +59,14 @@ void SkinnedPlayListSlider::mousePressEvent(QMouseEvent *e)
 {
     m_moving = true;
     m_pressed = true;
-    m_press_pos = e->pos().y();
-    if(m_pos < e->pos().y() && e->pos().y() < m_pos + 18 * m_skin->ratio())
+    m_press_pos = e->position().y();
+    if(m_pos < e->position().y() && e->position().y() < m_pos + 18 * m_skin->ratio())
     {
-        m_press_pos = e->pos().y()-m_pos;
+        m_press_pos = e->position().y()-m_pos;
     }
     else
     {
-        m_value = convert(qMax(qMin(height() - 18 * m_skin->ratio(), e->pos().y() - 9 * m_skin->ratio()), 0));
+        m_value = convert(qMax(qMin(height() - 18 * m_skin->ratio(), qRound(e->position().y()) - 9 * m_skin->ratio()), 0));
         m_press_pos = 9 * m_skin->ratio();
         if(m_value != m_old)
         {
@@ -88,7 +88,7 @@ void SkinnedPlayListSlider::mouseMoveEvent(QMouseEvent* e)
 {
     if(m_moving)
     {
-        int po = e->pos().y();
+        int po = e->position().y();
         po = po - m_press_pos;
 
         if(0 <= po && po <= height() - 18*m_skin->ratio())
