@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2007-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2007-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -50,7 +50,7 @@ SkinnedPlayListTitleBar::SkinnedPlayListTitleBar(QWidget *parent)
     setMinimumWidth(275 * m_ratio);
 
     readSettings();
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
 #ifdef QMMP_WS_X11
     if(m_pl->useCompiz())
         m_pl->setFixedSize(settings.value("Skinned/pl_size"_L1, QSize(m_ratio * 275, m_ratio * 116)).toSize());
@@ -68,7 +68,7 @@ SkinnedPlayListTitleBar::SkinnedPlayListTitleBar(QWidget *parent)
 
 SkinnedPlayListTitleBar::~SkinnedPlayListTitleBar()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.setValue("Skinned/pl_size"_L1, QSize (m_pl->width(), m_shaded ? m_height:m_pl->height()));
     settings.setValue("Skinned/pl_shaded"_L1, m_shaded);
 }
@@ -130,8 +130,12 @@ void SkinnedPlayListTitleBar::updatePixmap()
     }
     if(m_shaded)
     {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 4, 0)
+        QColor col = QColor::fromString(QString(skin()->getPLValue("normalbg")));
+#else
         QColor col;
         col.setNamedColor(QString(skin()->getPLValue("normalbg")));
+#endif
         paint.setBrush(QBrush(col));
         paint.setPen(col);
         paint.drawRect(8 * m_ratio, m_ratio, 235 * m_ratio + sx * 25, 11 * m_ratio);
@@ -165,7 +169,7 @@ void SkinnedPlayListTitleBar::mousePressEvent(QMouseEvent* event)
         }
         break;
     case Qt::RightButton:
-        m_mw->menu()->exec(event->globalPos());
+        m_mw->menu()->exec(event->globalPosition().toPoint());
         break;
     default:
         ;
@@ -181,7 +185,7 @@ void SkinnedPlayListTitleBar::mouseReleaseEvent(QMouseEvent*)
 
 void SkinnedPlayListTitleBar::mouseMoveEvent(QMouseEvent* event)
 {
-    QPoint npos = event->globalPos() - pos;
+    QPoint npos = event->globalPosition().toPoint() - pos;
     if(m_shaded && m_resize)
     {
 #ifdef QMMP_WS_X11
@@ -191,7 +195,7 @@ void SkinnedPlayListTitleBar::mouseMoveEvent(QMouseEvent* event)
 #endif
 
         int dx = 25 * m_ratio;
-        int sx = ((event->pos().x() - 275 * m_ratio) + 14) / dx;
+        int sx = ((event->position().x() - 275 * m_ratio) + 14) / dx;
         sx = qMax(sx, 0);
         resize(275 * m_ratio + dx * sx, height());
 
@@ -224,7 +228,7 @@ void SkinnedPlayListTitleBar::setModel(PlayListModel *selected, PlayListModel *p
 
 void SkinnedPlayListTitleBar::readSettings()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     m_font.fromString(settings.value("Skinned/pl_font"_L1, QApplication::font().toString()).toString());
     m_font.setPixelSize(12 * m_ratio);
 }
