@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -44,7 +44,7 @@ SkinnedPopupWidget::SkinnedPopupWidget(QWidget *parent)
     hlayout->addWidget (m_label1);
 
     //settings
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup("Skinned"_L1);
     setWindowOpacity(settings.value("popup_opacity"_L1, 1.0).toDouble());
     m_coverSize = settings.value("popup_cover_size"_L1, 48).toInt();
