@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2011-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2011-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -67,7 +67,7 @@ void SkinnedSettings::on_listWidget_itemClicked(QListWidgetItem *item)
 
 void SkinnedSettings::on_resetFontsButton_clicked()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.remove("Skinned/mw_font"_L1);
     settings.remove("Skinned/pl_font"_L1);
     settings.remove("Skinned/pl_group_font"_L1);
@@ -83,7 +83,7 @@ void SkinnedSettings::on_skinInstallButton_clicked()
     for(const QString &path : std::as_const(files))
     {
         QFile file(path);
-        file.copy(Qmmp::configDir() + u"/skins/"_s + QFileInfo(path).fileName());
+        file.copy(Qmmp::userDataPath() + u"/skins"_s + QFileInfo(path).fileName());
     }
     loadSkins();
 }
@@ -119,7 +119,7 @@ void SkinnedSettings::loadFonts()
     extraRowDefaultFont.setPointSize(extraRowDefaultFont.pointSize() - 1);
     extraRowDefaultFont.setStyle(QFont::StyleItalic);
 
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup("Skinned"_L1);
     setFont(m_ui->mainFontLabel, settings.value("mw_font"_L1, qApp->font().toString()).toString());
     setFont(m_ui->plFontLabel, settings.value("pl_font"_L1, qApp->font().toString()).toString());
@@ -142,14 +142,14 @@ void SkinnedSettings::loadSkins()
 {
     QStringList skinPaths = {
         Qmmp::configDir() + QStringLiteral("/skins"),
-    #if defined(Q_OS_WIN) && !defined(Q_OS_CYGWIN)
+#if defined(Q_OS_WIN) && !defined(Q_OS_CYGWIN)
         qApp->applicationDirPath() + QStringLiteral("/skins")
-    #else
+#else
         Qmmp::userDataPath() + QStringLiteral("/skins"),
         Qmmp::dataPath() + QStringLiteral("/skins"),
-        //2.x version compatibility
-        QDir(qApp->applicationDirPath() +  QStringLiteral("/../share/qmmp/skins")).absolutePath()
-    #endif
+        //1.x version compatibility
+        QDir(qApp->applicationDirPath() +  QStringLiteral("/../share/qmmp-1/skins")).absolutePath()
+#endif
     };
 
     skinPaths.removeDuplicates();
@@ -204,7 +204,7 @@ void SkinnedSettings::addWindowTitleString(const QString &str)
 
 void SkinnedSettings::readSettings()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup("Skinned"_L1);
     //playlist
     m_ui->protocolCheckBox->setChecked(settings.value ("pl_show_protocol"_L1, false).toBool());
@@ -248,7 +248,7 @@ void SkinnedSettings::readSettings()
 
 void SkinnedSettings::writeSettings()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup("Skinned"_L1);
     settings.setValue("pl_show_protocol"_L1, m_ui->protocolCheckBox->isChecked());
     settings.setValue("pl_show_numbers"_L1, m_ui->numbersCheckBox->isChecked());
