@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -65,7 +65,7 @@ SkinnedTextScroller::SkinnedTextScroller (QWidget *parent) : QWidget (parent),
 
 SkinnedTextScroller::~SkinnedTextScroller()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.setValue("Skinned/autoscroll"_L1, m_scrollAction->isChecked());
     settings.setValue("Skinned/scroller_transparency"_L1, m_transparencyAction->isChecked());
     delete m_metrics;
@@ -102,7 +102,7 @@ void SkinnedTextScroller::updateSkin()
 {
     setCursor(m_skin->getCursor(Skin::CUR_SONGNAME));
     m_color = m_skin->getMainColor(Skin::MW_FOREGROUND);
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     m_bitmap = settings.value("Skinned/bitmap_font"_L1, false).toBool();
     m_ratio = m_skin->ratio();
     QString fontname = settings.value("Skinned/mw_font"_L1, QApplication::font().toString()).toString();
@@ -166,11 +166,11 @@ void SkinnedTextScroller::paintEvent (QPaintEvent *)
 void SkinnedTextScroller::mousePressEvent(QMouseEvent *e)
 {
     if (e->button() == Qt::RightButton)
-        m_menu->exec(e->globalPos());
+        m_menu->exec(e->globalPosition().toPoint());
     else if (e->button() == Qt::LeftButton && m_scroll)
     {
         m_timer->stop();
-        m_press_pos = e->pos().x() - m_x1;
+        m_press_pos = e->position().x() - m_x1;
         m_pressed = true;
     }
     else
@@ -180,7 +180,7 @@ void SkinnedTextScroller::mousePressEvent(QMouseEvent *e)
 void SkinnedTextScroller::mouseReleaseEvent(QMouseEvent *e)
 {
    if(e->button() == Qt::RightButton)
-        m_menu->exec(e->globalPos());
+        m_menu->exec(e->globalPosition().toPoint());
     else if (e->button() == Qt::LeftButton && m_scroll)
         m_timer->start();
     else
@@ -193,7 +193,7 @@ void SkinnedTextScroller::mouseMoveEvent (QMouseEvent *e)
     if (m_pressed)
     {
         int bound = m_pixmap.width();
-        m_x1 = (e->pos().x() - m_press_pos) % bound;
+        m_x1 = (qRound(e->position().x()) - m_press_pos) % bound;
         if (m_x1 > 0)
             m_x1 -= bound;
         m_x2 = m_x1 + m_pixmap.width();
