@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -99,13 +99,13 @@ void SkinnedTimeIndicatorModel::toggleElapsed()
 
 void SkinnedTimeIndicatorModel::readSettings()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     m_elapsed = settings.value("Skinned/disp_elapsed"_L1, true).toBool();
 }
 
 void SkinnedTimeIndicatorModel::writeSettings()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.setValue("Skinned/disp_elapsed"_L1, m_elapsed);
 }
 
