@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2007-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2007-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -52,7 +52,7 @@ SkinnedTitleBar::SkinnedTitleBar(SkinnedTimeIndicatorModel *model, QWidget *pare
     m_close = new SkinnedButton(this,Skin::BT_CLOSE_N,Skin::BT_CLOSE_P, Skin::CUR_CLOSE);
     connect(m_close, &SkinnedButton::clicked, m_mw, &SkinnedMainWindow::close);
     setActive(false);
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     if(settings.value("Skinned/disp_shaded"_L1, false).toBool())
         shade();
     m_align = true;
@@ -63,7 +63,7 @@ SkinnedTitleBar::SkinnedTitleBar(SkinnedTimeIndicatorModel *model, QWidget *pare
 
 SkinnedTitleBar::~SkinnedTitleBar()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.setValue("Skinned/disp_shaded"_L1, m_shaded);
 }
 
@@ -94,7 +94,7 @@ void SkinnedTitleBar::mousePressEvent(QMouseEvent* event)
         Dock::instance()->updateDock();
         break;
     case Qt::RightButton:
-        m_mw->menu()->exec(event->globalPos());
+        m_mw->menu()->exec(event->globalPosition().toPoint());
     }
 }
 
@@ -106,7 +106,7 @@ void SkinnedTitleBar::mouseMoveEvent(QMouseEvent* event)
 {
     if(m_pos.x() < width() - skin()->ratio() * 37)
     {
-        QPoint npos = (event->globalPos() - m_pos);
+        QPoint npos = (event->globalPosition().toPoint() - m_pos);
         Dock::instance()->move(m_mw, npos);
     }
 }
