@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2007-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2007-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -118,7 +118,7 @@ void SkinnedVisualization::mousePressEvent (QMouseEvent *e)
 {
     if(e->button() == Qt::RightButton)
     {
-        m_menu->exec(e->globalPos());
+        m_menu->exec(e->globalPosition().toPoint());
         return;
     }
 
@@ -181,7 +181,7 @@ void SkinnedVisualization::drawBackGround()
 
 void SkinnedVisualization::writeSettings()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup("Skinned"_L1);
     QAction *act = m_peaksFalloffGroup->checkedAction ();
     settings.setValue("vis_peaks_falloff"_L1, act ? act->data().toDouble() : 0.2);
@@ -293,7 +293,7 @@ void SkinnedVisualization::createMenu()
 
 void SkinnedVisualization::readSettings()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup("Skinned"_L1);
     QString vis_name = settings.value(u"vis_type"_s, u"Analyzer"_s).toString();
     if(!m_update)
@@ -369,7 +369,7 @@ Analyzer::Analyzer()
     m_skin = Skin::instance();
     m_size = QSize(76 * m_skin->ratio(), 16 * m_skin->ratio());
 
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup("Skinned"_L1);
     m_peaks_falloff = settings.value("vis_peaks_falloff"_L1, 0.2).toDouble();
     m_analyzer_falloff = settings.value("vis_analyzer_falloff"_L1, 2.2).toDouble();
@@ -413,31 +413,35 @@ bool Analyzer::process(float *l)
     calc_freq (dest, l);
 
     const double y_scale = 3.60673760222;   /* 20.0 / log(256) */
-    int max = m_lines ? 75 : 19;
+    int max = m_lines ? 75 : 19, y, j;
 
     for(int i = 0; i < max; i++)
     {
-        int y = 0;
-
         if(m_lines)
         {
-            for(int j = xscale_long[i]; j < xscale_long[i + 1]; j++)
+            for(j = xscale_long[i], y = 0; j < xscale_long[i + 1]; j++)
             {
-                y = qMax(dest[j] >> 7, y); //128
+                if(dest[j] > y)
+                    y = dest[j];
             }
         }
         else
         {
-            for(int j = xscale_short[i]; j < xscale_short[i + 1]; j++)
+            for(j = xscale_short[i], y = 0; j < xscale_short[i + 1]; j++)
             {
-                y = qMax(dest[j] >> 7, y);
+                if(dest[j] > y)
+                    y = dest[j];
             }
         }
-
+        y >>= 7;
         int magnitude = 0;
-        if(y > 0)
+        if(y != 0)
         {
-            magnitude = qBound(0, int(log(y) * y_scale), 15);
+            magnitude = int(log (y) * y_scale);
+            if(magnitude > 15)
+                magnitude = 15;
+            if(magnitude < 0)
+                magnitude = 0;
         }
 
         m_intern_vis_data[i] -= m_analyzer_falloff;
