@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -135,11 +135,7 @@ void SkinReader::loadSkins(const QStringList &paths)
     }
 
     //clear removed skins from cache
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
     const QSet<QString> usedThumbnails(m_previewHash.constBegin(), m_previewHash.constEnd());
-#else
-    const QSet<QString> usedThumbnails = QSet<QString>::fromList(m_previewHash.values());
-#endif
     for(const QFileInfo &i : std::as_const(thumbnailes))
     {
         if(!usedThumbnails.contains(i.canonicalFilePath()))
@@ -295,8 +291,9 @@ void SkinReader::untar(const QString &from, const QString &to, bool preview)
                 name = str.contains(QLatin1Char('/')) ? str.section(QLatin1Char('/'), -1).toLower() : str.toLower();
 
             QFile file(to + QLatin1Char('/') + name);
-            if(file.open(QIODevice::WriteOnly))
-                file.write(array);
+            file.open(QIODevice::WriteOnly);
+            file.write(array);
+            file.close();
         }
     }
 }
