@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -23,8 +23,6 @@
 #include <QPixmap>
 #include "pixmapwidget.h"
 
-class Skin;
-
 /**
    @author Vladimir Kuznetsov <vovanec@gmail.com>
  */
@@ -41,13 +39,13 @@ public:
 
 public slots:
     void display(const QString&);
-    void display(int);
+    void displayNum(int);
 
 private slots:
     void draw();
+    void updateSkin() override;
 
 private:
-    Skin* m_skin;
     QString m_text;
     Qt::Alignment m_alignment = Qt::AlignRight;
     int m_digits;
