@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2007-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2007-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -87,17 +87,25 @@ void Analyzer::toggleFullScreen()
 
 void Analyzer::readSettings()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup("Analyzer"_L1);
     m_peaks_falloff = settings.value("peak_falloff"_L1, 0.2).toDouble();
     m_analyzer_falloff = settings.value("analyzer_falloff"_L1, 2.2).toDouble();
     m_show_peaks = settings.value("show_peaks"_L1, true).toBool();
     m_timer->setInterval(1000 / settings.value("refresh_rate"_L1, 25).toInt());
+#if QT_VERSION >= QT_VERSION_CHECK(6, 4, 0)
+    m_color1 = QColor::fromString(settings.value("color1"_L1, u"Green"_s).toString());
+    m_color2 = QColor::fromString(settings.value("color2"_L1, u"Yellow"_s).toString());
+    m_color3 = QColor::fromString(settings.value("color3"_L1, u"Red"_s).toString());
+    m_bgColor = QColor::fromString(settings.value("bg_color"_L1, u"Black"_s).toString());
+    m_peakColor = QColor::fromString(settings.value("peak_color"_L1, u"Cyan"_s).toString());
+#else
     m_color1.setNamedColor(settings.value("color1"_L1, u"Green"_s).toString());
     m_color2.setNamedColor(settings.value("color2"_L1, u"Yellow"_s).toString());
     m_color3.setNamedColor(settings.value("color3"_L1, u"Red"_s).toString());
     m_bgColor.setNamedColor(settings.value("bg_color"_L1, u"Black"_s).toString());
     m_peakColor.setNamedColor(settings.value("peak_color"_L1, u"Cyan"_s).toString());
+#endif
     m_cell_size = settings.value("cells_size"_L1, QSize(15, 6)).toSize();
 
 
@@ -145,7 +153,7 @@ void Analyzer::readSettings()
 
 void Analyzer::writeSettings()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup("Analyzer"_L1);
     QAction *act = m_fpsGroup->checkedAction();
     settings.setValue("refresh_rate"_L1, act ? act->data().toInt() : 25);
@@ -171,7 +179,7 @@ void Analyzer::showEvent (QShowEvent *)
 void Analyzer::closeEvent (QCloseEvent *event)
 {
     //save geometry
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.setValue("Analyzer/geometry"_L1, saveGeometry());
     Visual::closeEvent(event); //removes visualization object
 }
@@ -186,7 +194,7 @@ void Analyzer::paintEvent (QPaintEvent * e)
 void Analyzer::mousePressEvent(QMouseEvent *e)
 {
     if (e->button() == Qt::RightButton)
-        m_menu->exec(e->globalPos());
+        m_menu->exec(e->globalPosition().toPoint());
 }
 
 void Analyzer::process()
@@ -210,14 +218,7 @@ void Analyzer::process()
         m_x_scale = new int[m_cols + 1] { 0 };
 
         for(int i = 0; i < m_cols + 1; ++i)
-        {
-            m_x_scale[i] = powf(255.0, float(i) / m_cols);
-            if(i > 0)
-            {
-                if(m_x_scale[i - 1] >= m_x_scale[i]) //avoid several bars in a row with the same frequency
-                    m_x_scale[i] = qMin(m_x_scale[i - 1] + 1, m_cols);
-            }
-        }
+            m_x_scale[i] = pow(pow(255.0, 1.0 / m_cols), i);
     }
 
     short dest_l[256];
@@ -228,7 +229,7 @@ void Analyzer::process()
 
     double y_scale = (double) 1.25 * m_rows / log(256);
 
-    for(int i = 0; i < m_cols; i++)
+    for (int i = 0; i < m_cols; i++)
     {
         int j = m_cols * 2 - i - 1; //mirror index
         short yl = 0;
@@ -238,22 +239,27 @@ void Analyzer::process()
 
         if(m_x_scale[i] == m_x_scale[i + 1])
         {
-            yl = dest_l[m_x_scale[i]] >> 7; //128
-            yr = dest_r[m_x_scale[i]] >> 7;
+            yl = dest_l[i];
+            yr = dest_r[i];
         }
-        for(int k = m_x_scale[i]; k < m_x_scale[i + 1]; k++)
+        for (int k = m_x_scale[i]; k < m_x_scale[i + 1]; k++)
         {
-            yl = qMax(short(dest_l[k] >> 7), yl);
-            yr = qMax(short(dest_l[k] >> 7), yr);
+            yl = qMax(dest_l[k], yl);
+            yr = qMax(dest_r[k], yr);
         }
 
-        if(yl > 0)
+        yl >>= 7; //256
+        yr >>= 7;
+
+        if (yl)
         {
-            magnitude_l = qBound(0, int(log(yl) * y_scale), m_rows);
+            magnitude_l = int(log (yl) * y_scale);
+            magnitude_l = qBound(0, magnitude_l, m_rows);
         }
-        if(yr > 0)
+        if (yr)
         {
-            magnitude_r = qBound(0, int(log(yr) * y_scale), m_rows);
+            magnitude_r = int(log (yr) * y_scale);
+            magnitude_r = qBound(0, magnitude_r, m_rows);
         }
 
         m_intern_vis_data[i] -= m_analyzer_falloff * m_rows / 15;
@@ -355,7 +361,11 @@ void Analyzer::createMenu()
         peaksFalloff->addAction(act);
     }
     m_menu->addSeparator();
+#if QT_VERSION < QT_VERSION_CHECK(6, 3, 0)
     QAction *fullScreenAction = m_menu->addAction(tr("&Full Screen"), this, &Analyzer::toggleFullScreen, tr("F"));
+#else
+    QAction *fullScreenAction = m_menu->addAction(tr("&Full Screen"), tr("F"), this, &Analyzer::toggleFullScreen);
+#endif
     addAction(fullScreenAction);
     update();
 }
