@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2007-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2007-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -27,7 +27,7 @@
 AnalyzerSettingsDialog::AnalyzerSettingsDialog(QWidget *parent) : QDialog(parent), m_ui(new Ui::AnalyzerSettingsDialog)
 {
     m_ui->setupUi(this);
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup("Analyzer"_L1);
     m_ui->colorWidget1->setColor(settings.value("color1"_L1, u"Green"_s).toString());
     m_ui->colorWidget2->setColor(settings.value("color2"_L1, u"Yellow"_s).toString());
@@ -47,7 +47,7 @@ AnalyzerSettingsDialog::~AnalyzerSettingsDialog()
 
 void AnalyzerSettingsDialog::accept()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup("Analyzer"_L1);
     settings.setValue("color1"_L1, m_ui->colorWidget1->colorName());
     settings.setValue("color2"_L1, m_ui->colorWidget2->colorName());
