@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2015 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -20,14 +20,15 @@
 
 #include <QMessageBox>
 #include <qmmp/qmmp.h>
-#include "visualprojectmfactory.h"
 #include "projectmplugin.h"
+#include "visualprojectmfactory.h"
+
 
 VisualProperties VisualProjectMFactory::properties() const
 {
     VisualProperties properties;
     properties.name = tr("ProjectM");
-    properties.shortName = "projectm";
+    properties.shortName = "projectm"_L1;
     properties.hasSettings = false;
     properties.hasAbout = true;
     return properties;
@@ -38,7 +39,7 @@ Visual *VisualProjectMFactory::create(QWidget *parent)
     return new ProjectMPlugin(parent);
 }
 
-QDialog *VisualProjectMFactory::createConfigDialog(QWidget *parent)
+QDialog *VisualProjectMFactory::createSettings(QWidget *parent)
 {
     Q_UNUSED(parent);
     return nullptr;
@@ -47,9 +48,9 @@ QDialog *VisualProjectMFactory::createConfigDialog(QWidget *parent)
 void VisualProjectMFactory::showAbout(QWidget *parent)
 {
     QMessageBox::about (parent, tr("About ProjectM Visual Plugin"),
-                        tr("Qmmp ProjectM Visual Plugin")+"\n"+
-                        tr("This plugin adds projectM visualization")+"\n"+
-                        tr("Written by: Ilya Kotov <forkotov02@ya.ru>")+"\n"+
+                        tr("Qmmp ProjectM Visual Plugin") + QChar::LineFeed +
+                        tr("This plugin adds projectM visualization") + QChar::LineFeed +
+                        tr("Written by: Ilya Kotov <forkotov02@ya.ru>") + QChar::LineFeed +
                         tr("Based on libprojectM-qt library"));
 }
 
