@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -48,7 +48,7 @@ void AbstractEngine::loadPlugins()
         return;
 
     m_cache = new QList<QmmpPluginCache*>;
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     for(const QString &filePath : Qmmp::findPlugins(u"Engines"_s))
     {
         QmmpPluginCache *item = new QmmpPluginCache(filePath, &settings);
@@ -179,7 +179,7 @@ void AbstractEngine::setEnabled(EngineFactory *factory, bool enable)
         m_disabledNames.append(factory->properties().shortName);
 
     m_disabledNames.removeDuplicates();
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.setValue(u"Engine/disabled_plugins"_s, m_disabledNames);
 }
 
