@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2014-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2014-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -18,6 +18,7 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
+#include "qmmp.h"
 #include "channelconverter_p.h"
 
 ChannelConverter::ChannelConverter(ChannelMap out_map)
@@ -52,7 +53,7 @@ void ChannelConverter::configure(quint32 srate, ChannelMap in_map)
     for(int i = 0; i < m_out_map.count(); ++i)
     {
         m_reorder_array[i] = m_out_map.indexOf(in_map.at(i % in_map.count()));
-        reorderStringList << QString("%1").arg(m_reorder_array[i]);
+        reorderStringList << QString::number(m_reorder_array[i]);
     }
 
     static const QList<Qmmp::ChannelPosition> leftChannels = { Qmmp::CHAN_FRONT_LEFT, Qmmp::CHAN_SIDE_LEFT, Qmmp::CHAN_REAR_LEFT };
@@ -61,7 +62,7 @@ void ChannelConverter::configure(quint32 srate, ChannelMap in_map)
     if(m_out_map.count() == 2 && m_reorder_array[0] == -1 && m_reorder_array[1] == -1)
     {
         //remapping is not necessary
-        if((m_disabled = (leftChannels.contains(in_map[0]) && leftChannels.contains(m_out_map[0]))))
+        if((m_disabled = (leftChannels.contains(in_map.constFirst()) && leftChannels.contains(m_out_map.constFirst()))))
             return;
 
         //swap channels
@@ -69,8 +70,7 @@ void ChannelConverter::configure(quint32 srate, ChannelMap in_map)
         m_reorder_array[1] = 0;
     }
 
-    qDebug("ChannelConverter: {%s} ==> {%s}; {%s}", qPrintable(in_map.toString()),
-           qPrintable(m_out_map.toString()), qPrintable(reorderStringList.join(",")));
+    qCDebug(core) << "{%s} ==> {%s}; {%s}" << in_map.toString() << m_out_map.toString() << reorderStringList.join(QLatin1Char(','));
 }
 
 void ChannelConverter::applyEffect(Buffer *b)
