@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2007-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2007-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -80,7 +80,7 @@ void Effect::loadPlugins()
         return;
 
     m_cache = new QList<QmmpPluginCache *>;
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     for(const QString &filePath : Qmmp::findPlugins(u"Effect"_s))
     {
         QmmpPluginCache *item = new QmmpPluginCache(filePath, &settings);
@@ -163,7 +163,7 @@ void Effect::setEnabled(EffectFactory *factory, bool enable)
 
     m_enabledNames.removeDuplicates();
 
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.setValue(u"Effect/enabled_plugins"_s, m_enabledNames);
     QmmpPluginCache::cleanup(&settings);
 }
