@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -250,7 +250,7 @@ void InputSource::setEnabled(InputSourceFactory *factory, bool enable)
         m_disabledNames.append(factory->properties().shortName);
 
     m_disabledNames.removeDuplicates();
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.setValue("Transports/disabled_plugins"_L1, m_disabledNames);
 }
 
@@ -266,7 +266,7 @@ void InputSource::loadPlugins()
         return;
 
     m_cache = new QList<QmmpPluginCache*>;
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     for(const QString &filePath : Qmmp::findPlugins(u"Transports"_s))
     {
         QmmpPluginCache *item = new QmmpPluginCache(filePath, &settings);
