@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -25,7 +25,7 @@
 #include <QList>
 #include <QString>
 #include <QCoreApplication>
-#include <QPixmap>
+#include <QImage>
 #include <QVariant>
 #include <QFlags>
 #include "tagmodel.h"
@@ -41,7 +41,7 @@ public:
      * Constructor
      * \param name Localized name of property.
      * \param value Property value.
-     * \param suffix Localized suffix of property (i.e. kB, kB/s, etc).
+     * \param suffix Localized suffix of property (i.e. kbit, kbps, etc).
      */
     MetaDataItem(const QString &name, const QVariant &value, const QString &suffix = QString());
     /*!
@@ -99,7 +99,7 @@ public:
     /*!
      * Destructor.
      */
-    virtual ~MetaDataModel();
+    virtual ~MetaDataModel() = default;
     /*!
      * Returns extra properties of the media source (in addition to the \b Qmmp::TrackProperty values).
      * Default implemetation returns empty array.
@@ -116,16 +116,16 @@ public:
      */
     virtual QList<TagModel* > tags() const;
     /*!
-     * Returns cover pixmap.
+     * Returns cover image.
      * Subclass should reimplement this function. Default implementation returns empty pixmap.
      */
-    virtual QPixmap cover() const;
+    virtual QImage cover() const;
     /*!
      * Sets cover.
-     * @param pix Cover pixmap.
+     * @param img Cover image.
      * Subclass should reimplement this function. Default implementation does nothing.
      */
-    virtual void setCover(const QPixmap &pix);
+    virtual void setCover(const QImage &img);
     /*!
      * Removes cover.
      * Subclass should reimplement this function. Default implementation does nothing.
