@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -24,9 +24,9 @@
 #include <QLoggingCategory>
 #include "qmmp_export.h"
 
-#define QMMP_VERSION_MAJOR 1
-#define QMMP_VERSION_MINOR 7
-#define QMMP_VERSION_PATCH 9
+#define QMMP_VERSION_MAJOR 2
+#define QMMP_VERSION_MINOR 2
+#define QMMP_VERSION_PATCH 2
 #define QMMP_VERSION_STABLE 1
 
 #define QMMP_VERSION_INT (QMMP_VERSION_MAJOR<<16 | QMMP_VERSION_MINOR<<8 | QMMP_VERSION_PATCH)
@@ -40,21 +40,17 @@
 #define QStringToFileName(s) s.toLocal8Bit().constData()
 #endif
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
+
 #include <QLatin1String>
 
 namespace Qt {
-
-#if (QT_VERSION < QT_VERSION_CHECK(5, 14, 0))
-constexpr auto SkipEmptyParts = QString::SkipEmptyParts;
-constexpr auto KeepEmptyParts = QString::KeepEmptyParts;
-#endif
-
 inline namespace Literals {
 inline namespace StringLiterals {
 
 inline QString operator""_s(const char16_t *str, size_t size) noexcept
 {
-    return QString::fromUtf16(str, size);
+    return QString(QStringPrivate(nullptr, const_cast<char16_t *>(str), qsizetype(size)));
 }
 
 constexpr inline QLatin1String operator""_L1(const char *str, size_t size) noexcept
@@ -64,7 +60,7 @@ constexpr inline QLatin1String operator""_L1(const char *str, size_t size) noexc
 
 inline QByteArray operator""_ba(const char *str, size_t size) noexcept
 {
-    return QByteArray(str, qsizetype(size));
+    return QByteArray(QByteArrayData(nullptr, const_cast<char *>(str), qsizetype(size)));
 }
 
 } // StringLiterals
@@ -73,12 +69,16 @@ inline QByteArray operator""_ba(const char *str, size_t size) noexcept
 
 using QLatin1StringView = QLatin1String;
 
+#endif
+
 using namespace Qt::Literals::StringLiterals;
 
 QMMP_EXPORT Q_DECLARE_LOGGING_CATEGORY(core)
 QMMP_EXPORT Q_DECLARE_LOGGING_CATEGORY(plugin)
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 5, 0)
 #define qCFatal qCCritical
+#endif
 
 
 /*! @brief The Qmmp class stores global settings and enums.
@@ -179,10 +179,6 @@ public:
         CHAN_SIDE_RIGHT   = 0x80,   /*!< Side right channel */
         CHAN_LFE          = 0x100,  /*!< Low-frequency effects channel */
     };
-    /*!
-         * Returns the configuration file name, including the path.
-         */
-    static QString configFile();
     /*!
      * Returns the configuration directory path.
      */
