@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -42,19 +42,18 @@ QmmpAudioEngine::QmmpAudioEngine(QObject *parent) : AbstractEngine(parent)
 {
     m_converter = new AudioConverter;
     m_settings = QmmpSettings::instance();
-    connect(m_settings,SIGNAL(replayGainSettingsChanged()), SLOT(updateReplayGainSettings()));
-    connect(m_settings,SIGNAL(audioSettingsChanged()), SLOT(updateAudioSettings()));
-    connect(m_settings, SIGNAL(eqSettingsChanged()), SLOT(updateEqSettings()));
+    connect(m_settings, &QmmpSettings::replayGainSettingsChanged, this, &QmmpAudioEngine::updateReplayGainSettings);
+    connect(m_settings, &QmmpSettings::audioSettingsChanged, this, &QmmpAudioEngine::updateAudioSettings);
+    connect(m_settings, &QmmpSettings::eqSettingsChanged, this, &QmmpAudioEngine::updateEqSettings);
     reset();
     m_instance = this;
 }
 
 QmmpAudioEngine::~QmmpAudioEngine()
 {
-    stop();
+    QmmpAudioEngine::stop();
     reset();
-    if(m_output_buf)
-        delete [] m_output_buf;
+    delete [] m_output_buf;
     m_output_buf = nullptr;
     qDeleteAll(m_effects);
     m_instance = nullptr;
@@ -92,8 +91,8 @@ bool QmmpAudioEngine::play()
 {
     if(isRunning() || m_decoders.isEmpty() || (m_output && m_output->isRunning()))
         return false;
-    if(m_output)
-        delete m_output;
+
+    delete m_output;
     prepareEffects(m_decoders.head());
     if(!(m_output = createOutput()))
         return false;
@@ -122,28 +121,28 @@ bool QmmpAudioEngine::enqueue(InputSource *source)
 
     DecoderFactory *factory = nullptr;
 
-    if(!source->path().contains("://"))
+    if(!source->path().contains(u"://"_s))
         factory = Decoder::findByFilePath(source->path(), m_settings->determineFileTypeByContent());
     if(!factory)
         factory = Decoder::findByMime(source->contentType());
-    if(factory && !factory->properties().noInput && source->ioDevice() && source->path().contains("://"))
+    if(factory && !factory->properties().noInput && source->ioDevice() && source->path().contains(u"://"_s))
         factory = (factory->canDecode(source->ioDevice()) ? factory : nullptr);
-    if(!factory && source->ioDevice() && source->path().contains("://")) //ignore content of local files
+    if(!factory && source->ioDevice() && source->path().contains(u"://"_s)) //ignore content of local files
         factory = Decoder::findByContent(source->ioDevice());
-    if(!factory && source->path().contains("://"))
-        factory = Decoder::findByProtocol(source->path().section("://",0,0));
+    if(!factory && source->path().contains(u"://"_s))
+        factory = Decoder::findByProtocol(source->path().section(u"://"_s, 0, 0));
     if(!factory)
     {
-        qWarning("QmmpAudioEngine: unsupported file format");
+        qCWarning(core, "unsupported file format");
         return false;
     }
-    qDebug("QmmpAudioEngine: selected decoder: %s",qPrintable(factory->properties().shortName));
+    qCDebug(core) << "selected decoder:" << factory->properties().shortName;
     if(factory->properties().noInput && source->ioDevice())
         source->ioDevice()->close();
     Decoder *decoder = factory->create(source->path(), source->ioDevice());
     if(!decoder->initialize())
     {
-        qWarning("QmmpAudioEngine: invalid file format");
+        qCWarning(core, "invalid file format");
         delete decoder;
         return false;
     }
@@ -160,12 +159,11 @@ bool QmmpAudioEngine::enqueue(InputSource *source)
 
 void QmmpAudioEngine::addEffect(EffectFactory *factory)
 {
-    for(const Effect *effect : qAsConst(m_effects))
+    for(const Effect *effect : std::as_const(m_effects))
     {
         if(effect->factory() == factory)
         {
-            qWarning("QmmpAudioEngine: effect %s already exists",
-                     qPrintable(factory->properties().shortName));
+            qCWarning(core, "effect %s already exists", qPrintable(factory->properties().shortName));
             return;
         }
     }
@@ -183,7 +181,7 @@ void QmmpAudioEngine::addEffect(EffectFactory *factory)
         }
         else
         {
-            qDebug("QmmpAudioEngine: restart is required");
+            qCDebug(core) << "restart is required";
             delete effect;
         }
     }
@@ -192,7 +190,7 @@ void QmmpAudioEngine::addEffect(EffectFactory *factory)
 void QmmpAudioEngine::removeEffect(EffectFactory *factory)
 {
     Effect *effect = nullptr;
-    for(Effect *e : qAsConst(m_effects))
+    for(Effect *e : std::as_const(m_effects))
     {
         if(e->factory() == factory)
         {
@@ -206,7 +204,7 @@ void QmmpAudioEngine::removeEffect(EffectFactory *factory)
     {
         mutex()->lock();
         if(m_blockedEffects.contains(effect))
-            qDebug("QmmpAudioEngine: restart is required");
+            qCDebug(core) << "restart is required";
         else
             m_effects.removeAll(effect);
         mutex()->unlock();
@@ -281,7 +279,7 @@ qint64 QmmpAudioEngine::produceSound(unsigned char *data, qint64 size, quint32 b
 
     b->samples = samples;
     b->rate = brate;
-    for(Effect *effect : qAsConst(m_effects))
+    for(Effect *effect : std::as_const(m_effects))
     {
         effect->applyEffect(b);
     }
@@ -393,23 +391,21 @@ void QmmpAudioEngine::run()
             m_done = m_user_stop.load();
             if(delay > TRANSPORT_TIMEOUT)
             {
-                qWarning("QmmpAudioEngine: unable to receive more data");
+                qCWarning(core, "unable to receive more data");
                 m_done = true;
                 StateHandler::instance()->dispatch(Qmmp::NormalError);
                 break;
             }
-            else
-                continue;
-        }
-        else
-        {
-            delay = 0;
-            // decode
-            mutex()->unlock();
-            len = m_decoder->read((m_output_buf + m_output_at), m_output_size - m_output_at);
-            mutex()->lock();
+
+            continue;
         }
 
+        delay = 0;
+        // decode
+        mutex()->unlock();
+        len = m_decoder->read((m_output_buf + m_output_at), m_output_size - m_output_at);
+        mutex()->lock();
+
         if (len > 0)
         {
             m_bitrate = m_decoder->bitrate();
@@ -421,7 +417,7 @@ void QmmpAudioEngine::run()
             if(m_next) //decoder can play next track without initialization
             {
                 m_next = false;
-                qDebug("QmmpAudioEngine: switching to the next track");
+                qCDebug(core) << "switching to the next track";
                 StateHandler::instance()->sendFinished();
                 StateHandler::instance()->dispatch(Qmmp::Stopped); //fake stop/start cycle
                 StateHandler::instance()->dispatch(Qmmp::Buffering);
@@ -435,7 +431,8 @@ void QmmpAudioEngine::run()
                 mutex()->unlock();
                 continue;
             }
-            else if(!m_decoders.isEmpty())
+
+            if(!m_decoders.isEmpty())
             {
                 m_inputs.take(m_decoder)->deleteLater ();
                 delete m_decoder;
@@ -585,7 +582,7 @@ void QmmpAudioEngine::addOffset()
 void QmmpAudioEngine::attachMetaData(Decoder *decoder, DecoderFactory *factory, InputSource *source)
 {
     QString path = source->path();
-    QString scheme = path.section("://",0,0);
+    QString scheme = path.section(u"://"_s,0,0);
     QFileInfo fileInfo(path);
 
     if(fileInfo.isFile() || factory->properties().protocols.contains(scheme))
@@ -632,8 +629,7 @@ void QmmpAudioEngine::prepareEffects(Decoder *d)
 {
     m_ap = d->audioParameters();
     //output buffer for decoder
-    if(m_output_buf)
-        delete [] m_output_buf;
+    delete [] m_output_buf;
     m_bks = QMMP_BLOCK_FRAMES * m_ap.frameSize(); //block size
     m_output_size = m_bks * 4;
     m_sample_size = m_ap.sampleSize();
@@ -643,7 +639,7 @@ void QmmpAudioEngine::prepareEffects(Decoder *d)
     m_ap = AudioParameters(m_ap.sampleRate(), m_ap.channelMap(), Qmmp::PCM_FLOAT);
     //remove disabled and external effects
     const QList<Effect *> tmp = m_effects;
-    for(Effect *e : qAsConst(tmp))
+    for(Effect *e : std::as_const(tmp))
     {
         if(!e->factory() || !Effect::isEnabled(e->factory()))
         {
@@ -653,7 +649,7 @@ void QmmpAudioEngine::prepareEffects(Decoder *d)
     }
     m_replayGain = nullptr;
     m_dithering = nullptr;
-    QList <Effect *> tmp_effects = m_effects;
+    QList<Effect *> tmp_effects = m_effects;
     m_effects.clear();
 
     //replay gain
@@ -684,7 +680,7 @@ void QmmpAudioEngine::prepareEffects(Decoder *d)
     for(EffectFactory *factory : Effect::enabledFactories())
     {
         Effect *effect = nullptr;
-        for(Effect *e : qAsConst(tmp_effects)) //find effect
+        for(Effect *e : std::as_const(tmp_effects)) //find effect
         {
             if(e->factory() == factory)
             {
