@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2013-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2013-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -37,7 +37,7 @@ QmmpPluginCache::QmmpPluginCache(const QString &file, QSettings *settings)
     QFileInfo info(file);
     m_path = info.QFileInfo::canonicalFilePath();
 
-    settings->beginGroup("PluginCache");
+    settings->beginGroup(u"PluginCache"_s);
     QString key = m_path;
 #ifndef Q_OS_WIN
     key.remove(0,1);
@@ -51,15 +51,9 @@ QmmpPluginCache::QmmpPluginCache(const QString &file, QSettings *settings)
         {
             m_shortName = values.at(0);
             m_priority = values.at(1).toInt();
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
-            m_protocols = values.at(2).split(";", Qt::SkipEmptyParts);
-            m_filters = values.at(3).split(";", Qt::SkipEmptyParts);
-            m_contentTypes = values.at(4).split(";", Qt::SkipEmptyParts);
-#else
-            m_protocols = values.at(2).split(";", QString::SkipEmptyParts);
-            m_filters = values.at(3).split(";", QString::SkipEmptyParts);
-            m_contentTypes = values.at(4).split(";", QString::SkipEmptyParts);
-#endif
+            m_protocols = values.at(2).split(QLatin1Char(';'), Qt::SkipEmptyParts);
+            m_filters = values.at(3).split(QLatin1Char(';'), Qt::SkipEmptyParts);
+            m_contentTypes = values.at(4).split(QLatin1Char(';'), Qt::SkipEmptyParts);
             update = (info.lastModified().toString(Qt::ISODate) != values.at(5));
         }
     }
@@ -103,22 +97,21 @@ QmmpPluginCache::QmmpPluginCache(const QString &file, QSettings *settings)
         }
         else
         {
-            qWarning("QmmpPluginCache: unknown plugin type: %s", qPrintable(m_path));
+            qCWarning(core, "unknown plugin type: %s", qPrintable(m_path));
             m_error = true;
         }
 
-        if (!m_error)
+        if(!m_error)
         {
             QStringList values;
             values << m_shortName;
             values << QString::number(m_priority);
-            values << m_protocols.join(";");
-            values << m_filters.join(";");
-            values << m_contentTypes.join(";");
+            values << m_protocols.join(QLatin1Char(';'));
+            values << m_filters.join(QLatin1Char(';'));
+            values << m_contentTypes.join(QLatin1Char(';'));
             values << info.lastModified().toString(Qt::ISODate);
             settings->setValue(m_path, values);
-            qDebug("QmmpPluginCache: added cache item \"%s=%s\"",
-                   qPrintable(info.fileName()), qPrintable(values.join(",")));
+            qCDebug(core, "added cache item \"%s=%s\"", qPrintable(info.fileName()), qPrintable(values.join(QLatin1Char(','))));
         }
     }
     settings->endGroup();
@@ -223,14 +216,14 @@ QObject *QmmpPluginCache::instance()
     QPluginLoader loader(m_path);
     m_instance = loader.instance();
     if (loader.isLoaded())
-        qDebug("QmmpPluginCache: loaded plugin %s", qPrintable(QFileInfo(m_path).fileName()));
+        qCDebug(core) << "loaded plugin" << QFileInfo(m_path).fileName();
     else
     {
         m_error = true;
         m_filters.clear();
         m_contentTypes.clear();
         m_protocols.clear();
-        qWarning("QmmpPluginCache: error: %s", qPrintable(loader.errorString ()));
+        qCWarning(core, "error: %s", qPrintable(loader.errorString ()));
     }
     return m_instance;
 }
@@ -249,18 +242,18 @@ void QmmpPluginCache::loadTranslation(const QString &translation)
 
 void QmmpPluginCache::cleanup(QSettings *settings)
 {
-    settings->beginGroup("PluginCache");
+    settings->beginGroup(u"PluginCache"_s);
 
     for(const QString &key : settings->allKeys())
     {
 #ifdef Q_OS_WIN
         if(!QFile::exists(key))
 #else
-        if(!QFile::exists("/" + key))
+        if(!QFile::exists(u"/"_s + key))
 #endif
         {
             settings->remove(key);
-            qDebug("QmmpPluginCache: removed key %s", qPrintable(key));
+            qCDebug(core) << "removed key" << key;
         }
     }
     settings->endGroup();
