@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2010-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2010-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -31,7 +31,7 @@ QmmpSettings::QmmpSettings(QObject *parent) : QObject(parent)
     if(m_instance)
         qCFatal(core) << "only one instance is allowed";
     m_instance = this;
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     //replaygain settings
     settings.beginGroup(u"ReplayGain"_s);
     m_rg_mode = (ReplayGainMode) settings.value(u"mode"_s, REPLAYGAIN_DISABLED).toInt();
@@ -175,10 +175,6 @@ void QmmpSettings::setNetworkSettings(bool use_proxy, bool auth, ProxyType type,
     m_proxy_auth = auth;
     m_proxy_type = type;
     m_proxy_url = proxy;
-    if(type == HTTP_PROXY)
-        m_proxy_url.setScheme(u"http"_s);
-    else if(type == SOCKS5_PROXY)
-        m_proxy_url.setScheme(u"socks5"_s);
     saveSettings();
     emit networkSettingsChanged();
 }
@@ -198,7 +194,7 @@ void QmmpSettings::setEqSettings(const EqSettings &settings)
 void QmmpSettings::readEqSettings(EqSettings::Bands bands)
 {
     m_eq_settings = EqSettings(bands);
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(QStringLiteral("Equalizer_%1").arg(bands));
     for (int i = 0; i < bands; ++i)
         m_eq_settings.setGain(i, settings.value(QStringLiteral("band_%1").arg(i), 0).toDouble());
@@ -246,7 +242,7 @@ void QmmpSettings::sync()
     if(m_saveSettings)
     {
         qCDebug(core) << "saving settings...";
-        QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+        QSettings settings;
         //replaygain settings
         settings.beginGroup(u"ReplayGain"_s);
         settings.setValue(u"mode"_s, m_rg_mode);
