@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -23,7 +23,7 @@
 #include <QObject>
 #include <QMap>
 #include <QHash>
-#include <QMutex>
+#include <QRecursiveMutex>
 #include "abstractengine.h"
 #include "audioparameters.h"
 #include "qmmp.h"
@@ -144,7 +144,7 @@ private:
     QHash <QString, QString> m_streamInfo;
     Qmmp::State m_state = Qmmp::Stopped;
     AudioParameters m_audioParameters;
-    mutable QMutex m_mutex;
+    mutable QRecursiveMutex m_mutex;
 };
 
 #endif
