@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -116,7 +116,7 @@ void Visual::setEnabled(VisualFactory *factory, bool enable)
         return;
 
     QString name = factory->properties().shortName;
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     QStringList visList = settings.value(u"Visualization/enabled_plugins"_s).toStringList();
 
     if (enable)
@@ -145,7 +145,7 @@ bool Visual::isEnabled(const VisualFactory *factory)
 {
     checkFactories();
     QString name = factory->properties().shortName;
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     QStringList visList = settings.value(u"Visualization/enabled_plugins"_s).toStringList();
     return visList.contains(name);
 }
