@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -37,25 +37,25 @@ QHash<CommandLineHandler*, QString> *CommandLineManager::m_files = nullptr;
 
 void CommandLineManager::checkOptions()
 {
-    if (!m_options)
+    if(!m_options)
     {
         m_options = new QList<CommandLineHandler *>;
         m_files = new QHash<CommandLineHandler*, QString>;
 
-        for(const QString &filePath : Qmmp::findPlugins("CommandLineOptions"))
+        for(const QString &filePath : Qmmp::findPlugins(u"CommandLineOptions"_s))
         {
             QPluginLoader loader(filePath);
             QObject *plugin = loader.instance();
             if (loader.isLoaded())
-                /*qDebug("CommandLineManager: loaded plugin %s", qPrintable(QFileInfo(filePath).filePath()));*/;
+                /*qCDebug(core) << "loaded plugin" << QFileInfo(filePath).filePath();*/;
             else
-                qWarning("CommandLineManager: %s", qPrintable(loader.errorString ()));
+                qCWarning(core) << loader.errorString();
 
             CommandLineHandler *option = nullptr;
-            if (plugin)
+            if(plugin)
                 option = qobject_cast<CommandLineHandler *>(plugin);
 
-            if (option)
+            if(option)
             {
                 m_options->append(option);
                 m_files->insert(option, filePath);
@@ -73,26 +73,22 @@ void CommandLineManager::checkOptions()
     }
 }
 
-QString CommandLineManager::executeCommand(const QString &name, const QStringList &args)
+QString CommandLineManager::executeCommand(const QString &name, const QStringList &args, const QString &currentWorkingDir)
 {
     checkOptions();
     bool started = UiHelper::instance() && SoundCore::instance() && MediaPlayer::instance();
 
-    for(CommandLineHandler *opt : qAsConst(*m_options))
+    for(CommandLineHandler *opt : std::as_const(*m_options))
     {
         int id = opt->identify(name);
         if(id < 0)
             continue;
 
         if(started || (opt->flags(id) & CommandLineHandler::NoStart))
-            return opt->executeCommand(id, args);
-        else
-        {
-            qWarning("CommandLineManager: player objects are not created");
-            return QString();
-        }
-
+            return opt->executeCommand(id, args, currentWorkingDir);
 
+        qCWarning(core, "player objects are not created");
+        return QString();
     }
     return QString();
 }
@@ -102,7 +98,7 @@ bool CommandLineManager::hasOption(const QString &opt_str, CommandLineHandler::O
     checkOptions();
     if(flags)
         *flags = CommandLineHandler::OptionFlags();
-    for(const CommandLineHandler *opt : qAsConst(*m_options))
+    for(const CommandLineHandler *opt : std::as_const(*m_options))
     {
         int id = opt->identify(opt_str);
         if(id >= 0)
@@ -118,7 +114,7 @@ bool CommandLineManager::hasOption(const QString &opt_str, CommandLineHandler::O
 void CommandLineManager::printUsage()
 {
     checkOptions();
-    for(const CommandLineHandler *opt : qAsConst(*m_options))
+    for(const CommandLineHandler *opt : std::as_const(*m_options))
     {
         for(const QString &line : opt->helpString())
         {
@@ -131,10 +127,10 @@ void CommandLineManager::printUsage()
 
 QString CommandLineManager::formatHelpString(const QString &line)
 {
-    QStringList list = line.split("||", QString::SkipEmptyParts);
+    QStringList list = line.split(u"||"_s, Qt::SkipEmptyParts);
     if(list.count() == 1)
-        return list.at(0);
-    else if(list.count() >= 2)
-        return list.at(0).leftJustified(25) + list.at(1);
+        return list.constFirst();
+    if(list.count() >= 2)
+        return list.constFirst().leftJustified(25) + list.at(1);
     return QString();
 }
