@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2020 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -36,9 +36,10 @@ public:
      * Executes command \b opt_str.
      * @param name Command line option name.
      * @param args Command arguments.
+     * @param currentWorkingDir Current working directory.
      * @return Command output result.
      */
-    static QString executeCommand(const QString &name, const QStringList &args = QStringList());
+    static QString executeCommand(const QString &name, const QStringList &args, const QString &currentWorkingDir);
     /*!
      * Return \b true if command \b opt_str is supported, otherwise returns \b false.
      */
