@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2007-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2007-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -70,7 +70,9 @@ ConfigDialog::ConfigDialog (QWidget *parent) : QDialog (parent)
     m_ui->bitDepthComboBox->addItem(u"16"_s, Qmmp::PCM_S16LE);
     m_ui->bitDepthComboBox->addItem(u"24"_s, Qmmp::PCM_S24LE);
     m_ui->bitDepthComboBox->addItem(u"32"_s, Qmmp::PCM_S32LE);
+#ifndef Q_OS_WIN
     m_ui->bitDepthComboBox->addItem(u"32 (float)"_s, Qmmp::PCM_FLOAT);
+#endif
     m_ui->proxyTypeComboBox->addItem(tr("HTTP"), QmmpSettings::HTTP_PROXY);
     m_ui->proxyTypeComboBox->addItem(tr("SOCKS5"), QmmpSettings::SOCKS5_PROXY);
     m_ui->portLineEdit->setValidator(new QIntValidator(0, 65535, this));
@@ -80,11 +82,7 @@ ConfigDialog::ConfigDialog (QWidget *parent) : QDialog (parent)
     createMenus();
     updateGroupSettings();
     //connections
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 15, 0))
-    connect(m_ui->linesPerGroupComboBox, qOverload<int>(&QComboBox::currentIndexChanged), this, &ConfigDialog::updateGroupSettings);
-#else
-    connect(m_ui->linesPerGroupComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(updateGroupSettings()));
-#endif
+    connect(m_ui->linesPerGroupComboBox, &QComboBox::currentIndexChanged, this, &ConfigDialog::updateGroupSettings);
     connect(m_ui->showExtraRowCheckBox, &QCheckBox::clicked, this, &ConfigDialog::updateGroupSettings);
 }
 
@@ -172,7 +170,7 @@ void ConfigDialog::readSettings()
     //equalizer
     m_ui->twoPassEqCheckBox->setChecked(gs->eqSettings().twoPasses());
     //geometry
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     resize(settings.value(u"ConfigDialog/window_size"_s, QSize(700,470)).toSize());
     QList<QVariant> var_sizes = settings.value(u"ConfigDialog/splitter_sizes"_s).toList();
     if(var_sizes.count() != 2)
@@ -458,7 +456,7 @@ void ConfigDialog::saveSettings()
     eqs.setTwoPasses(m_ui->twoPassEqCheckBox->isChecked());
     gs->setEqSettings(eqs);
     QList<QVariant> var_sizes = { m_ui->splitter->sizes().constFirst(), m_ui->splitter->sizes().constLast() };
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.setValue(u"ConfigDialog/splitter_sizes"_s, var_sizes);
     settings.setValue(u"ConfigDialog/window_size"_s, size());
     //User interface language
