@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2017-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2017-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -36,14 +36,14 @@ CoverViewer::CoverViewer(QWidget *parent)
     connect(saveAsAction, &QAction::triggered, this, &CoverViewer::saveAs);
     addAction(saveAsAction);
     setContextMenuPolicy(Qt::ActionsContextMenu);
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     m_lastDir = QStandardPaths::writableLocation(QStandardPaths::PicturesLocation);
     m_lastDir = settings.value(u"CoverEditor/last_dir"_s, m_lastDir).toString();
 }
 
 CoverViewer::~CoverViewer()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.setValue(u"CoverEditor/last_dir"_s, m_lastDir);
 }
 
