@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2021-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2021-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -72,7 +72,7 @@ CueEditor::CueEditor(MetaDataModel *model, const TrackInfo &info, QWidget *paren
     m_ui->setupUi(this);
     m_ui->plainTextEdit->setPlainText(model->cue());
     m_parser.loadData(model->cue().toUtf8());
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     m_lastDir = settings.value(u"CueEditor/last_dir"_s,  QDir::homePath()).toString();
     if(!settings.value(u"CueEditor/use_system_font"_s, true).toBool())
     {
@@ -94,7 +94,7 @@ CueEditor::CueEditor(MetaDataModel *model, const TrackInfo &info, QWidget *paren
 
 CueEditor::~CueEditor()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.setValue(u"CueEditor/last_dir"_s, m_lastDir);
 
     delete m_ui;
@@ -133,10 +133,8 @@ void CueEditor::on_loadButton_clicked()
     {
         m_lastDir = QFileInfo(path).absoluteDir().path();
         QFile file(path);
-        if(file.open(QIODevice::ReadOnly))
-            m_ui->plainTextEdit->setPlainText(QString::fromUtf8(file.readAll()));
-        else
-            m_ui->plainTextEdit->clear();
+        file.open(QIODevice::ReadOnly);
+        m_ui->plainTextEdit->setPlainText(QString::fromUtf8(file.readAll()));
     }
 }
 
@@ -159,9 +157,7 @@ void CueEditor::on_saveAsButton_clicked()
         data.append(QChar::LineFeed);
 
         QFile file(path);
-        if(file.open(QIODevice::WriteOnly))
-            file.write(data.toUtf8());
-        else
-            qCWarning(core) << "unable to save cue file; error:" << file.errorString();
+        file.open(QIODevice::WriteOnly);
+        file.write(data.toUtf8());
     }
 }
