@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -205,10 +205,7 @@ void DetailsDialog::updatePage()
     }
 
     m_ui->pageLabel->setText(tr("%1/%2").arg(m_page + 1).arg(m_tracks.count()));
-    if(m_page >= 0 && m_page < m_tracks.count())
-        m_info = *m_tracks.at(m_page);
-    else
-        m_info.clear();
+    m_info = *m_tracks.at(m_page);
 
     setWindowTitle(m_info.path().section(QLatin1Char('/'),-1));
     m_ui->pathEdit->setText(m_info.path());
@@ -382,9 +379,9 @@ QString DetailsDialog::formatRow(const MetaDataItem &item) const
         return QString();
 
     QString value;
-    if(item.value().type() == QVariant::Bool)
+    if(item.value().typeId() == QMetaType::Bool)
         value = item.value().toBool() ? tr("Yes") : tr("No");
-    else if(item.value().type() == QVariant::Double)
+    else if(item.value().typeId() == QMetaType::Double)
         value = QStringLiteral("%1").arg(item.value().toDouble(), 0, 'f', 4);
     else
         value = item.value().toString();
