@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -173,11 +173,7 @@ void FileLoader::addDirectory(const QString &s, PlayListTrack *before)
         {
             QStringList paths;
             tracks.append(processFile(info.absoluteFilePath (), &paths));
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
             ignoredPaths.unite(QSet<QString>(paths.cbegin(), paths.cend()));
-#else
-            ignoredPaths.unite(QSet<QString>::fromList(paths));
-#endif
         }
 
         if (m_finished)
@@ -361,14 +357,11 @@ void FileLoader::removeIgnoredTracks(QList<PlayListTrack *> *tracks, QSet<QStrin
     {
         QString path = (*it)->path();
 
-        //extract path from URL
-        if(path.contains(u"://"_s))
-            path = TrackInfo::pathFromUrl(path);
-
         if(ignoredPaths->contains(path))
         {
             delete (*it);
             it = tracks->erase(it);
+            ignoredPaths->remove(path); //exclude ignored path from checking
         }
         else
         {
