@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -23,12 +23,13 @@
 #include <QObject>
 #include <QQueue>
 #include <QStringList>
+#include <QSet>
 #include <QFileInfo>
 #include <QMutex>
 #include <QThread>
 #include <qmmp/trackinfo.h>
+#include "playlisttrack.h"
 
-class PlayListTrack;
 class PlayListItem;
 class QmmpUiSettings;
 
@@ -50,10 +51,6 @@ public:
      * @param parent QObject parent
      */
     FileLoader(QObject *parent = nullptr);
-    /*!
-     * Object destructor.
-     */
-    ~FileLoader();
     /*!
      * Sets file/directory to load
      */
@@ -64,8 +61,8 @@ public:
     void add(const QStringList &paths);
     void addPlayList(const QString &fmt, const QByteArray &data);
 
-    void insert(PlayListItem *before, const QString &path);
-    void insert(PlayListItem *before, const QStringList &paths);
+    void insert(PlayListTrack *before, const QString &path);
+    void insert(PlayListTrack *before, const QStringList &paths);
 
 
 public slots:
@@ -79,21 +76,21 @@ signals:
      * Emitted when new playlist tracks are available.
      * @param tracks List of the pointers to the \b PlayListTrack objects.
      */
-    void newTracksToInsert(PlayListItem *before, QList<PlayListTrack *> tracks);
+    void newTracksToInsert(PlayListTrack *before, QList<PlayListTrack *> tracks);
 
 private:
     void run() override;
     QList<PlayListTrack*> processFile(const QString &path, QStringList *ignoredPaths = nullptr);
-    void insertPlayList(const QString &fmt, const QByteArray &contents, PlayListItem *before);
-    void insertPlayList(const QString &path, PlayListItem *before);
-    void addDirectory(const QString &s, PlayListItem *before = nullptr);
+    void insertPlayList(const QString &fmt, const QByteArray &contents, PlayListTrack *before);
+    void insertPlayList(const QString &path, PlayListTrack *before);
+    void addDirectory(const QString &s, PlayListTrack *before = nullptr);
     bool checkRestrictFilters(const QFileInfo &info);
     bool checkExcludeFilters(const QFileInfo &info);
-    void removeIgnoredTracks(QList<PlayListTrack *> *tracks, const QStringList &ignoredPaths);
+    void removeIgnoredTracks(QList<PlayListTrack *> *tracks, QSet<QString> *ignoredPaths);
     struct LoaderTask
     {
         QString path;
-        PlayListItem *before;
+        PlayListTrack *before;
         QString playListFormat;
         QByteArray playListContent;
     };
