@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2020 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -47,6 +47,22 @@ public:
      * Returns a list of the enabled general plugin factories.
      */
     static QList<GeneralFactory *> enabledFactories();
+    /*!
+     * Returns a list of the enabled widget IDs.
+     */
+    static QStringList enabledWidgets();
+    /*!
+     * Returns widget description.
+     * @param id Widget ID.
+     */
+    static WidgetDescription widgetDescription(const QString &id);
+    /*!
+     * Creates widget provided by general plugin. May return \b nullptr
+     * if widget ID is not found.
+     * \param id Widget ID.
+     * \param parent Parent Widget.
+     */
+    static QWidget *createWidget(const QString &id, QWidget *parent);
     /*!
      * Returns plugin file path.
      * @param factory General plugin factory.
@@ -57,13 +73,13 @@ public:
      * @param factory General plugin factory.
      * @param enable Plugin enable state (\b true - enable, \b false - disable)
      */
-    static void setEnabled(GeneralFactory* factory, bool enable = true);
+    static void setEnabled(GeneralFactory *factory, bool enable = true);
     /*!
      * Shows configuration dialog and updates settings automatically.
      * @param factory General plugin factory.
      * @param parentWidget Parent widget.
      */
-    static void showSettings(GeneralFactory* factory, QWidget* parentWidget);
+    static void showSettings(GeneralFactory *factory, QWidget *parentWidget);
     /*!
      * Returns \b true if general plugin is enabled, otherwise returns \b false
      * @param factory General plugin factory.
@@ -71,6 +87,8 @@ public:
     static bool isEnabled(const GeneralFactory* factory);
 
 private:
+    General() {}
+    ~General() {}
     static void loadPlugins();
     static QHash <GeneralFactory*, QObject*> *m_generals;
     static QObject *m_parent;
