@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2013-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2013-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -21,10 +21,6 @@
 #include <QRandomGenerator>
 #include "groupedcontainer_p.h"
 
-#if (QT_VERSION < QT_VERSION_CHECK(5, 13, 0))
-#define swapItemsAt swap
-#endif
-
 GroupedContainer::GroupedContainer()
 {
 
@@ -52,18 +48,15 @@ void GroupedContainer::addTrack(PlayListTrack *track)
             m_groups[i]->m_trackList.append(track);
             m_groups[i]->m_title2.clear();
             m_tracks.insert(lastIndex + 1, track);
-            track->m_track_index = lastIndex + 1;
             m_update = true;
             return;
         }
     }
-    //create new group
     PlayListGroup *group = new PlayListGroup(track->groupName());
     group->m_trackList.append(track);
     group->m_title2.clear();
     m_tracks.append(track);
     m_groups.append(group);
-    track->m_track_index = m_tracks.count() - 1;
 
     if(!m_update)
     {
@@ -169,7 +162,7 @@ void GroupedContainer::clearSelection()
 
 int GroupedContainer::indexOf(PlayListItem *item) const
 {
-    return item->isGroup() ? m_groups.indexOf(static_cast<PlayListGroup *>(item)) : m_tracks.indexOf(static_cast<PlayListTrack *>(item));
+    return item->isGroup() ? m_groups.indexOf(item) : m_tracks.indexOf(item);
 }
 
 PlayListTrack *GroupedContainer::track(int index) const
