@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -33,11 +33,11 @@ MediaPlayer::MediaPlayer(QObject *parent)
         : QObject(parent)
 {
     if(m_instance)
-        qFatal("StateHandler: only one instance is allowed");
+        qCFatal(core) << "only one instance is allowed";
     m_instance = this;
 
     QTranslator *translator = new QTranslator(qApp);
-    if(translator->load(QString(":/libqmmpui_") + Qmmp::systemLanguageID()))
+    if(translator->load(QStringLiteral(":/libqmmpui_") + Qmmp::systemLanguageID()))
         qApp->installTranslator(translator);
     else
         delete translator;
@@ -48,11 +48,12 @@ MediaPlayer::MediaPlayer(QObject *parent)
     m_finishTimer = new QTimer(this);
     m_finishTimer->setSingleShot(true);
     m_finishTimer->setInterval(500);
-    connect(m_finishTimer, SIGNAL(timeout()), SIGNAL(playbackFinished()));
-    connect(m_core, SIGNAL(nextTrackRequest()), SLOT(updateNextUrl()));
-    connect(m_core, SIGNAL(finished()), SLOT(playNext()));
-    connect(m_core, SIGNAL(stateChanged(Qmmp::State)), SLOT(processState(Qmmp::State)));
-    connect(m_core, SIGNAL(trackInfoChanged()),SLOT(updateMetaData()));
+    connect(m_finishTimer, &QTimer::timeout, this, &MediaPlayer::playbackFinished);
+    connect(m_core, &SoundCore::nextTrackRequest, this, &MediaPlayer::updateNextUrl);
+    connect(m_core, &SoundCore::finished, this, &MediaPlayer::playNext);
+    connect(m_core, &SoundCore::stateChanged, this, &MediaPlayer::processState);
+    connect(m_core, &SoundCore::trackInfoChanged, this, &MediaPlayer::updateMetaData);
+    connect(m_pl_manager, &PlayListManager::currentTrackRemoved, this, &MediaPlayer::onCurrentTrackRemoved);
 }
 
 MediaPlayer::~MediaPlayer()
@@ -70,7 +71,12 @@ PlayListManager *MediaPlayer::playListManager()
     return m_pl_manager;
 }
 
-void MediaPlayer::play(qint64 offset)
+void MediaPlayer::play()
+{
+    playFromPosition(-1);
+}
+
+void MediaPlayer::playFromPosition(qint64 offset)
 {
     m_pl_manager->currentPlayList()->doCurrentVisibleRequest();
     if (m_core->state() == Qmmp::Paused)
@@ -79,7 +85,7 @@ void MediaPlayer::play(qint64 offset)
         return;
     }
 
-    if (m_pl_manager->currentPlayList()->count() == 0)
+    if (m_pl_manager->currentPlayList()->isEmpty())
         return;
 
     QString s = m_pl_manager->currentPlayList()->currentTrack()->path();
@@ -179,13 +185,13 @@ void MediaPlayer::updateNextUrl()
         if(ok)
         {
             m_nextUrl = track->path();
-            qDebug("MediaPlayer: next track state: received");
+            qCDebug(core) << "next track state: received";
         }
         else
-            qDebug("MediaPlayer: next track state: error");
+            qCDebug(core) << "next track state: error";
     }
     else
-        qDebug("MediaPlayer: next track state: unknown");
+        qCDebug(core) << "next track state: unknown";
 
 }
 
@@ -196,7 +202,7 @@ void MediaPlayer::processState(Qmmp::State state)
     case Qmmp::NormalError:
         m_core->stop();
         m_nextUrl.clear();
-        if (m_skips <= m_pl_manager->currentPlayList()->count())
+        if (m_skips <= m_pl_manager->currentPlayList()->trackCount())
         {
             m_skips++;
             playNext();
@@ -221,32 +227,32 @@ void MediaPlayer::processState(Qmmp::State state)
 void MediaPlayer::updateMetaData()
 {
     TrackInfo info = m_core->trackInfo();
-    qDebug("===== metadata ======");
-    qDebug("ARTIST = %s", qPrintable(info.value(Qmmp::ARTIST)));
-    qDebug("TITLE = %s", qPrintable(info.value(Qmmp::TITLE)));
-    qDebug("ALBUMARTIST = %s", qPrintable(info.value(Qmmp::ALBUMARTIST)));
-    qDebug("ALBUM = %s", qPrintable(info.value(Qmmp::ALBUM)));
-    qDebug("COMMENT = %s", qPrintable(info.value(Qmmp::COMMENT)));
-    qDebug("GENRE = %s", qPrintable(info.value(Qmmp::GENRE)));
-    qDebug("YEAR = %s", qPrintable(info.value(Qmmp::YEAR)));
-    qDebug("TRACK = %s", qPrintable(info.value(Qmmp::TRACK)));
-    qDebug("DISCNUMBER = %s", qPrintable(info.value(Qmmp::DISCNUMBER)));
-    qDebug("---------------------");
-    qDebug("BITRATE = %s", qPrintable(info.value(Qmmp::BITRATE)));
-    qDebug("SAMPLERATE = %s", qPrintable(info.value(Qmmp::SAMPLERATE)));
-    qDebug("CHANNELS = %s", qPrintable(info.value(Qmmp::CHANNELS)));
-    qDebug("BITS_PER_SAMPLE = %s", qPrintable(info.value(Qmmp::BITS_PER_SAMPLE)));
-    qDebug("FORMAT_NAME = %s", qPrintable(info.value(Qmmp::FORMAT_NAME)));
-    qDebug("DECODER = %s", qPrintable(info.value(Qmmp::DECODER)));
-    qDebug("FILE_SIZE = %s", qPrintable(info.value(Qmmp::FILE_SIZE)));
-    qDebug("---------------------");
-    qDebug("REPLAYGAIN_TRACK_GAIN = %f", info.value(Qmmp::REPLAYGAIN_TRACK_GAIN));
-    qDebug("REPLAYGAIN_TRACK_PEAK = %f", info.value(Qmmp::REPLAYGAIN_TRACK_PEAK));
-    qDebug("REPLAYGAIN_ALBUM_GAIN = %f", info.value(Qmmp::REPLAYGAIN_ALBUM_GAIN));
-    qDebug("REPLAYGAIN_ALBUM_PEAK = %f", info.value(Qmmp::REPLAYGAIN_ALBUM_PEAK));
-    qDebug("---------------------");
-    qDebug("DURATION = %lld", info.duration());
-    qDebug("== end of metadata ==");
+    qCDebug(core) << "===== metadata ======";
+    qCDebug(core) << "ARTIST =" << info.value(Qmmp::ARTIST);
+    qCDebug(core) << "TITLE =" << info.value(Qmmp::TITLE);
+    qCDebug(core) << "ALBUMARTIST =" << info.value(Qmmp::ALBUMARTIST);
+    qCDebug(core) << "ALBUM =" << info.value(Qmmp::ALBUM);
+    qCDebug(core) << "COMMENT =" << info.value(Qmmp::COMMENT);
+    qCDebug(core) << "GENRE =" << info.value(Qmmp::GENRE);
+    qCDebug(core) << "YEAR =" << info.value(Qmmp::YEAR);
+    qCDebug(core) << "TRACK =" << info.value(Qmmp::TRACK);
+    qCDebug(core) << "DISCNUMBER =" << info.value(Qmmp::DISCNUMBER);
+    qCDebug(core) << "---------------------";
+    qCDebug(core) << "BITRATE =" << info.value(Qmmp::BITRATE);
+    qCDebug(core) << "SAMPLERATE =" << info.value(Qmmp::SAMPLERATE);
+    qCDebug(core) << "CHANNELS =" << info.value(Qmmp::CHANNELS);
+    qCDebug(core) << "BITS_PER_SAMPLE =" << info.value(Qmmp::BITS_PER_SAMPLE);
+    qCDebug(core) << "FORMAT_NAME =" << info.value(Qmmp::FORMAT_NAME);
+    qCDebug(core) << "DECODER =" << info.value(Qmmp::DECODER);
+    qCDebug(core) << "FILE_SIZE =" << info.value(Qmmp::FILE_SIZE);
+    qCDebug(core) << "---------------------";
+    qCDebug(core) << "REPLAYGAIN_TRACK_GAIN =" << info.value(Qmmp::REPLAYGAIN_TRACK_GAIN);
+    qCDebug(core) << "REPLAYGAIN_TRACK_PEAK =" << info.value(Qmmp::REPLAYGAIN_TRACK_PEAK);
+    qCDebug(core) << "REPLAYGAIN_ALBUM_GAIN =" << info.value(Qmmp::REPLAYGAIN_ALBUM_GAIN);
+    qCDebug(core) << "REPLAYGAIN_ALBUM_PEAK =" << info.value(Qmmp::REPLAYGAIN_ALBUM_PEAK);
+    qCDebug(core) << "---------------------";
+    qCDebug(core) << "DURATION =" << info.duration();
+    qCDebug(core) << "== end of metadata ==";
 
     PlayListModel *pl = m_pl_manager->currentPlayList();
     if (pl->currentTrack() && pl->currentTrack()->path() == info.path())
@@ -255,3 +261,9 @@ void MediaPlayer::updateMetaData()
         pl->updateMetaData();
     }
 }
+
+void MediaPlayer::onCurrentTrackRemoved()
+{
+    if(m_settings->stopAfterRemovingOfCurrentTrack())
+        m_core->stop();
+}
