@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2015-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2015-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -57,28 +57,32 @@ Syntax:
 
 MetaDataFormatter::MetaDataFormatter(const QString &pattern)
 {
-    m_fieldNames.insert("t", Qmmp::TITLE);
-    m_fieldNames.insert("p", Qmmp::ARTIST);
-    m_fieldNames.insert("aa", Qmmp::ALBUMARTIST);
-    m_fieldNames.insert("a", Qmmp::ALBUM);
-    m_fieldNames.insert("c", Qmmp::COMMENT);
-    m_fieldNames.insert("g", Qmmp::GENRE);
-    m_fieldNames.insert("C", Qmmp::COMPOSER);
-    m_fieldNames.insert("y", Qmmp::YEAR);
-    m_fieldNames.insert("n", Qmmp::TRACK);
-    m_fieldNames.insert("D", Qmmp::DISCNUMBER);
-    m_fieldNames.insert("F", Param::PATH);
-    m_fieldNames.insert("NN", Param::TWO_DIGIT_TRACK);
-    m_fieldNames.insert("l", Param::DURATION);
-    m_fieldNames.insert("f", Param::FILE_NAME);
-    m_fieldNames.insert("I", Param::TRACK_INDEX);
-    m_propertyNames.insert("bitrate", Qmmp::BITRATE);
-    m_propertyNames.insert("samplerate", Qmmp::SAMPLERATE);
-    m_propertyNames.insert("channels", Qmmp::CHANNELS);
-    m_propertyNames.insert("samplesize", Qmmp::BITS_PER_SAMPLE);
-    m_propertyNames.insert("format", Qmmp::FORMAT_NAME);
-    m_propertyNames.insert("decoder", Qmmp::DECODER);
-    m_propertyNames.insert("filesize", Qmmp::FILE_SIZE);
+    m_fieldNames = {
+        { QStringLiteral("t"), Qmmp::TITLE },
+        { QStringLiteral("p"), Qmmp::ARTIST },
+        { QStringLiteral("aa"), Qmmp::ALBUMARTIST },
+        { QStringLiteral("a"), Qmmp::ALBUM },
+        { QStringLiteral("c"), Qmmp::COMMENT },
+        { QStringLiteral("g"), Qmmp::GENRE },
+        { QStringLiteral("C"), Qmmp::COMPOSER },
+        { QStringLiteral("y"), Qmmp::YEAR },
+        { QStringLiteral("n"), Qmmp::TRACK },
+        { QStringLiteral("D"), Qmmp::DISCNUMBER },
+        { QStringLiteral("F"), Param::PATH },
+        { QStringLiteral("NN"), Param::TWO_DIGIT_TRACK },
+        { QStringLiteral("l"), Param::DURATION },
+        { QStringLiteral("f"), Param::FILE_NAME },
+        { QStringLiteral("I"), Param::TRACK_INDEX }
+    };
+    m_propertyNames = {
+        { QStringLiteral("bitrate"), Qmmp::BITRATE },
+        { QStringLiteral("samplerate"), Qmmp::SAMPLERATE },
+        { QStringLiteral("channels"), Qmmp::CHANNELS },
+        { QStringLiteral("samplesize"), Qmmp::BITS_PER_SAMPLE },
+        { QStringLiteral("format"), Qmmp::FORMAT_NAME },
+        { QStringLiteral("decoder"), Qmmp::DECODER },
+        { QStringLiteral("filesize"), Qmmp::FILE_SIZE }
+    };
 
     if(!pattern.isEmpty())
         setPattern(pattern);
@@ -93,16 +97,16 @@ void MetaDataFormatter::setPattern(const QString &pattern)
     m_nodes.clear();
 
 #ifdef DUMP_NODES
-    qDebug("MetaDataFormatter: pattern: %s", qPrintable(pattern));
+    qCDebug(core) << "pattern:" << pattern;
 #endif
     m_nodes = compile(pattern);
 #ifdef DUMP_NODES
-    qDebug("MetaDataFormatter: dump of nodes");
-    for(const Node &n : qAsConst(m_nodes))
+    qCDebug(core) << "dump of nodes";
+    for(const Node &n : std::as_const(m_nodes))
     {
-        qDebug("=>%s", qPrintable(dumpNode(n)));
+        qCDebug(core) << "=>" << dumpNode(n);
     }
-    qDebug("MetaDataFormatter: end of dump");
+    qCDebug(core)"MetaDataFormatter: end of dump");
 #endif
 }
 
@@ -111,9 +115,9 @@ const QString MetaDataFormatter::pattern() const
     return m_pattern;
 }
 
-QString MetaDataFormatter::format(const PlayListTrack *item) const
+QString MetaDataFormatter::format(const PlayListTrack *track) const
 {
-    return evalute(&m_nodes, item, item->trackIndex());
+    return evalute(&m_nodes, track, track->trackIndex());
 }
 
 QString MetaDataFormatter::format(const TrackInfo &info, int trackIndex) const
@@ -132,19 +136,19 @@ QString MetaDataFormatter::formatDuration(qint64 duration, bool hideZero, bool s
     {
         if(hideZero)
             return QString();
-        else
-            return showMs ? QLatin1String("0:00.000") : QLatin1String("0:00");
+
+        return showMs ? QStringLiteral("0:00.000") : QStringLiteral("0:00");
     }
 
     QString out;
     qint64 durationInSeconds = duration / 1000;
     if(durationInSeconds >= 3600)
-        out = QString("%1:%2").arg(durationInSeconds / 3600).arg(durationInSeconds % 3600 / 60, 2, 10, QChar('0'));
+        out = QStringLiteral("%1:%2").arg(durationInSeconds / 3600).arg(durationInSeconds % 3600 / 60, 2, 10, QLatin1Char('0'));
     else
-        out = QString("%1").arg(durationInSeconds % 3600 / 60);
-    out += QString(":%1").arg(durationInSeconds % 60, 2, 10, QChar('0'));
+        out = QStringLiteral("%1").arg(durationInSeconds % 3600 / 60);
+    out += QStringLiteral(":%1").arg(durationInSeconds % 60, 2, 10, QLatin1Char('0'));
     if(showMs)
-        out += QString(".%1").arg(duration % 1000, 3, 10, QChar('0'));
+        out += QStringLiteral(".%1").arg(duration % 1000, 3, 10, QLatin1Char('0'));
     return out;
 }
 
@@ -188,14 +192,14 @@ bool MetaDataFormatter::parseProperty(QList<Node> *nodes, QString::const_iterato
     if((*i) + 1 == end || (*i) + 2 == end)
         return false;
 
-    if((**i) != QChar('{'))
+    if((**i) != QLatin1Char('{'))
         return false;
 
     (*i)++; //skip '{'
 
     QString propertyName;
 
-    while((*i) != end && (**i) != QChar('}'))
+    while((*i) != end && (**i) != QLatin1Char('}'))
     {
         propertyName.append((**i));
         (*i)++;
@@ -221,7 +225,7 @@ bool MetaDataFormatter::parseIf(QList<MetaDataFormatter::Node> *nodes, QString::
     if((*i) + 1 == end || (*i) + 2 == end)
         return false;
 
-    if((**i) != QChar('i') || *((*i)+1) != QChar('f'))
+    if((**i) != QLatin1Char('i') || *((*i)+1) != QLatin1Char('f'))
         return false;
 
     (*i)+=2;
@@ -245,7 +249,7 @@ bool MetaDataFormatter::parseIf(QList<MetaDataFormatter::Node> *nodes, QString::
 
     while((*i) != end)
     {
-        if((**i) == QChar('\\'))
+        if((**i) == QLatin1Char('\\'))
         {
             (*i)++;
             escaped = true;
@@ -258,7 +262,7 @@ bool MetaDataFormatter::parseIf(QList<MetaDataFormatter::Node> *nodes, QString::
         }
         else
         {
-            if((**i) == QChar('('))
+            if((**i) == QLatin1Char('('))
             {
                 brackets_tracker++;
                 if(state == STARTING)
@@ -268,7 +272,7 @@ bool MetaDataFormatter::parseIf(QList<MetaDataFormatter::Node> *nodes, QString::
                     continue;
                 }
             }
-            else if((**i) == QChar(')'))
+            else if((**i) == QLatin1Char(')'))
                 brackets_tracker--;
         }
 
@@ -280,7 +284,7 @@ bool MetaDataFormatter::parseIf(QList<MetaDataFormatter::Node> *nodes, QString::
         }
         case READING_VAR1:
         {
-            if((**i) == QChar(',') && brackets_tracker == 1)
+            if((**i) == QLatin1Char(',') && brackets_tracker == 1)
             {
                 state = READING_VAR2;
                 break;
@@ -290,7 +294,7 @@ bool MetaDataFormatter::parseIf(QList<MetaDataFormatter::Node> *nodes, QString::
         }
         case READING_VAR2:
         {
-            if((**i) == QChar(',') && brackets_tracker == 1)
+            if((**i) == QLatin1Char(',') && brackets_tracker == 1)
             {
                 state = READING_VAR3;
                 break;
@@ -300,7 +304,7 @@ bool MetaDataFormatter::parseIf(QList<MetaDataFormatter::Node> *nodes, QString::
         }
         case READING_VAR3:
         {
-            if((**i) == QChar(')') && brackets_tracker == 0)
+            if((**i) == QLatin1Char(')') && brackets_tracker == 0)
             {
                 state = FINISHED;
                 break;
@@ -320,7 +324,7 @@ bool MetaDataFormatter::parseIf(QList<MetaDataFormatter::Node> *nodes, QString::
 
     if(state != FINISHED)
     {
-        qWarning("MetaDataFormatter: syntax error");
+        qCWarning(core, "syntax error");
         return false;
     }
 
@@ -339,7 +343,7 @@ bool MetaDataFormatter::parseDir(QList<MetaDataFormatter::Node> *nodes, QString:
     if((*i) + 1 == end || (*i) + 2 == end)
         return false;
 
-    if((**i) != QChar('d') || *((*i)+1) != QChar('i') || *((*i)+2) != QChar('r'))
+    if((**i) != QLatin1Char('d') || *((*i)+1) != QLatin1Char('i') || *((*i)+2) != QLatin1Char('r'))
         return false;
 
     (*i)+=3;
@@ -347,7 +351,7 @@ bool MetaDataFormatter::parseDir(QList<MetaDataFormatter::Node> *nodes, QString:
     Node node;
     node.command = Node::DIR_FUNCTION;
 
-    if((*i) == end || (**i) != QChar('(')) // %dir without params
+    if((*i) == end || (**i) != QLatin1Char('(')) // %dir without params
     {
         (*i)--;
         nodes->append(node);
@@ -365,7 +369,7 @@ bool MetaDataFormatter::parseDir(QList<MetaDataFormatter::Node> *nodes, QString:
 
     while((*i) != end)
     {
-        if((**i) == QChar('(') && state == STARTING)
+        if((**i) == QLatin1Char('(') && state == STARTING)
         {
             state = READING_VAR;
             (*i)++;
@@ -380,7 +384,7 @@ bool MetaDataFormatter::parseDir(QList<MetaDataFormatter::Node> *nodes, QString:
         }
         case READING_VAR:
         {
-            if((**i) == QChar(')'))
+            if((**i) == QLatin1Char(')'))
             {
                 state = FINISHED;
                 break;
@@ -400,16 +404,14 @@ bool MetaDataFormatter::parseDir(QList<MetaDataFormatter::Node> *nodes, QString:
 
     if(state != FINISHED)
     {
-        qWarning("MetaDataFormatter: syntax error");
+        qCWarning(core, "syntax error");
         return false;
     }
 
     Param param;
     param.type = Param::NUMERIC;
-    bool ok = false;
-    param.number = var.toInt(&ok);
-    if(!ok)
-        param.number = 0;
+    param.number = var.toInt();
+
     node.params << param;
     nodes->append(node);
     return true;
@@ -423,16 +425,13 @@ void MetaDataFormatter::parseText(QList<MetaDataFormatter::Node> *nodes, QString
     param.type = Param::TEXT;
     node.params.append(param);
 
-    forever
+    while((*i) != end &&  (**i) != QLatin1Char('%'))
     {
-        if((*i) == end || (**i) == QChar('%'))
-        {
-            (*i)--;
-            break;
-        }
         node.params[0].text.append(**i);
-        (*i)++;
+        ++(*i);
     }
+    (*i)--;
+
     if(!node.params[0].text.isEmpty())
         nodes->append(node);
 }
@@ -459,14 +458,14 @@ QString MetaDataFormatter::evalute(const QList<Node> *nodes, const TrackInfo *in
         Node node = nodes->at(i);
         if(node.command == Node::PRINT_TEXT)
         {
-            Param p = node.params.first();
+            Param p = node.params.constFirst();
             out.append(printParam(&p, info, trackIndex));
 
         }
         else if(node.command == Node::IF_KEYWORD)
         {
             QString var1 = printParam(&node.params[0], info, trackIndex);
-            if(var1.isEmpty() || var1 == "0")
+            if(var1.isEmpty() || var1 == QLatin1String("0"))
                 out.append(printParam(&node.params[2], info, trackIndex));
             else
                 out.append(printParam(&node.params[1], info, trackIndex));
@@ -476,26 +475,26 @@ QString MetaDataFormatter::evalute(const QList<Node> *nodes, const TrackInfo *in
             QString var1 = printParam(&node.params[0], info, trackIndex);
             QString var2 = printParam(&node.params[1], info, trackIndex);
             if(!var1.isEmpty() && !var2.isEmpty())
-                out.append("1");
+                out.append(QLatin1Char('1'));
         }
         else if(node.command == Node::OR_OPERATOR)
         {
             QString var1 = printParam(&node.params[0], info, trackIndex);
             if(!var1.isEmpty())
-                out.append("1");
+                out.append(QLatin1Char('1'));
             else
             {
                 QString var2 = printParam(&node.params[1], info, trackIndex);
                 if(!var2.isEmpty())
-                    out.append("1");
+                    out.append(QLatin1Char('1'));
             }
         }
         else if(node.command == Node::DIR_FUNCTION)
         {
             if(node.params.isEmpty())
-                out.append(info->path().mid(0, info->path().lastIndexOf('/')));
+                out.append(info->path().mid(0, info->path().lastIndexOf(QLatin1Char('/'))));
             else
-                out.append(info->path().section('/', -node.params[0].number - 2, -node.params[0].number - 2));
+                out.append(info->path().section(QLatin1Char('/'), -node.params[0].number - 2, -node.params[0].number - 2));
         }
     }
     return out;
@@ -507,18 +506,14 @@ QString MetaDataFormatter::printParam(MetaDataFormatter::Param *p, const TrackIn
     {
     case Param::FIELD:
         return printField(p->field, info, trackIndex);
-        break;
     case Param::PROPERTY:
         return printProperty(p->field, info);
-        break;
     case Param::TEXT:
         return p->text;
-        break;
     case Param::NODES:
         return evalute(&p->children, info, trackIndex);
-        break;
     default:
-        break;
+        ;
     }
     return QString();
 }
@@ -532,8 +527,8 @@ QString MetaDataFormatter::printField(int field, const TrackInfo *info, int trac
             QString title = info->value(Qmmp::TITLE);
             if(title.isEmpty()) //using file name if title is empty
             {
-                title = info->path().section('/',-1);
-                title = title.left(title.lastIndexOf('.'));
+                title = info->path().section(QLatin1Char('/'), -1);
+                title = title.left(title.lastIndexOf(QLatin1Char('.')));
             }
 
             if(title.isEmpty()) //using full path if file name is empty
@@ -543,23 +538,23 @@ QString MetaDataFormatter::printField(int field, const TrackInfo *info, int trac
         }
         return info->value((Qmmp::MetaData) field);
     }
-    else if(field == Param::PATH)
+    if(field == Param::PATH)
     {
         return info->path();
     }
-    else if(field == Param::TWO_DIGIT_TRACK)
+    if(field == Param::TWO_DIGIT_TRACK)
     {
-        return QString("%1").arg(info->value(Qmmp::TRACK),2,'0');
+        return QStringLiteral("%1").arg(info->value(Qmmp::TRACK), 2, QLatin1Char('0'));
     }
-    else if(field == Param::DURATION)
+    if(field == Param::DURATION)
     {
         return formatDuration(info->duration());
     }
-    else if(field == Param::FILE_NAME)
+    if(field == Param::FILE_NAME)
     {
-        return info->path().section('/',-1);
+        return info->path().section(QLatin1Char('/'), -1);
     }
-    else if(field == Param::TRACK_INDEX)
+    if(field == Param::TRACK_INDEX)
     {
         return QString::number(trackIndex + 1);
     }
@@ -576,49 +571,49 @@ QString MetaDataFormatter::dumpNode(MetaDataFormatter::Node node) const
     QString str;
     QStringList params;
     if(node.command == Node::PRINT_TEXT)
-        str += "PRINT_TEXT";
+        str += u"PRINT_TEXT"_s;
     else if(node.command == Node::IF_KEYWORD)
-        str += "IF_KEYWORD";
+        str += u"IF_KEYWORD"_s;
     else if(node.command == Node::AND_OPERATOR)
-        str += "AND_OPERATOR";
+        str += u"AND_OPERATOR"_s;
     else if(node.command == Node::OR_OPERATOR)
-        str += "OR_OPERATOR";
+        str += u"OR_OPERATOR"_s;
     else if(node.command == Node::DIR_FUNCTION)
-        str += "DIR_FUNCTION";
-    str += "(";
-    for(const Param &p : qAsConst(node.params))
+        str += u"DIR_FUNCTION"_s;
+    str += QLatin1Char('(');
+    for(const Param &p : std::as_const(node.params))
     {
         if(p.type == Param::FIELD)
-            params.append(QString("FIELD:%1").arg(p.field));
+            params.append(QStringLiteral("FIELD:%1").arg(p.field));
         else if(p.type == Param::PROPERTY)
-            params.append(QString("PROPERTY:%1").arg(p.field));
+            params.append(QStringLiteral("PROPERTY:%1").arg(p.field));
         else if(p.type == Param::TEXT)
-            params.append(QString("TEXT:%1").arg(p.text));
+            params.append(QStringLiteral("TEXT:%1").arg(p.text));
         else if(p.type == Param::NUMERIC)
-            params.append(QString("NUMBER:%1").arg(p.number));
+            params.append(QStringLiteral("NUMBER:%1").arg(p.number));
         else if(p.type == Param::NODES)
         {
             QStringList nodeStrList;
-            for(const Node &n : qAsConst(p.children))
+            for(const Node &n : std::as_const(p.children))
             {
                 nodeStrList.append(dumpNode(n));
             }
-            params.append(QString("NODES:%1").arg(nodeStrList.join(",")));
+            params.append(QStringLiteral("NODES:%1").arg(nodeStrList.join(QLatin1Char(','))));
         }
     }
-    str.append(params.join(","));
-    str.append(")");
+    str.append(params.join(QLatin1Char(',')));
+    str.append(QLatin1Char(')'));
     return str;
 }
 
 QList<MetaDataFormatter::Node> MetaDataFormatter::compile(const QString &expr)
 {
-    QList <Node> nodes;
+    QList<Node> nodes;
     QString::const_iterator i = expr.constBegin();
 
     while (i != expr.constEnd())
     {
-        if((*i) == QChar('%'))
+        if((*i) == QLatin1Char('%'))
         {
             ++i;
             if(i == expr.constEnd())
@@ -649,21 +644,22 @@ QList<MetaDataFormatter::Node> MetaDataFormatter::compile(const QString &expr)
             }
             continue;
         }
-        else if((*i) == QChar('&'))
+
+        if((*i) == QLatin1Char('&'))
         {
             ++i;
             Node node;
             node.command = Node::AND_OPERATOR;
             nodes.append(node);
         }
-        else if((*i) == QChar('|'))
+        else if((*i) == QLatin1Char('|'))
         {
             ++i;
             Node node;
             node.command = Node::OR_OPERATOR;
             nodes.append(node);
         }
-        else if((*i) == QChar('\\'))
+        else if((*i) == QLatin1Char('\\'))
         {
             ++i;
             parseEscape(&nodes, &i, expr.constEnd());
@@ -679,23 +675,22 @@ QList<MetaDataFormatter::Node> MetaDataFormatter::compile(const QString &expr)
     //wrap operators
     for(int j = 0; j < nodes.count(); ++j)
     {
-        if(nodes[j].command == Node::AND_OPERATOR ||
-                nodes[j].command == Node::OR_OPERATOR)
+        if(nodes[j].command == Node::AND_OPERATOR || nodes[j].command == Node::OR_OPERATOR)
         {
             if(j == 0 || j == nodes.count() - 1)
             {
                 nodes.clear();
-                qDebug("MetaDataFormatter: syntax error");
+                qCDebug(core) << "syntax error";
             }
 
             Param p1;
             p1.type = Param::NODES;
-            p1.children << nodes.takeAt(j+1);
+            p1.children << nodes.takeAt(j + 1);
             Param p2;
             p2.type = Param::NODES;
-            p2.children << nodes.takeAt(j-1);
-            nodes[j-1].params.append(p1);
-            nodes[j-1].params.append(p2);
+            p2.children << nodes.takeAt(j - 1);
+            nodes[j - 1].params.append(p1);
+            nodes[j - 1].params.append(p2);
             j--;
         }
     }
