@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2013-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2013-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -21,10 +21,6 @@
 #include <QRandomGenerator>
 #include "normalcontainer_p.h"
 
-#if (QT_VERSION < QT_VERSION_CHECK(5, 13, 0))
-#define swapItemsAt swap
-#endif
-
 NormalContainer::NormalContainer()
 {}
 
@@ -114,7 +110,7 @@ void NormalContainer::clearSelection()
 
 int NormalContainer::indexOf(PlayListItem *item) const
 {
-    return m_tracks.indexOf(static_cast<PlayListTrack *>(item));
+    return m_tracks.indexOf(item);
 }
 
 PlayListTrack *NormalContainer::track(int index) const
