@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2012-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2012-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -27,10 +27,10 @@
 #include "playlistdownloader.h"
 
 PlayListDownloader::PlayListDownloader(QObject *parent) : QObject(parent),
-    m_ua(QString("qmmp/%1").arg(Qmmp::strVersion()).toLatin1())
+    m_ua(QStringLiteral("qmmp/%1").arg(Qmmp::strVersion()).toLatin1())
 {
     m_manager = new QNetworkAccessManager(this);
-    connect(m_manager, SIGNAL(finished (QNetworkReply *)), SLOT(readResponse(QNetworkReply *)));
+    connect(m_manager, &QNetworkAccessManager::finished, this, &PlayListDownloader::readResponse);
     //load global proxy settings
     QmmpSettings *gs = QmmpSettings::instance();
     if (gs->isProxyEnabled())
@@ -64,7 +64,7 @@ void PlayListDownloader::start(const QUrl &url, PlayListModel *model)
     else
     {
         m_checkReply = m_manager->get(r); //check playlist
-        connect(m_checkReply, SIGNAL(downloadProgress(qint64, qint64)), SLOT(onDownloadProgress(qint64, qint64)));
+        connect(m_checkReply, &QNetworkReply::downloadProgress, this, &PlayListDownloader::onDownloadProgress);
     }
 }
 
@@ -93,7 +93,7 @@ void PlayListDownloader::readResponse(QNetworkReply *reply)
 
         if(reply->error() != QNetworkReply::NoError)
         {
-            emit finished(false, reply->errorString() + " (" + reply->error() + ")");
+            emit finished(false, QStringLiteral("%1 (%2)").arg(reply->errorString()).arg(reply->error()));
             reply->deleteLater();
             return;
         }
@@ -102,13 +102,13 @@ void PlayListDownloader::readResponse(QNetworkReply *reply)
         if(!url.isEmpty() && m_url != url)
         {
             reply->deleteLater();
-            qDebug("PlayListDownloader: redirect to %s", qPrintable(url.toString()));
+            qCDebug(core) << "redirect to" << url.toString();
             start(url, m_model);
             return;
         }
 
         QString contentType = reply->header(QNetworkRequest::ContentTypeHeader).toString();
-        qDebug("PlayListDownloader: content type: %s", qPrintable(contentType));
+        qCDebug(core) << "content type:" << contentType;
         PlayListFormat *fmt = PlayListParser::findByMime(contentType);
         if(!fmt)
             fmt = PlayListParser::findByUrl(m_url);
@@ -131,7 +131,7 @@ void PlayListDownloader::readResponse(QNetworkReply *reply)
 
         if(reply->error() != QNetworkReply::NoError) //playlist is not available, simply add URL
         {
-            m_model->add(m_url.toString());
+            m_model->addPath(m_url.toString());
             reply->deleteLater();
             emit finished(true);
             return;
@@ -141,13 +141,13 @@ void PlayListDownloader::readResponse(QNetworkReply *reply)
         if(!url.isEmpty() && m_url != url)
         {
             reply->deleteLater();
-            qDebug("PlayListDownloader: redirect to %s", qPrintable(url.toString()));
+            qCDebug(core) << "redirect to" << url.toString();
             start(url, m_model);
             return;
         }
 
         QString contentType = reply->header(QNetworkRequest::ContentTypeHeader).toString();
-        qDebug("PlayListDownloader: content type: %s", qPrintable(contentType));
+        qCDebug(core) << "content type:" << contentType;
         PlayListFormat *fmt = PlayListParser::findByMime(contentType);
         if(!fmt)
             fmt = PlayListParser::findByUrl(m_url);
@@ -159,7 +159,7 @@ void PlayListDownloader::readResponse(QNetworkReply *reply)
         }
         else
         {
-            m_model->add(m_url.toString());
+            m_model->addPath(m_url.toString());
             emit finished(true);
         }
 
