@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2015-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2015-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -45,7 +45,7 @@ PlayListHeaderModel::~PlayListHeaderModel()
 
 void PlayListHeaderModel::restoreSettings(const QString &groupName)
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(groupName);
     restoreSettings(&settings);
     settings.endGroup();
@@ -71,7 +71,7 @@ void PlayListHeaderModel::restoreSettings(QSettings *settings)
 
 void PlayListHeaderModel::saveSettings(const QString &groupName)
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.beginGroup(groupName);
     saveSettings(&settings);
     settings.endGroup();
