@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -42,3 +42,8 @@ int PlayListItem::trackIndex() const
 {
     return -1;
 }
+
+QImage PlayListItem::cover() const
+{
+    return QImage();
+}
