@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -29,36 +29,38 @@
 #include "qmmpuisettings.h"
 #include "playlistmanager.h"
 
+using namespace Qt::Literals::StringLiterals;
+
 PlayListManager *PlayListManager::m_instance = nullptr;
 
 //key names
 const QHash<QString, Qmmp::MetaData> PlayListManager::m_metaKeys = {
-    { "title", Qmmp::TITLE },
-    { "artist", Qmmp::ARTIST },
-    { "albumartist", Qmmp::ALBUMARTIST },
-    { "album", Qmmp::ALBUM },
-    { "comment", Qmmp::COMMENT },
-    { "genre", Qmmp::GENRE },
-    { "composer", Qmmp::COMPOSER },
-    { "year", Qmmp::YEAR },
-    { "track", Qmmp::TRACK },
-    { "disk", Qmmp::DISCNUMBER }
+    { u"title"_s, Qmmp::TITLE },
+    { u"artist"_s, Qmmp::ARTIST },
+    { u"albumartist"_s, Qmmp::ALBUMARTIST },
+    { u"album"_s, Qmmp::ALBUM },
+    { u"comment"_s, Qmmp::COMMENT },
+    { u"genre"_s, Qmmp::GENRE },
+    { u"composer"_s, Qmmp::COMPOSER },
+    { u"year"_s, Qmmp::YEAR },
+    { u"track"_s, Qmmp::TRACK },
+    { u"disk"_s, Qmmp::DISCNUMBER }
 };
 
 const QHash<QString, Qmmp::TrackProperty> PlayListManager::m_propKeys = {
-    { "bitrate", Qmmp::BITRATE },
-    { "samplerate", Qmmp::SAMPLERATE },
-    { "channels", Qmmp::CHANNELS },
-    { "bits_per_sample", Qmmp::BITS_PER_SAMPLE },
-    { "format_name", Qmmp::FORMAT_NAME },
-    { "decoder", Qmmp::DECODER },
-    { "file_size", Qmmp::FILE_SIZE }
+    { u"bitrate"_s, Qmmp::BITRATE },
+    { u"samplerate"_s, Qmmp::SAMPLERATE },
+    { u"channels"_s, Qmmp::CHANNELS },
+    { u"bits_per_sample"_s, Qmmp::BITS_PER_SAMPLE },
+    { u"format_name"_s, Qmmp::FORMAT_NAME },
+    { u"decoder"_s, Qmmp::DECODER },
+    { u"file_size"_s, Qmmp::FILE_SIZE }
 };
 
 PlayListManager::PlayListManager(QObject *parent) : QObject(parent)
 {
     if(m_instance)
-        qFatal("PlayListManager: only one instance is allowed");
+        qCFatal(core) << "only one instance is allowed";
     qRegisterMetaType<PlayListModel::SortMode>();
     m_instance = this;
     m_ui_settings = QmmpUiSettings::instance();
@@ -66,7 +68,7 @@ PlayListManager::PlayListManager(QObject *parent) : QObject(parent)
     m_timer = new QTimer(this);
     m_timer->setInterval(5000);
     m_timer->setSingleShot(true);
-    connect(m_timer, SIGNAL(timeout()), SLOT(writePlayLists()));
+    connect(m_timer, &QTimer::timeout, this, &PlayListManager::writePlayLists);
     readPlayLists(); //read playlists
 }
 
@@ -101,7 +103,7 @@ int PlayListManager::currentPlayListIndex() const
     return indexOf(m_current);
 }
 
-QList <PlayListModel *> PlayListManager::playLists() const
+QList<PlayListModel *> PlayListManager::playLists() const
 {
     return m_models;
 }
@@ -109,7 +111,7 @@ QList <PlayListModel *> PlayListManager::playLists() const
 QStringList PlayListManager::playListNames() const
 {
     QStringList names;
-    for(const PlayListModel *model : qAsConst(m_models))
+    for(const PlayListModel *model : std::as_const(m_models))
         names << model->name();
     return names;
 }
@@ -125,14 +127,14 @@ void PlayListManager::selectPlayList(PlayListModel *model)
     }
 }
 
-void PlayListManager::selectPlayList(int i)
+void PlayListManager::selectPlayListIndex(int i)
 {
-    if(i > m_models.count() - 1)
+    if(i < 0 || i > m_models.count() - 1)
         return;
     selectPlayList(playListAt(i));
 }
 
-void PlayListManager::selectPlayList(const QString &name)
+void PlayListManager::selectPlayListName(const QString &name)
 {
     int index = playListNames().indexOf(name);
     if(index >= 0)
@@ -141,18 +143,12 @@ void PlayListManager::selectPlayList(const QString &name)
 
 void PlayListManager::selectNextPlayList()
 {
-    int i = m_models.indexOf(m_selected);
-    i++;
-    if( i >= 0 && i < m_models.size())
-        selectPlayList(i);
+    selectPlayListIndex(m_models.indexOf(m_selected) + 1);
 }
 
 void PlayListManager::selectPreviousPlayList()
 {
-    int i = m_models.indexOf(m_selected);
-    i--;
-    if( i >= 0 && i < m_models.size())
-        selectPlayList(i);
+    selectPlayListIndex(m_models.indexOf(m_selected) - 1);
 }
 
 void PlayListManager::activatePlayList(PlayListModel *model)
@@ -166,7 +162,7 @@ void PlayListManager::activatePlayList(PlayListModel *model)
     }
 }
 
-void PlayListManager::activatePlayList(int index)
+void PlayListManager::activatePlayListIndex(int index)
 {
     activatePlayList(playListAt(index));
 }
@@ -178,25 +174,20 @@ void PlayListManager::activateSelectedPlayList()
 
 PlayListModel *PlayListManager::createPlayList(const QString &name)
 {
-    PlayListModel *model = new PlayListModel (name.isEmpty() ? tr("Playlist") : name, this);
-    QString pl_name = model->name();
-    if(playListNames().contains(pl_name))
-    {
-        int i = 0;
-        forever
-        {
-            i++;
-            if(!playListNames().contains(pl_name + QString(" (%1)").arg(i)))
-            {
-                pl_name = pl_name + QString(" (%1)").arg(i);
-                break;
-            }
-        }
-        model->setName(pl_name);
-    }
+    PlayListModel *model = new PlayListModel(name.isEmpty() ? tr("Playlist") : name, this);
+    QStringList names = playListNames();
+    QString uniqueName = model->name();
+    int i = 0;
+
+    while(names.contains(uniqueName))
+        uniqueName = model->name() + QStringLiteral(" (%1)").arg(++i);
+
+    model->setName(uniqueName);
+
     m_models.append(model);
-    connect(model, SIGNAL(nameChanged(QString)), SIGNAL(playListsChanged()));
-    connect(model, SIGNAL(listChanged(int)), SLOT(onListChanged(int)));
+    connect(model, &PlayListModel::nameChanged, this, &PlayListManager::playListsChanged);
+    connect(model, &PlayListModel::listChanged, this, &PlayListManager::onListChanged);
+    connect(model, &PlayListModel::currentTrackRemoved, this, &PlayListManager::onCurrentTrackRemoved);
     emit playListAdded(m_models.indexOf(model));
     selectPlayList(model);
     return model;
@@ -213,6 +204,7 @@ void PlayListManager::removePlayList(PlayListModel *model)
      {
          m_current = m_models.at((i > 0) ? (i - 1) : (i + 1));
          emit currentPlayListChanged(m_current, model);
+         emit currentTrackRemoved();
      }
      if(m_selected == model)
      {
@@ -225,7 +217,7 @@ void PlayListManager::removePlayList(PlayListModel *model)
      emit playListsChanged();
 }
 
-void PlayListManager::removePlayList(int index)
+void PlayListManager::removePlayListIndex(int index)
 {
     removePlayList(playListAt(index));
 }
@@ -270,8 +262,8 @@ void PlayListManager::readPlayLists()
     Qmmp::TrackProperty propKey;
     QString line, key, value;
     int current = 0, pl = 0;
-    QList <PlayListTrack *> tracks;
-    QFile file(Qmmp::configDir() + "/playlist.txt");
+    QList<PlayListTrack *> tracks;
+    QFile file(Qmmp::configDir() + u"/playlist.txt"_s);
     file.open(QIODevice::ReadOnly);
     QByteArray array = file.readAll();
     file.close();
@@ -281,40 +273,40 @@ void PlayListManager::readPlayLists()
     while (!buffer.atEnd())
     {
         line = QString::fromUtf8(buffer.readLine().constData()).trimmed();
-        int s = line.indexOf("=");
+        int s = line.indexOf(QLatin1Char('='));
         if (s < 0)
             continue;
 
         key = line.left(s);
         value = line.right(line.size() - s - 1);
 
-        if(key == "current_playlist")
+        if(key == "current_playlist"_L1)
             pl = value.toInt();
-        else if(key == "playlist")
+        else if(key == "playlist"_L1)
         {
             if(!m_models.isEmpty() && !tracks.isEmpty())
             {
-                m_models.last()->add(tracks);
-                m_models.last()->setCurrent(tracks.at(qBound(0, current, tracks.count()-1)));
+                m_models.last()->addTracks(tracks);
+                m_models.last()->setCurrent(tracks.at(qBound(0, current, tracks.count() - 1)));
             }
             tracks.clear();
             current = 0;
             m_models << new PlayListModel(value, this);
         }
-        else if (key == "current")
+        else if (key == "current"_L1)
         {
             current = value.toInt();
         }
-        else if (key == "file")
+        else if (key == "file"_L1)
         {
             tracks << new PlayListTrack();
             tracks.last()->setPath(value);
         }
         else if (tracks.isEmpty())
             continue;
-        else if (key == "duration")
+        else if (key == "duration"_L1)
             tracks.last()->setDuration(value.toInt());
-        else if (key == "length")
+        else if (key == "length"_L1)
             tracks.last()->setDuration(value.toInt() * 1000);
         else if((metaKey = m_metaKeys.value(key, Qmmp::UNKNOWN)) != Qmmp::UNKNOWN)
             tracks.last()->setValue(metaKey, value);
@@ -324,64 +316,62 @@ void PlayListManager::readPlayLists()
     buffer.close();
     if(m_models.isEmpty())
     {
-        m_models << new PlayListModel(tr("Playlist"),this);
+        m_models << new PlayListModel(tr("Playlist"), this);
     }
     else if(!tracks.isEmpty())
     {
-        m_models.last()->add(tracks);
-        m_models.last()->setCurrent(tracks.at(qBound(0, current, tracks.count()-1)));
+        m_models.last()->addTracks(tracks);
+        m_models.last()->setCurrent(tracks.at(qBound(0, current, tracks.count() - 1)));
     }
     if(pl < 0 || pl >= m_models.count())
         pl = 0;
     m_selected = m_models.at(pl);
     m_current = m_models.at(pl);
-    for(const PlayListModel *model : qAsConst(m_models))
+    for(const PlayListModel *model : std::as_const(m_models))
     {
-        connect(model, SIGNAL(nameChanged(QString)), SIGNAL(playListsChanged()));
-        connect(model, SIGNAL(listChanged(int)), SLOT(onListChanged(int)));
+        connect(model, &PlayListModel::nameChanged, this, &PlayListManager::playListsChanged);
+        connect(model, &PlayListModel::listChanged, this, &PlayListManager::onListChanged);
+        connect(model, &PlayListModel::currentTrackRemoved, this, &PlayListManager::onCurrentTrackRemoved);
     }
 }
 
 void PlayListManager::writePlayLists()
 {
-    qDebug("PlayListManager: saving playlists...");
+    qCDebug(core) << "saving playlists...";
     QString value;
-    QString plFilePath = Qmmp::configDir() + "/playlist.txt";
+    QString plFilePath = Qmmp::configDir() + u"/playlist.txt"_s;
     QSaveFile plFile(plFilePath);
     if(!plFile.open(QIODevice::WriteOnly))
     {
-        qDebug("PlayListManager: error: %s", qPrintable(plFile.errorString()));
+        qCDebug(core) << "error: %s" << plFile.errorString();
         return;
     }
-    plFile.write(QString("current_playlist=%1\n").arg(m_models.indexOf(m_current)).toUtf8());
-    for(const PlayListModel *model : qAsConst(m_models))
+    plFile.write(QStringLiteral("current_playlist=%1\n").arg(m_models.indexOf(m_current)).toUtf8());
+    for(const PlayListModel *model : std::as_const(m_models))
     {
-        plFile.write(QString("playlist=%1\n").arg(model->name()).toUtf8());
+        plFile.write(QStringLiteral("playlist=%1\n").arg(model->name()).toUtf8());
         if(model->isEmpty())
             continue;
-        const QList<PlayListItem *> items = model->items();
-        plFile.write(QString("current=%1\n").arg(model->indexOfTrack(model->currentIndex())).toUtf8());
-        for(PlayListItem *m : qAsConst(items))
+        const QList<PlayListTrack *> tracks = model->tracks();
+        plFile.write(QStringLiteral("current=%1\n").arg(model->currentIndex()).toLatin1());
+        for(PlayListTrack *t : std::as_const(tracks))
         {
-            if(m->isGroup())
-                continue;
-            PlayListTrack *t = dynamic_cast<PlayListTrack *>(m);
-            plFile.write(QString("file=%1\n").arg(t->path()).toUtf8());
+            plFile.write(QStringLiteral("file=%1\n").arg(t->path()).toUtf8());
 
             for(QHash<QString, Qmmp::MetaData>::const_iterator it = m_metaKeys.constBegin(); it != m_metaKeys.constEnd(); ++it)
             {
                 if(!(value = t->value(it.value())).isEmpty())
-                    plFile.write(QString("%1=%2\n").arg(it.key()).arg(value).toUtf8());
+                    plFile.write(QStringLiteral("%1=%2\n").arg(it.key(), value).toUtf8());
             }
 
             for(QHash<QString, Qmmp::TrackProperty>::const_iterator it = m_propKeys.constBegin(); it != m_propKeys.constEnd(); ++it)
             {
                 if(!(value = t->value(it.value())).isEmpty())
-                    plFile.write(QString("%1=%2\n").arg(it.key()).arg(value).toLatin1());
+                    plFile.write(QStringLiteral("%1=%2\n").arg(it.key(), value).toLatin1());
             }
 
             if(t->duration() > 0)
-                plFile.write(QString("duration=%1\n").arg(t->duration()).toLatin1());
+                plFile.write(QStringLiteral("duration=%1\n").arg(t->duration()).toLatin1());
         }
     }
     plFile.commit();
@@ -393,6 +383,12 @@ void PlayListManager::onListChanged(int flags)
         m_timer->start();
 }
 
+void PlayListManager::onCurrentTrackRemoved()
+{
+    if(sender() == m_current)
+        emit currentTrackRemoved();
+}
+
 void PlayListManager::clear()
 {
     m_selected->clear();
@@ -413,12 +409,12 @@ void PlayListManager::removeUnselected()
     m_selected->removeUnselected();
 }
 
-void PlayListManager::removeTrack (int i)
+void PlayListManager::removeTrack(int i)
 {
     m_selected->removeTrack(i);
 }
 
-void PlayListManager::removeTrack (PlayListTrack *track)
+void PlayListManager::removeTrack(PlayListTrack *track)
 {
     m_selected->removeTrack(track);
 }
@@ -438,19 +434,19 @@ void PlayListManager::showDetails()
     m_selected->showDetails();
 }
 
-void PlayListManager::add(const QList<PlayListTrack *> &tracks)
+void PlayListManager::addTracks(const QList<PlayListTrack *> &tracks)
 {
-    m_selected->add(tracks);
+    m_selected->addTracks(tracks);
 }
 
-void PlayListManager::add(const QString &path)
+void PlayListManager::addPath(const QString &path)
 {
-    m_selected->add(path);
+    m_selected->addPath(path);
 }
 
-void PlayListManager::add(const QStringList &paths)
+void PlayListManager::addPaths(const QStringList &paths)
 {
-    m_selected->add(paths);
+    m_selected->addPaths(paths);
 }
 
 void PlayListManager::randomizeList()
@@ -502,3 +498,9 @@ void PlayListManager::stopAfterSelected()
 {
     m_selected->stopAfterSelected();
 }
+
+void PlayListManager::rebuildGroups()
+{
+    for(PlayListModel *model : std::as_const(m_models))
+        model->rebuildGroups();
+}
