@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -53,7 +53,7 @@ public:
     /*!
      * Returns a list of all playlists.
      */
-    QList <PlayListModel *> playLists() const;
+    QList<PlayListModel *> playLists() const;
     /*!
      * Returns a names of all playlists.
      */
@@ -98,13 +98,13 @@ signals:
      * @param current Current playlist.
      * @param previous Previous playlist.
      */
-    void currentPlayListChanged (PlayListModel *current, PlayListModel *previous);
+    void currentPlayListChanged(PlayListModel *current, PlayListModel *previous);
     /*!
      * Emitted when selected playlist changes.
      * @param selected Selected playlist.
      * @param previous Previous selected playlist.
      */
-    void selectedPlayListChanged (PlayListModel *selected, PlayListModel *previous);
+    void selectedPlayListChanged(PlayListModel *selected, PlayListModel *previous);
     /*!
      * Emitted when the playlist with index \b index is added.
      */
@@ -121,6 +121,10 @@ signals:
      * Emitted when the list of playlists is changed.
      */
     void playListsChanged();
+    /*!
+     * Emitted when the current track of the current playlist is removed.
+     */
+    void currentTrackRemoved();
 
 public slots:
     /*!
@@ -130,11 +134,11 @@ public slots:
     /*!
      * Selects playlist with index \b index.
      */
-    void selectPlayList(int index);
+    void selectPlayListIndex(int index);
     /*!
      * Selects playlist with name \b name.
      */
-    void selectPlayList(const QString &name);
+    void selectPlayListName(const QString &name);
     /*!
      * Selects next playlist if possible.
      */
@@ -150,7 +154,7 @@ public slots:
     /*!
      * Sets current playlist with index \b index.
      */
-    void activatePlayList(int index);
+    void activatePlayListIndex(int index);
     /*!
      * Sets selected playlist as current.
      */
@@ -166,7 +170,7 @@ public slots:
     /*!
      * Removes playlist with index \b index.
      */
-    void removePlayList(int index);
+    void removePlayListIndex(int index);
     /*!
      * Moves playlist with index \b i to index \b j.
      */
@@ -190,11 +194,11 @@ public slots:
     /*!
      * This is a convenience function and is the same as calling \b selectedPlayList()->removeAt(i)
      */
-    void removeTrack (int i);
+    void removeTrack(int i);
     /*!
-     * This is a convenience function and is the same as calling \b selectedPlayList()->removeItem(item)
+     * This is a convenience function and is the same as calling \b selectedPlayList()->removeTrack(item)
      */
-    void removeTrack (PlayListTrack *item);
+    void removeTrack(PlayListTrack *item);
     /*!
      * This is a convenience function and is the same as calling \b selectedPlayList()->invertSelection()
      */
@@ -208,17 +212,17 @@ public slots:
      */
     void showDetails();
     /*!
-     * This is a convenience function and is the same as calling \b selectedPlayList()->add(tracks)
+     * This is a convenience function and is the same as calling \b selectedPlayList()->addTracks(tracks)
      */
-    void add(const QList<PlayListTrack *> &tracks);
+    void addTracks(const QList<PlayListTrack *> &tracks);
     /*!
-     * This is a convenience function and is the same as calling \b selectedPlayList()->add(path)
+     * This is a convenience function and is the same as calling \b selectedPlayList()->addPath(path)
      */
-    void add(const QString &path);
+    void addPath(const QString &path);
     /*!
-     * This is a convenience function and is the same as calling \b selectedPlayList()->add(paths)
+     * This is a convenience function and is the same as calling \b selectedPlayList()->addPaths(paths)
      */
-    void add(const QStringList &paths);
+    void addPaths(const QStringList &paths);
     /*!
      * This is a convenience function and is the same as calling \b selectedPlayList()->randomizeList()
      */
@@ -259,10 +263,15 @@ public slots:
      * This is a convenience function and is the same as calling \b selectedPlayList()->stopAfterSelected()
      */
     void stopAfterSelected();
+    /*!
+     * Rebuilds groups for all playlists.
+     */
+    void rebuildGroups();
 
 private slots:
     void writePlayLists();
     void onListChanged(int flags);
+    void onCurrentTrackRemoved();
 
 private:
     void readPlayLists();
@@ -270,7 +279,7 @@ private:
     static PlayListManager* m_instance;
     static const QHash<QString, Qmmp::MetaData> m_metaKeys;
     static const QHash<QString, Qmmp::TrackProperty> m_propKeys;
-    QList <PlayListModel *> m_models;
+    QList<PlayListModel *> m_models;
     PlayListModel *m_current = nullptr;
     PlayListModel *m_selected = nullptr;
     QTimer *m_timer;
