@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -34,26 +34,26 @@ QList<PlayListFormat*> *PlayListParser::m_formats = nullptr;
 
 //key names
 const QHash<QString, Qmmp::MetaData>  PlayListParser::m_metaKeys = {
-    { "title", Qmmp::TITLE },
-    { "artist", Qmmp::ARTIST },
-    { "albumArtist", Qmmp::ALBUMARTIST },
-    { "album", Qmmp::ALBUM },
-    { "comment", Qmmp::COMMENT },
-    { "genre", Qmmp::GENRE },
-    { "composer", Qmmp::COMPOSER },
-    { "year", Qmmp::YEAR },
-    { "track", Qmmp::TRACK },
-    { "disk", Qmmp::DISCNUMBER }
+    { u"title"_s, Qmmp::TITLE },
+    { u"artist"_s, Qmmp::ARTIST },
+    { u"albumArtist"_s, Qmmp::ALBUMARTIST },
+    { u"album"_s, Qmmp::ALBUM },
+    { u"comment"_s, Qmmp::COMMENT },
+    { u"genre"_s, Qmmp::GENRE },
+    { u"composer"_s, Qmmp::COMPOSER },
+    { u"year"_s, Qmmp::YEAR },
+    { u"track"_s, Qmmp::TRACK },
+    { u"disk"_s, Qmmp::DISCNUMBER }
 };
 
 const QHash<QString, Qmmp::TrackProperty>  PlayListParser::m_propKeys = {
-    { "bitrate", Qmmp::BITRATE },
-    { "samplerate", Qmmp::SAMPLERATE },
-    { "channels", Qmmp::CHANNELS },
-    { "bitsPerSample", Qmmp::BITS_PER_SAMPLE },
-    { "formatName", Qmmp::FORMAT_NAME },
-    { "decoder", Qmmp::DECODER },
-    { "fileSize", Qmmp::FILE_SIZE }
+    { u"bitrate"_s, Qmmp::BITRATE },
+    { u"samplerate"_s, Qmmp::SAMPLERATE },
+    { u"channels"_s, Qmmp::CHANNELS },
+    { u"bitsPerSample"_s, Qmmp::BITS_PER_SAMPLE },
+    { u"formatName"_s, Qmmp::FORMAT_NAME },
+    { u"decoder"_s, Qmmp::DECODER },
+    { u"fileSize"_s, Qmmp::FILE_SIZE }
 };
 
 QList<PlayListFormat *> PlayListParser::formats()
@@ -66,7 +66,7 @@ QStringList PlayListParser::nameFilters()
 {
     loadFormats();
     QStringList filters;
-    for(const PlayListFormat *format : qAsConst(*m_formats))
+    for(const PlayListFormat *format : std::as_const(*m_formats))
     {
         filters << format->properties().filters;
     }
@@ -77,17 +77,17 @@ QStringList PlayListParser::filters()
 {
     loadFormats();
     QStringList filters;
-    for(const PlayListFormat *format : qAsConst(*m_formats))
+    for(const PlayListFormat *format : std::as_const(*m_formats))
     {
         if (!format->properties().filters.isEmpty())
-            filters << format->properties().shortName.toUpper() + " (" + format->properties().filters.join(" ") + ")";
+            filters << QStringLiteral("%1 (%2)").arg(format->properties().shortName.toUpper(),  format->properties().filters.join(QChar::Space));
     }
     return filters;
 }
 
 bool PlayListParser::isPlayList(const QString &url)
 {
-    return QDir::match(nameFilters(), url.section(QChar('/'), -1));
+    return QDir::match(nameFilters(), url.section(QLatin1Char('/'), -1));
 }
 
 PlayListFormat *PlayListParser::findByMime(const QString &mime)
@@ -101,9 +101,9 @@ PlayListFormat *PlayListParser::findByMime(const QString &mime)
 PlayListFormat *PlayListParser::findByPath(const QString &filePath)
 {
     loadFormats();
-    for(PlayListFormat *format : qAsConst(*m_formats))
+    for(PlayListFormat *format : std::as_const(*m_formats))
     {
-        if(QDir::match(format->properties().filters, filePath.section(QChar('/'), -1)))
+        if(QDir::match(format->properties().filters, filePath.section(QLatin1Char('/'), -1)))
             return format;
     }
     return nullptr;
@@ -129,7 +129,7 @@ void PlayListParser::savePlayList(QList<PlayListTrack *> tracks, const QString &
         file.close();
     }
     else
-        qWarning("PlayListParser: unable to save playlist, error: %s", qPrintable(file.errorString()));
+        qCWarning(core, "unable to save playlist, error: %s", qPrintable(file.errorString()));
 }
 
 QList<PlayListTrack *> PlayListParser::loadPlaylist(const QString &f_name)
@@ -143,7 +143,7 @@ QList<PlayListTrack *> PlayListParser::loadPlaylist(const QString &f_name)
     QFile file(f_name);
     if (!file.open(QIODevice::ReadOnly))
     {
-        qWarning("PlayListParser: unable to open playlist, error: %s", qPrintable(file.errorString()));
+        qCWarning(core, "unable to open playlist, error: %s", qPrintable(file.errorString()));
         return QList<PlayListTrack *>();
     }
 
@@ -151,23 +151,23 @@ QList<PlayListTrack *> PlayListParser::loadPlaylist(const QString &f_name)
 
     if(tracks.isEmpty())
     {
-        qWarning("PlayListParser: error opening %s",qPrintable(f_name));
+        qCWarning(core, "error opening %s",qPrintable(f_name));
         return tracks;
     }
 
     QString path;
-    for(PlayListTrack *t : qAsConst(tracks))
+    for(PlayListTrack *t : std::as_const(tracks))
     {
         path = t->path();
 
-        if(path.contains("://"))
+        if(path.contains(u"://"_s))
             continue;
 
         if(QFileInfo(path).isRelative())
-            path.prepend(QFileInfo(f_name).canonicalPath () + "/");
+            path.prepend(QFileInfo(f_name).canonicalPath() + QLatin1Char('/'));
 
-        path.replace("\\","/");
-        path.replace("//","/");
+        path.replace(QLatin1Char('\\'), QLatin1Char('/'));
+        path.replace(u"//"_s, u"/"_s);
         t->setPath(path);
     }
     return tracks;
@@ -186,14 +186,14 @@ void PlayListParser::loadFormats()
         return;
 
     m_formats = new QList<PlayListFormat*>();
-    for(const QString &filePath : Qmmp::findPlugins("PlayListFormats"))
+    for(const QString &filePath : Qmmp::findPlugins(u"PlayListFormats"_s))
     {
         QPluginLoader loader(filePath);
         QObject *plugin = loader.instance();
         if (loader.isLoaded())
-            qDebug("PlayListParser: loaded plugin %s", qPrintable(QFileInfo(filePath).filePath()));
+            qCDebug(core) << "loaded plugin" << QFileInfo(filePath).filePath();
         else
-            qWarning("PlayListParser: %s", qPrintable(loader.errorString ()));
+            qCWarning(core) << loader.errorString();
 
         PlayListFormat *fmt = nullptr;
         if (plugin)
@@ -207,7 +207,7 @@ void PlayListParser::loadFormats()
 QByteArray PlayListParser::serialize(const QList<PlayListTrack *> &tracks)
 {
     QJsonArray array;
-    for(const PlayListTrack *t : qAsConst(tracks))
+    for(const PlayListTrack *t : std::as_const(tracks))
     {
         QJsonObject obj;
         QString value;
@@ -223,8 +223,8 @@ QByteArray PlayListParser::serialize(const QList<PlayListTrack *> &tracks)
                 obj.insert(it.key(), value);
         }
 
-        obj.insert("path", t->path());
-        obj.insert("duration", t->duration());
+        obj.insert(u"path"_s, t->path());
+        obj.insert(u"duration"_s, t->duration());
         array.append(obj);
     }
 
@@ -238,7 +238,7 @@ QList<PlayListTrack *> PlayListParser::deserialize(const QByteArray &json)
     QJsonDocument document = QJsonDocument::fromJson(json);
     if(!document.isArray())
     {
-        qWarning("PlayListParser: invalid JSON array");
+        qCWarning(core, "invalid JSON array");
         return out;
     }
 
@@ -250,12 +250,12 @@ QList<PlayListTrack *> PlayListParser::deserialize(const QByteArray &json)
 
         QJsonObject obj = (*it).toObject();
 
-        if(obj.value("path").isNull())
+        if(obj.value(u"path"_s).isNull())
             continue;
 
         PlayListTrack *t = new PlayListTrack();
-        t->setPath(obj.value("path").toString());
-        t->setDuration(obj.value("duration").toDouble());
+        t->setPath(obj.value(u"path"_s).toString());
+        t->setDuration(obj.value(u"duration"_s).toDouble());
 
         Qmmp::MetaData metaKey;
         Qmmp::TrackProperty propKey;
