@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2014-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2014-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -38,7 +38,7 @@ struct TrackField
 
 struct GroupdField
 {
-    QList <TrackField *> fields;
+    QList<TrackField *> fields;
     QString groupName;
 };
 
@@ -70,20 +70,12 @@ static bool _numberGreaterComparator(TrackField* s1, TrackField* s2)
 //by file creation date
 static bool _fileCreationDateLessComparator(TrackField* s1, TrackField* s2)
 {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
     return QFileInfo(s1->value).birthTime() < QFileInfo(s2->value).birthTime();
-#else
-    return QFileInfo(s1->value).created() < QFileInfo(s2->value).created();
-#endif
 }
 
 static bool _fileCreationDateGreaterComparator(TrackField* s1, TrackField* s2)
 {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
     return QFileInfo(s1->value).birthTime() > QFileInfo(s2->value).birthTime();
-#else
-    return QFileInfo(s1->value).created() > QFileInfo(s2->value).created();
-#endif
 }
 //by file modification date
 static bool _fileModificationDateLessComparator(TrackField* s1, TrackField* s2)
@@ -146,7 +138,7 @@ void PlayListTask::sort(QList<PlayListTrack *> tracks, PlayListModel::SortMode m
 
     m_align_groups = QmmpUiSettings::instance()->isGroupsEnabled() && (mode != PlayListModel::GROUP);
 
-    for(PlayListTrack *t : qAsConst(tracks))
+    for(PlayListTrack *t : std::as_const(tracks))
     {
         TrackField *f = new TrackField;
         f->track = t;
@@ -205,7 +197,7 @@ void PlayListTask::sortByColumn(QList<PlayListTrack *> tracks, int column)
     m_task = SORT_BY_COLUMN;
     m_input_tracks = tracks;
     m_column = column;
-    if(MetaDataHelper::instance()->titleFormatter(column)->pattern() == "%n")
+    if(MetaDataHelper::instance()->titleFormatter(column)->pattern() == "%n"_L1)
         m_sort_mode = PlayListModel::TRACK;
     else
         m_sort_mode = PlayListModel::TITLE;
@@ -286,7 +278,7 @@ void PlayListTask::refresh(QList<PlayListTrack *> tracks, PlayListTrack *current
 
 void PlayListTask::run()
 {
-    qDebug("PlayListTask: started");
+    qCDebug(core) << "started";
 
     if(m_task == SORT || m_task == SORT_SELECTION || m_task == SORT_BY_COLUMN)
     {
@@ -368,8 +360,8 @@ void PlayListTask::run()
         {
             TrackField *f = m_fields.at(i);
 
-            if(f->value.contains("://"))
-                ok = MetaDataManager::instance()->protocols().contains(f->value.section("://",0,0)); //url
+            if(f->value.contains(u"://"_s))
+                ok = MetaDataManager::instance()->protocols().contains(f->value.section(u"://"_s, 0, 0)); //url
             else
                 ok = MetaDataManager::instance()->supports(f->value); //local file
 
@@ -407,8 +399,8 @@ void PlayListTask::run()
         {
             TrackField *f = m_fields.at(i);
 
-            if(f->value.contains("://"))
-                ok = protocols.contains(f->value.section("://",0,0)) || MetaDataManager::hasMatch(regExps, f->value) ; //url
+            if(f->value.contains(u"://"_s))
+                ok = protocols.contains(f->value.section(u"://"_s, 0, 0)) || MetaDataManager::hasMatch(regExps, f->value) ; //url
             else
                 ok = mm->supports(f->value); //local file
 
@@ -421,7 +413,7 @@ void PlayListTask::run()
         {
             TrackField *f = m_fields.at(i);
 
-            if(f->value.contains("://")) //skip urls
+            if(f->value.contains(u"://"_s)) //skip urls
                 continue;
 
             path = QFileInfo(f->value).canonicalPath();
@@ -431,7 +423,7 @@ void PlayListTask::run()
         }
         //find all files
         QFileInfoList l;
-        for(const QString &p : qAsConst(dirs))
+        for(const QString &p : std::as_const(dirs))
         {
             QDir dir(p);
             dir.setFilter(QDir::Files | QDir::Hidden);
@@ -441,7 +433,7 @@ void PlayListTask::run()
         //generate URLs for the current playlist
         QSet<QString> urls;
         urls.reserve(m_fields.count());
-        for(const TrackField *t : qAsConst(m_fields))
+        for(const TrackField *t : std::as_const(m_fields))
             urls.insert(t->value);
 
         //find files that have already been added
@@ -461,7 +453,7 @@ void PlayListTask::run()
         //create new playlist tracks
         QStringList ignoredFiles;
         TrackInfo::Parts parts = QmmpUiSettings::instance()->useMetaData() ? TrackInfo::AllParts : TrackInfo::Parts();
-        for(const QFileInfo &i : qAsConst(l))
+        for(const QFileInfo &i : std::as_const(l))
         {
             QStringList ignored;
             for(TrackInfo *info : mm->createPlayList(i.canonicalFilePath(), parts, &ignored))
@@ -476,7 +468,7 @@ void PlayListTask::run()
         QList<PlayListTrack *>::iterator it = m_new_tracks.begin();
         while(it != m_new_tracks.end())
         {
-            if(((*it)->path().contains("://") && urls.contains((*it)->path())) ||
+            if(((*it)->path().contains(u"://"_s) && urls.contains((*it)->path())) ||
                     ignoredFiles.contains((*it)->path()))
             {
                 delete (*it);
@@ -488,7 +480,7 @@ void PlayListTask::run()
             }
         }
     }
-    qDebug("PlayListTask: finished");
+    qCDebug(core) << "finished";
 }
 
 PlayListTask::TaskType PlayListTask::type() const
@@ -508,7 +500,7 @@ QList<PlayListTrack *> PlayListTask::takeResults(PlayListTrack **current_track)
 {
     if(m_task == SORT || m_task == SORT_BY_COLUMN)
     {
-        for(const TrackField *f : qAsConst(m_fields))
+        for(const TrackField *f : std::as_const(m_fields))
             m_tracks.append(f->track);
     }
     else if(m_task == SORT_SELECTION)
