@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2013-2022 by Ilya Kotov                                 *
+ *   Copyright (C) 2013-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -36,10 +36,10 @@ QmmpUiPluginCache::QmmpUiPluginCache(const QString &file, QSettings *settings)
     QFileInfo info(file);
     m_path = info.QFileInfo::canonicalFilePath();
 
-    settings->beginGroup("PluginCache");
+    settings->beginGroup(u"PluginCache"_s);
     QString key = m_path;
 #ifndef Q_OS_WIN
-    key.remove(0,1);
+    key.remove(0, 1);
 #endif
     if(settings->allKeys().contains(key))
 
@@ -49,7 +49,7 @@ QmmpUiPluginCache::QmmpUiPluginCache(const QString &file, QSettings *settings)
             update = true;
         else
         {
-            m_shortName = values.at(0);
+            m_shortName = values.constFirst();
             m_priority = values.at(1).toInt();
             update = (info.lastModified().toString(Qt::ISODate) != values.at(2));
         }
@@ -77,7 +77,7 @@ QmmpUiPluginCache::QmmpUiPluginCache(const QString &file, QSettings *settings)
         }
         else
         {
-            qWarning("QmmpUiPluginCache: unknown plugin type: %s", qPrintable(m_path));
+            qCWarning(core, "unknown plugin type: %s", qPrintable(m_path));
             m_error = true;
         }
 
@@ -88,8 +88,7 @@ QmmpUiPluginCache::QmmpUiPluginCache(const QString &file, QSettings *settings)
             values << QString::number(m_priority);
             values << info.lastModified().toString(Qt::ISODate);
             settings->setValue(m_path, values);
-            qDebug("QmmpUiPluginCache: added cache item \"%s=%s\"",
-                   qPrintable(info.fileName()), qPrintable(values.join(",")));
+            qCDebug(core, "added cache item \"%s=%s\"", qPrintable(info.fileName()), qPrintable(values.join(QLatin1Char(','))));
         }
     }
     settings->endGroup();
@@ -116,11 +115,11 @@ QmmpUiPluginCache::QmmpUiPluginCache(QObject *instance)
     }
     else
     {
-        qWarning("QmmpUiPluginCache: unknown plugin type");
+        qCWarning(core, "unknown plugin type");
         m_error = true;
         return;
     }
-    qDebug("QmmpUiPluginCache: registered internal factory %s", qPrintable(m_shortName));
+    qCDebug(core) << "registered internal factory" << m_shortName;
 }
 
 const QString QmmpUiPluginCache::shortName() const
@@ -185,11 +184,11 @@ QObject *QmmpUiPluginCache::instance()
     QPluginLoader loader(m_path);
     m_instance = loader.instance();
     if (loader.isLoaded())
-        qDebug("QmmpUiPluginCache: loaded plugin %s", qPrintable(QFileInfo(m_path).fileName()));
+        qCDebug(core) << "loaded plugin" << QFileInfo(m_path).fileName();
     else
     {
         m_error = true;
-        qWarning("QmmpUiPluginCache: error: %s", qPrintable(loader.errorString ()));
+        qCWarning(core, "error: %s", qPrintable(loader.errorString ()));
     }
     return m_instance;
 }
@@ -208,18 +207,18 @@ void QmmpUiPluginCache::loadTranslation(const QString &translation)
 
 void QmmpUiPluginCache::cleanup(QSettings *settings)
 {
-    settings->beginGroup("PluginCache");
+    settings->beginGroup(u"PluginCache"_s);
 
     for(const QString &key : settings->allKeys())
     {
 #ifdef Q_OS_WIN
         if(!QFile::exists(key))
 #else
-        if(!QFile::exists("/" + key))
+        if(!QFile::exists(QLatin1Char('/') + key))
 #endif
         {
             settings->remove(key);
-            qDebug("QmmpUiPluginCache: removed key %s", qPrintable(key));
+            qCDebug(core) << "removed key" << key;
         }
     }
     settings->endGroup();
