@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2010-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2010-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -27,8 +27,10 @@ ShortcutDialog::ShortcutDialog(const QString &key, QWidget *parent)
 {
     m_ui->setupUi(this);
     m_ui->keyLineEdit->setText(key);
-    connect(this, &QDialog::accepted, this, [this] { releaseKeyboard(); });
-    connect(this, &QDialog::rejected, this, [this] { releaseKeyboard(); });
+
+    //buttons should not catch keys
+    for(QAbstractButton *button : m_ui->buttonBox->buttons())
+        button->setFocusPolicy(Qt::NoFocus);
 }
 
 ShortcutDialog::~ShortcutDialog()
@@ -55,17 +57,11 @@ void ShortcutDialog::keyPressEvent(QKeyEvent *event)
         QWidget::keyPressEvent(event);
         return;
     }
-    QKeySequence seq(event->modifiers() + event->key());
+    QKeySequence seq(event->keyCombination());
     m_ui->keyLineEdit->setText(seq.toString());
     QWidget::keyPressEvent(event);
 }
 
-void ShortcutDialog::showEvent(QShowEvent *event)
-{
-    Q_UNUSED(event);
-    grabKeyboard();
-}
-
 QString ShortcutDialog::key() const
 {
     return m_ui->keyLineEdit->text();
