@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2025 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -48,13 +48,13 @@ UiHelper::UiHelper(QObject *parent)
 {
     m_instance = this;
     General::create(parent);
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     m_lastDir = settings.value(u"General/last_dir"_s, QDir::homePath()).toString(); //last directory
 }
 
 UiHelper::~UiHelper()
 {
-    QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
+    QSettings settings;
     settings.setValue(u"General/last_dir"_s, m_lastDir);
 }
 
