@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2019 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2024 by Ilya Kotov                                 *
  *   forkotov02@ya.ru                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -26,7 +26,6 @@
 #include <QPointer>
 #include <QStringList>
 #include <QApplication>
-#include <QPointer>
 #include "playlistmanager.h"
 #include "playlistmodel.h"
 #include "qmmpui_export.h"
@@ -86,16 +85,18 @@ public:
      * Creates menu with type \b type
      * @param type Menu type.
      * @param title Menu title.
+     * @param autoHide Hide empty menu.
      * @param parent Parent widget
      */
-    QMenu *createMenu(MenuType type, const QString &title = QString(), QWidget *parent = nullptr);
+    QMenu *createMenu(MenuType type, const QString &title = QString(), bool autoHide = true, QWidget *parent = nullptr);
     /*!
      * Registers existing menu for access from general plugins.
      * @param type Menu type.
      * @param menu Menu pointer.
+     * @param autoHide Hide empty menu.
      * @param before An action, after which the rest are added.
      */
-    void registerMenu(MenuType type, QMenu *menu, QAction *before = nullptr);
+    void registerMenu(MenuType type, QMenu *menu, bool autoHide = false, QAction *before = nullptr);
     /*!
      * Opens 'Add Files' dialog
      * @param parent Parent widget
@@ -168,6 +169,16 @@ public slots:
      * Tells the player to exit.
      */
     void exit();
+    /*!
+     * This function does several tasks:
+     * 1) stops playback;
+     * 2) activates selected playlist;
+     * 3) clears selected playlist;
+     * 4) loads tracks for specified paths to the selected playlist;
+     * 5) starts playback from the first added track.
+     * \param paths A list of files or/and directories.
+     */
+    void replaceAndPlay(const QStringList &paths);
 
 signals:
     /*!
@@ -180,6 +191,21 @@ signals:
      * Use it to show player's window and to raise it to the top.
      */
     void showMainWindowCalled();
+    /*!
+     * Emitted when some general plugin adds widget.
+     * User interface should create this widget using the given \b id.
+     */
+    void widgetAdded(const QString &id);
+    /*!
+     * Emitted when some general plugin removes widget \b id.
+     * User interface should remove widget with the given \b id.
+     */
+    void widgetRemoved(const QString &id);
+    /*!
+     * Emitted when some general plugin changes settings of the widget \b id.
+     * User interface should recreate widget with the given \b id.
+     */
+    void widgetUpdated(const QString &id);
 
 private slots:
     void removeAction(QObject *action);
@@ -194,11 +220,12 @@ private:
         QPointer<QMenu> menu;
         QPointer<QAction> before;
         QList<QAction*> actions;
+        bool autoHide = false;
     };
     QMap<MenuType, MenuData> m_menus;
     QString m_lastDir;
     QPointer <JumpToTrackDialog> m_jumpDialog;
-    PlayListModel *m_model;
+    PlayListModel *m_model = nullptr;
     static UiHelper* m_instance;
 };
 
